/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 32000 Hz
 *          - Output sampling frequency: 44100 Hz
 *          - Re-sampling order: 10
 *          - Coefficients are normalized
 *          - Memory foot print: 8820 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 16000
 *          - Sampling frequency (fs_hz): 14112000
 *          - Actual FIR filter order (order): 4410
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord10_32000_44100_norm[] = {
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00001550),
  DSP16_Q(0.00007479),
  DSP16_Q(-0.00021255),
  DSP16_Q(0.00058774),
  DSP16_Q(0.57236007),
  DSP16_Q(-0.00058614),
  DSP16_Q(0.00021209),
  DSP16_Q(-0.00007459),
  DSP16_Q(0.00001543),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00004674),
  DSP16_Q(0.00022498),
  DSP16_Q(-0.00063903),
  DSP16_Q(0.00176802),
  DSP16_Q(0.57234980),
  DSP16_Q(-0.00175360),
  DSP16_Q(0.00063489),
  DSP16_Q(-0.00022315),
  DSP16_Q(0.00004605),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00007828),
  DSP16_Q(0.00037597),
  DSP16_Q(-0.00106733),
  DSP16_Q(0.00295469),
  DSP16_Q(0.57232928),
  DSP16_Q(-0.00291462),
  DSP16_Q(0.00105582),
  DSP16_Q(-0.00037090),
  DSP16_Q(0.00007637),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00011013),
  DSP16_Q(0.00052777),
  DSP16_Q(-0.00149743),
  DSP16_Q(0.00414771),
  DSP16_Q(0.57229849),
  DSP16_Q(-0.00406918),
  DSP16_Q(0.00147486),
  DSP16_Q(-0.00051782),
  DSP16_Q(0.00010637),
  DSP16_Q(0.00000001),
  DSP16_Q(-0.00014228),
  DSP16_Q(0.00068035),
  DSP16_Q(-0.00192932),
  DSP16_Q(0.00534708),
  DSP16_Q(0.57225744),
  DSP16_Q(-0.00521727),
  DSP16_Q(0.00189201),
  DSP16_Q(-0.00066391),
  DSP16_Q(0.00013608),
  DSP16_Q(0.00000002),
  DSP16_Q(-0.00017474),
  DSP16_Q(0.00083372),
  DSP16_Q(-0.00236297),
  DSP16_Q(0.00655277),
  DSP16_Q(0.57220613),
  DSP16_Q(-0.00635886),
  DSP16_Q(0.00230725),
  DSP16_Q(-0.00080916),
  DSP16_Q(0.00016547),
  DSP16_Q(0.00000003),
  DSP16_Q(-0.00020751),
  DSP16_Q(0.00098787),
  DSP16_Q(-0.00279838),
  DSP16_Q(0.00776477),
  DSP16_Q(0.57214456),
  DSP16_Q(-0.00749394),
  DSP16_Q(0.00272056),
  DSP16_Q(-0.00095358),
  DSP16_Q(0.00019456),
  DSP16_Q(0.00000005),
  DSP16_Q(-0.00024057),
  DSP16_Q(0.00114280),
  DSP16_Q(-0.00323553),
  DSP16_Q(0.00898304),
  DSP16_Q(0.57207274),
  DSP16_Q(-0.00862249),
  DSP16_Q(0.00313193),
  DSP16_Q(-0.00109714),
  DSP16_Q(0.00022333),
  DSP16_Q(0.00000007),
  DSP16_Q(-0.00027395),
  DSP16_Q(0.00129850),
  DSP16_Q(-0.00367439),
  DSP16_Q(0.01020757),
  DSP16_Q(0.57199066),
  DSP16_Q(-0.00974449),
  DSP16_Q(0.00354134),
  DSP16_Q(-0.00123986),
  DSP16_Q(0.00025180),
  DSP16_Q(0.00000010),
  DSP16_Q(-0.00030762),
  DSP16_Q(0.00145497),
  DSP16_Q(-0.00411495),
  DSP16_Q(0.01143834),
  DSP16_Q(0.57189834),
  DSP16_Q(-0.01085993),
  DSP16_Q(0.00394878),
  DSP16_Q(-0.00138173),
  DSP16_Q(0.00027997),
  DSP16_Q(0.00000014),
  DSP16_Q(-0.00034160),
  DSP16_Q(0.00161219),
  DSP16_Q(-0.00455720),
  DSP16_Q(0.01267532),
  DSP16_Q(0.57179576),
  DSP16_Q(-0.01196879),
  DSP16_Q(0.00435423),
  DSP16_Q(-0.00152273),
  DSP16_Q(0.00030782),
  DSP16_Q(0.00000018),
  DSP16_Q(-0.00037588),
  DSP16_Q(0.00177016),
  DSP16_Q(-0.00500112),
  DSP16_Q(0.01391850),
  DSP16_Q(0.57168295),
  DSP16_Q(-0.01307106),
  DSP16_Q(0.00475768),
  DSP16_Q(-0.00166288),
  DSP16_Q(0.00033537),
  DSP16_Q(0.00000024),
  DSP16_Q(-0.00041047),
  DSP16_Q(0.00192888),
  DSP16_Q(-0.00544668),
  DSP16_Q(0.01516786),
  DSP16_Q(0.57155989),
  DSP16_Q(-0.01416671),
  DSP16_Q(0.00515912),
  DSP16_Q(-0.00180215),
  DSP16_Q(0.00036261),
  DSP16_Q(0.00000030),
  DSP16_Q(-0.00044535),
  DSP16_Q(0.00208834),
  DSP16_Q(-0.00589388),
  DSP16_Q(0.01642336),
  DSP16_Q(0.57142659),
  DSP16_Q(-0.01525573),
  DSP16_Q(0.00555853),
  DSP16_Q(-0.00194055),
  DSP16_Q(0.00038954),
  DSP16_Q(0.00000038),
  DSP16_Q(-0.00048053),
  DSP16_Q(0.00224853),
  DSP16_Q(-0.00634268),
  DSP16_Q(0.01768498),
  DSP16_Q(0.57128307),
  DSP16_Q(-0.01633811),
  DSP16_Q(0.00595590),
  DSP16_Q(-0.00207807),
  DSP16_Q(0.00041617),
  DSP16_Q(0.00000046),
  DSP16_Q(-0.00051602),
  DSP16_Q(0.00240944),
  DSP16_Q(-0.00679309),
  DSP16_Q(0.01895271),
  DSP16_Q(0.57112932),
  DSP16_Q(-0.01741384),
  DSP16_Q(0.00635121),
  DSP16_Q(-0.00221472),
  DSP16_Q(0.00044249),
  DSP16_Q(0.00000056),
  DSP16_Q(-0.00055180),
  DSP16_Q(0.00257108),
  DSP16_Q(-0.00724507),
  DSP16_Q(0.02022652),
  DSP16_Q(0.57096535),
  DSP16_Q(-0.01848289),
  DSP16_Q(0.00674446),
  DSP16_Q(-0.00235047),
  DSP16_Q(0.00046850),
  DSP16_Q(0.00000067),
  DSP16_Q(-0.00058788),
  DSP16_Q(0.00273343),
  DSP16_Q(-0.00769860),
  DSP16_Q(0.02150639),
  DSP16_Q(0.57079116),
  DSP16_Q(-0.01954525),
  DSP16_Q(0.00713562),
  DSP16_Q(-0.00248534),
  DSP16_Q(0.00049420),
  DSP16_Q(0.00000079),
  DSP16_Q(-0.00062426),
  DSP16_Q(0.00289649),
  DSP16_Q(-0.00815368),
  DSP16_Q(0.02279229),
  DSP16_Q(0.57060677),
  DSP16_Q(-0.02060091),
  DSP16_Q(0.00752469),
  DSP16_Q(-0.00261931),
  DSP16_Q(0.00051960),
  DSP16_Q(0.00000093),
  DSP16_Q(-0.00066094),
  DSP16_Q(0.00306025),
  DSP16_Q(-0.00861028),
  DSP16_Q(0.02408419),
  DSP16_Q(0.57041217),
  DSP16_Q(-0.02164985),
  DSP16_Q(0.00791165),
  DSP16_Q(-0.00275239),
  DSP16_Q(0.00054469),
  DSP16_Q(0.00000109),
  DSP16_Q(-0.00069791),
  DSP16_Q(0.00322470),
  DSP16_Q(-0.00906838),
  DSP16_Q(0.02538208),
  DSP16_Q(0.57020738),
  DSP16_Q(-0.02269206),
  DSP16_Q(0.00829648),
  DSP16_Q(-0.00288457),
  DSP16_Q(0.00056948),
  DSP16_Q(0.00000126),
  DSP16_Q(-0.00073518),
  DSP16_Q(0.00338984),
  DSP16_Q(-0.00952796),
  DSP16_Q(0.02668593),
  DSP16_Q(0.56999239),
  DSP16_Q(-0.02372753),
  DSP16_Q(0.00867919),
  DSP16_Q(-0.00301584),
  DSP16_Q(0.00059396),
  DSP16_Q(0.00000144),
  DSP16_Q(-0.00077274),
  DSP16_Q(0.00355566),
  DSP16_Q(-0.00998900),
  DSP16_Q(0.02799571),
  DSP16_Q(0.56976723),
  DSP16_Q(-0.02475625),
  DSP16_Q(0.00905975),
  DSP16_Q(-0.00314620),
  DSP16_Q(0.00061813),
  DSP16_Q(0.00000165),
  DSP16_Q(-0.00081060),
  DSP16_Q(0.00372214),
  DSP16_Q(-0.01045149),
  DSP16_Q(0.02931139),
  DSP16_Q(0.56953189),
  DSP16_Q(-0.02577820),
  DSP16_Q(0.00943815),
  DSP16_Q(-0.00327565),
  DSP16_Q(0.00064200),
  DSP16_Q(0.00000187),
  DSP16_Q(-0.00084875),
  DSP16_Q(0.00388930),
  DSP16_Q(-0.01091541),
  DSP16_Q(0.03063296),
  DSP16_Q(0.56928639),
  DSP16_Q(-0.02679336),
  DSP16_Q(0.00981438),
  DSP16_Q(-0.00340418),
  DSP16_Q(0.00066556),
  DSP16_Q(0.00000211),
  DSP16_Q(-0.00088719),
  DSP16_Q(0.00405711),
  DSP16_Q(-0.01138072),
  DSP16_Q(0.03196039),
  DSP16_Q(0.56903073),
  DSP16_Q(-0.02780173),
  DSP16_Q(0.01018843),
  DSP16_Q(-0.00353180),
  DSP16_Q(0.00068882),
  DSP16_Q(0.00000238),
  DSP16_Q(-0.00092592),
  DSP16_Q(0.00422558),
  DSP16_Q(-0.01184742),
  DSP16_Q(0.03329364),
  DSP16_Q(0.56876492),
  DSP16_Q(-0.02880330),
  DSP16_Q(0.01056028),
  DSP16_Q(-0.00365849),
  DSP16_Q(0.00071178),
  DSP16_Q(0.00000266),
  DSP16_Q(-0.00096494),
  DSP16_Q(0.00439469),
  DSP16_Q(-0.01231549),
  DSP16_Q(0.03463270),
  DSP16_Q(0.56848897),
  DSP16_Q(-0.02979805),
  DSP16_Q(0.01092993),
  DSP16_Q(-0.00378426),
  DSP16_Q(0.00073443),
  DSP16_Q(0.00000296),
  DSP16_Q(-0.00100425),
  DSP16_Q(0.00456443),
  DSP16_Q(-0.01278490),
  DSP16_Q(0.03597754),
  DSP16_Q(0.56820290),
  DSP16_Q(-0.03078597),
  DSP16_Q(0.01129737),
  DSP16_Q(-0.00390909),
  DSP16_Q(0.00075678),
  DSP16_Q(0.00000329),
  DSP16_Q(-0.00104384),
  DSP16_Q(0.00473480),
  DSP16_Q(-0.01325563),
  DSP16_Q(0.03732812),
  DSP16_Q(0.56790670),
  DSP16_Q(-0.03176706),
  DSP16_Q(0.01166257),
  DSP16_Q(-0.00403300),
  DSP16_Q(0.00077883),
  DSP16_Q(0.00000364),
  DSP16_Q(-0.00108372),
  DSP16_Q(0.00490580),
  DSP16_Q(-0.01372767),
  DSP16_Q(0.03868443),
  DSP16_Q(0.56760040),
  DSP16_Q(-0.03274129),
  DSP16_Q(0.01202554),
  DSP16_Q(-0.00415596),
  DSP16_Q(0.00080057),
  DSP16_Q(0.00000401),
  DSP16_Q(-0.00112389),
  DSP16_Q(0.00507740),
  DSP16_Q(-0.01420099),
  DSP16_Q(0.04004643),
  DSP16_Q(0.56728399),
  DSP16_Q(-0.03370866),
  DSP16_Q(0.01238626),
  DSP16_Q(-0.00427799),
  DSP16_Q(0.00082202),
  DSP16_Q(0.00000441),
  DSP16_Q(-0.00116434),
  DSP16_Q(0.00524962),
  DSP16_Q(-0.01467557),
  DSP16_Q(0.04141410),
  DSP16_Q(0.56695750),
  DSP16_Q(-0.03466916),
  DSP16_Q(0.01274471),
  DSP16_Q(-0.00439908),
  DSP16_Q(0.00084316),
  DSP16_Q(0.00000483),
  DSP16_Q(-0.00120507),
  DSP16_Q(0.00542243),
  DSP16_Q(-0.01515140),
  DSP16_Q(0.04278740),
  DSP16_Q(0.56662093),
  DSP16_Q(-0.03562279),
  DSP16_Q(0.01310090),
  DSP16_Q(-0.00451923),
  DSP16_Q(0.00086400),
  DSP16_Q(0.00000528),
  DSP16_Q(-0.00124608),
  DSP16_Q(0.00559583),
  DSP16_Q(-0.01562844),
  DSP16_Q(0.04416632),
  DSP16_Q(0.56627430),
  DSP16_Q(-0.03656952),
  DSP16_Q(0.01345480),
  DSP16_Q(-0.00463843),
  DSP16_Q(0.00088455),
  DSP16_Q(0.00000576),
  DSP16_Q(-0.00128738),
  DSP16_Q(0.00576981),
  DSP16_Q(-0.01610668),
  DSP16_Q(0.04555081),
  DSP16_Q(0.56591761),
  DSP16_Q(-0.03750935),
  DSP16_Q(0.01380642),
  DSP16_Q(-0.00475667),
  DSP16_Q(0.00090479),
  DSP16_Q(0.00000627),
  DSP16_Q(-0.00132895),
  DSP16_Q(0.00594437),
  DSP16_Q(-0.01658610),
  DSP16_Q(0.04694086),
  DSP16_Q(0.56555089),
  DSP16_Q(-0.03844228),
  DSP16_Q(0.01415573),
  DSP16_Q(-0.00487397),
  DSP16_Q(0.00092474),
  DSP16_Q(0.00000680),
  DSP16_Q(-0.00137080),
  DSP16_Q(0.00611949),
  DSP16_Q(-0.01706667),
  DSP16_Q(0.04833644),
  DSP16_Q(0.56517413),
  DSP16_Q(-0.03936829),
  DSP16_Q(0.01450273),
  DSP16_Q(-0.00499031),
  DSP16_Q(0.00094439),
  DSP16_Q(0.00000736),
  DSP16_Q(-0.00141292),
  DSP16_Q(0.00629517),
  DSP16_Q(-0.01754838),
  DSP16_Q(0.04973750),
  DSP16_Q(0.56478736),
  DSP16_Q(-0.04028737),
  DSP16_Q(0.01484741),
  DSP16_Q(-0.00510569),
  DSP16_Q(0.00096374),
  DSP16_Q(0.00000795),
  DSP16_Q(-0.00145532),
  DSP16_Q(0.00647140),
  DSP16_Q(-0.01803120),
  DSP16_Q(0.05114403),
  DSP16_Q(0.56439059),
  DSP16_Q(-0.04119952),
  DSP16_Q(0.01518976),
  DSP16_Q(-0.00522011),
  DSP16_Q(0.00098279),
  DSP16_Q(0.00000858),
  DSP16_Q(-0.00149799),
  DSP16_Q(0.00664818),
  DSP16_Q(-0.01851510),
  DSP16_Q(0.05255600),
  DSP16_Q(0.56398383),
  DSP16_Q(-0.04210473),
  DSP16_Q(0.01552977),
  DSP16_Q(-0.00533357),
  DSP16_Q(0.00100155),
  DSP16_Q(0.00000923),
  DSP16_Q(-0.00154094),
  DSP16_Q(0.00682548),
  DSP16_Q(-0.01900008),
  DSP16_Q(0.05397336),
  DSP16_Q(0.56356710),
  DSP16_Q(-0.04300299),
  DSP16_Q(0.01586743),
  DSP16_Q(-0.00544607),
  DSP16_Q(0.00102002),
  DSP16_Q(0.00000992),
  DSP16_Q(-0.00158415),
  DSP16_Q(0.00700331),
  DSP16_Q(-0.01948610),
  DSP16_Q(0.05539610),
  DSP16_Q(0.56314040),
  DSP16_Q(-0.04389430),
  DSP16_Q(0.01620273),
  DSP16_Q(-0.00555760),
  DSP16_Q(0.00103819),
  DSP16_Q(0.00001064),
  DSP16_Q(-0.00162763),
  DSP16_Q(0.00718166),
  DSP16_Q(-0.01997315),
  DSP16_Q(0.05682418),
  DSP16_Q(0.56270376),
  DSP16_Q(-0.04477864),
  DSP16_Q(0.01653567),
  DSP16_Q(-0.00566816),
  DSP16_Q(0.00105607),
  DSP16_Q(0.00001139),
  DSP16_Q(-0.00167138),
  DSP16_Q(0.00736051),
  DSP16_Q(-0.02046119),
  DSP16_Q(0.05825758),
  DSP16_Q(0.56225720),
  DSP16_Q(-0.04565601),
  DSP16_Q(0.01686623),
  DSP16_Q(-0.00577775),
  DSP16_Q(0.00107366),
  DSP16_Q(0.00001218),
  DSP16_Q(-0.00171539),
  DSP16_Q(0.00753986),
  DSP16_Q(-0.02095021),
  DSP16_Q(0.05969625),
  DSP16_Q(0.56180071),
  DSP16_Q(-0.04652641),
  DSP16_Q(0.01719440),
  DSP16_Q(-0.00588637),
  DSP16_Q(0.00109096),
  DSP16_Q(0.00001300),
  DSP16_Q(-0.00175966),
  DSP16_Q(0.00771971),
  DSP16_Q(-0.02144019),
  DSP16_Q(0.06114017),
  DSP16_Q(0.56133433),
  DSP16_Q(-0.04738983),
  DSP16_Q(0.01752019),
  DSP16_Q(-0.00599401),
  DSP16_Q(0.00110796),
  DSP16_Q(0.00001386),
  DSP16_Q(-0.00180420),
  DSP16_Q(0.00790003),
  DSP16_Q(-0.02193109),
  DSP16_Q(0.06258931),
  DSP16_Q(0.56085807),
  DSP16_Q(-0.04824626),
  DSP16_Q(0.01784357),
  DSP16_Q(-0.00610068),
  DSP16_Q(0.00112468),
  DSP16_Q(0.00001475),
  DSP16_Q(-0.00184900),
  DSP16_Q(0.00808083),
  DSP16_Q(-0.02242291),
  DSP16_Q(0.06404363),
  DSP16_Q(0.56037194),
  DSP16_Q(-0.04909569),
  DSP16_Q(0.01816454),
  DSP16_Q(-0.00620637),
  DSP16_Q(0.00114111),
  DSP16_Q(0.00001569),
  DSP16_Q(-0.00189405),
  DSP16_Q(0.00826208),
  DSP16_Q(-0.02291561),
  DSP16_Q(0.06550310),
  DSP16_Q(0.55987596),
  DSP16_Q(-0.04993813),
  DSP16_Q(0.01848310),
  DSP16_Q(-0.00631108),
  DSP16_Q(0.00115725),
  DSP16_Q(0.00001666),
  DSP16_Q(-0.00193936),
  DSP16_Q(0.00844380),
  DSP16_Q(-0.02340917),
  DSP16_Q(0.06696769),
  DSP16_Q(0.55937015),
  DSP16_Q(-0.05077356),
  DSP16_Q(0.01879923),
  DSP16_Q(-0.00641481),
  DSP16_Q(0.00117310),
  DSP16_Q(0.00001767),
  DSP16_Q(-0.00198493),
  DSP16_Q(0.00862596),
  DSP16_Q(-0.02390357),
  DSP16_Q(0.06843736),
  DSP16_Q(0.55885453),
  DSP16_Q(-0.05160199),
  DSP16_Q(0.01911293),
  DSP16_Q(-0.00651755),
  DSP16_Q(0.00118867),
  DSP16_Q(0.00001871),
  DSP16_Q(-0.00203075),
  DSP16_Q(0.00880855),
  DSP16_Q(-0.02439879),
  DSP16_Q(0.06991209),
  DSP16_Q(0.55832910),
  DSP16_Q(-0.05242341),
  DSP16_Q(0.01942420),
  DSP16_Q(-0.00661931),
  DSP16_Q(0.00120396),
  DSP16_Q(0.00001980),
  DSP16_Q(-0.00207682),
  DSP16_Q(0.00899157),
  DSP16_Q(-0.02489479),
  DSP16_Q(0.07139184),
  DSP16_Q(0.55779390),
  DSP16_Q(-0.05323780),
  DSP16_Q(0.01973301),
  DSP16_Q(-0.00672009),
  DSP16_Q(0.00121896),
  DSP16_Q(0.00002093),
  DSP16_Q(-0.00212313),
  DSP16_Q(0.00917501),
  DSP16_Q(-0.02539156),
  DSP16_Q(0.07287657),
  DSP16_Q(0.55724894),
  DSP16_Q(-0.05404518),
  DSP16_Q(0.02003938),
  DSP16_Q(-0.00681988),
  DSP16_Q(0.00123368),
  DSP16_Q(0.00002210),
  DSP16_Q(-0.00216970),
  DSP16_Q(0.00935886),
  DSP16_Q(-0.02588907),
  DSP16_Q(0.07436626),
  DSP16_Q(0.55669424),
  DSP16_Q(-0.05484554),
  DSP16_Q(0.02034328),
  DSP16_Q(-0.00691868),
  DSP16_Q(0.00124812),
  DSP16_Q(0.00002331),
  DSP16_Q(-0.00221651),
  DSP16_Q(0.00954311),
  DSP16_Q(-0.02638730),
  DSP16_Q(0.07586086),
  DSP16_Q(0.55612981),
  DSP16_Q(-0.05563886),
  DSP16_Q(0.02064471),
  DSP16_Q(-0.00701649),
  DSP16_Q(0.00126228),
  DSP16_Q(0.00002457),
  DSP16_Q(-0.00226356),
  DSP16_Q(0.00972774),
  DSP16_Q(-0.02688623),
  DSP16_Q(0.07736035),
  DSP16_Q(0.55555568),
  DSP16_Q(-0.05642516),
  DSP16_Q(0.02094368),
  DSP16_Q(-0.00711331),
  DSP16_Q(0.00127616),
  DSP16_Q(0.00002586),
  DSP16_Q(-0.00231085),
  DSP16_Q(0.00991276),
  DSP16_Q(-0.02738582),
  DSP16_Q(0.07886468),
  DSP16_Q(0.55497186),
  DSP16_Q(-0.05720443),
  DSP16_Q(0.02124016),
  DSP16_Q(-0.00720914),
  DSP16_Q(0.00128976),
  DSP16_Q(0.00002720),
  DSP16_Q(-0.00235838),
  DSP16_Q(0.01009814),
  DSP16_Q(-0.02788605),
  DSP16_Q(0.08037383),
  DSP16_Q(0.55437839),
  DSP16_Q(-0.05797666),
  DSP16_Q(0.02153416),
  DSP16_Q(-0.00730398),
  DSP16_Q(0.00130308),
  DSP16_Q(0.00002859),
  DSP16_Q(-0.00240614),
  DSP16_Q(0.01028389),
  DSP16_Q(-0.02838691),
  DSP16_Q(0.08188775),
  DSP16_Q(0.55377527),
  DSP16_Q(-0.05874186),
  DSP16_Q(0.02182566),
  DSP16_Q(-0.00739782),
  DSP16_Q(0.00131613),
  DSP16_Q(0.00003002),
  DSP16_Q(-0.00245415),
  DSP16_Q(0.01046998),
  DSP16_Q(-0.02888836),
  DSP16_Q(0.08340642),
  DSP16_Q(0.55316253),
  DSP16_Q(-0.05950001),
  DSP16_Q(0.02211467),
  DSP16_Q(-0.00749067),
  DSP16_Q(0.00132891),
  DSP16_Q(0.00003150),
  DSP16_Q(-0.00250238),
  DSP16_Q(0.01065642),
  DSP16_Q(-0.02939038),
  DSP16_Q(0.08492980),
  DSP16_Q(0.55254018),
  DSP16_Q(-0.06025113),
  DSP16_Q(0.02240118),
  DSP16_Q(-0.00758252),
  DSP16_Q(0.00134141),
  DSP16_Q(0.00003302),
  DSP16_Q(-0.00255084),
  DSP16_Q(0.01084318),
  DSP16_Q(-0.02989294),
  DSP16_Q(0.08645784),
  DSP16_Q(0.55190826),
  DSP16_Q(-0.06099521),
  DSP16_Q(0.02268517),
  DSP16_Q(-0.00767338),
  DSP16_Q(0.00135364),
  DSP16_Q(0.00003459),
  DSP16_Q(-0.00259953),
  DSP16_Q(0.01103027),
  DSP16_Q(-0.03039602),
  DSP16_Q(0.08799052),
  DSP16_Q(0.55126678),
  DSP16_Q(-0.06173224),
  DSP16_Q(0.02296665),
  DSP16_Q(-0.00776325),
  DSP16_Q(0.00136560),
  DSP16_Q(0.00003621),
  DSP16_Q(-0.00264844),
  DSP16_Q(0.01121767),
  DSP16_Q(-0.03089959),
  DSP16_Q(0.08952780),
  DSP16_Q(0.55061576),
  DSP16_Q(-0.06246223),
  DSP16_Q(0.02324561),
  DSP16_Q(-0.00785212),
  DSP16_Q(0.00137729),
  DSP16_Q(0.00003788),
  DSP16_Q(-0.00269758),
  DSP16_Q(0.01140537),
  DSP16_Q(-0.03140364),
  DSP16_Q(0.09106964),
  DSP16_Q(0.54995523),
  DSP16_Q(-0.06318518),
  DSP16_Q(0.02352205),
  DSP16_Q(-0.00793999),
  DSP16_Q(0.00138871),
  DSP16_Q(0.00003959),
  DSP16_Q(-0.00274694),
  DSP16_Q(0.01159336),
  DSP16_Q(-0.03190812),
  DSP16_Q(0.09261601),
  DSP16_Q(0.54928521),
  DSP16_Q(-0.06390108),
  DSP16_Q(0.02379596),
  DSP16_Q(-0.00802686),
  DSP16_Q(0.00139987),
  DSP16_Q(0.00004136),
  DSP16_Q(-0.00279651),
  DSP16_Q(0.01178163),
  DSP16_Q(-0.03241302),
  DSP16_Q(0.09416687),
  DSP16_Q(0.54860572),
  DSP16_Q(-0.06460994),
  DSP16_Q(0.02406733),
  DSP16_Q(-0.00811274),
  DSP16_Q(0.00141076),
  DSP16_Q(0.00004318),
  DSP16_Q(-0.00284630),
  DSP16_Q(0.01197017),
  DSP16_Q(-0.03291831),
  DSP16_Q(0.09572217),
  DSP16_Q(0.54791678),
  DSP16_Q(-0.06531176),
  DSP16_Q(0.02433617),
  DSP16_Q(-0.00819761),
  DSP16_Q(0.00142138),
  DSP16_Q(0.00004504),
  DSP16_Q(-0.00289631),
  DSP16_Q(0.01215897),
  DSP16_Q(-0.03342396),
  DSP16_Q(0.09728189),
  DSP16_Q(0.54721843),
  DSP16_Q(-0.06600654),
  DSP16_Q(0.02460246),
  DSP16_Q(-0.00828149),
  DSP16_Q(0.00143175),
  DSP16_Q(0.00004696),
  DSP16_Q(-0.00294652),
  DSP16_Q(0.01234802),
  DSP16_Q(-0.03392995),
  DSP16_Q(0.09884598),
  DSP16_Q(0.54651068),
  DSP16_Q(-0.06669428),
  DSP16_Q(0.02486621),
  DSP16_Q(-0.00836438),
  DSP16_Q(0.00144185),
  DSP16_Q(0.00004893),
  DSP16_Q(-0.00299694),
  DSP16_Q(0.01253730),
  DSP16_Q(-0.03443625),
  DSP16_Q(0.10041441),
  DSP16_Q(0.54579355),
  DSP16_Q(-0.06737497),
  DSP16_Q(0.02512740),
  DSP16_Q(-0.00844626),
  DSP16_Q(0.00145169),
  DSP16_Q(0.00005095),
  DSP16_Q(-0.00304757),
  DSP16_Q(0.01272682),
  DSP16_Q(-0.03494283),
  DSP16_Q(0.10198714),
  DSP16_Q(0.54506708),
  DSP16_Q(-0.06804863),
  DSP16_Q(0.02538604),
  DSP16_Q(-0.00852715),
  DSP16_Q(0.00146127),
  DSP16_Q(0.00005302),
  DSP16_Q(-0.00309840),
  DSP16_Q(0.01291655),
  DSP16_Q(-0.03544968),
  DSP16_Q(0.10356413),
  DSP16_Q(0.54433128),
  DSP16_Q(-0.06871525),
  DSP16_Q(0.02564212),
  DSP16_Q(-0.00860703),
  DSP16_Q(0.00147060),
  DSP16_Q(0.00005515),
  DSP16_Q(-0.00314943),
  DSP16_Q(0.01310649),
  DSP16_Q(-0.03595675),
  DSP16_Q(0.10514534),
  DSP16_Q(0.54358619),
  DSP16_Q(-0.06937484),
  DSP16_Q(0.02589563),
  DSP16_Q(-0.00868592),
  DSP16_Q(0.00147967),
  DSP16_Q(0.00005733),
  DSP16_Q(-0.00320066),
  DSP16_Q(0.01329662),
  DSP16_Q(-0.03646403),
  DSP16_Q(0.10673073),
  DSP16_Q(0.54283182),
  DSP16_Q(-0.07002740),
  DSP16_Q(0.02614658),
  DSP16_Q(-0.00876382),
  DSP16_Q(0.00148848),
  DSP16_Q(0.00005956),
  DSP16_Q(-0.00325208),
  DSP16_Q(0.01348694),
  DSP16_Q(-0.03697148),
  DSP16_Q(0.10832027),
  DSP16_Q(0.54206821),
  DSP16_Q(-0.07067293),
  DSP16_Q(0.02639496),
  DSP16_Q(-0.00884071),
  DSP16_Q(0.00149705),
  DSP16_Q(0.00006185),
  DSP16_Q(-0.00330370),
  DSP16_Q(0.01367744),
  DSP16_Q(-0.03747909),
  DSP16_Q(0.10991391),
  DSP16_Q(0.54129538),
  DSP16_Q(-0.07131143),
  DSP16_Q(0.02664077),
  DSP16_Q(-0.00891661),
  DSP16_Q(0.00150536),
  DSP16_Q(0.00006420),
  DSP16_Q(-0.00335550),
  DSP16_Q(0.01386809),
  DSP16_Q(-0.03798682),
  DSP16_Q(0.11151161),
  DSP16_Q(0.54051335),
  DSP16_Q(-0.07194291),
  DSP16_Q(0.02688401),
  DSP16_Q(-0.00899151),
  DSP16_Q(0.00151342),
  DSP16_Q(0.00006660),
  DSP16_Q(-0.00340749),
  DSP16_Q(0.01405890),
  DSP16_Q(-0.03849464),
  DSP16_Q(0.11311334),
  DSP16_Q(0.53972216),
  DSP16_Q(-0.07256737),
  DSP16_Q(0.02712466),
  DSP16_Q(-0.00906542),
  DSP16_Q(0.00152123),
  DSP16_Q(0.00006906),
  DSP16_Q(-0.00345966),
  DSP16_Q(0.01424985),
  DSP16_Q(-0.03900254),
  DSP16_Q(0.11471905),
  DSP16_Q(0.53892183),
  DSP16_Q(-0.07318481),
  DSP16_Q(0.02736274),
  DSP16_Q(-0.00913833),
  DSP16_Q(0.00152880),
  DSP16_Q(0.00007157),
  DSP16_Q(-0.00351202),
  DSP16_Q(0.01444094),
  DSP16_Q(-0.03951047),
  DSP16_Q(0.11632870),
  DSP16_Q(0.53811238),
  DSP16_Q(-0.07379525),
  DSP16_Q(0.02759823),
  DSP16_Q(-0.00921025),
  DSP16_Q(0.00153612),
  DSP16_Q(0.00007414),
  DSP16_Q(-0.00356455),
  DSP16_Q(0.01463214),
  DSP16_Q(-0.04001842),
  DSP16_Q(0.11794226),
  DSP16_Q(0.53729385),
  DSP16_Q(-0.07439867),
  DSP16_Q(0.02783113),
  DSP16_Q(-0.00928117),
  DSP16_Q(0.00154319),
  DSP16_Q(0.00007677),
  DSP16_Q(-0.00361725),
  DSP16_Q(0.01482344),
  DSP16_Q(-0.04052635),
  DSP16_Q(0.11955968),
  DSP16_Q(0.53646626),
  DSP16_Q(-0.07499510),
  DSP16_Q(0.02806145),
  DSP16_Q(-0.00935110),
  DSP16_Q(0.00155003),
  DSP16_Q(0.00007946),
  DSP16_Q(-0.00367013),
  DSP16_Q(0.01501485),
  DSP16_Q(-0.04103424),
  DSP16_Q(0.12118092),
  DSP16_Q(0.53562964),
  DSP16_Q(-0.07558452),
  DSP16_Q(0.02828918),
  DSP16_Q(-0.00942003),
  DSP16_Q(0.00155662),
  DSP16_Q(0.00008220),
  DSP16_Q(-0.00372318),
  DSP16_Q(0.01520634),
  DSP16_Q(-0.04154206),
  DSP16_Q(0.12280594),
  DSP16_Q(0.53478403),
  DSP16_Q(-0.07616695),
  DSP16_Q(0.02851431),
  DSP16_Q(-0.00948798),
  DSP16_Q(0.00156298),
  DSP16_Q(0.00008501),
  DSP16_Q(-0.00377639),
  DSP16_Q(0.01539790),
  DSP16_Q(-0.04204978),
  DSP16_Q(0.12443470),
  DSP16_Q(0.53392944),
  DSP16_Q(-0.07674240),
  DSP16_Q(0.02873686),
  DSP16_Q(-0.00955493),
  DSP16_Q(0.00156909),
  DSP16_Q(0.00008787),
  DSP16_Q(-0.00382977),
  DSP16_Q(0.01558953),
  DSP16_Q(-0.04255737),
  DSP16_Q(0.12606716),
  DSP16_Q(0.53306591),
  DSP16_Q(-0.07731086),
  DSP16_Q(0.02895681),
  DSP16_Q(-0.00962089),
  DSP16_Q(0.00157497),
  DSP16_Q(0.00009080),
  DSP16_Q(-0.00388330),
  DSP16_Q(0.01578121),
  DSP16_Q(-0.04306481),
  DSP16_Q(0.12770328),
  DSP16_Q(0.53219347),
  DSP16_Q(-0.07787235),
  DSP16_Q(0.02917416),
  DSP16_Q(-0.00968587),
  DSP16_Q(0.00158062),
  DSP16_Q(0.00009378),
  DSP16_Q(-0.00393699),
  DSP16_Q(0.01597292),
  DSP16_Q(-0.04357207),
  DSP16_Q(0.12934300),
  DSP16_Q(0.53131215),
  DSP16_Q(-0.07842687),
  DSP16_Q(0.02938891),
  DSP16_Q(-0.00974985),
  DSP16_Q(0.00158603),
  DSP16_Q(0.00009682),
  DSP16_Q(-0.00399084),
  DSP16_Q(0.01616467),
  DSP16_Q(-0.04407911),
  DSP16_Q(0.13098630),
  DSP16_Q(0.53042197),
  DSP16_Q(-0.07897442),
  DSP16_Q(0.02960107),
  DSP16_Q(-0.00981286),
  DSP16_Q(0.00159121),
  DSP16_Q(0.00009993),
  DSP16_Q(-0.00404483),
  DSP16_Q(0.01635643),
  DSP16_Q(-0.04458591),
  DSP16_Q(0.13263312),
  DSP16_Q(0.52952298),
  DSP16_Q(-0.07951502),
  DSP16_Q(0.02981062),
  DSP16_Q(-0.00987487),
  DSP16_Q(0.00159617),
  DSP16_Q(0.00010310),
  DSP16_Q(-0.00409897),
  DSP16_Q(0.01654819),
  DSP16_Q(-0.04509245),
  DSP16_Q(0.13428343),
  DSP16_Q(0.52861519),
  DSP16_Q(-0.08004867),
  DSP16_Q(0.03001758),
  DSP16_Q(-0.00993590),
  DSP16_Q(0.00160089),
  DSP16_Q(0.00010632),
  DSP16_Q(-0.00415326),
  DSP16_Q(0.01673995),
  DSP16_Q(-0.04559868),
  DSP16_Q(0.13593719),
  DSP16_Q(0.52769864),
  DSP16_Q(-0.08057537),
  DSP16_Q(0.03022193),
  DSP16_Q(-0.00999595),
  DSP16_Q(0.00160539),
  DSP16_Q(0.00010961),
  DSP16_Q(-0.00420768),
  DSP16_Q(0.01693169),
  DSP16_Q(-0.04610459),
  DSP16_Q(0.13759434),
  DSP16_Q(0.52677336),
  DSP16_Q(-0.08109514),
  DSP16_Q(0.03042369),
  DSP16_Q(-0.01005502),
  DSP16_Q(0.00160966),
  DSP16_Q(0.00011297),
  DSP16_Q(-0.00426224),
  DSP16_Q(0.01712339),
  DSP16_Q(-0.04661014),
  DSP16_Q(0.13925485),
  DSP16_Q(0.52583938),
  DSP16_Q(-0.08160799),
  DSP16_Q(0.03062284),
  DSP16_Q(-0.01011311),
  DSP16_Q(0.00161372),
  DSP16_Q(0.00011638),
  DSP16_Q(-0.00431694),
  DSP16_Q(0.01731506),
  DSP16_Q(-0.04711531),
  DSP16_Q(0.14091867),
  DSP16_Q(0.52489674),
  DSP16_Q(-0.08211391),
  DSP16_Q(0.03081939),
  DSP16_Q(-0.01017022),
  DSP16_Q(0.00161755),
  DSP16_Q(0.00011986),
  DSP16_Q(-0.00437176),
  DSP16_Q(0.01750667),
  DSP16_Q(-0.04762006),
  DSP16_Q(0.14258577),
  DSP16_Q(0.52394547),
  DSP16_Q(-0.08261292),
  DSP16_Q(0.03101334),
  DSP16_Q(-0.01022636),
  DSP16_Q(0.00162116),
  DSP16_Q(0.00012340),
  DSP16_Q(-0.00442672),
  DSP16_Q(0.01769821),
  DSP16_Q(-0.04812437),
  DSP16_Q(0.14425608),
  DSP16_Q(0.52298559),
  DSP16_Q(-0.08310503),
  DSP16_Q(0.03120468),
  DSP16_Q(-0.01028152),
  DSP16_Q(0.00162455),
  DSP16_Q(0.00012700),
  DSP16_Q(-0.00448179),
  DSP16_Q(0.01788967),
  DSP16_Q(-0.04862820),
  DSP16_Q(0.14592958),
  DSP16_Q(0.52201715),
  DSP16_Q(-0.08359025),
  DSP16_Q(0.03139342),
  DSP16_Q(-0.01033571),
  DSP16_Q(0.00162773),
  DSP16_Q(0.00013067),
  DSP16_Q(-0.00453699),
  DSP16_Q(0.01808104),
  DSP16_Q(-0.04913154),
  DSP16_Q(0.14760622),
  DSP16_Q(0.52104017),
  DSP16_Q(-0.08406858),
  DSP16_Q(0.03157957),
  DSP16_Q(-0.01038892),
  DSP16_Q(0.00163069),
  DSP16_Q(0.00013440),
  DSP16_Q(-0.00459230),
  DSP16_Q(0.01827231),
  DSP16_Q(-0.04963434),
  DSP16_Q(0.14928595),
  DSP16_Q(0.52005469),
  DSP16_Q(-0.08454004),
  DSP16_Q(0.03176311),
  DSP16_Q(-0.01044117),
  DSP16_Q(0.00163344),
  DSP16_Q(0.00013820),
  DSP16_Q(-0.00464772),
  DSP16_Q(0.01846346),
  DSP16_Q(-0.05013658),
  DSP16_Q(0.15096872),
  DSP16_Q(0.51906074),
  DSP16_Q(-0.08500463),
  DSP16_Q(0.03194405),
  DSP16_Q(-0.01049245),
  DSP16_Q(0.00163598),
  DSP16_Q(0.00014206),
  DSP16_Q(-0.00470325),
  DSP16_Q(0.01865449),
  DSP16_Q(-0.05063822),
  DSP16_Q(0.15265450),
  DSP16_Q(0.51805836),
  DSP16_Q(-0.08546236),
  DSP16_Q(0.03212239),
  DSP16_Q(-0.01054277),
  DSP16_Q(0.00163831),
  DSP16_Q(0.00014599),
  DSP16_Q(-0.00475889),
  DSP16_Q(0.01884537),
  DSP16_Q(-0.05113925),
  DSP16_Q(0.15434324),
  DSP16_Q(0.51704757),
  DSP16_Q(-0.08591325),
  DSP16_Q(0.03229814),
  DSP16_Q(-0.01059212),
  DSP16_Q(0.00164043),
  DSP16_Q(0.00014998),
  DSP16_Q(-0.00481463),
  DSP16_Q(0.01903611),
  DSP16_Q(-0.05163962),
  DSP16_Q(0.15603489),
  DSP16_Q(0.51602842),
  DSP16_Q(-0.08635730),
  DSP16_Q(0.03247129),
  DSP16_Q(-0.01064051),
  DSP16_Q(0.00164235),
  DSP16_Q(0.00015403),
  DSP16_Q(-0.00487047),
  DSP16_Q(0.01922667),
  DSP16_Q(-0.05213931),
  DSP16_Q(0.15772941),
  DSP16_Q(0.51500094),
  DSP16_Q(-0.08679452),
  DSP16_Q(0.03264184),
  DSP16_Q(-0.01068794),
  DSP16_Q(0.00164407),
  DSP16_Q(0.00015815),
  DSP16_Q(-0.00492640),
  DSP16_Q(0.01941706),
  DSP16_Q(-0.05263829),
  DSP16_Q(0.15942675),
  DSP16_Q(0.51396516),
  DSP16_Q(-0.08722494),
  DSP16_Q(0.03280980),
  DSP16_Q(-0.01073441),
  DSP16_Q(0.00164558),
  DSP16_Q(0.00016234),
  DSP16_Q(-0.00498243),
  DSP16_Q(0.01960726),
  DSP16_Q(-0.05313653),
  DSP16_Q(0.16112687),
  DSP16_Q(0.51292112),
  DSP16_Q(-0.08764854),
  DSP16_Q(0.03297516),
  DSP16_Q(-0.01077993),
  DSP16_Q(0.00164689),
  DSP16_Q(0.00016659),
  DSP16_Q(-0.00503854),
  DSP16_Q(0.01979726),
  DSP16_Q(-0.05363400),
  DSP16_Q(0.16282971),
  DSP16_Q(0.51186885),
  DSP16_Q(-0.08806536),
  DSP16_Q(0.03313794),
  DSP16_Q(-0.01082449),
  DSP16_Q(0.00164801),
  DSP16_Q(0.00017091),
  DSP16_Q(-0.00509473),
  DSP16_Q(0.01998704),
  DSP16_Q(-0.05413066),
  DSP16_Q(0.16453525),
  DSP16_Q(0.51080840),
  DSP16_Q(-0.08847539),
  DSP16_Q(0.03329812),
  DSP16_Q(-0.01086811),
  DSP16_Q(0.00164893),
  DSP16_Q(0.00017529),
  DSP16_Q(-0.00515100),
  DSP16_Q(0.02017660),
  DSP16_Q(-0.05462650),
  DSP16_Q(0.16624341),
  DSP16_Q(0.50973978),
  DSP16_Q(-0.08887866),
  DSP16_Q(0.03345572),
  DSP16_Q(-0.01091078),
  DSP16_Q(0.00164965),
  DSP16_Q(0.00017974),
  DSP16_Q(-0.00520735),
  DSP16_Q(0.02036591),
  DSP16_Q(-0.05512146),
  DSP16_Q(0.16795417),
  DSP16_Q(0.50866305),
  DSP16_Q(-0.08927516),
  DSP16_Q(0.03361073),
  DSP16_Q(-0.01095250),
  DSP16_Q(0.00165018),
  DSP16_Q(0.00018426),
  DSP16_Q(-0.00526377),
  DSP16_Q(0.02055497),
  DSP16_Q(-0.05561554),
  DSP16_Q(0.16966748),
  DSP16_Q(0.50757824),
  DSP16_Q(-0.08966492),
  DSP16_Q(0.03376316),
  DSP16_Q(-0.01099328),
  DSP16_Q(0.00165052),
  DSP16_Q(0.00018884),
  DSP16_Q(-0.00532026),
  DSP16_Q(0.02074377),
  DSP16_Q(-0.05610869),
  DSP16_Q(0.17138328),
  DSP16_Q(0.50648539),
  DSP16_Q(-0.09004795),
  DSP16_Q(0.03391301),
  DSP16_Q(-0.01103312),
  DSP16_Q(0.00165067),
  DSP16_Q(0.00019349),
  DSP16_Q(-0.00537681),
  DSP16_Q(0.02093228),
  DSP16_Q(-0.05660088),
  DSP16_Q(0.17310153),
  DSP16_Q(0.50538452),
  DSP16_Q(-0.09042426),
  DSP16_Q(0.03406028),
  DSP16_Q(-0.01107202),
  DSP16_Q(0.00165063),
  DSP16_Q(0.00019820),
  DSP16_Q(-0.00543342),
  DSP16_Q(0.02112051),
  DSP16_Q(-0.05709209),
  DSP16_Q(0.17482219),
  DSP16_Q(0.50427569),
  DSP16_Q(-0.09079386),
  DSP16_Q(0.03420498),
  DSP16_Q(-0.01110999),
  DSP16_Q(0.00165041),
  DSP16_Q(0.00020299),
  DSP16_Q(-0.00549008),
  DSP16_Q(0.02130843),
  DSP16_Q(-0.05758228),
  DSP16_Q(0.17654521),
  DSP16_Q(0.50315892),
  DSP16_Q(-0.09115677),
  DSP16_Q(0.03434710),
  DSP16_Q(-0.01114702),
  DSP16_Q(0.00165001),
  DSP16_Q(0.00020783),
  DSP16_Q(-0.00554680),
  DSP16_Q(0.02149603),
  DSP16_Q(-0.05807142),
  DSP16_Q(0.17827053),
  DSP16_Q(0.50203426),
  DSP16_Q(-0.09151300),
  DSP16_Q(0.03448666),
  DSP16_Q(-0.01118313),
  DSP16_Q(0.00164942),
  DSP16_Q(0.00021275),
  DSP16_Q(-0.00560357),
  DSP16_Q(0.02168331),
  DSP16_Q(-0.05855949),
  DSP16_Q(0.17999811),
  DSP16_Q(0.50090174),
  DSP16_Q(-0.09186256),
  DSP16_Q(0.03462365),
  DSP16_Q(-0.01121830),
  DSP16_Q(0.00164865),
  DSP16_Q(0.00021773),
  DSP16_Q(-0.00566038),
  DSP16_Q(0.02187024),
  DSP16_Q(-0.05904644),
  DSP16_Q(0.18172791),
  DSP16_Q(0.49976140),
  DSP16_Q(-0.09220547),
  DSP16_Q(0.03475807),
  DSP16_Q(-0.01125256),
  DSP16_Q(0.00164771),
  DSP16_Q(0.00022278),
  DSP16_Q(-0.00571722),
  DSP16_Q(0.02205681),
  DSP16_Q(-0.05953226),
  DSP16_Q(0.18345987),
  DSP16_Q(0.49861328),
  DSP16_Q(-0.09254174),
  DSP16_Q(0.03488994),
  DSP16_Q(-0.01128589),
  DSP16_Q(0.00164659),
  DSP16_Q(0.00022789),
  DSP16_Q(-0.00577411),
  DSP16_Q(0.02224302),
  DSP16_Q(-0.06001690),
  DSP16_Q(0.18519396),
  DSP16_Q(0.49745742),
  DSP16_Q(-0.09287138),
  DSP16_Q(0.03501925),
  DSP16_Q(-0.01131831),
  DSP16_Q(0.00164529),
  DSP16_Q(0.00023307),
  DSP16_Q(-0.00583102),
  DSP16_Q(0.02242884),
  DSP16_Q(-0.06050033),
  DSP16_Q(0.18693011),
  DSP16_Q(0.49629386),
  DSP16_Q(-0.09319442),
  DSP16_Q(0.03514601),
  DSP16_Q(-0.01134981),
  DSP16_Q(0.00164382),
  DSP16_Q(0.00023832),
  DSP16_Q(-0.00588796),
  DSP16_Q(0.02261427),
  DSP16_Q(-0.06098254),
  DSP16_Q(0.18866828),
  DSP16_Q(0.49512263),
  DSP16_Q(-0.09351086),
  DSP16_Q(0.03527021),
  DSP16_Q(-0.01138039),
  DSP16_Q(0.00164219),
  DSP16_Q(0.00024364),
  DSP16_Q(-0.00594493),
  DSP16_Q(0.02279929),
  DSP16_Q(-0.06146347),
  DSP16_Q(0.19040842),
  DSP16_Q(0.49394378),
  DSP16_Q(-0.09382072),
  DSP16_Q(0.03539188),
  DSP16_Q(-0.01141007),
  DSP16_Q(0.00164038),
  DSP16_Q(0.00024902),
  DSP16_Q(-0.00600191),
  DSP16_Q(0.02298389),
  DSP16_Q(-0.06194311),
  DSP16_Q(0.19215049),
  DSP16_Q(0.49275735),
  DSP16_Q(-0.09412401),
  DSP16_Q(0.03551100),
  DSP16_Q(-0.01143884),
  DSP16_Q(0.00163841),
  DSP16_Q(0.00025447),
  DSP16_Q(-0.00605891),
  DSP16_Q(0.02316805),
  DSP16_Q(-0.06242142),
  DSP16_Q(0.19389443),
  DSP16_Q(0.49156337),
  DSP16_Q(-0.09442076),
  DSP16_Q(0.03562759),
  DSP16_Q(-0.01146672),
  DSP16_Q(0.00163627),
  DSP16_Q(0.00025998),
  DSP16_Q(-0.00611591),
  DSP16_Q(0.02335177),
  DSP16_Q(-0.06289836),
  DSP16_Q(0.19564020),
  DSP16_Q(0.49036189),
  DSP16_Q(-0.09471097),
  DSP16_Q(0.03574164),
  DSP16_Q(-0.01149369),
  DSP16_Q(0.00163397),
  DSP16_Q(0.00026556),
  DSP16_Q(-0.00617292),
  DSP16_Q(0.02353502),
  DSP16_Q(-0.06337392),
  DSP16_Q(0.19738774),
  DSP16_Q(0.48915294),
  DSP16_Q(-0.09499466),
  DSP16_Q(0.03585317),
  DSP16_Q(-0.01151976),
  DSP16_Q(0.00163151),
  DSP16_Q(0.00027121),
  DSP16_Q(-0.00622994),
  DSP16_Q(0.02371780),
  DSP16_Q(-0.06384805),
  DSP16_Q(0.19913701),
  DSP16_Q(0.48793658),
  DSP16_Q(-0.09527185),
  DSP16_Q(0.03596217),
  DSP16_Q(-0.01154494),
  DSP16_Q(0.00162889),
  DSP16_Q(0.00027692),
  DSP16_Q(-0.00628695),
  DSP16_Q(0.02390010),
  DSP16_Q(-0.06432072),
  DSP16_Q(0.20088796),
  DSP16_Q(0.48671283),
  DSP16_Q(-0.09554256),
  DSP16_Q(0.03606865),
  DSP16_Q(-0.01156924),
  DSP16_Q(0.00162611),
  DSP16_Q(0.00028270),
  DSP16_Q(-0.00634395),
  DSP16_Q(0.02408189),
  DSP16_Q(-0.06479191),
  DSP16_Q(0.20264054),
  DSP16_Q(0.48548174),
  DSP16_Q(-0.09580680),
  DSP16_Q(0.03617262),
  DSP16_Q(-0.01159264),
  DSP16_Q(0.00162318),
  DSP16_Q(0.00028855),
  DSP16_Q(-0.00640094),
  DSP16_Q(0.02426316),
  DSP16_Q(-0.06526157),
  DSP16_Q(0.20439470),
  DSP16_Q(0.48424335),
  DSP16_Q(-0.09606459),
  DSP16_Q(0.03627409),
  DSP16_Q(-0.01161517),
  DSP16_Q(0.00162009),
  DSP16_Q(0.00029446),
  DSP16_Q(-0.00645791),
  DSP16_Q(0.02444391),
  DSP16_Q(-0.06572969),
  DSP16_Q(0.20615038),
  DSP16_Q(0.48299771),
  DSP16_Q(-0.09631594),
  DSP16_Q(0.03637304),
  DSP16_Q(-0.01163681),
  DSP16_Q(0.00161685),
  DSP16_Q(0.00030043),
  DSP16_Q(-0.00651486),
  DSP16_Q(0.02462411),
  DSP16_Q(-0.06619622),
  DSP16_Q(0.20790754),
  DSP16_Q(0.48174485),
  DSP16_Q(-0.09656087),
  DSP16_Q(0.03646950),
  DSP16_Q(-0.01165758),
  DSP16_Q(0.00161347),
  DSP16_Q(0.00030647),
  DSP16_Q(-0.00657179),
  DSP16_Q(0.02480376),
  DSP16_Q(-0.06666114),
  DSP16_Q(0.20966614),
  DSP16_Q(0.48048481),
  DSP16_Q(-0.09679940),
  DSP16_Q(0.03656347),
  DSP16_Q(-0.01167748),
  DSP16_Q(0.00160993),
  DSP16_Q(0.00031258),
  DSP16_Q(-0.00662869),
  DSP16_Q(0.02498285),
  DSP16_Q(-0.06712440),
  DSP16_Q(0.21142611),
  DSP16_Q(0.47921765),
  DSP16_Q(-0.09703156),
  DSP16_Q(0.03665494),
  DSP16_Q(-0.01169651),
  DSP16_Q(0.00160625),
  DSP16_Q(0.00031875),
  DSP16_Q(-0.00668555),
  DSP16_Q(0.02516135),
  DSP16_Q(-0.06758599),
  DSP16_Q(0.21318741),
  DSP16_Q(0.47794339),
  DSP16_Q(-0.09725734),
  DSP16_Q(0.03674394),
  DSP16_Q(-0.01171468),
  DSP16_Q(0.00160243),
  DSP16_Q(0.00032499),
  DSP16_Q(-0.00674237),
  DSP16_Q(0.02533925),
  DSP16_Q(-0.06804587),
  DSP16_Q(0.21494998),
  DSP16_Q(0.47666209),
  DSP16_Q(-0.09747678),
  DSP16_Q(0.03683045),
  DSP16_Q(-0.01173198),
  DSP16_Q(0.00159846),
  DSP16_Q(0.00033129),
  DSP16_Q(-0.00679915),
  DSP16_Q(0.02551655),
  DSP16_Q(-0.06850400),
  DSP16_Q(0.21671379),
  DSP16_Q(0.47537379),
  DSP16_Q(-0.09768989),
  DSP16_Q(0.03691450),
  DSP16_Q(-0.01174843),
  DSP16_Q(0.00159436),
  DSP16_Q(0.00033765),
  DSP16_Q(-0.00685588),
  DSP16_Q(0.02569322),
  DSP16_Q(-0.06896036),
  DSP16_Q(0.21847877),
  DSP16_Q(0.47407853),
  DSP16_Q(-0.09789670),
  DSP16_Q(0.03699608),
  DSP16_Q(-0.01176402),
  DSP16_Q(0.00159012),
  DSP16_Q(0.00034408),
  DSP16_Q(-0.00691256),
  DSP16_Q(0.02586925),
  DSP16_Q(-0.06941491),
  DSP16_Q(0.22024487),
  DSP16_Q(0.47277635),
  DSP16_Q(-0.09809721),
  DSP16_Q(0.03707520),
  DSP16_Q(-0.01177877),
  DSP16_Q(0.00158574),
  DSP16_Q(0.00035057),
  DSP16_Q(-0.00696918),
  DSP16_Q(0.02604464),
  DSP16_Q(-0.06986761),
  DSP16_Q(0.22201205),
  DSP16_Q(0.47146730),
  DSP16_Q(-0.09829144),
  DSP16_Q(0.03715187),
  DSP16_Q(-0.01179267),
  DSP16_Q(0.00158122),
  DSP16_Q(0.00035713),
  DSP16_Q(-0.00702573),
  DSP16_Q(0.02621936),
  DSP16_Q(-0.07031845),
  DSP16_Q(0.22378025),
  DSP16_Q(0.47015142),
  DSP16_Q(-0.09847943),
  DSP16_Q(0.03722609),
  DSP16_Q(-0.01180572),
  DSP16_Q(0.00157658),
  DSP16_Q(0.00036375),
  DSP16_Q(-0.00708222),
  DSP16_Q(0.02639341),
  DSP16_Q(-0.07076738),
  DSP16_Q(0.22554943),
  DSP16_Q(0.46882875),
  DSP16_Q(-0.09866118),
  DSP16_Q(0.03729787),
  DSP16_Q(-0.01181794),
  DSP16_Q(0.00157180),
  DSP16_Q(0.00037043),
  DSP16_Q(-0.00713864),
  DSP16_Q(0.02656676),
  DSP16_Q(-0.07121437),
  DSP16_Q(0.22731952),
  DSP16_Q(0.46749935),
  DSP16_Q(-0.09883672),
  DSP16_Q(0.03736722),
  DSP16_Q(-0.01182933),
  DSP16_Q(0.00156690),
  DSP16_Q(0.00037717),
  DSP16_Q(-0.00719498),
  DSP16_Q(0.02673941),
  DSP16_Q(-0.07165939),
  DSP16_Q(0.22909049),
  DSP16_Q(0.46616325),
  DSP16_Q(-0.09900606),
  DSP16_Q(0.03743414),
  DSP16_Q(-0.01183989),
  DSP16_Q(0.00156187),
  DSP16_Q(0.00038398),
  DSP16_Q(-0.00725124),
  DSP16_Q(0.02691134),
  DSP16_Q(-0.07210241),
  DSP16_Q(0.23086227),
  DSP16_Q(0.46482049),
  DSP16_Q(-0.09916923),
  DSP16_Q(0.03749864),
  DSP16_Q(-0.01184962),
  DSP16_Q(0.00155671),
  DSP16_Q(0.00039085),
  DSP16_Q(-0.00730741),
  DSP16_Q(0.02708254),
  DSP16_Q(-0.07254339),
  DSP16_Q(0.23263482),
  DSP16_Q(0.46347113),
  DSP16_Q(-0.09932625),
  DSP16_Q(0.03756072),
  DSP16_Q(-0.01185853),
  DSP16_Q(0.00155143),
  DSP16_Q(0.00039777),
  DSP16_Q(-0.00736349),
  DSP16_Q(0.02725299),
  DSP16_Q(-0.07298231),
  DSP16_Q(0.23440808),
  DSP16_Q(0.46211521),
  DSP16_Q(-0.09947713),
  DSP16_Q(0.03762040),
  DSP16_Q(-0.01186662),
  DSP16_Q(0.00154604),
  DSP16_Q(0.00040476),
  DSP16_Q(-0.00741947),
  DSP16_Q(0.02742269),
  DSP16_Q(-0.07341913),
  DSP16_Q(0.23618201),
  DSP16_Q(0.46075277),
  DSP16_Q(-0.09962189),
  DSP16_Q(0.03767768),
  DSP16_Q(-0.01187390),
  DSP16_Q(0.00154052),
  DSP16_Q(0.00041181),
  DSP16_Q(-0.00747536),
  DSP16_Q(0.02759161),
  DSP16_Q(-0.07385381),
  DSP16_Q(0.23795654),
  DSP16_Q(0.45938386),
  DSP16_Q(-0.09976057),
  DSP16_Q(0.03773257),
  DSP16_Q(-0.01188037),
  DSP16_Q(0.00153488),
  DSP16_Q(0.00041892),
  DSP16_Q(-0.00753113),
  DSP16_Q(0.02775974),
  DSP16_Q(-0.07428633),
  DSP16_Q(0.23973164),
  DSP16_Q(0.45800853),
  DSP16_Q(-0.09989317),
  DSP16_Q(0.03778507),
  DSP16_Q(-0.01188603),
  DSP16_Q(0.00152913),
  DSP16_Q(0.00042609),
  DSP16_Q(-0.00758680),
  DSP16_Q(0.02792707),
  DSP16_Q(-0.07471665),
  DSP16_Q(0.24150724),
  DSP16_Q(0.45662681),
  DSP16_Q(-0.10001972),
  DSP16_Q(0.03783519),
  DSP16_Q(-0.01189090),
  DSP16_Q(0.00152327),
  DSP16_Q(0.00043332),
  DSP16_Q(-0.00764235),
  DSP16_Q(0.02809359),
  DSP16_Q(-0.07514475),
  DSP16_Q(0.24328330),
  DSP16_Q(0.45523876),
  DSP16_Q(-0.10014024),
  DSP16_Q(0.03788294),
  DSP16_Q(-0.01189497),
  DSP16_Q(0.00151730),
  DSP16_Q(0.00044061),
  DSP16_Q(-0.00769778),
  DSP16_Q(0.02825928),
  DSP16_Q(-0.07557058),
  DSP16_Q(0.24505975),
  DSP16_Q(0.45384442),
  DSP16_Q(-0.10025475),
  DSP16_Q(0.03792833),
  DSP16_Q(-0.01189824),
  DSP16_Q(0.00151122),
  DSP16_Q(0.00044795),
  DSP16_Q(-0.00775308),
  DSP16_Q(0.02842412),
  DSP16_Q(-0.07599411),
  DSP16_Q(0.24683656),
  DSP16_Q(0.45244385),
  DSP16_Q(-0.10036328),
  DSP16_Q(0.03797136),
  DSP16_Q(-0.01190073),
  DSP16_Q(0.00150503),
  DSP16_Q(0.00045535),
  DSP16_Q(-0.00780826),
  DSP16_Q(0.02858811),
  DSP16_Q(-0.07641532),
  DSP16_Q(0.24861367),
  DSP16_Q(0.45103707),
  DSP16_Q(-0.10046584),
  DSP16_Q(0.03801205),
  DSP16_Q(-0.01190244),
  DSP16_Q(0.00149873),
  DSP16_Q(0.00046281),
  DSP16_Q(-0.00786329),
  DSP16_Q(0.02875123),
  DSP16_Q(-0.07683416),
  DSP16_Q(0.25039102),
  DSP16_Q(0.44962415),
  DSP16_Q(-0.10056246),
  DSP16_Q(0.03805039),
  DSP16_Q(-0.01190337),
  DSP16_Q(0.00149233),
  DSP16_Q(0.00047033),
  DSP16_Q(-0.00791819),
  DSP16_Q(0.02891347),
  DSP16_Q(-0.07725061),
  DSP16_Q(0.25216856),
  DSP16_Q(0.44820513),
  DSP16_Q(-0.10065316),
  DSP16_Q(0.03808641),
  DSP16_Q(-0.01190352),
  DSP16_Q(0.00148583),
  DSP16_Q(0.00047790),
  DSP16_Q(-0.00797294),
  DSP16_Q(0.02907481),
  DSP16_Q(-0.07766464),
  DSP16_Q(0.25394624),
  DSP16_Q(0.44678005),
  DSP16_Q(-0.10073796),
  DSP16_Q(0.03812010),
  DSP16_Q(-0.01190291),
  DSP16_Q(0.00147923),
  DSP16_Q(0.00048553),
  DSP16_Q(-0.00802754),
  DSP16_Q(0.02923523),
  DSP16_Q(-0.07807621),
  DSP16_Q(0.25572400),
  DSP16_Q(0.44534897),
  DSP16_Q(-0.10081688),
  DSP16_Q(0.03815148),
  DSP16_Q(-0.01190153),
  DSP16_Q(0.00147253),
  DSP16_Q(0.00049321),
  DSP16_Q(-0.00808198),
  DSP16_Q(0.02939473),
  DSP16_Q(-0.07848528),
  DSP16_Q(0.25750180),
  DSP16_Q(0.44391192),
  DSP16_Q(-0.10088995),
  DSP16_Q(0.03818055),
  DSP16_Q(-0.01189939),
  DSP16_Q(0.00146573),
  DSP16_Q(0.00050095),
  DSP16_Q(-0.00813627),
  DSP16_Q(0.02955329),
  DSP16_Q(-0.07889183),
  DSP16_Q(0.25927958),
  DSP16_Q(0.44246897),
  DSP16_Q(-0.10095719),
  DSP16_Q(0.03820732),
  DSP16_Q(-0.01189649),
  DSP16_Q(0.00145884),
  DSP16_Q(0.00050874),
  DSP16_Q(-0.00819038),
  DSP16_Q(0.02971090),
  DSP16_Q(-0.07929583),
  DSP16_Q(0.26105729),
  DSP16_Q(0.44102015),
  DSP16_Q(-0.10101863),
  DSP16_Q(0.03823180),
  DSP16_Q(-0.01189284),
  DSP16_Q(0.00145186),
  DSP16_Q(0.00051659),
  DSP16_Q(-0.00824433),
  DSP16_Q(0.02986754),
  DSP16_Q(-0.07969724),
  DSP16_Q(0.26283487),
  DSP16_Q(0.43956551),
  DSP16_Q(-0.10107428),
  DSP16_Q(0.03825400),
  DSP16_Q(-0.01188845),
  DSP16_Q(0.00144479),
  DSP16_Q(0.00052448),
  DSP16_Q(-0.00829810),
  DSP16_Q(0.03002320),
  DSP16_Q(-0.08009602),
  DSP16_Q(0.26461227),
  DSP16_Q(0.43810511),
  DSP16_Q(-0.10112417),
  DSP16_Q(0.03827393),
  DSP16_Q(-0.01188331),
  DSP16_Q(0.00143763),
  DSP16_Q(0.00053243),
  DSP16_Q(-0.00835168),
  DSP16_Q(0.03017787),
  DSP16_Q(-0.08049215),
  DSP16_Q(0.26638944),
  DSP16_Q(0.43663898),
  DSP16_Q(-0.10116833),
  DSP16_Q(0.03829159),
  DSP16_Q(-0.01187744),
  DSP16_Q(0.00143038),
  DSP16_Q(0.00054043),
  DSP16_Q(-0.00840508),
  DSP16_Q(0.03033153),
  DSP16_Q(-0.08088559),
  DSP16_Q(0.26816633),
  DSP16_Q(0.43516718),
  DSP16_Q(-0.10120677),
  DSP16_Q(0.03830700),
  DSP16_Q(-0.01187083),
  DSP16_Q(0.00142305),
  DSP16_Q(0.00054848),
  DSP16_Q(-0.00845829),
  DSP16_Q(0.03048416),
  DSP16_Q(-0.08127631),
  DSP16_Q(0.26994287),
  DSP16_Q(0.43368976),
  DSP16_Q(-0.10123952),
  DSP16_Q(0.03832016),
  DSP16_Q(-0.01186350),
  DSP16_Q(0.00141563),
  DSP16_Q(0.00055658),
  DSP16_Q(-0.00851130),
  DSP16_Q(0.03063576),
  DSP16_Q(-0.08166428),
  DSP16_Q(0.27171902),
  DSP16_Q(0.43220677),
  DSP16_Q(-0.10126661),
  DSP16_Q(0.03833109),
  DSP16_Q(-0.01185545),
  DSP16_Q(0.00140814),
  DSP16_Q(0.00056473),
  DSP16_Q(-0.00856410),
  DSP16_Q(0.03078630),
  DSP16_Q(-0.08204946),
  DSP16_Q(0.27349473),
  DSP16_Q(0.43071825),
  DSP16_Q(-0.10128805),
  DSP16_Q(0.03833979),
  DSP16_Q(-0.01184667),
  DSP16_Q(0.00140056),
  DSP16_Q(0.00057293),
  DSP16_Q(-0.00861670),
  DSP16_Q(0.03093579),
  DSP16_Q(-0.08243183),
  DSP16_Q(0.27526994),
  DSP16_Q(0.42922425),
  DSP16_Q(-0.10130388),
  DSP16_Q(0.03834627),
  DSP16_Q(-0.01183718),
  DSP16_Q(0.00139291),
  DSP16_Q(0.00058117),
  DSP16_Q(-0.00866909),
  DSP16_Q(0.03108419),
  DSP16_Q(-0.08281134),
  DSP16_Q(0.27704459),
  DSP16_Q(0.42772483),
  DSP16_Q(-0.10131412),
  DSP16_Q(0.03835054),
  DSP16_Q(-0.01182699),
  DSP16_Q(0.00138517),
  DSP16_Q(0.00058946),
  DSP16_Q(-0.00872126),
  DSP16_Q(0.03123150),
  DSP16_Q(-0.08318798),
  DSP16_Q(0.27881864),
  DSP16_Q(0.42622003),
  DSP16_Q(-0.10131880),
  DSP16_Q(0.03835261),
  DSP16_Q(-0.01181609),
  DSP16_Q(0.00137737),
  DSP16_Q(0.00059780),
  DSP16_Q(-0.00877320),
  DSP16_Q(0.03137771),
  DSP16_Q(-0.08356169),
  DSP16_Q(0.28059203),
  DSP16_Q(0.42470990),
  DSP16_Q(-0.10131793),
  DSP16_Q(0.03835249),
  DSP16_Q(-0.01180449),
  DSP16_Q(0.00136949),
  DSP16_Q(0.00060619),
  DSP16_Q(-0.00882491),
  DSP16_Q(0.03152280),
  DSP16_Q(-0.08393246),
  DSP16_Q(0.28236470),
  DSP16_Q(0.42319449),
  DSP16_Q(-0.10131154),
  DSP16_Q(0.03835019),
  DSP16_Q(-0.01179220),
  DSP16_Q(0.00136155),
  DSP16_Q(0.00061461),
  DSP16_Q(-0.00887639),
  DSP16_Q(0.03166675),
  DSP16_Q(-0.08430024),
  DSP16_Q(0.28413660),
  DSP16_Q(0.42167385),
  DSP16_Q(-0.10129966),
  DSP16_Q(0.03834572),
  DSP16_Q(-0.01177922),
  DSP16_Q(0.00135353),
  DSP16_Q(0.00062309),
  DSP16_Q(-0.00892763),
  DSP16_Q(0.03180956),
  DSP16_Q(-0.08466501),
  DSP16_Q(0.28590769),
  DSP16_Q(0.42014803),
  DSP16_Q(-0.10128232),
  DSP16_Q(0.03833909),
  DSP16_Q(-0.01176556),
  DSP16_Q(0.00134545),
  DSP16_Q(0.00063160),
  DSP16_Q(-0.00897863),
  DSP16_Q(0.03195121),
  DSP16_Q(-0.08502674),
  DSP16_Q(0.28767789),
  DSP16_Q(0.41861708),
  DSP16_Q(-0.10125953),
  DSP16_Q(0.03833031),
  DSP16_Q(-0.01175122),
  DSP16_Q(0.00133730),
  DSP16_Q(0.00064016),
  DSP16_Q(-0.00902937),
  DSP16_Q(0.03209168),
  DSP16_Q(-0.08538539),
  DSP16_Q(0.28944717),
  DSP16_Q(0.41708106),
  DSP16_Q(-0.10123134),
  DSP16_Q(0.03831939),
  DSP16_Q(-0.01173621),
  DSP16_Q(0.00132909),
  DSP16_Q(0.00064875),
  DSP16_Q(-0.00907986),
  DSP16_Q(0.03223096),
  DSP16_Q(-0.08574092),
  DSP16_Q(0.29121546),
  DSP16_Q(0.41554000),
  DSP16_Q(-0.10119775),
  DSP16_Q(0.03830634),
  DSP16_Q(-0.01172052),
  DSP16_Q(0.00132082),
  DSP16_Q(0.00065739),
  DSP16_Q(-0.00913009),
  DSP16_Q(0.03236904),
  DSP16_Q(-0.08609331),
  DSP16_Q(0.29298272),
  DSP16_Q(0.41399397),
  DSP16_Q(-0.10115879),
  DSP16_Q(0.03829117),
  DSP16_Q(-0.01170418),
  DSP16_Q(0.00131249),
  DSP16_Q(0.00066607),
  DSP16_Q(-0.00918005),
  DSP16_Q(0.03250590),
  DSP16_Q(-0.08644253),
  DSP16_Q(0.29474888),
  DSP16_Q(0.41244301),
  DSP16_Q(-0.10111450),
  DSP16_Q(0.03827389),
  DSP16_Q(-0.01168717),
  DSP16_Q(0.00130410),
  DSP16_Q(0.00067479),
  DSP16_Q(-0.00922974),
  DSP16_Q(0.03264154),
  DSP16_Q(-0.08678853),
  DSP16_Q(0.29651390),
  DSP16_Q(0.41088717),
  DSP16_Q(-0.10106490),
  DSP16_Q(0.03825450),
  DSP16_Q(-0.01166951),
  DSP16_Q(0.00129565),
  DSP16_Q(0.00068354),
  DSP16_Q(-0.00927915),
  DSP16_Q(0.03277593),
  DSP16_Q(-0.08713130),
  DSP16_Q(0.29827772),
  DSP16_Q(0.40932650),
  DSP16_Q(-0.10101002),
  DSP16_Q(0.03823303),
  DSP16_Q(-0.01165121),
  DSP16_Q(0.00128715),
  DSP16_Q(0.00069233),
  DSP16_Q(-0.00932828),
  DSP16_Q(0.03290906),
  DSP16_Q(-0.08747079),
  DSP16_Q(0.30004028),
  DSP16_Q(0.40776106),
  DSP16_Q(-0.10094988),
  DSP16_Q(0.03820948),
  DSP16_Q(-0.01163226),
  DSP16_Q(0.00127859),
  DSP16_Q(0.00070116),
  DSP16_Q(-0.00937712),
  DSP16_Q(0.03304092),
  DSP16_Q(-0.08780698),
  DSP16_Q(0.30180153),
  DSP16_Q(0.40619089),
  DSP16_Q(-0.10088450),
  DSP16_Q(0.03818386),
  DSP16_Q(-0.01161267),
  DSP16_Q(0.00126999),
  DSP16_Q(0.00071002),
  DSP16_Q(-0.00942566),
  DSP16_Q(0.03317150),
  DSP16_Q(-0.08813983),
  DSP16_Q(0.30356143),
  DSP16_Q(0.40461605),
  DSP16_Q(-0.10081392),
  DSP16_Q(0.03815618),
  DSP16_Q(-0.01159245),
  DSP16_Q(0.00126133),
  DSP16_Q(0.00071891),
  DSP16_Q(-0.00947391),
  DSP16_Q(0.03330078),
  DSP16_Q(-0.08846930),
  DSP16_Q(0.30531990),
  DSP16_Q(0.40303659),
  DSP16_Q(-0.10073817),
  DSP16_Q(0.03812646),
  DSP16_Q(-0.01157161),
  DSP16_Q(0.00125263),
  DSP16_Q(0.00072784),
  DSP16_Q(-0.00952185),
  DSP16_Q(0.03342875),
  DSP16_Q(-0.08879538),
  DSP16_Q(0.30707691),
  DSP16_Q(0.40145255),
  DSP16_Q(-0.10065726),
  DSP16_Q(0.03809470),
  DSP16_Q(-0.01155014),
  DSP16_Q(0.00124388),
  DSP16_Q(0.00073680),
  DSP16_Q(-0.00956948),
  DSP16_Q(0.03355539),
  DSP16_Q(-0.08911802),
  DSP16_Q(0.30883239),
  DSP16_Q(0.39986400),
  DSP16_Q(-0.10057123),
  DSP16_Q(0.03806091),
  DSP16_Q(-0.01152806),
  DSP16_Q(0.00123509),
  DSP16_Q(0.00074579),
  DSP16_Q(-0.00961680),
  DSP16_Q(0.03368069),
  DSP16_Q(-0.08943719),
  DSP16_Q(0.31058629),
  DSP16_Q(0.39827098),
  DSP16_Q(-0.10048011),
  DSP16_Q(0.03802511),
  DSP16_Q(-0.01150536),
  DSP16_Q(0.00122625),
  DSP16_Q(0.00075481),
  DSP16_Q(-0.00966380),
  DSP16_Q(0.03380464),
  DSP16_Q(-0.08975287),
  DSP16_Q(0.31233855),
  DSP16_Q(0.39667355),
  DSP16_Q(-0.10038392),
  DSP16_Q(0.03798730),
  DSP16_Q(-0.01148206),
  DSP16_Q(0.00121738),
  DSP16_Q(0.00076386),
  DSP16_Q(-0.00971047),
  DSP16_Q(0.03392723),
  DSP16_Q(-0.09006501),
  DSP16_Q(0.31408913),
  DSP16_Q(0.39507175),
  DSP16_Q(-0.10028268),
  DSP16_Q(0.03794751),
  DSP16_Q(-0.01145815),
  DSP16_Q(0.00120846),
  DSP16_Q(0.00077294),
  DSP16_Q(-0.00975680),
  DSP16_Q(0.03404843),
  DSP16_Q(-0.09037359),
  DSP16_Q(0.31583797),
  DSP16_Q(0.39346563),
  DSP16_Q(-0.10017643),
  DSP16_Q(0.03790573),
  DSP16_Q(-0.01143365),
  DSP16_Q(0.00119951),
  DSP16_Q(0.00078204),
  DSP16_Q(-0.00980280),
  DSP16_Q(0.03416824),
  DSP16_Q(-0.09067858),
  DSP16_Q(0.31758501),
  DSP16_Q(0.39185526),
  DSP16_Q(-0.10006520),
  DSP16_Q(0.03786198),
  DSP16_Q(-0.01140856),
  DSP16_Q(0.00119052),
  DSP16_Q(0.00079117),
  DSP16_Q(-0.00984846),
  DSP16_Q(0.03428665),
  DSP16_Q(-0.09097994),
  DSP16_Q(0.31933020),
  DSP16_Q(0.39024068),
  DSP16_Q(-0.09994901),
  DSP16_Q(0.03781627),
  DSP16_Q(-0.01138289),
  DSP16_Q(0.00118149),
  DSP16_Q(0.00080033),
  DSP16_Q(-0.00989376),
  DSP16_Q(0.03440363),
  DSP16_Q(-0.09127764),
  DSP16_Q(0.32107348),
  DSP16_Q(0.38862194),
  DSP16_Q(-0.09982790),
  DSP16_Q(0.03776862),
  DSP16_Q(-0.01135664),
  DSP16_Q(0.00117243),
  DSP16_Q(0.00080950),
  DSP16_Q(-0.00993872),
  DSP16_Q(0.03451918),
  DSP16_Q(-0.09157165),
  DSP16_Q(0.32281481),
  DSP16_Q(0.38699910),
  DSP16_Q(-0.09970188),
  DSP16_Q(0.03771903),
  DSP16_Q(-0.01132981),
  DSP16_Q(0.00116334),
  DSP16_Q(0.00081870),
  DSP16_Q(-0.00998331),
  DSP16_Q(0.03463329),
  DSP16_Q(-0.09186193),
  DSP16_Q(0.32455412),
  DSP16_Q(0.38537221),
  DSP16_Q(-0.09957099),
  DSP16_Q(0.03766752),
  DSP16_Q(-0.01130241),
  DSP16_Q(0.00115423),
  DSP16_Q(0.00082793),
  DSP16_Q(-0.01002754),
  DSP16_Q(0.03474593),
  DSP16_Q(-0.09214847),
  DSP16_Q(0.32629136),
  DSP16_Q(0.38374132),
  DSP16_Q(-0.09943525),
  DSP16_Q(0.03761409),
  DSP16_Q(-0.01127445),
  DSP16_Q(0.00114508),
  DSP16_Q(0.00083717),
  DSP16_Q(-0.01007140),
  DSP16_Q(0.03485710),
  DSP16_Q(-0.09243122),
  DSP16_Q(0.32802648),
  DSP16_Q(0.38210648),
  DSP16_Q(-0.09929470),
  DSP16_Q(0.03755876),
  DSP16_Q(-0.01124593),
  DSP16_Q(0.00113591),
  DSP16_Q(0.00084643),
  DSP16_Q(-0.01011488),
  DSP16_Q(0.03496678),
  DSP16_Q(-0.09271015),
  DSP16_Q(0.32975943),
  DSP16_Q(0.38046775),
  DSP16_Q(-0.09914936),
  DSP16_Q(0.03750154),
  DSP16_Q(-0.01121686),
  DSP16_Q(0.00112671),
  DSP16_Q(0.00085571),
  DSP16_Q(-0.01015798),
  DSP16_Q(0.03507496),
  DSP16_Q(-0.09298523),
  DSP16_Q(0.33149014),
  DSP16_Q(0.37882518),
  DSP16_Q(-0.09899927),
  DSP16_Q(0.03744245),
  DSP16_Q(-0.01118724),
  DSP16_Q(0.00111749),
  DSP16_Q(0.00086500),
  DSP16_Q(-0.01020069),
  DSP16_Q(0.03518163),
  DSP16_Q(-0.09325643),
  DSP16_Q(0.33321857),
  DSP16_Q(0.37717882),
  DSP16_Q(-0.09884445),
  DSP16_Q(0.03738148),
  DSP16_Q(-0.01115708),
  DSP16_Q(0.00110824),
  DSP16_Q(0.00087431),
  DSP16_Q(-0.01024301),
  DSP16_Q(0.03528678),
  DSP16_Q(-0.09352372),
  DSP16_Q(0.33494466),
  DSP16_Q(0.37552872),
  DSP16_Q(-0.09868492),
  DSP16_Q(0.03731867),
  DSP16_Q(-0.01112638),
  DSP16_Q(0.00109898),
  DSP16_Q(0.00088363),
  DSP16_Q(-0.01028493),
  DSP16_Q(0.03539038),
  DSP16_Q(-0.09378707),
  DSP16_Q(0.33666836),
  DSP16_Q(0.37387495),
  DSP16_Q(-0.09852073),
  DSP16_Q(0.03725401),
  DSP16_Q(-0.01109515),
  DSP16_Q(0.00108970),
  DSP16_Q(0.00089297),
  DSP16_Q(-0.01032644),
  DSP16_Q(0.03549243),
  DSP16_Q(-0.09404644),
  DSP16_Q(0.33838961),
  DSP16_Q(0.37221754),
  DSP16_Q(-0.09835190),
  DSP16_Q(0.03718752),
  DSP16_Q(-0.01106340),
  DSP16_Q(0.00108040),
  DSP16_Q(0.00090232),
  DSP16_Q(-0.01036755),
  DSP16_Q(0.03559292),
  DSP16_Q(-0.09430181),
  DSP16_Q(0.34010836),
  DSP16_Q(0.37055656),
  DSP16_Q(-0.09817845),
  DSP16_Q(0.03711922),
  DSP16_Q(-0.01103113),
  DSP16_Q(0.00107108),
  DSP16_Q(0.00091168),
  DSP16_Q(-0.01040824),
  DSP16_Q(0.03569182),
  DSP16_Q(-0.09455314),
  DSP16_Q(0.34182455),
  DSP16_Q(0.36889206),
  DSP16_Q(-0.09800042),
  DSP16_Q(0.03704911),
  DSP16_Q(-0.01099834),
  DSP16_Q(0.00106175),
  DSP16_Q(0.00092104),
  DSP16_Q(-0.01044851),
  DSP16_Q(0.03578913),
  DSP16_Q(-0.09480041),
  DSP16_Q(0.34353814),
  DSP16_Q(0.36722408),
  DSP16_Q(-0.09781784),
  DSP16_Q(0.03697720),
  DSP16_Q(-0.01096504),
  DSP16_Q(0.00105241),
  DSP16_Q(0.00093042),
  DSP16_Q(-0.01048836),
  DSP16_Q(0.03588484),
  DSP16_Q(-0.09504358),
  DSP16_Q(0.34524906),
  DSP16_Q(0.36555269),
  DSP16_Q(-0.09763073),
  DSP16_Q(0.03690351),
  DSP16_Q(-0.01093124),
  DSP16_Q(0.00104305),
  DSP16_Q(0.00093980),
  DSP16_Q(-0.01052777),
  DSP16_Q(0.03597893),
  DSP16_Q(-0.09528261),
  DSP16_Q(0.34695726),
  DSP16_Q(0.36387794),
  DSP16_Q(-0.09743913),
  DSP16_Q(0.03682806),
  DSP16_Q(-0.01089694),
  DSP16_Q(0.00103369),
  DSP16_Q(0.00094919),
  DSP16_Q(-0.01056675),
  DSP16_Q(0.03607139),
  DSP16_Q(-0.09551749),
  DSP16_Q(0.34866269),
  DSP16_Q(0.36219988),
  DSP16_Q(-0.09724307),
  DSP16_Q(0.03675084),
  DSP16_Q(-0.01086215),
  DSP16_Q(0.00102431),
  DSP16_Q(0.00095858),
  DSP16_Q(-0.01060528),
  DSP16_Q(0.03616221),
  DSP16_Q(-0.09574818),
  DSP16_Q(0.35036529),
  DSP16_Q(0.36051856),
  DSP16_Q(-0.09704257),
  DSP16_Q(0.03667189),
  DSP16_Q(-0.01082687),
  DSP16_Q(0.00101493),
  DSP16_Q(0.00096797),
  DSP16_Q(-0.01064337),
  DSP16_Q(0.03625137),
  DSP16_Q(-0.09597464),
  DSP16_Q(0.35206502),
  DSP16_Q(0.35883404),
  DSP16_Q(-0.09683767),
  DSP16_Q(0.03659120),
  DSP16_Q(-0.01079111),
  DSP16_Q(0.00100555),
  DSP16_Q(0.00097737),
  DSP16_Q(-0.01068100),
  DSP16_Q(0.03633886),
  DSP16_Q(-0.09619685),
  DSP16_Q(0.35376181),
  DSP16_Q(0.35714637),
  DSP16_Q(-0.09662840),
  DSP16_Q(0.03650879),
  DSP16_Q(-0.01075488),
  DSP16_Q(0.00099616),
  DSP16_Q(0.00098676),
  DSP16_Q(-0.01071817),
  DSP16_Q(0.03642467),
  DSP16_Q(-0.09641478),
  DSP16_Q(0.35545561),
  DSP16_Q(0.35545561),
  DSP16_Q(-0.09641478),
  DSP16_Q(0.03642467),
  DSP16_Q(-0.01071817),
  DSP16_Q(0.00098676),
  DSP16_Q(0.00099616),
  DSP16_Q(-0.01075488),
  DSP16_Q(0.03650879),
  DSP16_Q(-0.09662840),
  DSP16_Q(0.35714637),
  DSP16_Q(0.35376181),
  DSP16_Q(-0.09619685),
  DSP16_Q(0.03633886),
  DSP16_Q(-0.01068100),
  DSP16_Q(0.00097737),
  DSP16_Q(0.00100555),
  DSP16_Q(-0.01079111),
  DSP16_Q(0.03659120),
  DSP16_Q(-0.09683767),
  DSP16_Q(0.35883404),
  DSP16_Q(0.35206502),
  DSP16_Q(-0.09597464),
  DSP16_Q(0.03625137),
  DSP16_Q(-0.01064337),
  DSP16_Q(0.00096797),
  DSP16_Q(0.00101493),
  DSP16_Q(-0.01082687),
  DSP16_Q(0.03667189),
  DSP16_Q(-0.09704257),
  DSP16_Q(0.36051856),
  DSP16_Q(0.35036529),
  DSP16_Q(-0.09574818),
  DSP16_Q(0.03616221),
  DSP16_Q(-0.01060528),
  DSP16_Q(0.00095858),
  DSP16_Q(0.00102431),
  DSP16_Q(-0.01086215),
  DSP16_Q(0.03675084),
  DSP16_Q(-0.09724307),
  DSP16_Q(0.36219988),
  DSP16_Q(0.34866269),
  DSP16_Q(-0.09551749),
  DSP16_Q(0.03607139),
  DSP16_Q(-0.01056675),
  DSP16_Q(0.00094919),
  DSP16_Q(0.00103369),
  DSP16_Q(-0.01089694),
  DSP16_Q(0.03682806),
  DSP16_Q(-0.09743913),
  DSP16_Q(0.36387794),
  DSP16_Q(0.34695726),
  DSP16_Q(-0.09528261),
  DSP16_Q(0.03597893),
  DSP16_Q(-0.01052777),
  DSP16_Q(0.00093980),
  DSP16_Q(0.00104305),
  DSP16_Q(-0.01093124),
  DSP16_Q(0.03690351),
  DSP16_Q(-0.09763073),
  DSP16_Q(0.36555269),
  DSP16_Q(0.34524906),
  DSP16_Q(-0.09504358),
  DSP16_Q(0.03588484),
  DSP16_Q(-0.01048836),
  DSP16_Q(0.00093042),
  DSP16_Q(0.00105241),
  DSP16_Q(-0.01096504),
  DSP16_Q(0.03697720),
  DSP16_Q(-0.09781784),
  DSP16_Q(0.36722408),
  DSP16_Q(0.34353814),
  DSP16_Q(-0.09480041),
  DSP16_Q(0.03578913),
  DSP16_Q(-0.01044851),
  DSP16_Q(0.00092104),
  DSP16_Q(0.00106175),
  DSP16_Q(-0.01099834),
  DSP16_Q(0.03704911),
  DSP16_Q(-0.09800042),
  DSP16_Q(0.36889206),
  DSP16_Q(0.34182455),
  DSP16_Q(-0.09455314),
  DSP16_Q(0.03569182),
  DSP16_Q(-0.01040824),
  DSP16_Q(0.00091168),
  DSP16_Q(0.00107108),
  DSP16_Q(-0.01103113),
  DSP16_Q(0.03711922),
  DSP16_Q(-0.09817845),
  DSP16_Q(0.37055656),
  DSP16_Q(0.34010836),
  DSP16_Q(-0.09430181),
  DSP16_Q(0.03559292),
  DSP16_Q(-0.01036755),
  DSP16_Q(0.00090232),
  DSP16_Q(0.00108040),
  DSP16_Q(-0.01106340),
  DSP16_Q(0.03718752),
  DSP16_Q(-0.09835190),
  DSP16_Q(0.37221754),
  DSP16_Q(0.33838961),
  DSP16_Q(-0.09404644),
  DSP16_Q(0.03549243),
  DSP16_Q(-0.01032644),
  DSP16_Q(0.00089297),
  DSP16_Q(0.00108970),
  DSP16_Q(-0.01109515),
  DSP16_Q(0.03725401),
  DSP16_Q(-0.09852073),
  DSP16_Q(0.37387495),
  DSP16_Q(0.33666836),
  DSP16_Q(-0.09378707),
  DSP16_Q(0.03539038),
  DSP16_Q(-0.01028493),
  DSP16_Q(0.00088363),
  DSP16_Q(0.00109898),
  DSP16_Q(-0.01112638),
  DSP16_Q(0.03731867),
  DSP16_Q(-0.09868492),
  DSP16_Q(0.37552872),
  DSP16_Q(0.33494466),
  DSP16_Q(-0.09352372),
  DSP16_Q(0.03528678),
  DSP16_Q(-0.01024301),
  DSP16_Q(0.00087431),
  DSP16_Q(0.00110824),
  DSP16_Q(-0.01115708),
  DSP16_Q(0.03738148),
  DSP16_Q(-0.09884445),
  DSP16_Q(0.37717882),
  DSP16_Q(0.33321857),
  DSP16_Q(-0.09325643),
  DSP16_Q(0.03518163),
  DSP16_Q(-0.01020069),
  DSP16_Q(0.00086500),
  DSP16_Q(0.00111749),
  DSP16_Q(-0.01118724),
  DSP16_Q(0.03744245),
  DSP16_Q(-0.09899927),
  DSP16_Q(0.37882518),
  DSP16_Q(0.33149014),
  DSP16_Q(-0.09298523),
  DSP16_Q(0.03507496),
  DSP16_Q(-0.01015798),
  DSP16_Q(0.00085571),
  DSP16_Q(0.00112671),
  DSP16_Q(-0.01121686),
  DSP16_Q(0.03750154),
  DSP16_Q(-0.09914936),
  DSP16_Q(0.38046775),
  DSP16_Q(0.32975943),
  DSP16_Q(-0.09271015),
  DSP16_Q(0.03496678),
  DSP16_Q(-0.01011488),
  DSP16_Q(0.00084643),
  DSP16_Q(0.00113591),
  DSP16_Q(-0.01124593),
  DSP16_Q(0.03755876),
  DSP16_Q(-0.09929470),
  DSP16_Q(0.38210648),
  DSP16_Q(0.32802648),
  DSP16_Q(-0.09243122),
  DSP16_Q(0.03485710),
  DSP16_Q(-0.01007140),
  DSP16_Q(0.00083717),
  DSP16_Q(0.00114508),
  DSP16_Q(-0.01127445),
  DSP16_Q(0.03761409),
  DSP16_Q(-0.09943525),
  DSP16_Q(0.38374132),
  DSP16_Q(0.32629136),
  DSP16_Q(-0.09214847),
  DSP16_Q(0.03474593),
  DSP16_Q(-0.01002754),
  DSP16_Q(0.00082793),
  DSP16_Q(0.00115423),
  DSP16_Q(-0.01130241),
  DSP16_Q(0.03766752),
  DSP16_Q(-0.09957099),
  DSP16_Q(0.38537221),
  DSP16_Q(0.32455412),
  DSP16_Q(-0.09186193),
  DSP16_Q(0.03463329),
  DSP16_Q(-0.00998331),
  DSP16_Q(0.00081870),
  DSP16_Q(0.00116334),
  DSP16_Q(-0.01132981),
  DSP16_Q(0.03771903),
  DSP16_Q(-0.09970188),
  DSP16_Q(0.38699910),
  DSP16_Q(0.32281481),
  DSP16_Q(-0.09157165),
  DSP16_Q(0.03451918),
  DSP16_Q(-0.00993872),
  DSP16_Q(0.00080950),
  DSP16_Q(0.00117243),
  DSP16_Q(-0.01135664),
  DSP16_Q(0.03776862),
  DSP16_Q(-0.09982790),
  DSP16_Q(0.38862194),
  DSP16_Q(0.32107348),
  DSP16_Q(-0.09127764),
  DSP16_Q(0.03440363),
  DSP16_Q(-0.00989376),
  DSP16_Q(0.00080033),
  DSP16_Q(0.00118149),
  DSP16_Q(-0.01138289),
  DSP16_Q(0.03781627),
  DSP16_Q(-0.09994901),
  DSP16_Q(0.39024068),
  DSP16_Q(0.31933020),
  DSP16_Q(-0.09097994),
  DSP16_Q(0.03428665),
  DSP16_Q(-0.00984846),
  DSP16_Q(0.00079117),
  DSP16_Q(0.00119052),
  DSP16_Q(-0.01140856),
  DSP16_Q(0.03786198),
  DSP16_Q(-0.10006520),
  DSP16_Q(0.39185526),
  DSP16_Q(0.31758501),
  DSP16_Q(-0.09067858),
  DSP16_Q(0.03416824),
  DSP16_Q(-0.00980280),
  DSP16_Q(0.00078204),
  DSP16_Q(0.00119951),
  DSP16_Q(-0.01143365),
  DSP16_Q(0.03790573),
  DSP16_Q(-0.10017643),
  DSP16_Q(0.39346563),
  DSP16_Q(0.31583797),
  DSP16_Q(-0.09037359),
  DSP16_Q(0.03404843),
  DSP16_Q(-0.00975680),
  DSP16_Q(0.00077294),
  DSP16_Q(0.00120846),
  DSP16_Q(-0.01145815),
  DSP16_Q(0.03794751),
  DSP16_Q(-0.10028268),
  DSP16_Q(0.39507175),
  DSP16_Q(0.31408913),
  DSP16_Q(-0.09006501),
  DSP16_Q(0.03392723),
  DSP16_Q(-0.00971047),
  DSP16_Q(0.00076386),
  DSP16_Q(0.00121738),
  DSP16_Q(-0.01148206),
  DSP16_Q(0.03798730),
  DSP16_Q(-0.10038392),
  DSP16_Q(0.39667355),
  DSP16_Q(0.31233855),
  DSP16_Q(-0.08975287),
  DSP16_Q(0.03380464),
  DSP16_Q(-0.00966380),
  DSP16_Q(0.00075481),
  DSP16_Q(0.00122625),
  DSP16_Q(-0.01150536),
  DSP16_Q(0.03802511),
  DSP16_Q(-0.10048011),
  DSP16_Q(0.39827098),
  DSP16_Q(0.31058629),
  DSP16_Q(-0.08943719),
  DSP16_Q(0.03368069),
  DSP16_Q(-0.00961680),
  DSP16_Q(0.00074579),
  DSP16_Q(0.00123509),
  DSP16_Q(-0.01152806),
  DSP16_Q(0.03806091),
  DSP16_Q(-0.10057123),
  DSP16_Q(0.39986400),
  DSP16_Q(0.30883239),
  DSP16_Q(-0.08911802),
  DSP16_Q(0.03355539),
  DSP16_Q(-0.00956948),
  DSP16_Q(0.00073680),
  DSP16_Q(0.00124388),
  DSP16_Q(-0.01155014),
  DSP16_Q(0.03809470),
  DSP16_Q(-0.10065726),
  DSP16_Q(0.40145255),
  DSP16_Q(0.30707691),
  DSP16_Q(-0.08879538),
  DSP16_Q(0.03342875),
  DSP16_Q(-0.00952185),
  DSP16_Q(0.00072784),
  DSP16_Q(0.00125263),
  DSP16_Q(-0.01157161),
  DSP16_Q(0.03812646),
  DSP16_Q(-0.10073817),
  DSP16_Q(0.40303659),
  DSP16_Q(0.30531990),
  DSP16_Q(-0.08846930),
  DSP16_Q(0.03330078),
  DSP16_Q(-0.00947391),
  DSP16_Q(0.00071891),
  DSP16_Q(0.00126133),
  DSP16_Q(-0.01159245),
  DSP16_Q(0.03815618),
  DSP16_Q(-0.10081392),
  DSP16_Q(0.40461605),
  DSP16_Q(0.30356143),
  DSP16_Q(-0.08813983),
  DSP16_Q(0.03317150),
  DSP16_Q(-0.00942566),
  DSP16_Q(0.00071002),
  DSP16_Q(0.00126999),
  DSP16_Q(-0.01161267),
  DSP16_Q(0.03818386),
  DSP16_Q(-0.10088450),
  DSP16_Q(0.40619089),
  DSP16_Q(0.30180153),
  DSP16_Q(-0.08780698),
  DSP16_Q(0.03304092),
  DSP16_Q(-0.00937712),
  DSP16_Q(0.00070116),
  DSP16_Q(0.00127859),
  DSP16_Q(-0.01163226),
  DSP16_Q(0.03820948),
  DSP16_Q(-0.10094988),
  DSP16_Q(0.40776106),
  DSP16_Q(0.30004028),
  DSP16_Q(-0.08747079),
  DSP16_Q(0.03290906),
  DSP16_Q(-0.00932828),
  DSP16_Q(0.00069233),
  DSP16_Q(0.00128715),
  DSP16_Q(-0.01165121),
  DSP16_Q(0.03823303),
  DSP16_Q(-0.10101002),
  DSP16_Q(0.40932650),
  DSP16_Q(0.29827772),
  DSP16_Q(-0.08713130),
  DSP16_Q(0.03277593),
  DSP16_Q(-0.00927915),
  DSP16_Q(0.00068354),
  DSP16_Q(0.00129565),
  DSP16_Q(-0.01166951),
  DSP16_Q(0.03825450),
  DSP16_Q(-0.10106490),
  DSP16_Q(0.41088717),
  DSP16_Q(0.29651390),
  DSP16_Q(-0.08678853),
  DSP16_Q(0.03264154),
  DSP16_Q(-0.00922974),
  DSP16_Q(0.00067479),
  DSP16_Q(0.00130410),
  DSP16_Q(-0.01168717),
  DSP16_Q(0.03827389),
  DSP16_Q(-0.10111450),
  DSP16_Q(0.41244301),
  DSP16_Q(0.29474888),
  DSP16_Q(-0.08644253),
  DSP16_Q(0.03250590),
  DSP16_Q(-0.00918005),
  DSP16_Q(0.00066607),
  DSP16_Q(0.00131249),
  DSP16_Q(-0.01170418),
  DSP16_Q(0.03829117),
  DSP16_Q(-0.10115879),
  DSP16_Q(0.41399397),
  DSP16_Q(0.29298272),
  DSP16_Q(-0.08609331),
  DSP16_Q(0.03236904),
  DSP16_Q(-0.00913009),
  DSP16_Q(0.00065739),
  DSP16_Q(0.00132082),
  DSP16_Q(-0.01172052),
  DSP16_Q(0.03830634),
  DSP16_Q(-0.10119775),
  DSP16_Q(0.41554000),
  DSP16_Q(0.29121546),
  DSP16_Q(-0.08574092),
  DSP16_Q(0.03223096),
  DSP16_Q(-0.00907986),
  DSP16_Q(0.00064875),
  DSP16_Q(0.00132909),
  DSP16_Q(-0.01173621),
  DSP16_Q(0.03831939),
  DSP16_Q(-0.10123134),
  DSP16_Q(0.41708106),
  DSP16_Q(0.28944717),
  DSP16_Q(-0.08538539),
  DSP16_Q(0.03209168),
  DSP16_Q(-0.00902937),
  DSP16_Q(0.00064016),
  DSP16_Q(0.00133730),
  DSP16_Q(-0.01175122),
  DSP16_Q(0.03833031),
  DSP16_Q(-0.10125953),
  DSP16_Q(0.41861708),
  DSP16_Q(0.28767789),
  DSP16_Q(-0.08502674),
  DSP16_Q(0.03195121),
  DSP16_Q(-0.00897863),
  DSP16_Q(0.00063160),
  DSP16_Q(0.00134545),
  DSP16_Q(-0.01176556),
  DSP16_Q(0.03833909),
  DSP16_Q(-0.10128232),
  DSP16_Q(0.42014803),
  DSP16_Q(0.28590769),
  DSP16_Q(-0.08466501),
  DSP16_Q(0.03180956),
  DSP16_Q(-0.00892763),
  DSP16_Q(0.00062309),
  DSP16_Q(0.00135353),
  DSP16_Q(-0.01177922),
  DSP16_Q(0.03834572),
  DSP16_Q(-0.10129966),
  DSP16_Q(0.42167385),
  DSP16_Q(0.28413660),
  DSP16_Q(-0.08430024),
  DSP16_Q(0.03166675),
  DSP16_Q(-0.00887639),
  DSP16_Q(0.00061461),
  DSP16_Q(0.00136155),
  DSP16_Q(-0.01179220),
  DSP16_Q(0.03835019),
  DSP16_Q(-0.10131154),
  DSP16_Q(0.42319449),
  DSP16_Q(0.28236470),
  DSP16_Q(-0.08393246),
  DSP16_Q(0.03152280),
  DSP16_Q(-0.00882491),
  DSP16_Q(0.00060619),
  DSP16_Q(0.00136949),
  DSP16_Q(-0.01180449),
  DSP16_Q(0.03835249),
  DSP16_Q(-0.10131793),
  DSP16_Q(0.42470990),
  DSP16_Q(0.28059203),
  DSP16_Q(-0.08356169),
  DSP16_Q(0.03137771),
  DSP16_Q(-0.00877320),
  DSP16_Q(0.00059780),
  DSP16_Q(0.00137737),
  DSP16_Q(-0.01181609),
  DSP16_Q(0.03835261),
  DSP16_Q(-0.10131880),
  DSP16_Q(0.42622003),
  DSP16_Q(0.27881864),
  DSP16_Q(-0.08318798),
  DSP16_Q(0.03123150),
  DSP16_Q(-0.00872126),
  DSP16_Q(0.00058946),
  DSP16_Q(0.00138517),
  DSP16_Q(-0.01182699),
  DSP16_Q(0.03835054),
  DSP16_Q(-0.10131412),
  DSP16_Q(0.42772483),
  DSP16_Q(0.27704459),
  DSP16_Q(-0.08281134),
  DSP16_Q(0.03108419),
  DSP16_Q(-0.00866909),
  DSP16_Q(0.00058117),
  DSP16_Q(0.00139291),
  DSP16_Q(-0.01183718),
  DSP16_Q(0.03834627),
  DSP16_Q(-0.10130388),
  DSP16_Q(0.42922425),
  DSP16_Q(0.27526994),
  DSP16_Q(-0.08243183),
  DSP16_Q(0.03093579),
  DSP16_Q(-0.00861670),
  DSP16_Q(0.00057293),
  DSP16_Q(0.00140056),
  DSP16_Q(-0.01184667),
  DSP16_Q(0.03833979),
  DSP16_Q(-0.10128805),
  DSP16_Q(0.43071825),
  DSP16_Q(0.27349473),
  DSP16_Q(-0.08204946),
  DSP16_Q(0.03078630),
  DSP16_Q(-0.00856410),
  DSP16_Q(0.00056473),
  DSP16_Q(0.00140814),
  DSP16_Q(-0.01185545),
  DSP16_Q(0.03833109),
  DSP16_Q(-0.10126661),
  DSP16_Q(0.43220677),
  DSP16_Q(0.27171902),
  DSP16_Q(-0.08166428),
  DSP16_Q(0.03063576),
  DSP16_Q(-0.00851130),
  DSP16_Q(0.00055658),
  DSP16_Q(0.00141563),
  DSP16_Q(-0.01186350),
  DSP16_Q(0.03832016),
  DSP16_Q(-0.10123952),
  DSP16_Q(0.43368976),
  DSP16_Q(0.26994287),
  DSP16_Q(-0.08127631),
  DSP16_Q(0.03048416),
  DSP16_Q(-0.00845829),
  DSP16_Q(0.00054848),
  DSP16_Q(0.00142305),
  DSP16_Q(-0.01187083),
  DSP16_Q(0.03830700),
  DSP16_Q(-0.10120677),
  DSP16_Q(0.43516718),
  DSP16_Q(0.26816633),
  DSP16_Q(-0.08088559),
  DSP16_Q(0.03033153),
  DSP16_Q(-0.00840508),
  DSP16_Q(0.00054043),
  DSP16_Q(0.00143038),
  DSP16_Q(-0.01187744),
  DSP16_Q(0.03829159),
  DSP16_Q(-0.10116833),
  DSP16_Q(0.43663898),
  DSP16_Q(0.26638944),
  DSP16_Q(-0.08049215),
  DSP16_Q(0.03017787),
  DSP16_Q(-0.00835168),
  DSP16_Q(0.00053243),
  DSP16_Q(0.00143763),
  DSP16_Q(-0.01188331),
  DSP16_Q(0.03827393),
  DSP16_Q(-0.10112417),
  DSP16_Q(0.43810511),
  DSP16_Q(0.26461227),
  DSP16_Q(-0.08009602),
  DSP16_Q(0.03002320),
  DSP16_Q(-0.00829810),
  DSP16_Q(0.00052448),
  DSP16_Q(0.00144479),
  DSP16_Q(-0.01188845),
  DSP16_Q(0.03825400),
  DSP16_Q(-0.10107428),
  DSP16_Q(0.43956551),
  DSP16_Q(0.26283487),
  DSP16_Q(-0.07969724),
  DSP16_Q(0.02986754),
  DSP16_Q(-0.00824433),
  DSP16_Q(0.00051659),
  DSP16_Q(0.00145186),
  DSP16_Q(-0.01189284),
  DSP16_Q(0.03823180),
  DSP16_Q(-0.10101863),
  DSP16_Q(0.44102015),
  DSP16_Q(0.26105729),
  DSP16_Q(-0.07929583),
  DSP16_Q(0.02971090),
  DSP16_Q(-0.00819038),
  DSP16_Q(0.00050874),
  DSP16_Q(0.00145884),
  DSP16_Q(-0.01189649),
  DSP16_Q(0.03820732),
  DSP16_Q(-0.10095719),
  DSP16_Q(0.44246897),
  DSP16_Q(0.25927958),
  DSP16_Q(-0.07889183),
  DSP16_Q(0.02955329),
  DSP16_Q(-0.00813627),
  DSP16_Q(0.00050095),
  DSP16_Q(0.00146573),
  DSP16_Q(-0.01189939),
  DSP16_Q(0.03818055),
  DSP16_Q(-0.10088995),
  DSP16_Q(0.44391192),
  DSP16_Q(0.25750180),
  DSP16_Q(-0.07848528),
  DSP16_Q(0.02939473),
  DSP16_Q(-0.00808198),
  DSP16_Q(0.00049321),
  DSP16_Q(0.00147253),
  DSP16_Q(-0.01190153),
  DSP16_Q(0.03815148),
  DSP16_Q(-0.10081688),
  DSP16_Q(0.44534897),
  DSP16_Q(0.25572400),
  DSP16_Q(-0.07807621),
  DSP16_Q(0.02923523),
  DSP16_Q(-0.00802754),
  DSP16_Q(0.00048553),
  DSP16_Q(0.00147923),
  DSP16_Q(-0.01190291),
  DSP16_Q(0.03812010),
  DSP16_Q(-0.10073796),
  DSP16_Q(0.44678005),
  DSP16_Q(0.25394624),
  DSP16_Q(-0.07766464),
  DSP16_Q(0.02907481),
  DSP16_Q(-0.00797294),
  DSP16_Q(0.00047790),
  DSP16_Q(0.00148583),
  DSP16_Q(-0.01190352),
  DSP16_Q(0.03808641),
  DSP16_Q(-0.10065316),
  DSP16_Q(0.44820513),
  DSP16_Q(0.25216856),
  DSP16_Q(-0.07725061),
  DSP16_Q(0.02891347),
  DSP16_Q(-0.00791819),
  DSP16_Q(0.00047033),
  DSP16_Q(0.00149233),
  DSP16_Q(-0.01190337),
  DSP16_Q(0.03805039),
  DSP16_Q(-0.10056246),
  DSP16_Q(0.44962415),
  DSP16_Q(0.25039102),
  DSP16_Q(-0.07683416),
  DSP16_Q(0.02875123),
  DSP16_Q(-0.00786329),
  DSP16_Q(0.00046281),
  DSP16_Q(0.00149873),
  DSP16_Q(-0.01190244),
  DSP16_Q(0.03801205),
  DSP16_Q(-0.10046584),
  DSP16_Q(0.45103707),
  DSP16_Q(0.24861367),
  DSP16_Q(-0.07641532),
  DSP16_Q(0.02858811),
  DSP16_Q(-0.00780826),
  DSP16_Q(0.00045535),
  DSP16_Q(0.00150503),
  DSP16_Q(-0.01190073),
  DSP16_Q(0.03797136),
  DSP16_Q(-0.10036328),
  DSP16_Q(0.45244385),
  DSP16_Q(0.24683656),
  DSP16_Q(-0.07599411),
  DSP16_Q(0.02842412),
  DSP16_Q(-0.00775308),
  DSP16_Q(0.00044795),
  DSP16_Q(0.00151122),
  DSP16_Q(-0.01189824),
  DSP16_Q(0.03792833),
  DSP16_Q(-0.10025475),
  DSP16_Q(0.45384442),
  DSP16_Q(0.24505975),
  DSP16_Q(-0.07557058),
  DSP16_Q(0.02825928),
  DSP16_Q(-0.00769778),
  DSP16_Q(0.00044061),
  DSP16_Q(0.00151730),
  DSP16_Q(-0.01189497),
  DSP16_Q(0.03788294),
  DSP16_Q(-0.10014024),
  DSP16_Q(0.45523876),
  DSP16_Q(0.24328330),
  DSP16_Q(-0.07514475),
  DSP16_Q(0.02809359),
  DSP16_Q(-0.00764235),
  DSP16_Q(0.00043332),
  DSP16_Q(0.00152327),
  DSP16_Q(-0.01189090),
  DSP16_Q(0.03783519),
  DSP16_Q(-0.10001972),
  DSP16_Q(0.45662681),
  DSP16_Q(0.24150724),
  DSP16_Q(-0.07471665),
  DSP16_Q(0.02792707),
  DSP16_Q(-0.00758680),
  DSP16_Q(0.00042609),
  DSP16_Q(0.00152913),
  DSP16_Q(-0.01188603),
  DSP16_Q(0.03778507),
  DSP16_Q(-0.09989317),
  DSP16_Q(0.45800853),
  DSP16_Q(0.23973164),
  DSP16_Q(-0.07428633),
  DSP16_Q(0.02775974),
  DSP16_Q(-0.00753113),
  DSP16_Q(0.00041892),
  DSP16_Q(0.00153488),
  DSP16_Q(-0.01188037),
  DSP16_Q(0.03773257),
  DSP16_Q(-0.09976057),
  DSP16_Q(0.45938386),
  DSP16_Q(0.23795654),
  DSP16_Q(-0.07385381),
  DSP16_Q(0.02759161),
  DSP16_Q(-0.00747536),
  DSP16_Q(0.00041181),
  DSP16_Q(0.00154052),
  DSP16_Q(-0.01187390),
  DSP16_Q(0.03767768),
  DSP16_Q(-0.09962189),
  DSP16_Q(0.46075277),
  DSP16_Q(0.23618201),
  DSP16_Q(-0.07341913),
  DSP16_Q(0.02742269),
  DSP16_Q(-0.00741947),
  DSP16_Q(0.00040476),
  DSP16_Q(0.00154604),
  DSP16_Q(-0.01186662),
  DSP16_Q(0.03762040),
  DSP16_Q(-0.09947713),
  DSP16_Q(0.46211521),
  DSP16_Q(0.23440808),
  DSP16_Q(-0.07298231),
  DSP16_Q(0.02725299),
  DSP16_Q(-0.00736349),
  DSP16_Q(0.00039777),
  DSP16_Q(0.00155143),
  DSP16_Q(-0.01185853),
  DSP16_Q(0.03756072),
  DSP16_Q(-0.09932625),
  DSP16_Q(0.46347113),
  DSP16_Q(0.23263482),
  DSP16_Q(-0.07254339),
  DSP16_Q(0.02708254),
  DSP16_Q(-0.00730741),
  DSP16_Q(0.00039085),
  DSP16_Q(0.00155671),
  DSP16_Q(-0.01184962),
  DSP16_Q(0.03749864),
  DSP16_Q(-0.09916923),
  DSP16_Q(0.46482049),
  DSP16_Q(0.23086227),
  DSP16_Q(-0.07210241),
  DSP16_Q(0.02691134),
  DSP16_Q(-0.00725124),
  DSP16_Q(0.00038398),
  DSP16_Q(0.00156187),
  DSP16_Q(-0.01183989),
  DSP16_Q(0.03743414),
  DSP16_Q(-0.09900606),
  DSP16_Q(0.46616325),
  DSP16_Q(0.22909049),
  DSP16_Q(-0.07165939),
  DSP16_Q(0.02673941),
  DSP16_Q(-0.00719498),
  DSP16_Q(0.00037717),
  DSP16_Q(0.00156690),
  DSP16_Q(-0.01182933),
  DSP16_Q(0.03736722),
  DSP16_Q(-0.09883672),
  DSP16_Q(0.46749935),
  DSP16_Q(0.22731952),
  DSP16_Q(-0.07121437),
  DSP16_Q(0.02656676),
  DSP16_Q(-0.00713864),
  DSP16_Q(0.00037043),
  DSP16_Q(0.00157180),
  DSP16_Q(-0.01181794),
  DSP16_Q(0.03729787),
  DSP16_Q(-0.09866118),
  DSP16_Q(0.46882875),
  DSP16_Q(0.22554943),
  DSP16_Q(-0.07076738),
  DSP16_Q(0.02639341),
  DSP16_Q(-0.00708222),
  DSP16_Q(0.00036375),
  DSP16_Q(0.00157658),
  DSP16_Q(-0.01180572),
  DSP16_Q(0.03722609),
  DSP16_Q(-0.09847943),
  DSP16_Q(0.47015142),
  DSP16_Q(0.22378025),
  DSP16_Q(-0.07031845),
  DSP16_Q(0.02621936),
  DSP16_Q(-0.00702573),
  DSP16_Q(0.00035713),
  DSP16_Q(0.00158122),
  DSP16_Q(-0.01179267),
  DSP16_Q(0.03715187),
  DSP16_Q(-0.09829144),
  DSP16_Q(0.47146730),
  DSP16_Q(0.22201205),
  DSP16_Q(-0.06986761),
  DSP16_Q(0.02604464),
  DSP16_Q(-0.00696918),
  DSP16_Q(0.00035057),
  DSP16_Q(0.00158574),
  DSP16_Q(-0.01177877),
  DSP16_Q(0.03707520),
  DSP16_Q(-0.09809721),
  DSP16_Q(0.47277635),
  DSP16_Q(0.22024487),
  DSP16_Q(-0.06941491),
  DSP16_Q(0.02586925),
  DSP16_Q(-0.00691256),
  DSP16_Q(0.00034408),
  DSP16_Q(0.00159012),
  DSP16_Q(-0.01176402),
  DSP16_Q(0.03699608),
  DSP16_Q(-0.09789670),
  DSP16_Q(0.47407853),
  DSP16_Q(0.21847877),
  DSP16_Q(-0.06896036),
  DSP16_Q(0.02569322),
  DSP16_Q(-0.00685588),
  DSP16_Q(0.00033765),
  DSP16_Q(0.00159436),
  DSP16_Q(-0.01174843),
  DSP16_Q(0.03691450),
  DSP16_Q(-0.09768989),
  DSP16_Q(0.47537379),
  DSP16_Q(0.21671379),
  DSP16_Q(-0.06850400),
  DSP16_Q(0.02551655),
  DSP16_Q(-0.00679915),
  DSP16_Q(0.00033129),
  DSP16_Q(0.00159846),
  DSP16_Q(-0.01173198),
  DSP16_Q(0.03683045),
  DSP16_Q(-0.09747678),
  DSP16_Q(0.47666209),
  DSP16_Q(0.21494998),
  DSP16_Q(-0.06804587),
  DSP16_Q(0.02533925),
  DSP16_Q(-0.00674237),
  DSP16_Q(0.00032499),
  DSP16_Q(0.00160243),
  DSP16_Q(-0.01171468),
  DSP16_Q(0.03674394),
  DSP16_Q(-0.09725734),
  DSP16_Q(0.47794339),
  DSP16_Q(0.21318741),
  DSP16_Q(-0.06758599),
  DSP16_Q(0.02516135),
  DSP16_Q(-0.00668555),
  DSP16_Q(0.00031875),
  DSP16_Q(0.00160625),
  DSP16_Q(-0.01169651),
  DSP16_Q(0.03665494),
  DSP16_Q(-0.09703156),
  DSP16_Q(0.47921765),
  DSP16_Q(0.21142611),
  DSP16_Q(-0.06712440),
  DSP16_Q(0.02498285),
  DSP16_Q(-0.00662869),
  DSP16_Q(0.00031258),
  DSP16_Q(0.00160993),
  DSP16_Q(-0.01167748),
  DSP16_Q(0.03656347),
  DSP16_Q(-0.09679940),
  DSP16_Q(0.48048481),
  DSP16_Q(0.20966614),
  DSP16_Q(-0.06666114),
  DSP16_Q(0.02480376),
  DSP16_Q(-0.00657179),
  DSP16_Q(0.00030647),
  DSP16_Q(0.00161347),
  DSP16_Q(-0.01165758),
  DSP16_Q(0.03646950),
  DSP16_Q(-0.09656087),
  DSP16_Q(0.48174485),
  DSP16_Q(0.20790754),
  DSP16_Q(-0.06619622),
  DSP16_Q(0.02462411),
  DSP16_Q(-0.00651486),
  DSP16_Q(0.00030043),
  DSP16_Q(0.00161685),
  DSP16_Q(-0.01163681),
  DSP16_Q(0.03637304),
  DSP16_Q(-0.09631594),
  DSP16_Q(0.48299771),
  DSP16_Q(0.20615038),
  DSP16_Q(-0.06572969),
  DSP16_Q(0.02444391),
  DSP16_Q(-0.00645791),
  DSP16_Q(0.00029446),
  DSP16_Q(0.00162009),
  DSP16_Q(-0.01161517),
  DSP16_Q(0.03627409),
  DSP16_Q(-0.09606459),
  DSP16_Q(0.48424335),
  DSP16_Q(0.20439470),
  DSP16_Q(-0.06526157),
  DSP16_Q(0.02426316),
  DSP16_Q(-0.00640094),
  DSP16_Q(0.00028855),
  DSP16_Q(0.00162318),
  DSP16_Q(-0.01159264),
  DSP16_Q(0.03617262),
  DSP16_Q(-0.09580680),
  DSP16_Q(0.48548174),
  DSP16_Q(0.20264054),
  DSP16_Q(-0.06479191),
  DSP16_Q(0.02408189),
  DSP16_Q(-0.00634395),
  DSP16_Q(0.00028270),
  DSP16_Q(0.00162611),
  DSP16_Q(-0.01156924),
  DSP16_Q(0.03606865),
  DSP16_Q(-0.09554256),
  DSP16_Q(0.48671283),
  DSP16_Q(0.20088796),
  DSP16_Q(-0.06432072),
  DSP16_Q(0.02390010),
  DSP16_Q(-0.00628695),
  DSP16_Q(0.00027692),
  DSP16_Q(0.00162889),
  DSP16_Q(-0.01154494),
  DSP16_Q(0.03596217),
  DSP16_Q(-0.09527185),
  DSP16_Q(0.48793658),
  DSP16_Q(0.19913701),
  DSP16_Q(-0.06384805),
  DSP16_Q(0.02371780),
  DSP16_Q(-0.00622994),
  DSP16_Q(0.00027121),
  DSP16_Q(0.00163151),
  DSP16_Q(-0.01151976),
  DSP16_Q(0.03585317),
  DSP16_Q(-0.09499466),
  DSP16_Q(0.48915294),
  DSP16_Q(0.19738774),
  DSP16_Q(-0.06337392),
  DSP16_Q(0.02353502),
  DSP16_Q(-0.00617292),
  DSP16_Q(0.00026556),
  DSP16_Q(0.00163397),
  DSP16_Q(-0.01149369),
  DSP16_Q(0.03574164),
  DSP16_Q(-0.09471097),
  DSP16_Q(0.49036189),
  DSP16_Q(0.19564020),
  DSP16_Q(-0.06289836),
  DSP16_Q(0.02335177),
  DSP16_Q(-0.00611591),
  DSP16_Q(0.00025998),
  DSP16_Q(0.00163627),
  DSP16_Q(-0.01146672),
  DSP16_Q(0.03562759),
  DSP16_Q(-0.09442076),
  DSP16_Q(0.49156337),
  DSP16_Q(0.19389443),
  DSP16_Q(-0.06242142),
  DSP16_Q(0.02316805),
  DSP16_Q(-0.00605891),
  DSP16_Q(0.00025447),
  DSP16_Q(0.00163841),
  DSP16_Q(-0.01143884),
  DSP16_Q(0.03551100),
  DSP16_Q(-0.09412401),
  DSP16_Q(0.49275735),
  DSP16_Q(0.19215049),
  DSP16_Q(-0.06194311),
  DSP16_Q(0.02298389),
  DSP16_Q(-0.00600191),
  DSP16_Q(0.00024902),
  DSP16_Q(0.00164038),
  DSP16_Q(-0.01141007),
  DSP16_Q(0.03539188),
  DSP16_Q(-0.09382072),
  DSP16_Q(0.49394378),
  DSP16_Q(0.19040842),
  DSP16_Q(-0.06146347),
  DSP16_Q(0.02279929),
  DSP16_Q(-0.00594493),
  DSP16_Q(0.00024364),
  DSP16_Q(0.00164219),
  DSP16_Q(-0.01138039),
  DSP16_Q(0.03527021),
  DSP16_Q(-0.09351086),
  DSP16_Q(0.49512263),
  DSP16_Q(0.18866828),
  DSP16_Q(-0.06098254),
  DSP16_Q(0.02261427),
  DSP16_Q(-0.00588796),
  DSP16_Q(0.00023832),
  DSP16_Q(0.00164382),
  DSP16_Q(-0.01134981),
  DSP16_Q(0.03514601),
  DSP16_Q(-0.09319442),
  DSP16_Q(0.49629386),
  DSP16_Q(0.18693011),
  DSP16_Q(-0.06050033),
  DSP16_Q(0.02242884),
  DSP16_Q(-0.00583102),
  DSP16_Q(0.00023307),
  DSP16_Q(0.00164529),
  DSP16_Q(-0.01131831),
  DSP16_Q(0.03501925),
  DSP16_Q(-0.09287138),
  DSP16_Q(0.49745742),
  DSP16_Q(0.18519396),
  DSP16_Q(-0.06001690),
  DSP16_Q(0.02224302),
  DSP16_Q(-0.00577411),
  DSP16_Q(0.00022789),
  DSP16_Q(0.00164659),
  DSP16_Q(-0.01128589),
  DSP16_Q(0.03488994),
  DSP16_Q(-0.09254174),
  DSP16_Q(0.49861328),
  DSP16_Q(0.18345987),
  DSP16_Q(-0.05953226),
  DSP16_Q(0.02205681),
  DSP16_Q(-0.00571722),
  DSP16_Q(0.00022278),
  DSP16_Q(0.00164771),
  DSP16_Q(-0.01125256),
  DSP16_Q(0.03475807),
  DSP16_Q(-0.09220547),
  DSP16_Q(0.49976140),
  DSP16_Q(0.18172791),
  DSP16_Q(-0.05904644),
  DSP16_Q(0.02187024),
  DSP16_Q(-0.00566038),
  DSP16_Q(0.00021773),
  DSP16_Q(0.00164865),
  DSP16_Q(-0.01121830),
  DSP16_Q(0.03462365),
  DSP16_Q(-0.09186256),
  DSP16_Q(0.50090174),
  DSP16_Q(0.17999811),
  DSP16_Q(-0.05855949),
  DSP16_Q(0.02168331),
  DSP16_Q(-0.00560357),
  DSP16_Q(0.00021275),
  DSP16_Q(0.00164942),
  DSP16_Q(-0.01118313),
  DSP16_Q(0.03448666),
  DSP16_Q(-0.09151300),
  DSP16_Q(0.50203426),
  DSP16_Q(0.17827053),
  DSP16_Q(-0.05807142),
  DSP16_Q(0.02149603),
  DSP16_Q(-0.00554680),
  DSP16_Q(0.00020783),
  DSP16_Q(0.00165001),
  DSP16_Q(-0.01114702),
  DSP16_Q(0.03434710),
  DSP16_Q(-0.09115677),
  DSP16_Q(0.50315892),
  DSP16_Q(0.17654521),
  DSP16_Q(-0.05758228),
  DSP16_Q(0.02130843),
  DSP16_Q(-0.00549008),
  DSP16_Q(0.00020299),
  DSP16_Q(0.00165041),
  DSP16_Q(-0.01110999),
  DSP16_Q(0.03420498),
  DSP16_Q(-0.09079386),
  DSP16_Q(0.50427569),
  DSP16_Q(0.17482219),
  DSP16_Q(-0.05709209),
  DSP16_Q(0.02112051),
  DSP16_Q(-0.00543342),
  DSP16_Q(0.00019820),
  DSP16_Q(0.00165063),
  DSP16_Q(-0.01107202),
  DSP16_Q(0.03406028),
  DSP16_Q(-0.09042426),
  DSP16_Q(0.50538452),
  DSP16_Q(0.17310153),
  DSP16_Q(-0.05660088),
  DSP16_Q(0.02093228),
  DSP16_Q(-0.00537681),
  DSP16_Q(0.00019349),
  DSP16_Q(0.00165067),
  DSP16_Q(-0.01103312),
  DSP16_Q(0.03391301),
  DSP16_Q(-0.09004795),
  DSP16_Q(0.50648539),
  DSP16_Q(0.17138328),
  DSP16_Q(-0.05610869),
  DSP16_Q(0.02074377),
  DSP16_Q(-0.00532026),
  DSP16_Q(0.00018884),
  DSP16_Q(0.00165052),
  DSP16_Q(-0.01099328),
  DSP16_Q(0.03376316),
  DSP16_Q(-0.08966492),
  DSP16_Q(0.50757824),
  DSP16_Q(0.16966748),
  DSP16_Q(-0.05561554),
  DSP16_Q(0.02055497),
  DSP16_Q(-0.00526377),
  DSP16_Q(0.00018426),
  DSP16_Q(0.00165018),
  DSP16_Q(-0.01095250),
  DSP16_Q(0.03361073),
  DSP16_Q(-0.08927516),
  DSP16_Q(0.50866305),
  DSP16_Q(0.16795417),
  DSP16_Q(-0.05512146),
  DSP16_Q(0.02036591),
  DSP16_Q(-0.00520735),
  DSP16_Q(0.00017974),
  DSP16_Q(0.00164965),
  DSP16_Q(-0.01091078),
  DSP16_Q(0.03345572),
  DSP16_Q(-0.08887866),
  DSP16_Q(0.50973978),
  DSP16_Q(0.16624341),
  DSP16_Q(-0.05462650),
  DSP16_Q(0.02017660),
  DSP16_Q(-0.00515100),
  DSP16_Q(0.00017529),
  DSP16_Q(0.00164893),
  DSP16_Q(-0.01086811),
  DSP16_Q(0.03329812),
  DSP16_Q(-0.08847539),
  DSP16_Q(0.51080840),
  DSP16_Q(0.16453525),
  DSP16_Q(-0.05413066),
  DSP16_Q(0.01998704),
  DSP16_Q(-0.00509473),
  DSP16_Q(0.00017091),
  DSP16_Q(0.00164801),
  DSP16_Q(-0.01082449),
  DSP16_Q(0.03313794),
  DSP16_Q(-0.08806536),
  DSP16_Q(0.51186885),
  DSP16_Q(0.16282971),
  DSP16_Q(-0.05363400),
  DSP16_Q(0.01979726),
  DSP16_Q(-0.00503854),
  DSP16_Q(0.00016659),
  DSP16_Q(0.00164689),
  DSP16_Q(-0.01077993),
  DSP16_Q(0.03297516),
  DSP16_Q(-0.08764854),
  DSP16_Q(0.51292112),
  DSP16_Q(0.16112687),
  DSP16_Q(-0.05313653),
  DSP16_Q(0.01960726),
  DSP16_Q(-0.00498243),
  DSP16_Q(0.00016234),
  DSP16_Q(0.00164558),
  DSP16_Q(-0.01073441),
  DSP16_Q(0.03280980),
  DSP16_Q(-0.08722494),
  DSP16_Q(0.51396516),
  DSP16_Q(0.15942675),
  DSP16_Q(-0.05263829),
  DSP16_Q(0.01941706),
  DSP16_Q(-0.00492640),
  DSP16_Q(0.00015815),
  DSP16_Q(0.00164407),
  DSP16_Q(-0.01068794),
  DSP16_Q(0.03264184),
  DSP16_Q(-0.08679452),
  DSP16_Q(0.51500094),
  DSP16_Q(0.15772941),
  DSP16_Q(-0.05213931),
  DSP16_Q(0.01922667),
  DSP16_Q(-0.00487047),
  DSP16_Q(0.00015403),
  DSP16_Q(0.00164235),
  DSP16_Q(-0.01064051),
  DSP16_Q(0.03247129),
  DSP16_Q(-0.08635730),
  DSP16_Q(0.51602842),
  DSP16_Q(0.15603489),
  DSP16_Q(-0.05163962),
  DSP16_Q(0.01903611),
  DSP16_Q(-0.00481463),
  DSP16_Q(0.00014998),
  DSP16_Q(0.00164043),
  DSP16_Q(-0.01059212),
  DSP16_Q(0.03229814),
  DSP16_Q(-0.08591325),
  DSP16_Q(0.51704757),
  DSP16_Q(0.15434324),
  DSP16_Q(-0.05113925),
  DSP16_Q(0.01884537),
  DSP16_Q(-0.00475889),
  DSP16_Q(0.00014599),
  DSP16_Q(0.00163831),
  DSP16_Q(-0.01054277),
  DSP16_Q(0.03212239),
  DSP16_Q(-0.08546236),
  DSP16_Q(0.51805836),
  DSP16_Q(0.15265450),
  DSP16_Q(-0.05063822),
  DSP16_Q(0.01865449),
  DSP16_Q(-0.00470325),
  DSP16_Q(0.00014206),
  DSP16_Q(0.00163598),
  DSP16_Q(-0.01049245),
  DSP16_Q(0.03194405),
  DSP16_Q(-0.08500463),
  DSP16_Q(0.51906074),
  DSP16_Q(0.15096872),
  DSP16_Q(-0.05013658),
  DSP16_Q(0.01846346),
  DSP16_Q(-0.00464772),
  DSP16_Q(0.00013820),
  DSP16_Q(0.00163344),
  DSP16_Q(-0.01044117),
  DSP16_Q(0.03176311),
  DSP16_Q(-0.08454004),
  DSP16_Q(0.52005469),
  DSP16_Q(0.14928595),
  DSP16_Q(-0.04963434),
  DSP16_Q(0.01827231),
  DSP16_Q(-0.00459230),
  DSP16_Q(0.00013440),
  DSP16_Q(0.00163069),
  DSP16_Q(-0.01038892),
  DSP16_Q(0.03157957),
  DSP16_Q(-0.08406858),
  DSP16_Q(0.52104017),
  DSP16_Q(0.14760622),
  DSP16_Q(-0.04913154),
  DSP16_Q(0.01808104),
  DSP16_Q(-0.00453699),
  DSP16_Q(0.00013067),
  DSP16_Q(0.00162773),
  DSP16_Q(-0.01033571),
  DSP16_Q(0.03139342),
  DSP16_Q(-0.08359025),
  DSP16_Q(0.52201715),
  DSP16_Q(0.14592958),
  DSP16_Q(-0.04862820),
  DSP16_Q(0.01788967),
  DSP16_Q(-0.00448179),
  DSP16_Q(0.00012700),
  DSP16_Q(0.00162455),
  DSP16_Q(-0.01028152),
  DSP16_Q(0.03120468),
  DSP16_Q(-0.08310503),
  DSP16_Q(0.52298559),
  DSP16_Q(0.14425608),
  DSP16_Q(-0.04812437),
  DSP16_Q(0.01769821),
  DSP16_Q(-0.00442672),
  DSP16_Q(0.00012340),
  DSP16_Q(0.00162116),
  DSP16_Q(-0.01022636),
  DSP16_Q(0.03101334),
  DSP16_Q(-0.08261292),
  DSP16_Q(0.52394547),
  DSP16_Q(0.14258577),
  DSP16_Q(-0.04762006),
  DSP16_Q(0.01750667),
  DSP16_Q(-0.00437176),
  DSP16_Q(0.00011986),
  DSP16_Q(0.00161755),
  DSP16_Q(-0.01017022),
  DSP16_Q(0.03081939),
  DSP16_Q(-0.08211391),
  DSP16_Q(0.52489674),
  DSP16_Q(0.14091867),
  DSP16_Q(-0.04711531),
  DSP16_Q(0.01731506),
  DSP16_Q(-0.00431694),
  DSP16_Q(0.00011638),
  DSP16_Q(0.00161372),
  DSP16_Q(-0.01011311),
  DSP16_Q(0.03062284),
  DSP16_Q(-0.08160799),
  DSP16_Q(0.52583938),
  DSP16_Q(0.13925485),
  DSP16_Q(-0.04661014),
  DSP16_Q(0.01712339),
  DSP16_Q(-0.00426224),
  DSP16_Q(0.00011297),
  DSP16_Q(0.00160966),
  DSP16_Q(-0.01005502),
  DSP16_Q(0.03042369),
  DSP16_Q(-0.08109514),
  DSP16_Q(0.52677336),
  DSP16_Q(0.13759434),
  DSP16_Q(-0.04610459),
  DSP16_Q(0.01693169),
  DSP16_Q(-0.00420768),
  DSP16_Q(0.00010961),
  DSP16_Q(0.00160539),
  DSP16_Q(-0.00999595),
  DSP16_Q(0.03022193),
  DSP16_Q(-0.08057537),
  DSP16_Q(0.52769864),
  DSP16_Q(0.13593719),
  DSP16_Q(-0.04559868),
  DSP16_Q(0.01673995),
  DSP16_Q(-0.00415326),
  DSP16_Q(0.00010632),
  DSP16_Q(0.00160089),
  DSP16_Q(-0.00993590),
  DSP16_Q(0.03001758),
  DSP16_Q(-0.08004867),
  DSP16_Q(0.52861519),
  DSP16_Q(0.13428343),
  DSP16_Q(-0.04509245),
  DSP16_Q(0.01654819),
  DSP16_Q(-0.00409897),
  DSP16_Q(0.00010310),
  DSP16_Q(0.00159617),
  DSP16_Q(-0.00987487),
  DSP16_Q(0.02981062),
  DSP16_Q(-0.07951502),
  DSP16_Q(0.52952298),
  DSP16_Q(0.13263312),
  DSP16_Q(-0.04458591),
  DSP16_Q(0.01635643),
  DSP16_Q(-0.00404483),
  DSP16_Q(0.00009993),
  DSP16_Q(0.00159121),
  DSP16_Q(-0.00981286),
  DSP16_Q(0.02960107),
  DSP16_Q(-0.07897442),
  DSP16_Q(0.53042197),
  DSP16_Q(0.13098630),
  DSP16_Q(-0.04407911),
  DSP16_Q(0.01616467),
  DSP16_Q(-0.00399084),
  DSP16_Q(0.00009682),
  DSP16_Q(0.00158603),
  DSP16_Q(-0.00974985),
  DSP16_Q(0.02938891),
  DSP16_Q(-0.07842687),
  DSP16_Q(0.53131215),
  DSP16_Q(0.12934300),
  DSP16_Q(-0.04357207),
  DSP16_Q(0.01597292),
  DSP16_Q(-0.00393699),
  DSP16_Q(0.00009378),
  DSP16_Q(0.00158062),
  DSP16_Q(-0.00968587),
  DSP16_Q(0.02917416),
  DSP16_Q(-0.07787235),
  DSP16_Q(0.53219347),
  DSP16_Q(0.12770328),
  DSP16_Q(-0.04306481),
  DSP16_Q(0.01578121),
  DSP16_Q(-0.00388330),
  DSP16_Q(0.00009080),
  DSP16_Q(0.00157497),
  DSP16_Q(-0.00962089),
  DSP16_Q(0.02895681),
  DSP16_Q(-0.07731086),
  DSP16_Q(0.53306591),
  DSP16_Q(0.12606716),
  DSP16_Q(-0.04255737),
  DSP16_Q(0.01558953),
  DSP16_Q(-0.00382977),
  DSP16_Q(0.00008787),
  DSP16_Q(0.00156909),
  DSP16_Q(-0.00955493),
  DSP16_Q(0.02873686),
  DSP16_Q(-0.07674240),
  DSP16_Q(0.53392944),
  DSP16_Q(0.12443470),
  DSP16_Q(-0.04204978),
  DSP16_Q(0.01539790),
  DSP16_Q(-0.00377639),
  DSP16_Q(0.00008501),
  DSP16_Q(0.00156298),
  DSP16_Q(-0.00948798),
  DSP16_Q(0.02851431),
  DSP16_Q(-0.07616695),
  DSP16_Q(0.53478403),
  DSP16_Q(0.12280594),
  DSP16_Q(-0.04154206),
  DSP16_Q(0.01520634),
  DSP16_Q(-0.00372318),
  DSP16_Q(0.00008220),
  DSP16_Q(0.00155662),
  DSP16_Q(-0.00942003),
  DSP16_Q(0.02828918),
  DSP16_Q(-0.07558452),
  DSP16_Q(0.53562964),
  DSP16_Q(0.12118092),
  DSP16_Q(-0.04103424),
  DSP16_Q(0.01501485),
  DSP16_Q(-0.00367013),
  DSP16_Q(0.00007946),
  DSP16_Q(0.00155003),
  DSP16_Q(-0.00935110),
  DSP16_Q(0.02806145),
  DSP16_Q(-0.07499510),
  DSP16_Q(0.53646626),
  DSP16_Q(0.11955968),
  DSP16_Q(-0.04052635),
  DSP16_Q(0.01482344),
  DSP16_Q(-0.00361725),
  DSP16_Q(0.00007677),
  DSP16_Q(0.00154319),
  DSP16_Q(-0.00928117),
  DSP16_Q(0.02783113),
  DSP16_Q(-0.07439867),
  DSP16_Q(0.53729385),
  DSP16_Q(0.11794226),
  DSP16_Q(-0.04001842),
  DSP16_Q(0.01463214),
  DSP16_Q(-0.00356455),
  DSP16_Q(0.00007414),
  DSP16_Q(0.00153612),
  DSP16_Q(-0.00921025),
  DSP16_Q(0.02759823),
  DSP16_Q(-0.07379525),
  DSP16_Q(0.53811238),
  DSP16_Q(0.11632870),
  DSP16_Q(-0.03951047),
  DSP16_Q(0.01444094),
  DSP16_Q(-0.00351202),
  DSP16_Q(0.00007157),
  DSP16_Q(0.00152880),
  DSP16_Q(-0.00913833),
  DSP16_Q(0.02736274),
  DSP16_Q(-0.07318481),
  DSP16_Q(0.53892183),
  DSP16_Q(0.11471905),
  DSP16_Q(-0.03900254),
  DSP16_Q(0.01424985),
  DSP16_Q(-0.00345966),
  DSP16_Q(0.00006906),
  DSP16_Q(0.00152123),
  DSP16_Q(-0.00906542),
  DSP16_Q(0.02712466),
  DSP16_Q(-0.07256737),
  DSP16_Q(0.53972216),
  DSP16_Q(0.11311334),
  DSP16_Q(-0.03849464),
  DSP16_Q(0.01405890),
  DSP16_Q(-0.00340749),
  DSP16_Q(0.00006660),
  DSP16_Q(0.00151342),
  DSP16_Q(-0.00899151),
  DSP16_Q(0.02688401),
  DSP16_Q(-0.07194291),
  DSP16_Q(0.54051335),
  DSP16_Q(0.11151161),
  DSP16_Q(-0.03798682),
  DSP16_Q(0.01386809),
  DSP16_Q(-0.00335550),
  DSP16_Q(0.00006420),
  DSP16_Q(0.00150536),
  DSP16_Q(-0.00891661),
  DSP16_Q(0.02664077),
  DSP16_Q(-0.07131143),
  DSP16_Q(0.54129538),
  DSP16_Q(0.10991391),
  DSP16_Q(-0.03747909),
  DSP16_Q(0.01367744),
  DSP16_Q(-0.00330370),
  DSP16_Q(0.00006185),
  DSP16_Q(0.00149705),
  DSP16_Q(-0.00884071),
  DSP16_Q(0.02639496),
  DSP16_Q(-0.07067293),
  DSP16_Q(0.54206821),
  DSP16_Q(0.10832027),
  DSP16_Q(-0.03697148),
  DSP16_Q(0.01348694),
  DSP16_Q(-0.00325208),
  DSP16_Q(0.00005956),
  DSP16_Q(0.00148848),
  DSP16_Q(-0.00876382),
  DSP16_Q(0.02614658),
  DSP16_Q(-0.07002740),
  DSP16_Q(0.54283182),
  DSP16_Q(0.10673073),
  DSP16_Q(-0.03646403),
  DSP16_Q(0.01329662),
  DSP16_Q(-0.00320066),
  DSP16_Q(0.00005733),
  DSP16_Q(0.00147967),
  DSP16_Q(-0.00868592),
  DSP16_Q(0.02589563),
  DSP16_Q(-0.06937484),
  DSP16_Q(0.54358619),
  DSP16_Q(0.10514534),
  DSP16_Q(-0.03595675),
  DSP16_Q(0.01310649),
  DSP16_Q(-0.00314943),
  DSP16_Q(0.00005515),
  DSP16_Q(0.00147060),
  DSP16_Q(-0.00860703),
  DSP16_Q(0.02564212),
  DSP16_Q(-0.06871525),
  DSP16_Q(0.54433128),
  DSP16_Q(0.10356413),
  DSP16_Q(-0.03544968),
  DSP16_Q(0.01291655),
  DSP16_Q(-0.00309840),
  DSP16_Q(0.00005302),
  DSP16_Q(0.00146127),
  DSP16_Q(-0.00852715),
  DSP16_Q(0.02538604),
  DSP16_Q(-0.06804863),
  DSP16_Q(0.54506708),
  DSP16_Q(0.10198714),
  DSP16_Q(-0.03494283),
  DSP16_Q(0.01272682),
  DSP16_Q(-0.00304757),
  DSP16_Q(0.00005095),
  DSP16_Q(0.00145169),
  DSP16_Q(-0.00844626),
  DSP16_Q(0.02512740),
  DSP16_Q(-0.06737497),
  DSP16_Q(0.54579355),
  DSP16_Q(0.10041441),
  DSP16_Q(-0.03443625),
  DSP16_Q(0.01253730),
  DSP16_Q(-0.00299694),
  DSP16_Q(0.00004893),
  DSP16_Q(0.00144185),
  DSP16_Q(-0.00836438),
  DSP16_Q(0.02486621),
  DSP16_Q(-0.06669428),
  DSP16_Q(0.54651068),
  DSP16_Q(0.09884598),
  DSP16_Q(-0.03392995),
  DSP16_Q(0.01234802),
  DSP16_Q(-0.00294652),
  DSP16_Q(0.00004696),
  DSP16_Q(0.00143175),
  DSP16_Q(-0.00828149),
  DSP16_Q(0.02460246),
  DSP16_Q(-0.06600654),
  DSP16_Q(0.54721843),
  DSP16_Q(0.09728189),
  DSP16_Q(-0.03342396),
  DSP16_Q(0.01215897),
  DSP16_Q(-0.00289631),
  DSP16_Q(0.00004504),
  DSP16_Q(0.00142138),
  DSP16_Q(-0.00819761),
  DSP16_Q(0.02433617),
  DSP16_Q(-0.06531176),
  DSP16_Q(0.54791678),
  DSP16_Q(0.09572217),
  DSP16_Q(-0.03291831),
  DSP16_Q(0.01197017),
  DSP16_Q(-0.00284630),
  DSP16_Q(0.00004318),
  DSP16_Q(0.00141076),
  DSP16_Q(-0.00811274),
  DSP16_Q(0.02406733),
  DSP16_Q(-0.06460994),
  DSP16_Q(0.54860572),
  DSP16_Q(0.09416687),
  DSP16_Q(-0.03241302),
  DSP16_Q(0.01178163),
  DSP16_Q(-0.00279651),
  DSP16_Q(0.00004136),
  DSP16_Q(0.00139987),
  DSP16_Q(-0.00802686),
  DSP16_Q(0.02379596),
  DSP16_Q(-0.06390108),
  DSP16_Q(0.54928521),
  DSP16_Q(0.09261601),
  DSP16_Q(-0.03190812),
  DSP16_Q(0.01159336),
  DSP16_Q(-0.00274694),
  DSP16_Q(0.00003959),
  DSP16_Q(0.00138871),
  DSP16_Q(-0.00793999),
  DSP16_Q(0.02352205),
  DSP16_Q(-0.06318518),
  DSP16_Q(0.54995523),
  DSP16_Q(0.09106964),
  DSP16_Q(-0.03140364),
  DSP16_Q(0.01140537),
  DSP16_Q(-0.00269758),
  DSP16_Q(0.00003788),
  DSP16_Q(0.00137729),
  DSP16_Q(-0.00785212),
  DSP16_Q(0.02324561),
  DSP16_Q(-0.06246223),
  DSP16_Q(0.55061576),
  DSP16_Q(0.08952780),
  DSP16_Q(-0.03089959),
  DSP16_Q(0.01121767),
  DSP16_Q(-0.00264844),
  DSP16_Q(0.00003621),
  DSP16_Q(0.00136560),
  DSP16_Q(-0.00776325),
  DSP16_Q(0.02296665),
  DSP16_Q(-0.06173224),
  DSP16_Q(0.55126678),
  DSP16_Q(0.08799052),
  DSP16_Q(-0.03039602),
  DSP16_Q(0.01103027),
  DSP16_Q(-0.00259953),
  DSP16_Q(0.00003459),
  DSP16_Q(0.00135364),
  DSP16_Q(-0.00767338),
  DSP16_Q(0.02268517),
  DSP16_Q(-0.06099521),
  DSP16_Q(0.55190826),
  DSP16_Q(0.08645784),
  DSP16_Q(-0.02989294),
  DSP16_Q(0.01084318),
  DSP16_Q(-0.00255084),
  DSP16_Q(0.00003302),
  DSP16_Q(0.00134141),
  DSP16_Q(-0.00758252),
  DSP16_Q(0.02240118),
  DSP16_Q(-0.06025113),
  DSP16_Q(0.55254018),
  DSP16_Q(0.08492980),
  DSP16_Q(-0.02939038),
  DSP16_Q(0.01065642),
  DSP16_Q(-0.00250238),
  DSP16_Q(0.00003150),
  DSP16_Q(0.00132891),
  DSP16_Q(-0.00749067),
  DSP16_Q(0.02211467),
  DSP16_Q(-0.05950001),
  DSP16_Q(0.55316253),
  DSP16_Q(0.08340642),
  DSP16_Q(-0.02888836),
  DSP16_Q(0.01046998),
  DSP16_Q(-0.00245415),
  DSP16_Q(0.00003002),
  DSP16_Q(0.00131613),
  DSP16_Q(-0.00739782),
  DSP16_Q(0.02182566),
  DSP16_Q(-0.05874186),
  DSP16_Q(0.55377527),
  DSP16_Q(0.08188775),
  DSP16_Q(-0.02838691),
  DSP16_Q(0.01028389),
  DSP16_Q(-0.00240614),
  DSP16_Q(0.00002859),
  DSP16_Q(0.00130308),
  DSP16_Q(-0.00730398),
  DSP16_Q(0.02153416),
  DSP16_Q(-0.05797666),
  DSP16_Q(0.55437839),
  DSP16_Q(0.08037383),
  DSP16_Q(-0.02788605),
  DSP16_Q(0.01009814),
  DSP16_Q(-0.00235838),
  DSP16_Q(0.00002720),
  DSP16_Q(0.00128976),
  DSP16_Q(-0.00720914),
  DSP16_Q(0.02124016),
  DSP16_Q(-0.05720443),
  DSP16_Q(0.55497186),
  DSP16_Q(0.07886468),
  DSP16_Q(-0.02738582),
  DSP16_Q(0.00991276),
  DSP16_Q(-0.00231085),
  DSP16_Q(0.00002586),
  DSP16_Q(0.00127616),
  DSP16_Q(-0.00711331),
  DSP16_Q(0.02094368),
  DSP16_Q(-0.05642516),
  DSP16_Q(0.55555568),
  DSP16_Q(0.07736035),
  DSP16_Q(-0.02688623),
  DSP16_Q(0.00972774),
  DSP16_Q(-0.00226356),
  DSP16_Q(0.00002457),
  DSP16_Q(0.00126228),
  DSP16_Q(-0.00701649),
  DSP16_Q(0.02064471),
  DSP16_Q(-0.05563886),
  DSP16_Q(0.55612981),
  DSP16_Q(0.07586086),
  DSP16_Q(-0.02638730),
  DSP16_Q(0.00954311),
  DSP16_Q(-0.00221651),
  DSP16_Q(0.00002331),
  DSP16_Q(0.00124812),
  DSP16_Q(-0.00691868),
  DSP16_Q(0.02034328),
  DSP16_Q(-0.05484554),
  DSP16_Q(0.55669424),
  DSP16_Q(0.07436626),
  DSP16_Q(-0.02588907),
  DSP16_Q(0.00935886),
  DSP16_Q(-0.00216970),
  DSP16_Q(0.00002210),
  DSP16_Q(0.00123368),
  DSP16_Q(-0.00681988),
  DSP16_Q(0.02003938),
  DSP16_Q(-0.05404518),
  DSP16_Q(0.55724894),
  DSP16_Q(0.07287657),
  DSP16_Q(-0.02539156),
  DSP16_Q(0.00917501),
  DSP16_Q(-0.00212313),
  DSP16_Q(0.00002093),
  DSP16_Q(0.00121896),
  DSP16_Q(-0.00672009),
  DSP16_Q(0.01973301),
  DSP16_Q(-0.05323780),
  DSP16_Q(0.55779390),
  DSP16_Q(0.07139184),
  DSP16_Q(-0.02489479),
  DSP16_Q(0.00899157),
  DSP16_Q(-0.00207682),
  DSP16_Q(0.00001980),
  DSP16_Q(0.00120396),
  DSP16_Q(-0.00661931),
  DSP16_Q(0.01942420),
  DSP16_Q(-0.05242341),
  DSP16_Q(0.55832910),
  DSP16_Q(0.06991209),
  DSP16_Q(-0.02439879),
  DSP16_Q(0.00880855),
  DSP16_Q(-0.00203075),
  DSP16_Q(0.00001871),
  DSP16_Q(0.00118867),
  DSP16_Q(-0.00651755),
  DSP16_Q(0.01911293),
  DSP16_Q(-0.05160199),
  DSP16_Q(0.55885453),
  DSP16_Q(0.06843736),
  DSP16_Q(-0.02390357),
  DSP16_Q(0.00862596),
  DSP16_Q(-0.00198493),
  DSP16_Q(0.00001767),
  DSP16_Q(0.00117310),
  DSP16_Q(-0.00641481),
  DSP16_Q(0.01879923),
  DSP16_Q(-0.05077356),
  DSP16_Q(0.55937015),
  DSP16_Q(0.06696769),
  DSP16_Q(-0.02340917),
  DSP16_Q(0.00844380),
  DSP16_Q(-0.00193936),
  DSP16_Q(0.00001666),
  DSP16_Q(0.00115725),
  DSP16_Q(-0.00631108),
  DSP16_Q(0.01848310),
  DSP16_Q(-0.04993813),
  DSP16_Q(0.55987596),
  DSP16_Q(0.06550310),
  DSP16_Q(-0.02291561),
  DSP16_Q(0.00826208),
  DSP16_Q(-0.00189405),
  DSP16_Q(0.00001569),
  DSP16_Q(0.00114111),
  DSP16_Q(-0.00620637),
  DSP16_Q(0.01816454),
  DSP16_Q(-0.04909569),
  DSP16_Q(0.56037194),
  DSP16_Q(0.06404363),
  DSP16_Q(-0.02242291),
  DSP16_Q(0.00808083),
  DSP16_Q(-0.00184900),
  DSP16_Q(0.00001475),
  DSP16_Q(0.00112468),
  DSP16_Q(-0.00610068),
  DSP16_Q(0.01784357),
  DSP16_Q(-0.04824626),
  DSP16_Q(0.56085807),
  DSP16_Q(0.06258931),
  DSP16_Q(-0.02193109),
  DSP16_Q(0.00790003),
  DSP16_Q(-0.00180420),
  DSP16_Q(0.00001386),
  DSP16_Q(0.00110796),
  DSP16_Q(-0.00599401),
  DSP16_Q(0.01752019),
  DSP16_Q(-0.04738983),
  DSP16_Q(0.56133433),
  DSP16_Q(0.06114017),
  DSP16_Q(-0.02144019),
  DSP16_Q(0.00771971),
  DSP16_Q(-0.00175966),
  DSP16_Q(0.00001300),
  DSP16_Q(0.00109096),
  DSP16_Q(-0.00588637),
  DSP16_Q(0.01719440),
  DSP16_Q(-0.04652641),
  DSP16_Q(0.56180071),
  DSP16_Q(0.05969625),
  DSP16_Q(-0.02095021),
  DSP16_Q(0.00753986),
  DSP16_Q(-0.00171539),
  DSP16_Q(0.00001218),
  DSP16_Q(0.00107366),
  DSP16_Q(-0.00577775),
  DSP16_Q(0.01686623),
  DSP16_Q(-0.04565601),
  DSP16_Q(0.56225720),
  DSP16_Q(0.05825758),
  DSP16_Q(-0.02046119),
  DSP16_Q(0.00736051),
  DSP16_Q(-0.00167138),
  DSP16_Q(0.00001139),
  DSP16_Q(0.00105607),
  DSP16_Q(-0.00566816),
  DSP16_Q(0.01653567),
  DSP16_Q(-0.04477864),
  DSP16_Q(0.56270376),
  DSP16_Q(0.05682418),
  DSP16_Q(-0.01997315),
  DSP16_Q(0.00718166),
  DSP16_Q(-0.00162763),
  DSP16_Q(0.00001064),
  DSP16_Q(0.00103819),
  DSP16_Q(-0.00555760),
  DSP16_Q(0.01620273),
  DSP16_Q(-0.04389430),
  DSP16_Q(0.56314040),
  DSP16_Q(0.05539610),
  DSP16_Q(-0.01948610),
  DSP16_Q(0.00700331),
  DSP16_Q(-0.00158415),
  DSP16_Q(0.00000992),
  DSP16_Q(0.00102002),
  DSP16_Q(-0.00544607),
  DSP16_Q(0.01586743),
  DSP16_Q(-0.04300299),
  DSP16_Q(0.56356710),
  DSP16_Q(0.05397336),
  DSP16_Q(-0.01900008),
  DSP16_Q(0.00682548),
  DSP16_Q(-0.00154094),
  DSP16_Q(0.00000923),
  DSP16_Q(0.00100155),
  DSP16_Q(-0.00533357),
  DSP16_Q(0.01552977),
  DSP16_Q(-0.04210473),
  DSP16_Q(0.56398383),
  DSP16_Q(0.05255600),
  DSP16_Q(-0.01851510),
  DSP16_Q(0.00664818),
  DSP16_Q(-0.00149799),
  DSP16_Q(0.00000858),
  DSP16_Q(0.00098279),
  DSP16_Q(-0.00522011),
  DSP16_Q(0.01518976),
  DSP16_Q(-0.04119952),
  DSP16_Q(0.56439059),
  DSP16_Q(0.05114403),
  DSP16_Q(-0.01803120),
  DSP16_Q(0.00647140),
  DSP16_Q(-0.00145532),
  DSP16_Q(0.00000795),
  DSP16_Q(0.00096374),
  DSP16_Q(-0.00510569),
  DSP16_Q(0.01484741),
  DSP16_Q(-0.04028737),
  DSP16_Q(0.56478736),
  DSP16_Q(0.04973750),
  DSP16_Q(-0.01754838),
  DSP16_Q(0.00629517),
  DSP16_Q(-0.00141292),
  DSP16_Q(0.00000736),
  DSP16_Q(0.00094439),
  DSP16_Q(-0.00499031),
  DSP16_Q(0.01450273),
  DSP16_Q(-0.03936829),
  DSP16_Q(0.56517413),
  DSP16_Q(0.04833644),
  DSP16_Q(-0.01706667),
  DSP16_Q(0.00611949),
  DSP16_Q(-0.00137080),
  DSP16_Q(0.00000680),
  DSP16_Q(0.00092474),
  DSP16_Q(-0.00487397),
  DSP16_Q(0.01415573),
  DSP16_Q(-0.03844228),
  DSP16_Q(0.56555089),
  DSP16_Q(0.04694086),
  DSP16_Q(-0.01658610),
  DSP16_Q(0.00594437),
  DSP16_Q(-0.00132895),
  DSP16_Q(0.00000627),
  DSP16_Q(0.00090479),
  DSP16_Q(-0.00475667),
  DSP16_Q(0.01380642),
  DSP16_Q(-0.03750935),
  DSP16_Q(0.56591761),
  DSP16_Q(0.04555081),
  DSP16_Q(-0.01610668),
  DSP16_Q(0.00576981),
  DSP16_Q(-0.00128738),
  DSP16_Q(0.00000576),
  DSP16_Q(0.00088455),
  DSP16_Q(-0.00463843),
  DSP16_Q(0.01345480),
  DSP16_Q(-0.03656952),
  DSP16_Q(0.56627430),
  DSP16_Q(0.04416632),
  DSP16_Q(-0.01562844),
  DSP16_Q(0.00559583),
  DSP16_Q(-0.00124608),
  DSP16_Q(0.00000528),
  DSP16_Q(0.00086400),
  DSP16_Q(-0.00451923),
  DSP16_Q(0.01310090),
  DSP16_Q(-0.03562279),
  DSP16_Q(0.56662093),
  DSP16_Q(0.04278740),
  DSP16_Q(-0.01515140),
  DSP16_Q(0.00542243),
  DSP16_Q(-0.00120507),
  DSP16_Q(0.00000483),
  DSP16_Q(0.00084316),
  DSP16_Q(-0.00439908),
  DSP16_Q(0.01274471),
  DSP16_Q(-0.03466916),
  DSP16_Q(0.56695750),
  DSP16_Q(0.04141410),
  DSP16_Q(-0.01467557),
  DSP16_Q(0.00524962),
  DSP16_Q(-0.00116434),
  DSP16_Q(0.00000441),
  DSP16_Q(0.00082202),
  DSP16_Q(-0.00427799),
  DSP16_Q(0.01238626),
  DSP16_Q(-0.03370866),
  DSP16_Q(0.56728399),
  DSP16_Q(0.04004643),
  DSP16_Q(-0.01420099),
  DSP16_Q(0.00507740),
  DSP16_Q(-0.00112389),
  DSP16_Q(0.00000401),
  DSP16_Q(0.00080057),
  DSP16_Q(-0.00415596),
  DSP16_Q(0.01202554),
  DSP16_Q(-0.03274129),
  DSP16_Q(0.56760040),
  DSP16_Q(0.03868443),
  DSP16_Q(-0.01372767),
  DSP16_Q(0.00490580),
  DSP16_Q(-0.00108372),
  DSP16_Q(0.00000364),
  DSP16_Q(0.00077883),
  DSP16_Q(-0.00403300),
  DSP16_Q(0.01166257),
  DSP16_Q(-0.03176706),
  DSP16_Q(0.56790670),
  DSP16_Q(0.03732812),
  DSP16_Q(-0.01325563),
  DSP16_Q(0.00473480),
  DSP16_Q(-0.00104384),
  DSP16_Q(0.00000329),
  DSP16_Q(0.00075678),
  DSP16_Q(-0.00390909),
  DSP16_Q(0.01129737),
  DSP16_Q(-0.03078597),
  DSP16_Q(0.56820290),
  DSP16_Q(0.03597754),
  DSP16_Q(-0.01278490),
  DSP16_Q(0.00456443),
  DSP16_Q(-0.00100425),
  DSP16_Q(0.00000296),
  DSP16_Q(0.00073443),
  DSP16_Q(-0.00378426),
  DSP16_Q(0.01092993),
  DSP16_Q(-0.02979805),
  DSP16_Q(0.56848897),
  DSP16_Q(0.03463270),
  DSP16_Q(-0.01231549),
  DSP16_Q(0.00439469),
  DSP16_Q(-0.00096494),
  DSP16_Q(0.00000266),
  DSP16_Q(0.00071178),
  DSP16_Q(-0.00365849),
  DSP16_Q(0.01056028),
  DSP16_Q(-0.02880330),
  DSP16_Q(0.56876492),
  DSP16_Q(0.03329364),
  DSP16_Q(-0.01184742),
  DSP16_Q(0.00422558),
  DSP16_Q(-0.00092592),
  DSP16_Q(0.00000238),
  DSP16_Q(0.00068882),
  DSP16_Q(-0.00353180),
  DSP16_Q(0.01018843),
  DSP16_Q(-0.02780173),
  DSP16_Q(0.56903073),
  DSP16_Q(0.03196039),
  DSP16_Q(-0.01138072),
  DSP16_Q(0.00405711),
  DSP16_Q(-0.00088719),
  DSP16_Q(0.00000211),
  DSP16_Q(0.00066556),
  DSP16_Q(-0.00340418),
  DSP16_Q(0.00981438),
  DSP16_Q(-0.02679336),
  DSP16_Q(0.56928639),
  DSP16_Q(0.03063296),
  DSP16_Q(-0.01091541),
  DSP16_Q(0.00388930),
  DSP16_Q(-0.00084875),
  DSP16_Q(0.00000187),
  DSP16_Q(0.00064200),
  DSP16_Q(-0.00327565),
  DSP16_Q(0.00943815),
  DSP16_Q(-0.02577820),
  DSP16_Q(0.56953189),
  DSP16_Q(0.02931139),
  DSP16_Q(-0.01045149),
  DSP16_Q(0.00372214),
  DSP16_Q(-0.00081060),
  DSP16_Q(0.00000165),
  DSP16_Q(0.00061813),
  DSP16_Q(-0.00314620),
  DSP16_Q(0.00905975),
  DSP16_Q(-0.02475625),
  DSP16_Q(0.56976723),
  DSP16_Q(0.02799571),
  DSP16_Q(-0.00998900),
  DSP16_Q(0.00355566),
  DSP16_Q(-0.00077274),
  DSP16_Q(0.00000144),
  DSP16_Q(0.00059396),
  DSP16_Q(-0.00301584),
  DSP16_Q(0.00867919),
  DSP16_Q(-0.02372753),
  DSP16_Q(0.56999239),
  DSP16_Q(0.02668593),
  DSP16_Q(-0.00952796),
  DSP16_Q(0.00338984),
  DSP16_Q(-0.00073518),
  DSP16_Q(0.00000126),
  DSP16_Q(0.00056948),
  DSP16_Q(-0.00288457),
  DSP16_Q(0.00829648),
  DSP16_Q(-0.02269206),
  DSP16_Q(0.57020738),
  DSP16_Q(0.02538208),
  DSP16_Q(-0.00906838),
  DSP16_Q(0.00322470),
  DSP16_Q(-0.00069791),
  DSP16_Q(0.00000109),
  DSP16_Q(0.00054469),
  DSP16_Q(-0.00275239),
  DSP16_Q(0.00791165),
  DSP16_Q(-0.02164985),
  DSP16_Q(0.57041217),
  DSP16_Q(0.02408419),
  DSP16_Q(-0.00861028),
  DSP16_Q(0.00306025),
  DSP16_Q(-0.00066094),
  DSP16_Q(0.00000093),
  DSP16_Q(0.00051960),
  DSP16_Q(-0.00261931),
  DSP16_Q(0.00752469),
  DSP16_Q(-0.02060091),
  DSP16_Q(0.57060677),
  DSP16_Q(0.02279229),
  DSP16_Q(-0.00815368),
  DSP16_Q(0.00289649),
  DSP16_Q(-0.00062426),
  DSP16_Q(0.00000079),
  DSP16_Q(0.00049420),
  DSP16_Q(-0.00248534),
  DSP16_Q(0.00713562),
  DSP16_Q(-0.01954525),
  DSP16_Q(0.57079116),
  DSP16_Q(0.02150639),
  DSP16_Q(-0.00769860),
  DSP16_Q(0.00273343),
  DSP16_Q(-0.00058788),
  DSP16_Q(0.00000067),
  DSP16_Q(0.00046850),
  DSP16_Q(-0.00235047),
  DSP16_Q(0.00674446),
  DSP16_Q(-0.01848289),
  DSP16_Q(0.57096535),
  DSP16_Q(0.02022652),
  DSP16_Q(-0.00724507),
  DSP16_Q(0.00257108),
  DSP16_Q(-0.00055180),
  DSP16_Q(0.00000056),
  DSP16_Q(0.00044249),
  DSP16_Q(-0.00221472),
  DSP16_Q(0.00635121),
  DSP16_Q(-0.01741384),
  DSP16_Q(0.57112932),
  DSP16_Q(0.01895271),
  DSP16_Q(-0.00679309),
  DSP16_Q(0.00240944),
  DSP16_Q(-0.00051602),
  DSP16_Q(0.00000046),
  DSP16_Q(0.00041617),
  DSP16_Q(-0.00207807),
  DSP16_Q(0.00595590),
  DSP16_Q(-0.01633811),
  DSP16_Q(0.57128307),
  DSP16_Q(0.01768498),
  DSP16_Q(-0.00634268),
  DSP16_Q(0.00224853),
  DSP16_Q(-0.00048053),
  DSP16_Q(0.00000038),
  DSP16_Q(0.00038954),
  DSP16_Q(-0.00194055),
  DSP16_Q(0.00555853),
  DSP16_Q(-0.01525573),
  DSP16_Q(0.57142659),
  DSP16_Q(0.01642336),
  DSP16_Q(-0.00589388),
  DSP16_Q(0.00208834),
  DSP16_Q(-0.00044535),
  DSP16_Q(0.00000030),
  DSP16_Q(0.00036261),
  DSP16_Q(-0.00180215),
  DSP16_Q(0.00515912),
  DSP16_Q(-0.01416671),
  DSP16_Q(0.57155989),
  DSP16_Q(0.01516786),
  DSP16_Q(-0.00544668),
  DSP16_Q(0.00192888),
  DSP16_Q(-0.00041047),
  DSP16_Q(0.00000024),
  DSP16_Q(0.00033537),
  DSP16_Q(-0.00166288),
  DSP16_Q(0.00475768),
  DSP16_Q(-0.01307106),
  DSP16_Q(0.57168295),
  DSP16_Q(0.01391850),
  DSP16_Q(-0.00500112),
  DSP16_Q(0.00177016),
  DSP16_Q(-0.00037588),
  DSP16_Q(0.00000018),
  DSP16_Q(0.00030782),
  DSP16_Q(-0.00152273),
  DSP16_Q(0.00435423),
  DSP16_Q(-0.01196879),
  DSP16_Q(0.57179576),
  DSP16_Q(0.01267532),
  DSP16_Q(-0.00455720),
  DSP16_Q(0.00161219),
  DSP16_Q(-0.00034160),
  DSP16_Q(0.00000014),
  DSP16_Q(0.00027997),
  DSP16_Q(-0.00138173),
  DSP16_Q(0.00394878),
  DSP16_Q(-0.01085993),
  DSP16_Q(0.57189834),
  DSP16_Q(0.01143834),
  DSP16_Q(-0.00411495),
  DSP16_Q(0.00145497),
  DSP16_Q(-0.00030762),
  DSP16_Q(0.00000010),
  DSP16_Q(0.00025180),
  DSP16_Q(-0.00123986),
  DSP16_Q(0.00354134),
  DSP16_Q(-0.00974449),
  DSP16_Q(0.57199066),
  DSP16_Q(0.01020757),
  DSP16_Q(-0.00367439),
  DSP16_Q(0.00129850),
  DSP16_Q(-0.00027395),
  DSP16_Q(0.00000007),
  DSP16_Q(0.00022333),
  DSP16_Q(-0.00109714),
  DSP16_Q(0.00313193),
  DSP16_Q(-0.00862249),
  DSP16_Q(0.57207274),
  DSP16_Q(0.00898304),
  DSP16_Q(-0.00323553),
  DSP16_Q(0.00114280),
  DSP16_Q(-0.00024057),
  DSP16_Q(0.00000005),
  DSP16_Q(0.00019456),
  DSP16_Q(-0.00095358),
  DSP16_Q(0.00272056),
  DSP16_Q(-0.00749394),
  DSP16_Q(0.57214456),
  DSP16_Q(0.00776477),
  DSP16_Q(-0.00279838),
  DSP16_Q(0.00098787),
  DSP16_Q(-0.00020751),
  DSP16_Q(0.00000003),
  DSP16_Q(0.00016547),
  DSP16_Q(-0.00080916),
  DSP16_Q(0.00230725),
  DSP16_Q(-0.00635886),
  DSP16_Q(0.57220613),
  DSP16_Q(0.00655277),
  DSP16_Q(-0.00236297),
  DSP16_Q(0.00083372),
  DSP16_Q(-0.00017474),
  DSP16_Q(0.00000002),
  DSP16_Q(0.00013608),
  DSP16_Q(-0.00066391),
  DSP16_Q(0.00189201),
  DSP16_Q(-0.00521727),
  DSP16_Q(0.57225744),
  DSP16_Q(0.00534708),
  DSP16_Q(-0.00192932),
  DSP16_Q(0.00068035),
  DSP16_Q(-0.00014228),
  DSP16_Q(0.00000001),
  DSP16_Q(0.00010637),
  DSP16_Q(-0.00051782),
  DSP16_Q(0.00147486),
  DSP16_Q(-0.00406918),
  DSP16_Q(0.57229849),
  DSP16_Q(0.00414771),
  DSP16_Q(-0.00149743),
  DSP16_Q(0.00052777),
  DSP16_Q(-0.00011013),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00007637),
  DSP16_Q(-0.00037090),
  DSP16_Q(0.00105582),
  DSP16_Q(-0.00291462),
  DSP16_Q(0.57232928),
  DSP16_Q(0.00295469),
  DSP16_Q(-0.00106733),
  DSP16_Q(0.00037597),
  DSP16_Q(-0.00007828),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00004605),
  DSP16_Q(-0.00022315),
  DSP16_Q(0.00063489),
  DSP16_Q(-0.00175360),
  DSP16_Q(0.57234980),
  DSP16_Q(0.00176802),
  DSP16_Q(-0.00063903),
  DSP16_Q(0.00022498),
  DSP16_Q(-0.00004674),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00001543),
  DSP16_Q(-0.00007459),
  DSP16_Q(0.00021209),
  DSP16_Q(-0.00058614),
  DSP16_Q(0.57236007),
  DSP16_Q(0.00058774),
  DSP16_Q(-0.00021255),
  DSP16_Q(0.00007479),
  DSP16_Q(-0.00001550),
  DSP16_Q(0.00000000)
};
