/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 32000 Hz
 *          - Output sampling frequency: 44000 Hz
 *          - Re-sampling order: 30
 *          - Coefficients are normalized
 *          - Memory foot print: 660 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 16000
 *          - Sampling frequency (fs_hz): ******
 *          - Actual FIR filter order (order): 330
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord30_32000_44000_norm[] = {
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00001458),
  DSP16_Q(0.00006214),
  DSP16_Q(-0.00014874),
  DSP16_Q(0.00028116),
  DSP16_Q(-0.00046747),
  DSP16_Q(0.00071799),
  DSP16_Q(-0.00104712),
  DSP16_Q(0.00147676),
  DSP16_Q(-0.00204322),
  DSP16_Q(0.00281250),
  DSP16_Q(-0.00391883),
  DSP16_Q(0.00568118),
  DSP16_Q(-0.00907747),
  DSP16_Q(0.01919887),
  DSP16_Q(0.40724733),
  DSP16_Q(-0.01749414),
  DSP16_Q(0.00863877),
  DSP16_Q(-0.00547738),
  DSP16_Q(0.00379822),
  DSP16_Q(-0.00273143),
  DSP16_Q(0.00198465),
  DSP16_Q(-0.00143274),
  DSP16_Q(0.00101345),
  DSP16_Q(-0.00069222),
  DSP16_Q(0.00044806),
  DSP16_Q(-0.00026703),
  DSP16_Q(0.00013908),
  DSP16_Q(-0.00005630),
  DSP16_Q(0.00001198),
  DSP16_Q(0.00000033),
  DSP16_Q(-0.00005095),
  DSP16_Q(0.00019938),
  DSP16_Q(-0.00046346),
  DSP16_Q(0.00086325),
  DSP16_Q(-0.00142275),
  DSP16_Q(0.00217289),
  DSP16_Q(-0.00315721),
  DSP16_Q(0.00444238),
  DSP16_Q(-0.00613985),
  DSP16_Q(0.00845413),
  DSP16_Q(-0.01180593),
  DSP16_Q(0.01721312),
  DSP16_Q(-0.02789762),
  DSP16_Q(0.06205371),
  DSP16_Q(0.39617749),
  DSP16_Q(-0.04687680),
  DSP16_Q(0.02404071),
  DSP16_Q(-0.01542551),
  DSP16_Q(0.01074881),
  DSP16_Q(-0.00774381),
  DSP16_Q(0.00562680),
  DSP16_Q(-0.00405682),
  DSP16_Q(0.00286230),
  DSP16_Q(-0.00194722),
  DSP16_Q(0.00125272),
  DSP16_Q(-0.00073949),
  DSP16_Q(0.00037888),
  DSP16_Q(-0.00014821),
  DSP16_Q(0.00002816),
  DSP16_Q(0.00000210),
  DSP16_Q(-0.00009482),
  DSP16_Q(0.00034417),
  DSP16_Q(-0.00077854),
  DSP16_Q(0.00142998),
  DSP16_Q(-0.00233705),
  DSP16_Q(0.00354991),
  DSP16_Q(-0.00513962),
  DSP16_Q(0.00721591),
  DSP16_Q(-0.00996372),
  DSP16_Q(0.01372547),
  DSP16_Q(-0.01921430),
  DSP16_Q(0.02818815),
  DSP16_Q(-0.04640413),
  DSP16_Q(0.10951000),
  DSP16_Q(0.37458414),
  DSP16_Q(-0.06825996),
  DSP16_Q(0.03618937),
  DSP16_Q(-0.02347561),
  DSP16_Q(0.01643193),
  DSP16_Q(-0.01185718),
  DSP16_Q(0.00861479),
  DSP16_Q(-0.00620240),
  DSP16_Q(0.00436450),
  DSP16_Q(-0.00295680),
  DSP16_Q(0.00189020),
  DSP16_Q(-0.00110469),
  DSP16_Q(0.00055623),
  DSP16_Q(-0.00020966),
  DSP16_Q(0.00003487),
  DSP16_Q(0.00000611),
  DSP16_Q(-0.00014209),
  DSP16_Q(0.00048246),
  DSP16_Q(-0.00106402),
  DSP16_Q(0.00192852),
  DSP16_Q(-0.00312652),
  DSP16_Q(0.00472430),
  DSP16_Q(-0.00681647),
  DSP16_Q(0.00955034),
  DSP16_Q(-0.01317610),
  DSP16_Q(0.01816148),
  DSP16_Q(-0.02549292),
  DSP16_Q(0.03765005),
  DSP16_Q(-0.06305493),
  DSP16_Q(0.15967033),
  DSP16_Q(0.34352760),
  DSP16_Q(-0.08143185),
  DSP16_Q(0.04445969),
  DSP16_Q(-0.02913139),
  DSP16_Q(0.02047536),
  DSP16_Q(-0.01479593),
  DSP16_Q(0.01074747),
  DSP16_Q(-0.00772616),
  DSP16_Q(0.00542162),
  DSP16_Q(-0.00365709),
  DSP16_Q(0.00232252),
  DSP16_Q(-0.00134323),
  DSP16_Q(0.00066397),
  DSP16_Q(-0.00024035),
  DSP16_Q(0.00003410),
  DSP16_Q(0.00001247),
  DSP16_Q(-0.00018711),
  DSP16_Q(0.00059854),
  DSP16_Q(-0.00128909),
  DSP16_Q(0.00230710),
  DSP16_Q(-0.00371146),
  DSP16_Q(0.00557996),
  DSP16_Q(-0.00802455),
  DSP16_Q(0.01122090),
  DSP16_Q(-0.01546979),
  DSP16_Q(0.02133900),
  DSP16_Q(-0.03004167),
  DSP16_Q(0.04469047),
  DSP16_Q(-0.07627943),
  DSP16_Q(0.21039831),
  DSP16_Q(0.30451950),
  DSP16_Q(-0.08664615),
  DSP16_Q(0.04855937),
  DSP16_Q(-0.03211286),
  DSP16_Q(0.02265719),
  DSP16_Q(-0.01639294),
  DSP16_Q(0.01190329),
  DSP16_Q(-0.00854316),
  DSP16_Q(0.00597752),
  DSP16_Q(-0.00401395),
  DSP16_Q(0.00253173),
  DSP16_Q(-0.00144828),
  DSP16_Q(0.00070202),
  DSP16_Q(-0.00024312),
  DSP16_Q(0.00002840),
  DSP16_Q(0.00002043),
  DSP16_Q(-0.00022317),
  DSP16_Q(0.00067651),
  DSP16_Q(-0.00142504),
  DSP16_Q(0.00251987),
  DSP16_Q(-0.00402375),
  DSP16_Q(0.00602019),
  DSP16_Q(-0.00863029),
  DSP16_Q(0.01204561),
  DSP16_Q(-0.01659686),
  DSP16_Q(0.02291445),
  DSP16_Q(-0.03236374),
  DSP16_Q(0.04852408),
  DSP16_Q(-0.08458203),
  DSP16_Q(0.25943397),
  DSP16_Q(0.25943397),
  DSP16_Q(-0.08458203),
  DSP16_Q(0.04852408),
  DSP16_Q(-0.03236374),
  DSP16_Q(0.02291445),
  DSP16_Q(-0.01659686),
  DSP16_Q(0.01204561),
  DSP16_Q(-0.00863029),
  DSP16_Q(0.00602019),
  DSP16_Q(-0.00402375),
  DSP16_Q(0.00251987),
  DSP16_Q(-0.00142504),
  DSP16_Q(0.00067651),
  DSP16_Q(-0.00022317),
  DSP16_Q(0.00002043),
  DSP16_Q(0.00002840),
  DSP16_Q(-0.00024312),
  DSP16_Q(0.00070202),
  DSP16_Q(-0.00144828),
  DSP16_Q(0.00253173),
  DSP16_Q(-0.00401395),
  DSP16_Q(0.00597752),
  DSP16_Q(-0.00854316),
  DSP16_Q(0.01190329),
  DSP16_Q(-0.01639294),
  DSP16_Q(0.02265719),
  DSP16_Q(-0.03211286),
  DSP16_Q(0.04855937),
  DSP16_Q(-0.08664615),
  DSP16_Q(0.30451950),
  DSP16_Q(0.21039831),
  DSP16_Q(-0.07627943),
  DSP16_Q(0.04469047),
  DSP16_Q(-0.03004167),
  DSP16_Q(0.02133900),
  DSP16_Q(-0.01546979),
  DSP16_Q(0.01122090),
  DSP16_Q(-0.00802455),
  DSP16_Q(0.00557996),
  DSP16_Q(-0.00371146),
  DSP16_Q(0.00230710),
  DSP16_Q(-0.00128909),
  DSP16_Q(0.00059854),
  DSP16_Q(-0.00018711),
  DSP16_Q(0.00001247),
  DSP16_Q(0.00003410),
  DSP16_Q(-0.00024035),
  DSP16_Q(0.00066397),
  DSP16_Q(-0.00134323),
  DSP16_Q(0.00232252),
  DSP16_Q(-0.00365709),
  DSP16_Q(0.00542162),
  DSP16_Q(-0.00772616),
  DSP16_Q(0.01074747),
  DSP16_Q(-0.01479593),
  DSP16_Q(0.02047536),
  DSP16_Q(-0.02913139),
  DSP16_Q(0.04445969),
  DSP16_Q(-0.08143185),
  DSP16_Q(0.34352760),
  DSP16_Q(0.15967033),
  DSP16_Q(-0.06305493),
  DSP16_Q(0.03765005),
  DSP16_Q(-0.02549292),
  DSP16_Q(0.01816148),
  DSP16_Q(-0.01317610),
  DSP16_Q(0.00955034),
  DSP16_Q(-0.00681647),
  DSP16_Q(0.00472430),
  DSP16_Q(-0.00312652),
  DSP16_Q(0.00192852),
  DSP16_Q(-0.00106402),
  DSP16_Q(0.00048246),
  DSP16_Q(-0.00014209),
  DSP16_Q(0.00000611),
  DSP16_Q(0.00003487),
  DSP16_Q(-0.00020966),
  DSP16_Q(0.00055623),
  DSP16_Q(-0.00110469),
  DSP16_Q(0.00189020),
  DSP16_Q(-0.00295680),
  DSP16_Q(0.00436450),
  DSP16_Q(-0.00620240),
  DSP16_Q(0.00861479),
  DSP16_Q(-0.01185718),
  DSP16_Q(0.01643193),
  DSP16_Q(-0.02347561),
  DSP16_Q(0.03618937),
  DSP16_Q(-0.06825996),
  DSP16_Q(0.37458414),
  DSP16_Q(0.10951000),
  DSP16_Q(-0.04640413),
  DSP16_Q(0.02818815),
  DSP16_Q(-0.01921430),
  DSP16_Q(0.01372547),
  DSP16_Q(-0.00996372),
  DSP16_Q(0.00721591),
  DSP16_Q(-0.00513962),
  DSP16_Q(0.00354991),
  DSP16_Q(-0.00233705),
  DSP16_Q(0.00142998),
  DSP16_Q(-0.00077854),
  DSP16_Q(0.00034417),
  DSP16_Q(-0.00009482),
  DSP16_Q(0.00000210),
  DSP16_Q(0.00002816),
  DSP16_Q(-0.00014821),
  DSP16_Q(0.00037888),
  DSP16_Q(-0.00073949),
  DSP16_Q(0.00125272),
  DSP16_Q(-0.00194722),
  DSP16_Q(0.00286230),
  DSP16_Q(-0.00405682),
  DSP16_Q(0.00562680),
  DSP16_Q(-0.00774381),
  DSP16_Q(0.01074881),
  DSP16_Q(-0.01542551),
  DSP16_Q(0.02404071),
  DSP16_Q(-0.04687680),
  DSP16_Q(0.39617749),
  DSP16_Q(0.06205371),
  DSP16_Q(-0.02789762),
  DSP16_Q(0.01721312),
  DSP16_Q(-0.01180593),
  DSP16_Q(0.00845413),
  DSP16_Q(-0.00613985),
  DSP16_Q(0.00444238),
  DSP16_Q(-0.00315721),
  DSP16_Q(0.00217289),
  DSP16_Q(-0.00142275),
  DSP16_Q(0.00086325),
  DSP16_Q(-0.00046346),
  DSP16_Q(0.00019938),
  DSP16_Q(-0.00005095),
  DSP16_Q(0.00000033),
  DSP16_Q(0.00001198),
  DSP16_Q(-0.00005630),
  DSP16_Q(0.00013908),
  DSP16_Q(-0.00026703),
  DSP16_Q(0.00044806),
  DSP16_Q(-0.00069222),
  DSP16_Q(0.00101345),
  DSP16_Q(-0.00143274),
  DSP16_Q(0.00198465),
  DSP16_Q(-0.00273143),
  DSP16_Q(0.00379822),
  DSP16_Q(-0.00547738),
  DSP16_Q(0.00863877),
  DSP16_Q(-0.01749414),
  DSP16_Q(0.40724733),
  DSP16_Q(0.01919887),
  DSP16_Q(-0.00907747),
  DSP16_Q(0.00568118),
  DSP16_Q(-0.00391883),
  DSP16_Q(0.00281250),
  DSP16_Q(-0.00204322),
  DSP16_Q(0.00147676),
  DSP16_Q(-0.00104712),
  DSP16_Q(0.00071799),
  DSP16_Q(-0.00046747),
  DSP16_Q(0.00028116),
  DSP16_Q(-0.00014874),
  DSP16_Q(0.00006214),
  DSP16_Q(-0.00001458),
  DSP16_Q(0.00000000)
};
