/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 32000 Hz
 *          - Output sampling frequency: 44100 Hz
 *          - Re-sampling order: 15
 *          - Coefficients are normalized
 *          - Memory foot print: 13230 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 16000
 *          - Sampling frequency (fs_hz): 14112000
 *          - Actual FIR filter order (order): 6615
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord15_32000_44100_norm[] = {
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00105534),
  DSP16_Q(-0.00477330),
  DSP16_Q(0.01218398),
  DSP16_Q(-0.02504148),
  DSP16_Q(0.04761447),
  DSP16_Q(-0.09572925),
  DSP16_Q(0.31448947),
  DSP16_Q(0.31303518),
  DSP16_Q(-0.09555514),
  DSP16_Q(0.04754521),
  DSP16_Q(-0.02500386),
  DSP16_Q(0.01216192),
  DSP16_Q(-0.00476115),
  DSP16_Q(0.00105026),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00106037),
  DSP16_Q(-0.00478521),
  DSP16_Q(0.01220544),
  DSP16_Q(-0.02507787),
  DSP16_Q(0.04768142),
  DSP16_Q(-0.09589899),
  DSP16_Q(0.31594087),
  DSP16_Q(0.31157804),
  DSP16_Q(-0.09537668),
  DSP16_Q(0.04747365),
  DSP16_Q(-0.02496502),
  DSP16_Q(0.01213928),
  DSP16_Q(-0.00474879),
  DSP16_Q(0.00104514),
  DSP16_Q(-0.00000002),
  DSP16_Q(0.00106537),
  DSP16_Q(-0.00479690),
  DSP16_Q(0.01222631),
  DSP16_Q(-0.02511303),
  DSP16_Q(0.04774605),
  DSP16_Q(-0.09606432),
  DSP16_Q(0.31738933),
  DSP16_Q(0.31011809),
  DSP16_Q(-0.09519389),
  DSP16_Q(0.04739981),
  DSP16_Q(-0.02492496),
  DSP16_Q(0.01211605),
  DSP16_Q(-0.00473620),
  DSP16_Q(0.00103999),
  DSP16_Q(-0.00000004),
  DSP16_Q(0.00107032),
  DSP16_Q(-0.00480837),
  DSP16_Q(0.01224658),
  DSP16_Q(-0.02514696),
  DSP16_Q(0.04780835),
  DSP16_Q(-0.09622522),
  DSP16_Q(0.31883480),
  DSP16_Q(0.30865538),
  DSP16_Q(-0.09500679),
  DSP16_Q(0.04732369),
  DSP16_Q(-0.02488370),
  DSP16_Q(0.01209224),
  DSP16_Q(-0.00472340),
  DSP16_Q(0.00103479),
  DSP16_Q(-0.00000008),
  DSP16_Q(0.00107524),
  DSP16_Q(-0.00481960),
  DSP16_Q(0.01226624),
  DSP16_Q(-0.02517964),
  DSP16_Q(0.04786831),
  DSP16_Q(-0.09638167),
  DSP16_Q(0.32027726),
  DSP16_Q(0.30718995),
  DSP16_Q(-0.09481541),
  DSP16_Q(0.04724530),
  DSP16_Q(-0.02484123),
  DSP16_Q(0.01206785),
  DSP16_Q(-0.00471038),
  DSP16_Q(0.00102956),
  DSP16_Q(-0.00000012),
  DSP16_Q(0.00108010),
  DSP16_Q(-0.00483061),
  DSP16_Q(0.01228531),
  DSP16_Q(-0.02521107),
  DSP16_Q(0.04792593),
  DSP16_Q(-0.09653365),
  DSP16_Q(0.32171664),
  DSP16_Q(0.30572185),
  DSP16_Q(-0.09461978),
  DSP16_Q(0.04716466),
  DSP16_Q(-0.02479756),
  DSP16_Q(0.01204288),
  DSP16_Q(-0.00469715),
  DSP16_Q(0.00102430),
  DSP16_Q(-0.00000017),
  DSP16_Q(0.00108493),
  DSP16_Q(-0.00484138),
  DSP16_Q(0.01230376),
  DSP16_Q(-0.02524125),
  DSP16_Q(0.04798118),
  DSP16_Q(-0.09668113),
  DSP16_Q(0.32315291),
  DSP16_Q(0.30425112),
  DSP16_Q(-0.09441991),
  DSP16_Q(0.04708177),
  DSP16_Q(-0.02475271),
  DSP16_Q(0.01201734),
  DSP16_Q(-0.00468370),
  DSP16_Q(0.00101899),
  DSP16_Q(-0.00000023),
  DSP16_Q(0.00108971),
  DSP16_Q(-0.00485191),
  DSP16_Q(0.01232160),
  DSP16_Q(-0.02527018),
  DSP16_Q(0.04803407),
  DSP16_Q(-0.09682409),
  DSP16_Q(0.32458603),
  DSP16_Q(0.30277780),
  DSP16_Q(-0.09421584),
  DSP16_Q(0.04699665),
  DSP16_Q(-0.02470667),
  DSP16_Q(0.01199123),
  DSP16_Q(-0.00467004),
  DSP16_Q(0.00101366),
  DSP16_Q(-0.00000031),
  DSP16_Q(0.00109444),
  DSP16_Q(-0.00486221),
  DSP16_Q(0.01233883),
  DSP16_Q(-0.02529783),
  DSP16_Q(0.04808458),
  DSP16_Q(-0.09696251),
  DSP16_Q(0.32601594),
  DSP16_Q(0.30130194),
  DSP16_Q(-0.09400759),
  DSP16_Q(0.04690930),
  DSP16_Q(-0.02465945),
  DSP16_Q(0.01196456),
  DSP16_Q(-0.00465617),
  DSP16_Q(0.00100828),
  DSP16_Q(-0.00000039),
  DSP16_Q(0.00109913),
  DSP16_Q(-0.00487227),
  DSP16_Q(0.01235543),
  DSP16_Q(-0.02532422),
  DSP16_Q(0.04813270),
  DSP16_Q(-0.09709635),
  DSP16_Q(0.32744261),
  DSP16_Q(0.29982358),
  DSP16_Q(-0.09379519),
  DSP16_Q(0.04681974),
  DSP16_Q(-0.02461105),
  DSP16_Q(0.01193733),
  DSP16_Q(-0.00464209),
  DSP16_Q(0.00100288),
  DSP16_Q(-0.00000048),
  DSP16_Q(0.00110377),
  DSP16_Q(-0.00488209),
  DSP16_Q(0.01237142),
  DSP16_Q(-0.02534933),
  DSP16_Q(0.04817843),
  DSP16_Q(-0.09722561),
  DSP16_Q(0.32886600),
  DSP16_Q(0.29834277),
  DSP16_Q(-0.09357865),
  DSP16_Q(0.04672798),
  DSP16_Q(-0.02456149),
  DSP16_Q(0.01190954),
  DSP16_Q(-0.00462781),
  DSP16_Q(0.00099744),
  DSP16_Q(-0.00000058),
  DSP16_Q(0.00110836),
  DSP16_Q(-0.00489167),
  DSP16_Q(0.01238678),
  DSP16_Q(-0.02537317),
  DSP16_Q(0.04822175),
  DSP16_Q(-0.09735025),
  DSP16_Q(0.33028606),
  DSP16_Q(0.29685955),
  DSP16_Q(-0.09335801),
  DSP16_Q(0.04663402),
  DSP16_Q(-0.02451077),
  DSP16_Q(0.01188119),
  DSP16_Q(-0.00461333),
  DSP16_Q(0.00099197),
  DSP16_Q(-0.00000069),
  DSP16_Q(0.00111291),
  DSP16_Q(-0.00490100),
  DSP16_Q(0.01240152),
  DSP16_Q(-0.02539572),
  DSP16_Q(0.04826266),
  DSP16_Q(-0.09747025),
  DSP16_Q(0.33170274),
  DSP16_Q(0.29537397),
  DSP16_Q(-0.09313329),
  DSP16_Q(0.04653789),
  DSP16_Q(-0.02445889),
  DSP16_Q(0.01185230),
  DSP16_Q(-0.00459864),
  DSP16_Q(0.00098647),
  DSP16_Q(-0.00000081),
  DSP16_Q(0.00111740),
  DSP16_Q(-0.00491009),
  DSP16_Q(0.01241562),
  DSP16_Q(-0.02541697),
  DSP16_Q(0.04830114),
  DSP16_Q(-0.09758559),
  DSP16_Q(0.33311601),
  DSP16_Q(0.29388607),
  DSP16_Q(-0.09290452),
  DSP16_Q(0.04643959),
  DSP16_Q(-0.02440586),
  DSP16_Q(0.01182285),
  DSP16_Q(-0.00458375),
  DSP16_Q(0.00098094),
  DSP16_Q(-0.00000093),
  DSP16_Q(0.00112185),
  DSP16_Q(-0.00491893),
  DSP16_Q(0.01242909),
  DSP16_Q(-0.02543694),
  DSP16_Q(0.04833718),
  DSP16_Q(-0.09769624),
  DSP16_Q(0.33452582),
  DSP16_Q(0.29239589),
  DSP16_Q(-0.09267172),
  DSP16_Q(0.04633913),
  DSP16_Q(-0.02435169),
  DSP16_Q(0.01179287),
  DSP16_Q(-0.00456867),
  DSP16_Q(0.00097538),
  DSP16_Q(-0.00000107),
  DSP16_Q(0.00112624),
  DSP16_Q(-0.00492752),
  DSP16_Q(0.01244193),
  DSP16_Q(-0.02545560),
  DSP16_Q(0.04837079),
  DSP16_Q(-0.09780220),
  DSP16_Q(0.33593213),
  DSP16_Q(0.29090348),
  DSP16_Q(-0.09243492),
  DSP16_Q(0.04623653),
  DSP16_Q(-0.02429639),
  DSP16_Q(0.01176234),
  DSP16_Q(-0.00455339),
  DSP16_Q(0.00096979),
  DSP16_Q(-0.00000122),
  DSP16_Q(0.00113058),
  DSP16_Q(-0.00493586),
  DSP16_Q(0.01245412),
  DSP16_Q(-0.02547296),
  DSP16_Q(0.04840194),
  DSP16_Q(-0.09790342),
  DSP16_Q(0.33733489),
  DSP16_Q(0.28940888),
  DSP16_Q(-0.09219414),
  DSP16_Q(0.04613179),
  DSP16_Q(-0.02423995),
  DSP16_Q(0.01173127),
  DSP16_Q(-0.00453792),
  DSP16_Q(0.00096417),
  DSP16_Q(-0.00000138),
  DSP16_Q(0.00113487),
  DSP16_Q(-0.00494395),
  DSP16_Q(0.01246568),
  DSP16_Q(-0.02548901),
  DSP16_Q(0.04843064),
  DSP16_Q(-0.09799989),
  DSP16_Q(0.33873407),
  DSP16_Q(0.28791214),
  DSP16_Q(-0.09194941),
  DSP16_Q(0.04602493),
  DSP16_Q(-0.02418240),
  DSP16_Q(0.01169968),
  DSP16_Q(-0.00452225),
  DSP16_Q(0.00095853),
  DSP16_Q(-0.00000154),
  DSP16_Q(0.00113911),
  DSP16_Q(-0.00495178),
  DSP16_Q(0.01247659),
  DSP16_Q(-0.02550375),
  DSP16_Q(0.04845686),
  DSP16_Q(-0.09809159),
  DSP16_Q(0.34012961),
  DSP16_Q(0.28641331),
  DSP16_Q(-0.09170076),
  DSP16_Q(0.04591596),
  DSP16_Q(-0.02412372),
  DSP16_Q(0.01166755),
  DSP16_Q(-0.00450639),
  DSP16_Q(0.00095285),
  DSP16_Q(-0.00000172),
  DSP16_Q(0.00114329),
  DSP16_Q(-0.00495936),
  DSP16_Q(0.01248685),
  DSP16_Q(-0.02551717),
  DSP16_Q(0.04848061),
  DSP16_Q(-0.09817849),
  DSP16_Q(0.34152149),
  DSP16_Q(0.28491242),
  DSP16_Q(-0.09144820),
  DSP16_Q(0.04580490),
  DSP16_Q(-0.02406394),
  DSP16_Q(0.01163490),
  DSP16_Q(-0.00449035),
  DSP16_Q(0.00094716),
  DSP16_Q(-0.00000190),
  DSP16_Q(0.00114742),
  DSP16_Q(-0.00496668),
  DSP16_Q(0.01249646),
  DSP16_Q(-0.02552926),
  DSP16_Q(0.04850188),
  DSP16_Q(-0.09826057),
  DSP16_Q(0.34290965),
  DSP16_Q(0.28340952),
  DSP16_Q(-0.09119178),
  DSP16_Q(0.04569174),
  DSP16_Q(-0.02400305),
  DSP16_Q(0.01160173),
  DSP16_Q(-0.00447412),
  DSP16_Q(0.00094143),
  DSP16_Q(-0.00000209),
  DSP16_Q(0.00115149),
  DSP16_Q(-0.00497374),
  DSP16_Q(0.01250541),
  DSP16_Q(-0.02554003),
  DSP16_Q(0.04852064),
  DSP16_Q(-0.09833782),
  DSP16_Q(0.34429405),
  DSP16_Q(0.28190466),
  DSP16_Q(-0.09093151),
  DSP16_Q(0.04557651),
  DSP16_Q(-0.02394106),
  DSP16_Q(0.01156804),
  DSP16_Q(-0.00445770),
  DSP16_Q(0.00093568),
  DSP16_Q(-0.00000230),
  DSP16_Q(0.00115550),
  DSP16_Q(-0.00498054),
  DSP16_Q(0.01251371),
  DSP16_Q(-0.02554946),
  DSP16_Q(0.04853691),
  DSP16_Q(-0.09841020),
  DSP16_Q(0.34567465),
  DSP16_Q(0.28039789),
  DSP16_Q(-0.09066742),
  DSP16_Q(0.04545921),
  DSP16_Q(-0.02387798),
  DSP16_Q(0.01153383),
  DSP16_Q(-0.00444110),
  DSP16_Q(0.00092991),
  DSP16_Q(-0.00000251),
  DSP16_Q(0.00115946),
  DSP16_Q(-0.00498708),
  DSP16_Q(0.01252135),
  DSP16_Q(-0.02555756),
  DSP16_Q(0.04855067),
  DSP16_Q(-0.09847770),
  DSP16_Q(0.34705141),
  DSP16_Q(0.27888923),
  DSP16_Q(-0.09039954),
  DSP16_Q(0.04533987),
  DSP16_Q(-0.02381382),
  DSP16_Q(0.01149912),
  DSP16_Q(-0.00442432),
  DSP16_Q(0.00092412),
  DSP16_Q(-0.00000273),
  DSP16_Q(0.00116336),
  DSP16_Q(-0.00499336),
  DSP16_Q(0.01252833),
  DSP16_Q(-0.02556431),
  DSP16_Q(0.04856191),
  DSP16_Q(-0.09854030),
  DSP16_Q(0.34842428),
  DSP16_Q(0.27737875),
  DSP16_Q(-0.09012789),
  DSP16_Q(0.04521849),
  DSP16_Q(-0.02374858),
  DSP16_Q(0.01146390),
  DSP16_Q(-0.00440736),
  DSP16_Q(0.00091830),
  DSP16_Q(-0.00000296),
  DSP16_Q(0.00116720),
  DSP16_Q(-0.00499936),
  DSP16_Q(0.01253464),
  DSP16_Q(-0.02556972),
  DSP16_Q(0.04857062),
  DSP16_Q(-0.09859797),
  DSP16_Q(0.34979323),
  DSP16_Q(0.27586648),
  DSP16_Q(-0.08985250),
  DSP16_Q(0.04509508),
  DSP16_Q(-0.02368227),
  DSP16_Q(0.01142817),
  DSP16_Q(-0.00439023),
  DSP16_Q(0.00091246),
  DSP16_Q(-0.00000319),
  DSP16_Q(0.00117098),
  DSP16_Q(-0.00500511),
  DSP16_Q(0.01254029),
  DSP16_Q(-0.02557378),
  DSP16_Q(0.04857680),
  DSP16_Q(-0.09865069),
  DSP16_Q(0.35115821),
  DSP16_Q(0.27435248),
  DSP16_Q(-0.08957340),
  DSP16_Q(0.04496965),
  DSP16_Q(-0.02361490),
  DSP16_Q(0.01139195),
  DSP16_Q(-0.00437292),
  DSP16_Q(0.00090660),
  DSP16_Q(-0.00000344),
  DSP16_Q(0.00117470),
  DSP16_Q(-0.00501058),
  DSP16_Q(0.01254527),
  DSP16_Q(-0.02557649),
  DSP16_Q(0.04858044),
  DSP16_Q(-0.09869845),
  DSP16_Q(0.35251918),
  DSP16_Q(0.27283677),
  DSP16_Q(-0.08929061),
  DSP16_Q(0.04484222),
  DSP16_Q(-0.02354647),
  DSP16_Q(0.01135523),
  DSP16_Q(-0.00435544),
  DSP16_Q(0.00090072),
  DSP16_Q(-0.00000370),
  DSP16_Q(0.00117836),
  DSP16_Q(-0.00501578),
  DSP16_Q(0.01254957),
  DSP16_Q(-0.02557783),
  DSP16_Q(0.04858153),
  DSP16_Q(-0.09874122),
  DSP16_Q(0.35387609),
  DSP16_Q(0.27131942),
  DSP16_Q(-0.08900417),
  DSP16_Q(0.04471281),
  DSP16_Q(-0.02347699),
  DSP16_Q(0.01131802),
  DSP16_Q(-0.00433779),
  DSP16_Q(0.00089482),
  DSP16_Q(-0.00000396),
  DSP16_Q(0.00118196),
  DSP16_Q(-0.00502071),
  DSP16_Q(0.01255320),
  DSP16_Q(-0.02557782),
  DSP16_Q(0.04858006),
  DSP16_Q(-0.09877898),
  DSP16_Q(0.35522892),
  DSP16_Q(0.26980046),
  DSP16_Q(-0.08871409),
  DSP16_Q(0.04458141),
  DSP16_Q(-0.02340646),
  DSP16_Q(0.01128033),
  DSP16_Q(-0.00431997),
  DSP16_Q(0.00088890),
  DSP16_Q(-0.00000423),
  DSP16_Q(0.00118549),
  DSP16_Q(-0.00502536),
  DSP16_Q(0.01255615),
  DSP16_Q(-0.02557644),
  DSP16_Q(0.04857603),
  DSP16_Q(-0.09881171),
  DSP16_Q(0.35657760),
  DSP16_Q(0.26827994),
  DSP16_Q(-0.08842040),
  DSP16_Q(0.04444805),
  DSP16_Q(-0.02333490),
  DSP16_Q(0.01124215),
  DSP16_Q(-0.00430198),
  DSP16_Q(0.00088296),
  DSP16_Q(-0.00000451),
  DSP16_Q(0.00118896),
  DSP16_Q(-0.00502974),
  DSP16_Q(0.01255842),
  DSP16_Q(-0.02557369),
  DSP16_Q(0.04856942),
  DSP16_Q(-0.09883938),
  DSP16_Q(0.35792211),
  DSP16_Q(0.26675790),
  DSP16_Q(-0.08812314),
  DSP16_Q(0.04431274),
  DSP16_Q(-0.02326231),
  DSP16_Q(0.01120349),
  DSP16_Q(-0.00428383),
  DSP16_Q(0.00087701),
  DSP16_Q(-0.00000480),
  DSP16_Q(0.00119237),
  DSP16_Q(-0.00503384),
  DSP16_Q(0.01256001),
  DSP16_Q(-0.02556956),
  DSP16_Q(0.04856024),
  DSP16_Q(-0.09886199),
  DSP16_Q(0.35926240),
  DSP16_Q(0.26523440),
  DSP16_Q(-0.08782232),
  DSP16_Q(0.04417549),
  DSP16_Q(-0.02318870),
  DSP16_Q(0.01116435),
  DSP16_Q(-0.00426551),
  DSP16_Q(0.00087104),
  DSP16_Q(-0.00000510),
  DSP16_Q(0.00119571),
  DSP16_Q(-0.00503767),
  DSP16_Q(0.01256091),
  DSP16_Q(-0.02556406),
  DSP16_Q(0.04854848),
  DSP16_Q(-0.09887951),
  DSP16_Q(0.36059844),
  DSP16_Q(0.26370946),
  DSP16_Q(-0.08751799),
  DSP16_Q(0.04403631),
  DSP16_Q(-0.02311407),
  DSP16_Q(0.01112475),
  DSP16_Q(-0.00424703),
  DSP16_Q(0.00086505),
  DSP16_Q(-0.00000541),
  DSP16_Q(0.00119899),
  DSP16_Q(-0.00504121),
  DSP16_Q(0.01256113),
  DSP16_Q(-0.02555717),
  DSP16_Q(0.04853412),
  DSP16_Q(-0.09889192),
  DSP16_Q(0.36193017),
  DSP16_Q(0.26218315),
  DSP16_Q(-0.08721015),
  DSP16_Q(0.04389522),
  DSP16_Q(-0.02303843),
  DSP16_Q(0.01108467),
  DSP16_Q(-0.00422840),
  DSP16_Q(0.00085905),
  DSP16_Q(-0.00000572),
  DSP16_Q(0.00120220),
  DSP16_Q(-0.00504447),
  DSP16_Q(0.01256065),
  DSP16_Q(-0.02554890),
  DSP16_Q(0.04851716),
  DSP16_Q(-0.09889919),
  DSP16_Q(0.36325756),
  DSP16_Q(0.26065549),
  DSP16_Q(-0.08689885),
  DSP16_Q(0.04375223),
  DSP16_Q(-0.02296179),
  DSP16_Q(0.01104413),
  DSP16_Q(-0.00420960),
  DSP16_Q(0.00085303),
  DSP16_Q(-0.00000604),
  DSP16_Q(0.00120534),
  DSP16_Q(-0.00504745),
  DSP16_Q(0.01255949),
  DSP16_Q(-0.02553924),
  DSP16_Q(0.04849759),
  DSP16_Q(-0.09890132),
  DSP16_Q(0.36458057),
  DSP16_Q(0.25912655),
  DSP16_Q(-0.08658410),
  DSP16_Q(0.04360735),
  DSP16_Q(-0.02288416),
  DSP16_Q(0.01100314),
  DSP16_Q(-0.00419066),
  DSP16_Q(0.00084700),
  DSP16_Q(-0.00000637),
  DSP16_Q(0.00120842),
  DSP16_Q(-0.00505015),
  DSP16_Q(0.01255762),
  DSP16_Q(-0.02552819),
  DSP16_Q(0.04847542),
  DSP16_Q(-0.09889827),
  DSP16_Q(0.36589915),
  DSP16_Q(0.25759635),
  DSP16_Q(-0.08626594),
  DSP16_Q(0.04346059),
  DSP16_Q(-0.02280554),
  DSP16_Q(0.01096168),
  DSP16_Q(-0.00417156),
  DSP16_Q(0.00084095),
  DSP16_Q(-0.00000671),
  DSP16_Q(0.00121142),
  DSP16_Q(-0.00505256),
  DSP16_Q(0.01255507),
  DSP16_Q(-0.02551574),
  DSP16_Q(0.04845062),
  DSP16_Q(-0.09889004),
  DSP16_Q(0.36721327),
  DSP16_Q(0.25606496),
  DSP16_Q(-0.08594439),
  DSP16_Q(0.04331197),
  DSP16_Q(-0.02272595),
  DSP16_Q(0.01091978),
  DSP16_Q(-0.00415230),
  DSP16_Q(0.00083490),
  DSP16_Q(-0.00000706),
  DSP16_Q(0.00121436),
  DSP16_Q(-0.00505468),
  DSP16_Q(0.01255181),
  DSP16_Q(-0.02550189),
  DSP16_Q(0.04842320),
  DSP16_Q(-0.09887660),
  DSP16_Q(0.36852288),
  DSP16_Q(0.25453240),
  DSP16_Q(-0.08561949),
  DSP16_Q(0.04316151),
  DSP16_Q(-0.02264537),
  DSP16_Q(0.01087742),
  DSP16_Q(-0.00413290),
  DSP16_Q(0.00082883),
  DSP16_Q(-0.00000741),
  DSP16_Q(0.00121722),
  DSP16_Q(-0.00505651),
  DSP16_Q(0.01254785),
  DSP16_Q(-0.02548664),
  DSP16_Q(0.04839315),
  DSP16_Q(-0.09885793),
  DSP16_Q(0.36982795),
  DSP16_Q(0.25299873),
  DSP16_Q(-0.08529125),
  DSP16_Q(0.04300920),
  DSP16_Q(-0.02256384),
  DSP16_Q(0.01083462),
  DSP16_Q(-0.00411335),
  DSP16_Q(0.00082274),
  DSP16_Q(-0.00000777),
  DSP16_Q(0.00122002),
  DSP16_Q(-0.00505805),
  DSP16_Q(0.01254319),
  DSP16_Q(-0.02546999),
  DSP16_Q(0.04836046),
  DSP16_Q(-0.09883401),
  DSP16_Q(0.37112843),
  DSP16_Q(0.25146400),
  DSP16_Q(-0.08495971),
  DSP16_Q(0.04285508),
  DSP16_Q(-0.02248134),
  DSP16_Q(0.01079139),
  DSP16_Q(-0.00409366),
  DSP16_Q(0.00081665),
  DSP16_Q(-0.00000814),
  DSP16_Q(0.00122274),
  DSP16_Q(-0.00505930),
  DSP16_Q(0.01253782),
  DSP16_Q(-0.02545192),
  DSP16_Q(0.04832513),
  DSP16_Q(-0.09880483),
  DSP16_Q(0.37242429),
  DSP16_Q(0.24992823),
  DSP16_Q(-0.08462489),
  DSP16_Q(0.04269914),
  DSP16_Q(-0.02239790),
  DSP16_Q(0.01074771),
  DSP16_Q(-0.00407383),
  DSP16_Q(0.00081055),
  DSP16_Q(-0.00000851),
  DSP16_Q(0.00122539),
  DSP16_Q(-0.00506026),
  DSP16_Q(0.01253174),
  DSP16_Q(-0.02543244),
  DSP16_Q(0.04828715),
  DSP16_Q(-0.09877036),
  DSP16_Q(0.37371548),
  DSP16_Q(0.24839150),
  DSP16_Q(-0.08428682),
  DSP16_Q(0.04254141),
  DSP16_Q(-0.02231351),
  DSP16_Q(0.01070361),
  DSP16_Q(-0.00405385),
  DSP16_Q(0.00080444),
  DSP16_Q(-0.00000890),
  DSP16_Q(0.00122797),
  DSP16_Q(-0.00506092),
  DSP16_Q(0.01252495),
  DSP16_Q(-0.02541155),
  DSP16_Q(0.04824651),
  DSP16_Q(-0.09873059),
  DSP16_Q(0.37500197),
  DSP16_Q(0.24685382),
  DSP16_Q(-0.08394554),
  DSP16_Q(0.04238190),
  DSP16_Q(-0.02222819),
  DSP16_Q(0.01065908),
  DSP16_Q(-0.00403373),
  DSP16_Q(0.00079832),
  DSP16_Q(-0.00000929),
  DSP16_Q(0.00123047),
  DSP16_Q(-0.00506129),
  DSP16_Q(0.01251746),
  DSP16_Q(-0.02538923),
  DSP16_Q(0.04820321),
  DSP16_Q(-0.09868550),
  DSP16_Q(0.37628370),
  DSP16_Q(0.24531526),
  DSP16_Q(-0.08360106),
  DSP16_Q(0.04222061),
  DSP16_Q(-0.02214194),
  DSP16_Q(0.01061412),
  DSP16_Q(-0.00401348),
  DSP16_Q(0.00079219),
  DSP16_Q(-0.00000968),
  DSP16_Q(0.00123289),
  DSP16_Q(-0.00506136),
  DSP16_Q(0.01250924),
  DSP16_Q(-0.02536550),
  DSP16_Q(0.04815725),
  DSP16_Q(-0.09863508),
  DSP16_Q(0.37756066),
  DSP16_Q(0.24377585),
  DSP16_Q(-0.08325342),
  DSP16_Q(0.04205758),
  DSP16_Q(-0.02205476),
  DSP16_Q(0.01056875),
  DSP16_Q(-0.00399309),
  DSP16_Q(0.00078606),
  DSP16_Q(-0.00001009),
  DSP16_Q(0.00123525),
  DSP16_Q(-0.00506113),
  DSP16_Q(0.01250031),
  DSP16_Q(-0.02534034),
  DSP16_Q(0.04810861),
  DSP16_Q(-0.09857929),
  DSP16_Q(0.37883278),
  DSP16_Q(0.24223564),
  DSP16_Q(-0.08290264),
  DSP16_Q(0.04189280),
  DSP16_Q(-0.02196668),
  DSP16_Q(0.01052296),
  DSP16_Q(-0.00397257),
  DSP16_Q(0.00077991),
  DSP16_Q(-0.00001050),
  DSP16_Q(0.00123752),
  DSP16_Q(-0.00506059),
  DSP16_Q(0.01249067),
  DSP16_Q(-0.02531375),
  DSP16_Q(0.04805730),
  DSP16_Q(-0.09851813),
  DSP16_Q(0.38010005),
  DSP16_Q(0.24069467),
  DSP16_Q(-0.08254875),
  DSP16_Q(0.04172629),
  DSP16_Q(-0.02187768),
  DSP16_Q(0.01047675),
  DSP16_Q(-0.00395191),
  DSP16_Q(0.00077376),
  DSP16_Q(-0.00001091),
  DSP16_Q(0.00123972),
  DSP16_Q(-0.00505976),
  DSP16_Q(0.01248030),
  DSP16_Q(-0.02528573),
  DSP16_Q(0.04800331),
  DSP16_Q(-0.09845158),
  DSP16_Q(0.38136240),
  DSP16_Q(0.23915299),
  DSP16_Q(-0.08219179),
  DSP16_Q(0.04155806),
  DSP16_Q(-0.02178779),
  DSP16_Q(0.01043015),
  DSP16_Q(-0.00393113),
  DSP16_Q(0.00076761),
  DSP16_Q(-0.00001134),
  DSP16_Q(0.00124184),
  DSP16_Q(-0.00505863),
  DSP16_Q(0.01246921),
  DSP16_Q(-0.02525628),
  DSP16_Q(0.04794663),
  DSP16_Q(-0.09837962),
  DSP16_Q(0.38261982),
  DSP16_Q(0.23761065),
  DSP16_Q(-0.08183177),
  DSP16_Q(0.04138814),
  DSP16_Q(-0.02169701),
  DSP16_Q(0.01038313),
  DSP16_Q(-0.00391022),
  DSP16_Q(0.00076145),
  DSP16_Q(-0.00001177),
  DSP16_Q(0.00124388),
  DSP16_Q(-0.00505719),
  DSP16_Q(0.01245740),
  DSP16_Q(-0.02522540),
  DSP16_Q(0.04788725),
  DSP16_Q(-0.09830223),
  DSP16_Q(0.38387225),
  DSP16_Q(0.23606768),
  DSP16_Q(-0.08146873),
  DSP16_Q(0.04121652),
  DSP16_Q(-0.02160534),
  DSP16_Q(0.01033572),
  DSP16_Q(-0.00388918),
  DSP16_Q(0.00075529),
  DSP16_Q(-0.00001220),
  DSP16_Q(0.00124584),
  DSP16_Q(-0.00505544),
  DSP16_Q(0.01244486),
  DSP16_Q(-0.02519307),
  DSP16_Q(0.04782518),
  DSP16_Q(-0.09821940),
  DSP16_Q(0.38511966),
  DSP16_Q(0.23452414),
  DSP16_Q(-0.08110270),
  DSP16_Q(0.04104324),
  DSP16_Q(-0.02151280),
  DSP16_Q(0.01028792),
  DSP16_Q(-0.00386802),
  DSP16_Q(0.00074912),
  DSP16_Q(-0.00001264),
  DSP16_Q(0.00124772),
  DSP16_Q(-0.00505339),
  DSP16_Q(0.01243160),
  DSP16_Q(-0.02515931),
  DSP16_Q(0.04776041),
  DSP16_Q(-0.09813110),
  DSP16_Q(0.38636201),
  DSP16_Q(0.23298006),
  DSP16_Q(-0.08073369),
  DSP16_Q(0.04086829),
  DSP16_Q(-0.02141939),
  DSP16_Q(0.01023972),
  DSP16_Q(-0.00384674),
  DSP16_Q(0.00074295),
  DSP16_Q(-0.00001309),
  DSP16_Q(0.00124952),
  DSP16_Q(-0.00505103),
  DSP16_Q(0.01241760),
  DSP16_Q(-0.02512410),
  DSP16_Q(0.04769294),
  DSP16_Q(-0.09803733),
  DSP16_Q(0.38759926),
  DSP16_Q(0.23143550),
  DSP16_Q(-0.08036176),
  DSP16_Q(0.04069170),
  DSP16_Q(-0.02132512),
  DSP16_Q(0.01019114),
  DSP16_Q(-0.00382534),
  DSP16_Q(0.00073678),
  DSP16_Q(-0.00001354),
  DSP16_Q(0.00125124),
  DSP16_Q(-0.00504836),
  DSP16_Q(0.01240288),
  DSP16_Q(-0.02508745),
  DSP16_Q(0.04762275),
  DSP16_Q(-0.09793806),
  DSP16_Q(0.38883137),
  DSP16_Q(0.22989049),
  DSP16_Q(-0.07998691),
  DSP16_Q(0.04051348),
  DSP16_Q(-0.02123000),
  DSP16_Q(0.01014218),
  DSP16_Q(-0.00380383),
  DSP16_Q(0.00073060),
  DSP16_Q(-0.00001400),
  DSP16_Q(0.00125287),
  DSP16_Q(-0.00504538),
  DSP16_Q(0.01238742),
  DSP16_Q(-0.02504935),
  DSP16_Q(0.04754985),
  DSP16_Q(-0.09783329),
  DSP16_Q(0.39005831),
  DSP16_Q(0.22834508),
  DSP16_Q(-0.07960918),
  DSP16_Q(0.04033364),
  DSP16_Q(-0.02113404),
  DSP16_Q(0.01009283),
  DSP16_Q(-0.00378219),
  DSP16_Q(0.00072443),
  DSP16_Q(-0.00001447),
  DSP16_Q(0.00125442),
  DSP16_Q(-0.00504209),
  DSP16_Q(0.01237123),
  DSP16_Q(-0.02500980),
  DSP16_Q(0.04747423),
  DSP16_Q(-0.09772298),
  DSP16_Q(0.39128003),
  DSP16_Q(0.22679931),
  DSP16_Q(-0.07922860),
  DSP16_Q(0.04015219),
  DSP16_Q(-0.02103723),
  DSP16_Q(0.01004312),
  DSP16_Q(-0.00376045),
  DSP16_Q(0.00071825),
  DSP16_Q(-0.00001494),
  DSP16_Q(0.00125589),
  DSP16_Q(-0.00503848),
  DSP16_Q(0.01235430),
  DSP16_Q(-0.02496880),
  DSP16_Q(0.04739588),
  DSP16_Q(-0.09760714),
  DSP16_Q(0.39249650),
  DSP16_Q(0.22525323),
  DSP16_Q(-0.07884519),
  DSP16_Q(0.03996916),
  DSP16_Q(-0.02093960),
  DSP16_Q(0.00999303),
  DSP16_Q(-0.00373859),
  DSP16_Q(0.00071208),
  DSP16_Q(-0.00001541),
  DSP16_Q(0.00125728),
  DSP16_Q(-0.00503456),
  DSP16_Q(0.01233664),
  DSP16_Q(-0.02492635),
  DSP16_Q(0.04731481),
  DSP16_Q(-0.09748573),
  DSP16_Q(0.39370768),
  DSP16_Q(0.22370689),
  DSP16_Q(-0.07845899),
  DSP16_Q(0.03978454),
  DSP16_Q(-0.02084114),
  DSP16_Q(0.00994258),
  DSP16_Q(-0.00371662),
  DSP16_Q(0.00070590),
  DSP16_Q(-0.00001589),
  DSP16_Q(0.00125857),
  DSP16_Q(-0.00503033),
  DSP16_Q(0.01231823),
  DSP16_Q(-0.02488244),
  DSP16_Q(0.04723101),
  DSP16_Q(-0.09735875),
  DSP16_Q(0.39491354),
  DSP16_Q(0.22216032),
  DSP16_Q(-0.07807002),
  DSP16_Q(0.03959837),
  DSP16_Q(-0.02074187),
  DSP16_Q(0.00989177),
  DSP16_Q(-0.00369455),
  DSP16_Q(0.00069972),
  DSP16_Q(-0.00001638),
  DSP16_Q(0.00125978),
  DSP16_Q(-0.00502578),
  DSP16_Q(0.01229909),
  DSP16_Q(-0.02483707),
  DSP16_Q(0.04714448),
  DSP16_Q(-0.09722617),
  DSP16_Q(0.39611402),
  DSP16_Q(0.22061357),
  DSP16_Q(-0.07767831),
  DSP16_Q(0.03941065),
  DSP16_Q(-0.02064180),
  DSP16_Q(0.00984060),
  DSP16_Q(-0.00367237),
  DSP16_Q(0.00069355),
  DSP16_Q(-0.00001687),
  DSP16_Q(0.00126091),
  DSP16_Q(-0.00502091),
  DSP16_Q(0.01227920),
  DSP16_Q(-0.02479024),
  DSP16_Q(0.04705520),
  DSP16_Q(-0.09708799),
  DSP16_Q(0.39730911),
  DSP16_Q(0.21906669),
  DSP16_Q(-0.07728390),
  DSP16_Q(0.03922140),
  DSP16_Q(-0.02054092),
  DSP16_Q(0.00978908),
  DSP16_Q(-0.00365009),
  DSP16_Q(0.00068738),
  DSP16_Q(-0.00001736),
  DSP16_Q(0.00126195),
  DSP16_Q(-0.00501572),
  DSP16_Q(0.01225857),
  DSP16_Q(-0.02474195),
  DSP16_Q(0.04696319),
  DSP16_Q(-0.09694419),
  DSP16_Q(0.39849875),
  DSP16_Q(0.21751972),
  DSP16_Q(-0.07688680),
  DSP16_Q(0.03903063),
  DSP16_Q(-0.02043926),
  DSP16_Q(0.00973721),
  DSP16_Q(-0.00362770),
  DSP16_Q(0.00068121),
  DSP16_Q(-0.00001786),
  DSP16_Q(0.00126290),
  DSP16_Q(-0.00501021),
  DSP16_Q(0.01223720),
  DSP16_Q(-0.02469220),
  DSP16_Q(0.04686843),
  DSP16_Q(-0.09679476),
  DSP16_Q(0.39968291),
  DSP16_Q(0.21597270),
  DSP16_Q(-0.07648706),
  DSP16_Q(0.03883836),
  DSP16_Q(-0.02033681),
  DSP16_Q(0.00968499),
  DSP16_Q(-0.00360522),
  DSP16_Q(0.00067505),
  DSP16_Q(-0.00001836),
  DSP16_Q(0.00126376),
  DSP16_Q(-0.00500438),
  DSP16_Q(0.01221508),
  DSP16_Q(-0.02464098),
  DSP16_Q(0.04677093),
  DSP16_Q(-0.09663967),
  DSP16_Q(0.40086156),
  DSP16_Q(0.21442568),
  DSP16_Q(-0.07608469),
  DSP16_Q(0.03864459),
  DSP16_Q(-0.02023359),
  DSP16_Q(0.00963244),
  DSP16_Q(-0.00358263),
  DSP16_Q(0.00066889),
  DSP16_Q(-0.00001887),
  DSP16_Q(0.00126453),
  DSP16_Q(-0.00499823),
  DSP16_Q(0.01219222),
  DSP16_Q(-0.02458830),
  DSP16_Q(0.04667067),
  DSP16_Q(-0.09647892),
  DSP16_Q(0.40203466),
  DSP16_Q(0.21287870),
  DSP16_Q(-0.07567972),
  DSP16_Q(0.03844935),
  DSP16_Q(-0.02012961),
  DSP16_Q(0.00957955),
  DSP16_Q(-0.00355996),
  DSP16_Q(0.00066273),
  DSP16_Q(-0.00001938),
  DSP16_Q(0.00126520),
  DSP16_Q(-0.00499176),
  DSP16_Q(0.01216860),
  DSP16_Q(-0.02453415),
  DSP16_Q(0.04656766),
  DSP16_Q(-0.09631248),
  DSP16_Q(0.40320217),
  DSP16_Q(0.21133180),
  DSP16_Q(-0.07527219),
  DSP16_Q(0.03825265),
  DSP16_Q(-0.02002486),
  DSP16_Q(0.00952633),
  DSP16_Q(-0.00353718),
  DSP16_Q(0.00065658),
  DSP16_Q(-0.00001989),
  DSP16_Q(0.00126579),
  DSP16_Q(-0.00498496),
  DSP16_Q(0.01214424),
  DSP16_Q(-0.02447853),
  DSP16_Q(0.04646190),
  DSP16_Q(-0.09614035),
  DSP16_Q(0.40436405),
  DSP16_Q(0.20978504),
  DSP16_Q(-0.07486213),
  DSP16_Q(0.03805450),
  DSP16_Q(-0.01991936),
  DSP16_Q(0.00947278),
  DSP16_Q(-0.00351432),
  DSP16_Q(0.00065044),
  DSP16_Q(-0.00002041),
  DSP16_Q(0.00126629),
  DSP16_Q(-0.00497783),
  DSP16_Q(0.01211912),
  DSP16_Q(-0.02442144),
  DSP16_Q(0.04635337),
  DSP16_Q(-0.09596252),
  DSP16_Q(0.40552027),
  DSP16_Q(0.20823845),
  DSP16_Q(-0.07444956),
  DSP16_Q(0.03785492),
  DSP16_Q(-0.01981313),
  DSP16_Q(0.00941891),
  DSP16_Q(-0.00349137),
  DSP16_Q(0.00064430),
  DSP16_Q(-0.00002093),
  DSP16_Q(0.00126669),
  DSP16_Q(-0.00497038),
  DSP16_Q(0.01209326),
  DSP16_Q(-0.02436288),
  DSP16_Q(0.04624209),
  DSP16_Q(-0.09577896),
  DSP16_Q(0.40667079),
  DSP16_Q(0.20669207),
  DSP16_Q(-0.07403451),
  DSP16_Q(0.03765392),
  DSP16_Q(-0.01970615),
  DSP16_Q(0.00936472),
  DSP16_Q(-0.00346833),
  DSP16_Q(0.00063817),
  DSP16_Q(-0.00002146),
  DSP16_Q(0.00126700),
  DSP16_Q(-0.00496260),
  DSP16_Q(0.01206664),
  DSP16_Q(-0.02430285),
  DSP16_Q(0.04612804),
  DSP16_Q(-0.09558966),
  DSP16_Q(0.40781558),
  DSP16_Q(0.20514595),
  DSP16_Q(-0.07361701),
  DSP16_Q(0.03745152),
  DSP16_Q(-0.01959845),
  DSP16_Q(0.00931021),
  DSP16_Q(-0.00344520),
  DSP16_Q(0.00063204),
  DSP16_Q(-0.00002198),
  DSP16_Q(0.00126722),
  DSP16_Q(-0.00495449),
  DSP16_Q(0.01203926),
  DSP16_Q(-0.02424135),
  DSP16_Q(0.04601123),
  DSP16_Q(-0.09539462),
  DSP16_Q(0.40895460),
  DSP16_Q(0.20360014),
  DSP16_Q(-0.07319709),
  DSP16_Q(0.03724773),
  DSP16_Q(-0.01949003),
  DSP16_Q(0.00925540),
  DSP16_Q(-0.00342199),
  DSP16_Q(0.00062593),
  DSP16_Q(-0.00002251),
  DSP16_Q(0.00126734),
  DSP16_Q(-0.00494606),
  DSP16_Q(0.01201113),
  DSP16_Q(-0.02417836),
  DSP16_Q(0.04589164),
  DSP16_Q(-0.09519381),
  DSP16_Q(0.41008782),
  DSP16_Q(0.20205468),
  DSP16_Q(-0.07277477),
  DSP16_Q(0.03704257),
  DSP16_Q(-0.01938090),
  DSP16_Q(0.00920028),
  DSP16_Q(-0.00339869),
  DSP16_Q(0.00061982),
  DSP16_Q(-0.00002304),
  DSP16_Q(0.00126737),
  DSP16_Q(-0.00493729),
  DSP16_Q(0.01198225),
  DSP16_Q(-0.02411391),
  DSP16_Q(0.04576929),
  DSP16_Q(-0.09498722),
  DSP16_Q(0.41121519),
  DSP16_Q(0.20050960),
  DSP16_Q(-0.07235010),
  DSP16_Q(0.03683604),
  DSP16_Q(-0.01927107),
  DSP16_Q(0.00914485),
  DSP16_Q(-0.00337532),
  DSP16_Q(0.00061372),
  DSP16_Q(-0.00002358),
  DSP16_Q(0.00126730),
  DSP16_Q(-0.00492819),
  DSP16_Q(0.01195261),
  DSP16_Q(-0.02404798),
  DSP16_Q(0.04564417),
  DSP16_Q(-0.09477485),
  DSP16_Q(0.41233669),
  DSP16_Q(0.19896496),
  DSP16_Q(-0.07192309),
  DSP16_Q(0.03662818),
  DSP16_Q(-0.01916055),
  DSP16_Q(0.00908913),
  DSP16_Q(-0.00335187),
  DSP16_Q(0.00060763),
  DSP16_Q(-0.00002412),
  DSP16_Q(0.00126713),
  DSP16_Q(-0.00491876),
  DSP16_Q(0.01192221),
  DSP16_Q(-0.02398057),
  DSP16_Q(0.04551628),
  DSP16_Q(-0.09455667),
  DSP16_Q(0.41345227),
  DSP16_Q(0.19742080),
  DSP16_Q(-0.07149378),
  DSP16_Q(0.03641898),
  DSP16_Q(-0.01904933),
  DSP16_Q(0.00903312),
  DSP16_Q(-0.00332834),
  DSP16_Q(0.00060155),
  DSP16_Q(-0.00002465),
  DSP16_Q(0.00126687),
  DSP16_Q(-0.00490899),
  DSP16_Q(0.01189105),
  DSP16_Q(-0.02391168),
  DSP16_Q(0.04538561),
  DSP16_Q(-0.09433268),
  DSP16_Q(0.41456191),
  DSP16_Q(0.19587716),
  DSP16_Q(-0.07106220),
  DSP16_Q(0.03620847),
  DSP16_Q(-0.01893744),
  DSP16_Q(0.00897682),
  DSP16_Q(-0.00330474),
  DSP16_Q(0.00059548),
  DSP16_Q(-0.00002519),
  DSP16_Q(0.00126651),
  DSP16_Q(-0.00489890),
  DSP16_Q(0.01185913),
  DSP16_Q(-0.02384131),
  DSP16_Q(0.04525216),
  DSP16_Q(-0.09410286),
  DSP16_Q(0.41566556),
  DSP16_Q(0.19433408),
  DSP16_Q(-0.07062836),
  DSP16_Q(0.03599666),
  DSP16_Q(-0.01882488),
  DSP16_Q(0.00892023),
  DSP16_Q(-0.00328106),
  DSP16_Q(0.00058942),
  DSP16_Q(-0.00002574),
  DSP16_Q(0.00126605),
  DSP16_Q(-0.00488846),
  DSP16_Q(0.01182645),
  DSP16_Q(-0.02376947),
  DSP16_Q(0.04511594),
  DSP16_Q(-0.09386720),
  DSP16_Q(0.41676320),
  DSP16_Q(0.19279161),
  DSP16_Q(-0.07019231),
  DSP16_Q(0.03578356),
  DSP16_Q(-0.01871166),
  DSP16_Q(0.00886337),
  DSP16_Q(-0.00325732),
  DSP16_Q(0.00058338),
  DSP16_Q(-0.00002628),
  DSP16_Q(0.00126549),
  DSP16_Q(-0.00487769),
  DSP16_Q(0.01179301),
  DSP16_Q(-0.02369614),
  DSP16_Q(0.04497693),
  DSP16_Q(-0.09362568),
  DSP16_Q(0.41785478),
  DSP16_Q(0.19124979),
  DSP16_Q(-0.06975408),
  DSP16_Q(0.03556920),
  DSP16_Q(-0.01859778),
  DSP16_Q(0.00880623),
  DSP16_Q(-0.00323350),
  DSP16_Q(0.00057734),
  DSP16_Q(-0.00002682),
  DSP16_Q(0.00126483),
  DSP16_Q(-0.00486659),
  DSP16_Q(0.01175881),
  DSP16_Q(-0.02362134),
  DSP16_Q(0.04483515),
  DSP16_Q(-0.09337831),
  DSP16_Q(0.41894028),
  DSP16_Q(0.18970866),
  DSP16_Q(-0.06931368),
  DSP16_Q(0.03535357),
  DSP16_Q(-0.01848326),
  DSP16_Q(0.00874881),
  DSP16_Q(-0.00320962),
  DSP16_Q(0.00057132),
  DSP16_Q(-0.00002737),
  DSP16_Q(0.00126406),
  DSP16_Q(-0.00485514),
  DSP16_Q(0.01172384),
  DSP16_Q(-0.02354506),
  DSP16_Q(0.04469059),
  DSP16_Q(-0.09312506),
  DSP16_Q(0.42001967),
  DSP16_Q(0.18816826),
  DSP16_Q(-0.06887116),
  DSP16_Q(0.03513671),
  DSP16_Q(-0.01836810),
  DSP16_Q(0.00869113),
  DSP16_Q(-0.00318567),
  DSP16_Q(0.00056531),
  DSP16_Q(-0.00002792),
  DSP16_Q(0.00126320),
  DSP16_Q(-0.00484336),
  DSP16_Q(0.01168812),
  DSP16_Q(-0.02346729),
  DSP16_Q(0.04454325),
  DSP16_Q(-0.09286592),
  DSP16_Q(0.42109289),
  DSP16_Q(0.18662865),
  DSP16_Q(-0.06842653),
  DSP16_Q(0.03491862),
  DSP16_Q(-0.01825232),
  DSP16_Q(0.00863319),
  DSP16_Q(-0.00316167),
  DSP16_Q(0.00055932),
  DSP16_Q(-0.00002846),
  DSP16_Q(0.00126224),
  DSP16_Q(-0.00483124),
  DSP16_Q(0.01165163),
  DSP16_Q(-0.02338805),
  DSP16_Q(0.04439313),
  DSP16_Q(-0.09260089),
  DSP16_Q(0.42215993),
  DSP16_Q(0.18508986),
  DSP16_Q(-0.06797983),
  DSP16_Q(0.03469932),
  DSP16_Q(-0.01813591),
  DSP16_Q(0.00857499),
  DSP16_Q(-0.00313760),
  DSP16_Q(0.00055334),
  DSP16_Q(-0.00002901),
  DSP16_Q(0.00126117),
  DSP16_Q(-0.00481878),
  DSP16_Q(0.01161437),
  DSP16_Q(-0.02330732),
  DSP16_Q(0.04424022),
  DSP16_Q(-0.09232995),
  DSP16_Q(0.42322075),
  DSP16_Q(0.18355193),
  DSP16_Q(-0.06753109),
  DSP16_Q(0.03447883),
  DSP16_Q(-0.01801889),
  DSP16_Q(0.00851653),
  DSP16_Q(-0.00311347),
  DSP16_Q(0.00054737),
  DSP16_Q(-0.00002956),
  DSP16_Q(0.00126000),
  DSP16_Q(-0.00480598),
  DSP16_Q(0.01157635),
  DSP16_Q(-0.02322512),
  DSP16_Q(0.04408454),
  DSP16_Q(-0.09205309),
  DSP16_Q(0.42427531),
  DSP16_Q(0.18201491),
  DSP16_Q(-0.06708034),
  DSP16_Q(0.03425715),
  DSP16_Q(-0.01790126),
  DSP16_Q(0.00845782),
  DSP16_Q(-0.00308928),
  DSP16_Q(0.00054142),
  DSP16_Q(-0.00003010),
  DSP16_Q(0.00125873),
  DSP16_Q(-0.00479284),
  DSP16_Q(0.01153757),
  DSP16_Q(-0.02314143),
  DSP16_Q(0.04392607),
  DSP16_Q(-0.09177029),
  DSP16_Q(0.42532359),
  DSP16_Q(0.18047883),
  DSP16_Q(-0.06662761),
  DSP16_Q(0.03403431),
  DSP16_Q(-0.01778304),
  DSP16_Q(0.00839887),
  DSP16_Q(-0.00306504),
  DSP16_Q(0.00053548),
  DSP16_Q(-0.00003065),
  DSP16_Q(0.00125735),
  DSP16_Q(-0.00477935),
  DSP16_Q(0.01149802),
  DSP16_Q(-0.02305626),
  DSP16_Q(0.04376482),
  DSP16_Q(-0.09148156),
  DSP16_Q(0.42636554),
  DSP16_Q(0.17894375),
  DSP16_Q(-0.06617291),
  DSP16_Q(0.03381032),
  DSP16_Q(-0.01766423),
  DSP16_Q(0.00833968),
  DSP16_Q(-0.00304074),
  DSP16_Q(0.00052956),
  DSP16_Q(-0.00003120),
  DSP16_Q(0.00125586),
  DSP16_Q(-0.00476552),
  DSP16_Q(0.01145770),
  DSP16_Q(-0.02296962),
  DSP16_Q(0.04360078),
  DSP16_Q(-0.09118688),
  DSP16_Q(0.42740114),
  DSP16_Q(0.17740970),
  DSP16_Q(-0.06571630),
  DSP16_Q(0.03358519),
  DSP16_Q(-0.01754483),
  DSP16_Q(0.00828025),
  DSP16_Q(-0.00301640),
  DSP16_Q(0.00052365),
  DSP16_Q(-0.00003174),
  DSP16_Q(0.00125427),
  DSP16_Q(-0.00475135),
  DSP16_Q(0.01141662),
  DSP16_Q(-0.02288149),
  DSP16_Q(0.04343397),
  DSP16_Q(-0.09088623),
  DSP16_Q(0.42843035),
  DSP16_Q(0.17587673),
  DSP16_Q(-0.06525779),
  DSP16_Q(0.03335894),
  DSP16_Q(-0.01742487),
  DSP16_Q(0.00822058),
  DSP16_Q(-0.00299200),
  DSP16_Q(0.00051776),
  DSP16_Q(-0.00003229),
  DSP16_Q(0.00125258),
  DSP16_Q(-0.00473684),
  DSP16_Q(0.01137477),
  DSP16_Q(-0.02279189),
  DSP16_Q(0.04326437),
  DSP16_Q(-0.09057961),
  DSP16_Q(0.42945314),
  DSP16_Q(0.17434488),
  DSP16_Q(-0.06479740),
  DSP16_Q(0.03313159),
  DSP16_Q(-0.01730435),
  DSP16_Q(0.00816069),
  DSP16_Q(-0.00296756),
  DSP16_Q(0.00051189),
  DSP16_Q(-0.00003283),
  DSP16_Q(0.00125078),
  DSP16_Q(-0.00472198),
  DSP16_Q(0.01133215),
  DSP16_Q(-0.02270081),
  DSP16_Q(0.04309199),
  DSP16_Q(-0.09026702),
  DSP16_Q(0.43046948),
  DSP16_Q(0.17281418),
  DSP16_Q(-0.06433519),
  DSP16_Q(0.03290314),
  DSP16_Q(-0.01718327),
  DSP16_Q(0.00810057),
  DSP16_Q(-0.00294307),
  DSP16_Q(0.00050604),
  DSP16_Q(-0.00003337),
  DSP16_Q(0.00124886),
  DSP16_Q(-0.00470677),
  DSP16_Q(0.01128877),
  DSP16_Q(-0.02260825),
  DSP16_Q(0.04291683),
  DSP16_Q(-0.08994843),
  DSP16_Q(0.43147934),
  DSP16_Q(0.17128469),
  DSP16_Q(-0.06387116),
  DSP16_Q(0.03267362),
  DSP16_Q(-0.01706164),
  DSP16_Q(0.00804024),
  DSP16_Q(-0.00291853),
  DSP16_Q(0.00050020),
  DSP16_Q(-0.00003391),
  DSP16_Q(0.00124685),
  DSP16_Q(-0.00469122),
  DSP16_Q(0.01124462),
  DSP16_Q(-0.02251421),
  DSP16_Q(0.04273890),
  DSP16_Q(-0.08962384),
  DSP16_Q(0.43248268),
  DSP16_Q(0.16975644),
  DSP16_Q(-0.06340535),
  DSP16_Q(0.03244304),
  DSP16_Q(-0.01693947),
  DSP16_Q(0.00797968),
  DSP16_Q(-0.00289395),
  DSP16_Q(0.00049439),
  DSP16_Q(-0.00003445),
  DSP16_Q(0.00124472),
  DSP16_Q(-0.00467533),
  DSP16_Q(0.01119971),
  DSP16_Q(-0.02241869),
  DSP16_Q(0.04255818),
  DSP16_Q(-0.08929325),
  DSP16_Q(0.43347947),
  DSP16_Q(0.16822948),
  DSP16_Q(-0.06293779),
  DSP16_Q(0.03221141),
  DSP16_Q(-0.01681678),
  DSP16_Q(0.00791892),
  DSP16_Q(-0.00286934),
  DSP16_Q(0.00048859),
  DSP16_Q(-0.00003498),
  DSP16_Q(0.00124248),
  DSP16_Q(-0.00465908),
  DSP16_Q(0.01115402),
  DSP16_Q(-0.02232170),
  DSP16_Q(0.04237469),
  DSP16_Q(-0.08895664),
  DSP16_Q(0.43446968),
  DSP16_Q(0.16670384),
  DSP16_Q(-0.06246851),
  DSP16_Q(0.03197876),
  DSP16_Q(-0.01669356),
  DSP16_Q(0.00785795),
  DSP16_Q(-0.00284468),
  DSP16_Q(0.00048281),
  DSP16_Q(-0.00003552),
  DSP16_Q(0.00124013),
  DSP16_Q(-0.00464249),
  DSP16_Q(0.01110757),
  DSP16_Q(-0.02222324),
  DSP16_Q(0.04218842),
  DSP16_Q(-0.08861400),
  DSP16_Q(0.43545328),
  DSP16_Q(0.16517958),
  DSP16_Q(-0.06199754),
  DSP16_Q(0.03174509),
  DSP16_Q(-0.01656983),
  DSP16_Q(0.00779677),
  DSP16_Q(-0.00281999),
  DSP16_Q(0.00047705),
  DSP16_Q(-0.00003605),
  DSP16_Q(0.00123768),
  DSP16_Q(-0.00462555),
  DSP16_Q(0.01106035),
  DSP16_Q(-0.02212330),
  DSP16_Q(0.04199938),
  DSP16_Q(-0.08826533),
  DSP16_Q(0.43643024),
  DSP16_Q(0.16365672),
  DSP16_Q(-0.06152491),
  DSP16_Q(0.03151041),
  DSP16_Q(-0.01644559),
  DSP16_Q(0.00773540),
  DSP16_Q(-0.00279526),
  DSP16_Q(0.00047131),
  DSP16_Q(-0.00003658),
  DSP16_Q(0.00123511),
  DSP16_Q(-0.00460826),
  DSP16_Q(0.01101237),
  DSP16_Q(-0.02202189),
  DSP16_Q(0.04180756),
  DSP16_Q(-0.08791062),
  DSP16_Q(0.43740053),
  DSP16_Q(0.16213532),
  DSP16_Q(-0.06105064),
  DSP16_Q(0.03127476),
  DSP16_Q(-0.01632086),
  DSP16_Q(0.00767383),
  DSP16_Q(-0.00277050),
  DSP16_Q(0.00046559),
  DSP16_Q(-0.00003710),
  DSP16_Q(0.00123243),
  DSP16_Q(-0.00459062),
  DSP16_Q(0.01096362),
  DSP16_Q(-0.02191901),
  DSP16_Q(0.04161298),
  DSP16_Q(-0.08754986),
  DSP16_Q(0.43836411),
  DSP16_Q(0.16061541),
  DSP16_Q(-0.06057476),
  DSP16_Q(0.03103813),
  DSP16_Q(-0.01619563),
  DSP16_Q(0.00761208),
  DSP16_Q(-0.00274570),
  DSP16_Q(0.00045990),
  DSP16_Q(-0.00003762),
  DSP16_Q(0.00122963),
  DSP16_Q(-0.00457264),
  DSP16_Q(0.01091410),
  DSP16_Q(-0.02181465),
  DSP16_Q(0.04141562),
  DSP16_Q(-0.08718304),
  DSP16_Q(0.43932096),
  DSP16_Q(0.15909703),
  DSP16_Q(-0.06009731),
  DSP16_Q(0.03080055),
  DSP16_Q(-0.01606993),
  DSP16_Q(0.00755014),
  DSP16_Q(-0.00272088),
  DSP16_Q(0.00045422),
  DSP16_Q(-0.00003814),
  DSP16_Q(0.00122673),
  DSP16_Q(-0.00455430),
  DSP16_Q(0.01086381),
  DSP16_Q(-0.02170883),
  DSP16_Q(0.04121550),
  DSP16_Q(-0.08681015),
  DSP16_Q(0.44027105),
  DSP16_Q(0.15758022),
  DSP16_Q(-0.05961831),
  DSP16_Q(0.03056204),
  DSP16_Q(-0.01594376),
  DSP16_Q(0.00748801),
  DSP16_Q(-0.00269603),
  DSP16_Q(0.00044857),
  DSP16_Q(-0.00003865),
  DSP16_Q(0.00122371),
  DSP16_Q(-0.00453561),
  DSP16_Q(0.01081276),
  DSP16_Q(-0.02160154),
  DSP16_Q(0.04101261),
  DSP16_Q(-0.08643119),
  DSP16_Q(0.44121434),
  DSP16_Q(0.15606504),
  DSP16_Q(-0.05913779),
  DSP16_Q(0.03032259),
  DSP16_Q(-0.01581712),
  DSP16_Q(0.00742571),
  DSP16_Q(-0.00267115),
  DSP16_Q(0.00044293),
  DSP16_Q(-0.00003916),
  DSP16_Q(0.00122058),
  DSP16_Q(-0.00451657),
  DSP16_Q(0.01076094),
  DSP16_Q(-0.02149279),
  DSP16_Q(0.04080696),
  DSP16_Q(-0.08604615),
  DSP16_Q(0.44215080),
  DSP16_Q(0.15455151),
  DSP16_Q(-0.05865578),
  DSP16_Q(0.03008224),
  DSP16_Q(-0.01569002),
  DSP16_Q(0.00736324),
  DSP16_Q(-0.00264625),
  DSP16_Q(0.00043733),
  DSP16_Q(-0.00003967),
  DSP16_Q(0.00121733),
  DSP16_Q(-0.00449718),
  DSP16_Q(0.01070836),
  DSP16_Q(-0.02138257),
  DSP16_Q(0.04059854),
  DSP16_Q(-0.08565503),
  DSP16_Q(0.44308041),
  DSP16_Q(0.15303967),
  DSP16_Q(-0.05817232),
  DSP16_Q(0.02984100),
  DSP16_Q(-0.01556248),
  DSP16_Q(0.00730059),
  DSP16_Q(-0.00262133),
  DSP16_Q(0.00043174),
  DSP16_Q(-0.00004017),
  DSP16_Q(0.00121397),
  DSP16_Q(-0.00447744),
  DSP16_Q(0.01065501),
  DSP16_Q(-0.02127088),
  DSP16_Q(0.04038737),
  DSP16_Q(-0.08525781),
  DSP16_Q(0.44400314),
  DSP16_Q(0.15152958),
  DSP16_Q(-0.05768742),
  DSP16_Q(0.02959888),
  DSP16_Q(-0.01543450),
  DSP16_Q(0.00723779),
  DSP16_Q(-0.00259639),
  DSP16_Q(0.00042617),
  DSP16_Q(-0.00004067),
  DSP16_Q(0.00121049),
  DSP16_Q(-0.00445735),
  DSP16_Q(0.01060090),
  DSP16_Q(-0.02115774),
  DSP16_Q(0.04017345),
  DSP16_Q(-0.08485449),
  DSP16_Q(0.44491895),
  DSP16_Q(0.15002126),
  DSP16_Q(-0.05720112),
  DSP16_Q(0.02935589),
  DSP16_Q(-0.01530609),
  DSP16_Q(0.00717482),
  DSP16_Q(-0.00257142),
  DSP16_Q(0.00042063),
  DSP16_Q(-0.00004116),
  DSP16_Q(0.00120690),
  DSP16_Q(-0.00443690),
  DSP16_Q(0.01054602),
  DSP16_Q(-0.02104314),
  DSP16_Q(0.03995677),
  DSP16_Q(-0.08444507),
  DSP16_Q(0.44582782),
  DSP16_Q(0.14851477),
  DSP16_Q(-0.05671344),
  DSP16_Q(0.02911206),
  DSP16_Q(-0.01517726),
  DSP16_Q(0.00711169),
  DSP16_Q(-0.00254644),
  DSP16_Q(0.00041512),
  DSP16_Q(-0.00004164),
  DSP16_Q(0.00120319),
  DSP16_Q(-0.00441610),
  DSP16_Q(0.01049038),
  DSP16_Q(-0.02092708),
  DSP16_Q(0.03973735),
  DSP16_Q(-0.08402953),
  DSP16_Q(0.44672972),
  DSP16_Q(0.14701013),
  DSP16_Q(-0.05622442),
  DSP16_Q(0.02886740),
  DSP16_Q(-0.01504801),
  DSP16_Q(0.00704842),
  DSP16_Q(-0.00252145),
  DSP16_Q(0.00040963),
  DSP16_Q(-0.00004212),
  DSP16_Q(0.00119936),
  DSP16_Q(-0.00439495),
  DSP16_Q(0.01043398),
  DSP16_Q(-0.02080956),
  DSP16_Q(0.03951518),
  DSP16_Q(-0.08360787),
  DSP16_Q(0.44762462),
  DSP16_Q(0.14550739),
  DSP16_Q(-0.05573409),
  DSP16_Q(0.02862191),
  DSP16_Q(-0.01491836),
  DSP16_Q(0.00698500),
  DSP16_Q(-0.00249644),
  DSP16_Q(0.00040416),
  DSP16_Q(-0.00004260),
  DSP16_Q(0.00119541),
  DSP16_Q(-0.00437345),
  DSP16_Q(0.01037681),
  DSP16_Q(-0.02069059),
  DSP16_Q(0.03929026),
  DSP16_Q(-0.08318009),
  DSP16_Q(0.44851249),
  DSP16_Q(0.14400659),
  DSP16_Q(-0.05524246),
  DSP16_Q(0.02837563),
  DSP16_Q(-0.01478831),
  DSP16_Q(0.00692143),
  DSP16_Q(-0.00247142),
  DSP16_Q(0.00039872),
  DSP16_Q(-0.00004306),
  DSP16_Q(0.00119135),
  DSP16_Q(-0.00435159),
  DSP16_Q(0.01031888),
  DSP16_Q(-0.02057017),
  DSP16_Q(0.03906261),
  DSP16_Q(-0.08274619),
  DSP16_Q(0.44939331),
  DSP16_Q(0.14250777),
  DSP16_Q(-0.05474958),
  DSP16_Q(0.02812856),
  DSP16_Q(-0.01465787),
  DSP16_Q(0.00685772),
  DSP16_Q(-0.00244639),
  DSP16_Q(0.00039330),
  DSP16_Q(-0.00004353),
  DSP16_Q(0.00118717),
  DSP16_Q(-0.00432938),
  DSP16_Q(0.01026019),
  DSP16_Q(-0.02044830),
  DSP16_Q(0.03883222),
  DSP16_Q(-0.08230614),
  DSP16_Q(0.45026703),
  DSP16_Q(0.14101097),
  DSP16_Q(-0.05425547),
  DSP16_Q(0.02788072),
  DSP16_Q(-0.01452705),
  DSP16_Q(0.00679388),
  DSP16_Q(-0.00242135),
  DSP16_Q(0.00038791),
  DSP16_Q(-0.00004398),
  DSP16_Q(0.00118287),
  DSP16_Q(-0.00430682),
  DSP16_Q(0.01020074),
  DSP16_Q(-0.02032499),
  DSP16_Q(0.03859910),
  DSP16_Q(-0.08185996),
  DSP16_Q(0.45113365),
  DSP16_Q(0.13951622),
  DSP16_Q(-0.05376016),
  DSP16_Q(0.02763212),
  DSP16_Q(-0.01439585),
  DSP16_Q(0.00672991),
  DSP16_Q(-0.00239630),
  DSP16_Q(0.00038255),
  DSP16_Q(-0.00004443),
  DSP16_Q(0.00117845),
  DSP16_Q(-0.00428390),
  DSP16_Q(0.01014053),
  DSP16_Q(-0.02020023),
  DSP16_Q(0.03836325),
  DSP16_Q(-0.08140763),
  DSP16_Q(0.45199313),
  DSP16_Q(0.13802358),
  DSP16_Q(-0.05326368),
  DSP16_Q(0.02738278),
  DSP16_Q(-0.01426430),
  DSP16_Q(0.00666582),
  DSP16_Q(-0.00237125),
  DSP16_Q(0.00037721),
  DSP16_Q(-0.00004487),
  DSP16_Q(0.00117391),
  DSP16_Q(-0.00426063),
  DSP16_Q(0.01007956),
  DSP16_Q(-0.02007403),
  DSP16_Q(0.03812467),
  DSP16_Q(-0.08094916),
  DSP16_Q(0.45284543),
  DSP16_Q(0.13653307),
  DSP16_Q(-0.05276605),
  DSP16_Q(0.02713271),
  DSP16_Q(-0.01413239),
  DSP16_Q(0.00660160),
  DSP16_Q(-0.00234619),
  DSP16_Q(0.00037189),
  DSP16_Q(-0.00004530),
  DSP16_Q(0.00116925),
  DSP16_Q(-0.00423701),
  DSP16_Q(0.01001783),
  DSP16_Q(-0.01994639),
  DSP16_Q(0.03788338),
  DSP16_Q(-0.08048453),
  DSP16_Q(0.45369055),
  DSP16_Q(0.13504474),
  DSP16_Q(-0.05226731),
  DSP16_Q(0.02688194),
  DSP16_Q(-0.01400013),
  DSP16_Q(0.00653726),
  DSP16_Q(-0.00232113),
  DSP16_Q(0.00036661),
  DSP16_Q(-0.00004573),
  DSP16_Q(0.00116447),
  DSP16_Q(-0.00421303),
  DSP16_Q(0.00995534),
  DSP16_Q(-0.01981732),
  DSP16_Q(0.03763937),
  DSP16_Q(-0.08001375),
  DSP16_Q(0.45452844),
  DSP16_Q(0.13355862),
  DSP16_Q(-0.05176748),
  DSP16_Q(0.02663047),
  DSP16_Q(-0.01386753),
  DSP16_Q(0.00647280),
  DSP16_Q(-0.00229607),
  DSP16_Q(0.00036135),
  DSP16_Q(-0.00004615),
  DSP16_Q(0.00115957),
  DSP16_Q(-0.00418869),
  DSP16_Q(0.00989210),
  DSP16_Q(-0.01968681),
  DSP16_Q(0.03739266),
  DSP16_Q(-0.07953680),
  DSP16_Q(0.45535908),
  DSP16_Q(0.13207476),
  DSP16_Q(-0.05126659),
  DSP16_Q(0.02637831),
  DSP16_Q(-0.01373460),
  DSP16_Q(0.00640824),
  DSP16_Q(-0.00227102),
  DSP16_Q(0.00035612),
  DSP16_Q(-0.00004656),
  DSP16_Q(0.00115455),
  DSP16_Q(-0.00416401),
  DSP16_Q(0.00982811),
  DSP16_Q(-0.01955487),
  DSP16_Q(0.03714323),
  DSP16_Q(-0.07905369),
  DSP16_Q(0.45618245),
  DSP16_Q(0.13059319),
  DSP16_Q(-0.05076468),
  DSP16_Q(0.02612550),
  DSP16_Q(-0.01360134),
  DSP16_Q(0.00634357),
  DSP16_Q(-0.00224597),
  DSP16_Q(0.00035092),
  DSP16_Q(-0.00004696),
  DSP16_Q(0.00114940),
  DSP16_Q(-0.00413896),
  DSP16_Q(0.00976336),
  DSP16_Q(-0.01942150),
  DSP16_Q(0.03689110),
  DSP16_Q(-0.07856441),
  DSP16_Q(0.45699852),
  DSP16_Q(0.12911396),
  DSP16_Q(-0.05026176),
  DSP16_Q(0.02587203),
  DSP16_Q(-0.01346778),
  DSP16_Q(0.00627881),
  DSP16_Q(-0.00222092),
  DSP16_Q(0.00034575),
  DSP16_Q(-0.00004735),
  DSP16_Q(0.00114413),
  DSP16_Q(-0.00411357),
  DSP16_Q(0.00969785),
  DSP16_Q(-0.01928671),
  DSP16_Q(0.03663628),
  DSP16_Q(-0.07806896),
  DSP16_Q(0.45780726),
  DSP16_Q(0.12763710),
  DSP16_Q(-0.04975787),
  DSP16_Q(0.02561793),
  DSP16_Q(-0.01333390),
  DSP16_Q(0.00621394),
  DSP16_Q(-0.00219588),
  DSP16_Q(0.00034060),
  DSP16_Q(-0.00004774),
  DSP16_Q(0.00113874),
  DSP16_Q(-0.00408782),
  DSP16_Q(0.00963160),
  DSP16_Q(-0.01915049),
  DSP16_Q(0.03637877),
  DSP16_Q(-0.07756734),
  DSP16_Q(0.45860864),
  DSP16_Q(0.12616264),
  DSP16_Q(-0.04925304),
  DSP16_Q(0.02536321),
  DSP16_Q(-0.01319973),
  DSP16_Q(0.00614898),
  DSP16_Q(-0.00217084),
  DSP16_Q(0.00033548),
  DSP16_Q(-0.00004811),
  DSP16_Q(0.00113323),
  DSP16_Q(-0.00406171),
  DSP16_Q(0.00956459),
  DSP16_Q(-0.01901286),
  DSP16_Q(0.03611857),
  DSP16_Q(-0.07705954),
  DSP16_Q(0.45940265),
  DSP16_Q(0.12469063),
  DSP16_Q(-0.04874729),
  DSP16_Q(0.02510788),
  DSP16_Q(-0.01306527),
  DSP16_Q(0.00608393),
  DSP16_Q(-0.00214582),
  DSP16_Q(0.00033039),
  DSP16_Q(-0.00004848),
  DSP16_Q(0.00112759),
  DSP16_Q(-0.00403525),
  DSP16_Q(0.00949684),
  DSP16_Q(-0.01887381),
  DSP16_Q(0.03585569),
  DSP16_Q(-0.07654556),
  DSP16_Q(0.46018926),
  DSP16_Q(0.12322111),
  DSP16_Q(-0.04824065),
  DSP16_Q(0.02485197),
  DSP16_Q(-0.01293053),
  DSP16_Q(0.00601879),
  DSP16_Q(-0.00212081),
  DSP16_Q(0.00032534),
  DSP16_Q(-0.00004883),
  DSP16_Q(0.00112183),
  DSP16_Q(-0.00400844),
  DSP16_Q(0.00942834),
  DSP16_Q(-0.01873335),
  DSP16_Q(0.03559013),
  DSP16_Q(-0.07602539),
  DSP16_Q(0.46096843),
  DSP16_Q(0.12175412),
  DSP16_Q(-0.04773316),
  DSP16_Q(0.02459548),
  DSP16_Q(-0.01279551),
  DSP16_Q(0.00595358),
  DSP16_Q(-0.00209581),
  DSP16_Q(0.00032031),
  DSP16_Q(-0.00004918),
  DSP16_Q(0.00111594),
  DSP16_Q(-0.00398127),
  DSP16_Q(0.00935909),
  DSP16_Q(-0.01859149),
  DSP16_Q(0.03532191),
  DSP16_Q(-0.07549905),
  DSP16_Q(0.46174015),
  DSP16_Q(0.12028968),
  DSP16_Q(-0.04722483),
  DSP16_Q(0.02433844),
  DSP16_Q(-0.01266023),
  DSP16_Q(0.00588829),
  DSP16_Q(-0.00207082),
  DSP16_Q(0.00031531),
  DSP16_Q(-0.00004951),
  DSP16_Q(0.00110993),
  DSP16_Q(-0.00395375),
  DSP16_Q(0.00928909),
  DSP16_Q(-0.01844822),
  DSP16_Q(0.03505102),
  DSP16_Q(-0.07496652),
  DSP16_Q(0.46250439),
  DSP16_Q(0.11882785),
  DSP16_Q(-0.04671570),
  DSP16_Q(0.02408085),
  DSP16_Q(-0.01252469),
  DSP16_Q(0.00582292),
  DSP16_Q(-0.00204585),
  DSP16_Q(0.00031034),
  DSP16_Q(-0.00004983),
  DSP16_Q(0.00110379),
  DSP16_Q(-0.00392587),
  DSP16_Q(0.00921836),
  DSP16_Q(-0.01830354),
  DSP16_Q(0.03477748),
  DSP16_Q(-0.07442780),
  DSP16_Q(0.46326113),
  DSP16_Q(0.11736865),
  DSP16_Q(-0.04620580),
  DSP16_Q(0.02382273),
  DSP16_Q(-0.01238890),
  DSP16_Q(0.00575749),
  DSP16_Q(-0.00202090),
  DSP16_Q(0.00030540),
  DSP16_Q(-0.00005015),
  DSP16_Q(0.00109753),
  DSP16_Q(-0.00389765),
  DSP16_Q(0.00914688),
  DSP16_Q(-0.01815747),
  DSP16_Q(0.03450128),
  DSP16_Q(-0.07388289),
  DSP16_Q(0.46401034),
  DSP16_Q(0.11591213),
  DSP16_Q(-0.04569515),
  DSP16_Q(0.02356409),
  DSP16_Q(-0.01225288),
  DSP16_Q(0.00569199),
  DSP16_Q(-0.00199597),
  DSP16_Q(0.00030049),
  DSP16_Q(-0.00005045),
  DSP16_Q(0.00109114),
  DSP16_Q(-0.00386906),
  DSP16_Q(0.00907466),
  DSP16_Q(-0.01801001),
  DSP16_Q(0.03422244),
  DSP16_Q(-0.07333179),
  DSP16_Q(0.46475200),
  DSP16_Q(0.11445832),
  DSP16_Q(-0.04518378),
  DSP16_Q(0.02330496),
  DSP16_Q(-0.01211662),
  DSP16_Q(0.00562643),
  DSP16_Q(-0.00197106),
  DSP16_Q(0.00029561),
  DSP16_Q(-0.00005074),
  DSP16_Q(0.00108463),
  DSP16_Q(-0.00384013),
  DSP16_Q(0.00900170),
  DSP16_Q(-0.01786115),
  DSP16_Q(0.03394096),
  DSP16_Q(-0.07277450),
  DSP16_Q(0.46548608),
  DSP16_Q(0.11300726),
  DSP16_Q(-0.04467172),
  DSP16_Q(0.02304535),
  DSP16_Q(-0.01198013),
  DSP16_Q(0.00556081),
  DSP16_Q(-0.00194617),
  DSP16_Q(0.00029077),
  DSP16_Q(-0.00005102),
  DSP16_Q(0.00107798),
  DSP16_Q(-0.00381084),
  DSP16_Q(0.00892800),
  DSP16_Q(-0.01771091),
  DSP16_Q(0.03365685),
  DSP16_Q(-0.07221102),
  DSP16_Q(0.46621257),
  DSP16_Q(0.11155898),
  DSP16_Q(-0.04415900),
  DSP16_Q(0.02278527),
  DSP16_Q(-0.01184343),
  DSP16_Q(0.00549514),
  DSP16_Q(-0.00192131),
  DSP16_Q(0.00028595),
  DSP16_Q(-0.00005129),
  DSP16_Q(0.00107122),
  DSP16_Q(-0.00378120),
  DSP16_Q(0.00885356),
  DSP16_Q(-0.01755929),
  DSP16_Q(0.03337011),
  DSP16_Q(-0.07164135),
  DSP16_Q(0.46693143),
  DSP16_Q(0.11011353),
  DSP16_Q(-0.04364565),
  DSP16_Q(0.02252473),
  DSP16_Q(-0.01170652),
  DSP16_Q(0.00542943),
  DSP16_Q(-0.00189647),
  DSP16_Q(0.00028117),
  DSP16_Q(-0.00005154),
  DSP16_Q(0.00106432),
  DSP16_Q(-0.00375121),
  DSP16_Q(0.00877840),
  DSP16_Q(-0.01740629),
  DSP16_Q(0.03308076),
  DSP16_Q(-0.07106549),
  DSP16_Q(0.46764265),
  DSP16_Q(0.10867094),
  DSP16_Q(-0.04313168),
  DSP16_Q(0.02226376),
  DSP16_Q(-0.01156942),
  DSP16_Q(0.00536366),
  DSP16_Q(-0.00187166),
  DSP16_Q(0.00027641),
  DSP16_Q(-0.00005178),
  DSP16_Q(0.00105730),
  DSP16_Q(-0.00372086),
  DSP16_Q(0.00870250),
  DSP16_Q(-0.01725191),
  DSP16_Q(0.03278879),
  DSP16_Q(-0.07048343),
  DSP16_Q(0.46834620),
  DSP16_Q(0.10723124),
  DSP16_Q(-0.04261714),
  DSP16_Q(0.02200236),
  DSP16_Q(-0.01143212),
  DSP16_Q(0.00529786),
  DSP16_Q(-0.00184688),
  DSP16_Q(0.00027169),
  DSP16_Q(-0.00005201),
  DSP16_Q(0.00105015),
  DSP16_Q(-0.00369016),
  DSP16_Q(0.00862587),
  DSP16_Q(-0.01709617),
  DSP16_Q(0.03249422),
  DSP16_Q(-0.06989518),
  DSP16_Q(0.46904206),
  DSP16_Q(0.10579448),
  DSP16_Q(-0.04210204),
  DSP16_Q(0.02174055),
  DSP16_Q(-0.01129463),
  DSP16_Q(0.00523202),
  DSP16_Q(-0.00182213),
  DSP16_Q(0.00026701),
  DSP16_Q(-0.00005223),
  DSP16_Q(0.00104287),
  DSP16_Q(-0.00365912),
  DSP16_Q(0.00854851),
  DSP16_Q(-0.01693906),
  DSP16_Q(0.03219705),
  DSP16_Q(-0.06930074),
  DSP16_Q(0.46973021),
  DSP16_Q(0.10436069),
  DSP16_Q(-0.04158643),
  DSP16_Q(0.02147836),
  DSP16_Q(-0.01115697),
  DSP16_Q(0.00516615),
  DSP16_Q(-0.00179741),
  DSP16_Q(0.00026235),
  DSP16_Q(-0.00005243),
  DSP16_Q(0.00103546),
  DSP16_Q(-0.00362772),
  DSP16_Q(0.00847042),
  DSP16_Q(-0.01678060),
  DSP16_Q(0.03189730),
  DSP16_Q(-0.06870011),
  DSP16_Q(0.47041062),
  DSP16_Q(0.10292990),
  DSP16_Q(-0.04107031),
  DSP16_Q(0.02121578),
  DSP16_Q(-0.01101915),
  DSP16_Q(0.00510025),
  DSP16_Q(-0.00177272),
  DSP16_Q(0.00025773),
  DSP16_Q(-0.00005262),
  DSP16_Q(0.00102792),
  DSP16_Q(-0.00359597),
  DSP16_Q(0.00839162),
  DSP16_Q(-0.01662077),
  DSP16_Q(0.03159496),
  DSP16_Q(-0.06809329),
  DSP16_Q(0.47108328),
  DSP16_Q(0.10150216),
  DSP16_Q(-0.04055373),
  DSP16_Q(0.02095284),
  DSP16_Q(-0.01088116),
  DSP16_Q(0.00503432),
  DSP16_Q(-0.00174807),
  DSP16_Q(0.00025314),
  DSP16_Q(-0.00005280),
  DSP16_Q(0.00102025),
  DSP16_Q(-0.00356387),
  DSP16_Q(0.00831208),
  DSP16_Q(-0.01645960),
  DSP16_Q(0.03129005),
  DSP16_Q(-0.06748028),
  DSP16_Q(0.47174816),
  DSP16_Q(0.10007749),
  DSP16_Q(-0.04003670),
  DSP16_Q(0.02068955),
  DSP16_Q(-0.01074303),
  DSP16_Q(0.00496838),
  DSP16_Q(-0.00172345),
  DSP16_Q(0.00024858),
  DSP16_Q(-0.00005296),
  DSP16_Q(0.00101246),
  DSP16_Q(-0.00353142),
  DSP16_Q(0.00823183),
  DSP16_Q(-0.01629707),
  DSP16_Q(0.03098258),
  DSP16_Q(-0.06686108),
  DSP16_Q(0.47240524),
  DSP16_Q(0.09865593),
  DSP16_Q(-0.03951926),
  DSP16_Q(0.02042592),
  DSP16_Q(-0.01060475),
  DSP16_Q(0.00490241),
  DSP16_Q(-0.00169887),
  DSP16_Q(0.00024405),
  DSP16_Q(-0.00005310),
  DSP16_Q(0.00100453),
  DSP16_Q(-0.00349862),
  DSP16_Q(0.00815086),
  DSP16_Q(-0.01613321),
  DSP16_Q(0.03067254),
  DSP16_Q(-0.06623569),
  DSP16_Q(0.47305450),
  DSP16_Q(0.09723752),
  DSP16_Q(-0.03900143),
  DSP16_Q(0.02016198),
  DSP16_Q(-0.01046633),
  DSP16_Q(0.00483644),
  DSP16_Q(-0.00167433),
  DSP16_Q(0.00023956),
  DSP16_Q(-0.00005324),
  DSP16_Q(0.00099648),
  DSP16_Q(-0.00346547),
  DSP16_Q(0.00806917),
  DSP16_Q(-0.01596801),
  DSP16_Q(0.03035996),
  DSP16_Q(-0.06560413),
  DSP16_Q(0.47369592),
  DSP16_Q(0.09582230),
  DSP16_Q(-0.03848325),
  DSP16_Q(0.01989774),
  DSP16_Q(-0.01032779),
  DSP16_Q(0.00477045),
  DSP16_Q(-0.00164983),
  DSP16_Q(0.00023510),
  DSP16_Q(-0.00005335),
  DSP16_Q(0.00098829),
  DSP16_Q(-0.00343197),
  DSP16_Q(0.00798677),
  DSP16_Q(-0.01580148),
  DSP16_Q(0.03004484),
  DSP16_Q(-0.06496637),
  DSP16_Q(0.47432947),
  DSP16_Q(0.09441029),
  DSP16_Q(-0.03796473),
  DSP16_Q(0.01963320),
  DSP16_Q(-0.01018913),
  DSP16_Q(0.00470446),
  DSP16_Q(-0.00162537),
  DSP16_Q(0.00023068),
  DSP16_Q(-0.00005345),
  DSP16_Q(0.00097998),
  DSP16_Q(-0.00339813),
  DSP16_Q(0.00790365),
  DSP16_Q(-0.01563362),
  DSP16_Q(0.02972718),
  DSP16_Q(-0.06432244),
  DSP16_Q(0.47495515),
  DSP16_Q(0.09300154),
  DSP16_Q(-0.03744590),
  DSP16_Q(0.01936839),
  DSP16_Q(-0.01005035),
  DSP16_Q(0.00463847),
  DSP16_Q(-0.00160096),
  DSP16_Q(0.00022629),
  DSP16_Q(-0.00005354),
  DSP16_Q(0.00097153),
  DSP16_Q(-0.00336394),
  DSP16_Q(0.00781983),
  DSP16_Q(-0.01546444),
  DSP16_Q(0.02940700),
  DSP16_Q(-0.06367233),
  DSP16_Q(0.47557292),
  DSP16_Q(0.09159608),
  DSP16_Q(-0.03692680),
  DSP16_Q(0.01910332),
  DSP16_Q(-0.00991147),
  DSP16_Q(0.00457248),
  DSP16_Q(-0.00157659),
  DSP16_Q(0.00022193),
  DSP16_Q(-0.00005361),
  DSP16_Q(0.00096296),
  DSP16_Q(-0.00332940),
  DSP16_Q(0.00773530),
  DSP16_Q(-0.01529394),
  DSP16_Q(0.02908431),
  DSP16_Q(-0.06301605),
  DSP16_Q(0.47618277),
  DSP16_Q(0.09019394),
  DSP16_Q(-0.03640745),
  DSP16_Q(0.01883801),
  DSP16_Q(-0.00977250),
  DSP16_Q(0.00450649),
  DSP16_Q(-0.00155226),
  DSP16_Q(0.00021761),
  DSP16_Q(-0.00005366),
  DSP16_Q(0.00095425),
  DSP16_Q(-0.00329452),
  DSP16_Q(0.00765006),
  DSP16_Q(-0.01512214),
  DSP16_Q(0.02875911),
  DSP16_Q(-0.06235360),
  DSP16_Q(0.47678468),
  DSP16_Q(0.08879516),
  DSP16_Q(-0.03588787),
  DSP16_Q(0.01857246),
  DSP16_Q(-0.00963344),
  DSP16_Q(0.00444052),
  DSP16_Q(-0.00152799),
  DSP16_Q(0.00021332),
  DSP16_Q(-0.00005370),
  DSP16_Q(0.00094541),
  DSP16_Q(-0.00325929),
  DSP16_Q(0.00756413),
  DSP16_Q(-0.01494902),
  DSP16_Q(0.02843142),
  DSP16_Q(-0.06168497),
  DSP16_Q(0.47737863),
  DSP16_Q(0.08739977),
  DSP16_Q(-0.03536809),
  DSP16_Q(0.01830670),
  DSP16_Q(-0.00949430),
  DSP16_Q(0.00437456),
  DSP16_Q(-0.00150376),
  DSP16_Q(0.00020907),
  DSP16_Q(-0.00005372),
  DSP16_Q(0.00093644),
  DSP16_Q(-0.00322371),
  DSP16_Q(0.00747749),
  DSP16_Q(-0.01477461),
  DSP16_Q(0.02810124),
  DSP16_Q(-0.06101018),
  DSP16_Q(0.47796460),
  DSP16_Q(0.08600781),
  DSP16_Q(-0.03484815),
  DSP16_Q(0.01804074),
  DSP16_Q(-0.00935509),
  DSP16_Q(0.00430861),
  DSP16_Q(-0.00147958),
  DSP16_Q(0.00020485),
  DSP16_Q(-0.00005373),
  DSP16_Q(0.00092734),
  DSP16_Q(-0.00318780),
  DSP16_Q(0.00739015),
  DSP16_Q(-0.01459890),
  DSP16_Q(0.02776858),
  DSP16_Q(-0.06032923),
  DSP16_Q(0.47854257),
  DSP16_Q(0.08461931),
  DSP16_Q(-0.03432805),
  DSP16_Q(0.01777459),
  DSP16_Q(-0.00921581),
  DSP16_Q(0.00424269),
  DSP16_Q(-0.00145545),
  DSP16_Q(0.00020066),
  DSP16_Q(-0.00005371),
  DSP16_Q(0.00091810),
  DSP16_Q(-0.00315153),
  DSP16_Q(0.00730212),
  DSP16_Q(-0.01442191),
  DSP16_Q(0.02743345),
  DSP16_Q(-0.05964212),
  DSP16_Q(0.47911252),
  DSP16_Q(0.08323430),
  DSP16_Q(-0.03380785),
  DSP16_Q(0.01750827),
  DSP16_Q(-0.00907648),
  DSP16_Q(0.00417680),
  DSP16_Q(-0.00143138),
  DSP16_Q(0.00019651),
  DSP16_Q(-0.00005368),
  DSP16_Q(0.00090874),
  DSP16_Q(-0.00311493),
  DSP16_Q(0.00721340),
  DSP16_Q(-0.01424363),
  DSP16_Q(0.02709586),
  DSP16_Q(-0.05894886),
  DSP16_Q(0.47967443),
  DSP16_Q(0.08185282),
  DSP16_Q(-0.03328755),
  DSP16_Q(0.01724179),
  DSP16_Q(-0.00893710),
  DSP16_Q(0.00411093),
  DSP16_Q(-0.00140736),
  DSP16_Q(0.00019240),
  DSP16_Q(-0.00005363),
  DSP16_Q(0.00089924),
  DSP16_Q(-0.00307799),
  DSP16_Q(0.00712399),
  DSP16_Q(-0.01406407),
  DSP16_Q(0.02675583),
  DSP16_Q(-0.05824945),
  DSP16_Q(0.48022830),
  DSP16_Q(0.08047490),
  DSP16_Q(-0.03276718),
  DSP16_Q(0.01697517),
  DSP16_Q(-0.00879768),
  DSP16_Q(0.00404509),
  DSP16_Q(-0.00138340),
  DSP16_Q(0.00018832),
  DSP16_Q(-0.00005357),
  DSP16_Q(0.00088961),
  DSP16_Q(-0.00304070),
  DSP16_Q(0.00703389),
  DSP16_Q(-0.01388324),
  DSP16_Q(0.02641336),
  DSP16_Q(-0.05754390),
  DSP16_Q(0.48077409),
  DSP16_Q(0.07910057),
  DSP16_Q(-0.03224678),
  DSP16_Q(0.01670842),
  DSP16_Q(-0.00865822),
  DSP16_Q(0.00397930),
  DSP16_Q(-0.00135949),
  DSP16_Q(0.00018427),
  DSP16_Q(-0.00005348),
  DSP16_Q(0.00087985),
  DSP16_Q(-0.00300307),
  DSP16_Q(0.00694311),
  DSP16_Q(-0.01370115),
  DSP16_Q(0.02606846),
  DSP16_Q(-0.05683220),
  DSP16_Q(0.48131179),
  DSP16_Q(0.07772987),
  DSP16_Q(-0.03172637),
  DSP16_Q(0.01644156),
  DSP16_Q(-0.00851874),
  DSP16_Q(0.00391354),
  DSP16_Q(-0.00133565),
  DSP16_Q(0.00018026),
  DSP16_Q(-0.00005338),
  DSP16_Q(0.00086996),
  DSP16_Q(-0.00296511),
  DSP16_Q(0.00685164),
  DSP16_Q(-0.01351779),
  DSP16_Q(0.02572114),
  DSP16_Q(-0.05611438),
  DSP16_Q(0.48184138),
  DSP16_Q(0.07636284),
  DSP16_Q(-0.03120597),
  DSP16_Q(0.01617460),
  DSP16_Q(-0.00837925),
  DSP16_Q(0.00384782),
  DSP16_Q(-0.00131186),
  DSP16_Q(0.00017629),
  DSP16_Q(-0.00005326),
  DSP16_Q(0.00085993),
  DSP16_Q(-0.00292680),
  DSP16_Q(0.00675950),
  DSP16_Q(-0.01333319),
  DSP16_Q(0.02537142),
  DSP16_Q(-0.05539042),
  DSP16_Q(0.48236286),
  DSP16_Q(0.07499950),
  DSP16_Q(-0.03068561),
  DSP16_Q(0.01590755),
  DSP16_Q(-0.00823974),
  DSP16_Q(0.00378215),
  DSP16_Q(-0.00128813),
  DSP16_Q(0.00017235),
  DSP16_Q(-0.00005312),
  DSP16_Q(0.00084977),
  DSP16_Q(-0.00288816),
  DSP16_Q(0.00666668),
  DSP16_Q(-0.01314733),
  DSP16_Q(0.02501930),
  DSP16_Q(-0.05466034),
  DSP16_Q(0.48287619),
  DSP16_Q(0.07363988),
  DSP16_Q(-0.03016531),
  DSP16_Q(0.01564043),
  DSP16_Q(-0.00810023),
  DSP16_Q(0.00371654),
  DSP16_Q(-0.00126447),
  DSP16_Q(0.00016844),
  DSP16_Q(-0.00005295),
  DSP16_Q(0.00083948),
  DSP16_Q(-0.00284919),
  DSP16_Q(0.00657319),
  DSP16_Q(-0.01296024),
  DSP16_Q(0.02466480),
  DSP16_Q(-0.05392414),
  DSP16_Q(0.48338136),
  DSP16_Q(0.07228402),
  DSP16_Q(-0.02964511),
  DSP16_Q(0.01537326),
  DSP16_Q(-0.00796073),
  DSP16_Q(0.00365098),
  DSP16_Q(-0.00124087),
  DSP16_Q(0.00016457),
  DSP16_Q(-0.00005277),
  DSP16_Q(0.00082906),
  DSP16_Q(-0.00280987),
  DSP16_Q(0.00647904),
  DSP16_Q(-0.01277191),
  DSP16_Q(0.02430792),
  DSP16_Q(-0.05318183),
  DSP16_Q(0.48387837),
  DSP16_Q(0.07093195),
  DSP16_Q(-0.02912503),
  DSP16_Q(0.01510604),
  DSP16_Q(-0.00782124),
  DSP16_Q(0.00358547),
  DSP16_Q(-0.00121733),
  DSP16_Q(0.00016074),
  DSP16_Q(-0.00005257),
  DSP16_Q(0.00081850),
  DSP16_Q(-0.00277022),
  DSP16_Q(0.00638421),
  DSP16_Q(-0.01258236),
  DSP16_Q(0.02394868),
  DSP16_Q(-0.05243341),
  DSP16_Q(0.48436718),
  DSP16_Q(0.06958371),
  DSP16_Q(-0.02860510),
  DSP16_Q(0.01483879),
  DSP16_Q(-0.00768177),
  DSP16_Q(0.00352003),
  DSP16_Q(-0.00119386),
  DSP16_Q(0.00015695),
  DSP16_Q(-0.00005235),
  DSP16_Q(0.00080781),
  DSP16_Q(-0.00273024),
  DSP16_Q(0.00628872),
  DSP16_Q(-0.01239158),
  DSP16_Q(0.02358708),
  DSP16_Q(-0.05167889),
  DSP16_Q(0.48484779),
  DSP16_Q(0.06823931),
  DSP16_Q(-0.02808533),
  DSP16_Q(0.01457153),
  DSP16_Q(-0.00754233),
  DSP16_Q(0.00345466),
  DSP16_Q(-0.00117045),
  DSP16_Q(0.00015318),
  DSP16_Q(-0.00005211),
  DSP16_Q(0.00079699),
  DSP16_Q(-0.00268993),
  DSP16_Q(0.00619257),
  DSP16_Q(-0.01219959),
  DSP16_Q(0.02322315),
  DSP16_Q(-0.05091829),
  DSP16_Q(0.48532018),
  DSP16_Q(0.06689881),
  DSP16_Q(-0.02756576),
  DSP16_Q(0.01430427),
  DSP16_Q(-0.00740292),
  DSP16_Q(0.00338935),
  DSP16_Q(-0.00114712),
  DSP16_Q(0.00014946),
  DSP16_Q(-0.00005185),
  DSP16_Q(0.00078603),
  DSP16_Q(-0.00264928),
  DSP16_Q(0.00609577),
  DSP16_Q(-0.01200639),
  DSP16_Q(0.02285689),
  DSP16_Q(-0.05015159),
  DSP16_Q(0.48578433),
  DSP16_Q(0.06556222),
  DSP16_Q(-0.02704641),
  DSP16_Q(0.01403703),
  DSP16_Q(-0.00726356),
  DSP16_Q(0.00332411),
  DSP16_Q(-0.00112385),
  DSP16_Q(0.00014577),
  DSP16_Q(-0.00005157),
  DSP16_Q(0.00077494),
  DSP16_Q(-0.00260830),
  DSP16_Q(0.00599831),
  DSP16_Q(-0.01181199),
  DSP16_Q(0.02248831),
  DSP16_Q(-0.04937882),
  DSP16_Q(0.48624023),
  DSP16_Q(0.06422958),
  DSP16_Q(-0.02652730),
  DSP16_Q(0.01376981),
  DSP16_Q(-0.00712425),
  DSP16_Q(0.00325895),
  DSP16_Q(-0.00110066),
  DSP16_Q(0.00014212),
  DSP16_Q(-0.00005126),
  DSP16_Q(0.00076372),
  DSP16_Q(-0.00256699),
  DSP16_Q(0.00590020),
  DSP16_Q(-0.01161640),
  DSP16_Q(0.02211742),
  DSP16_Q(-0.04859998),
  DSP16_Q(0.48668787),
  DSP16_Q(0.06290093),
  DSP16_Q(-0.02600847),
  DSP16_Q(0.01350264),
  DSP16_Q(-0.00698500),
  DSP16_Q(0.00319388),
  DSP16_Q(-0.00107753),
  DSP16_Q(0.00013850),
  DSP16_Q(-0.00005094),
  DSP16_Q(0.00075237),
  DSP16_Q(-0.00252536),
  DSP16_Q(0.00580144),
  DSP16_Q(-0.01141962),
  DSP16_Q(0.02174424),
  DSP16_Q(-0.04781508),
  DSP16_Q(0.48712723),
  DSP16_Q(0.06157628),
  DSP16_Q(-0.02548994),
  DSP16_Q(0.01323552),
  DSP16_Q(-0.00684581),
  DSP16_Q(0.00312888),
  DSP16_Q(-0.00105448),
  DSP16_Q(0.00013492),
  DSP16_Q(-0.00005059),
  DSP16_Q(0.00074088),
  DSP16_Q(-0.00248339),
  DSP16_Q(0.00570204),
  DSP16_Q(-0.01122166),
  DSP16_Q(0.02136878),
  DSP16_Q(-0.04702412),
  DSP16_Q(0.48755829),
  DSP16_Q(0.06025567),
  DSP16_Q(-0.02497173),
  DSP16_Q(0.01296848),
  DSP16_Q(-0.00670670),
  DSP16_Q(0.00306397),
  DSP16_Q(-0.00103151),
  DSP16_Q(0.00013138),
  DSP16_Q(-0.00005022),
  DSP16_Q(0.00072926),
  DSP16_Q(-0.00244110),
  DSP16_Q(0.00560200),
  DSP16_Q(-0.01102253),
  DSP16_Q(0.02099106),
  DSP16_Q(-0.04622711),
  DSP16_Q(0.48798105),
  DSP16_Q(0.05893914),
  DSP16_Q(-0.02445386),
  DSP16_Q(0.01270151),
  DSP16_Q(-0.00656766),
  DSP16_Q(0.00299915),
  DSP16_Q(-0.00100861),
  DSP16_Q(0.00012787),
  DSP16_Q(-0.00004983),
  DSP16_Q(0.00071751),
  DSP16_Q(-0.00239849),
  DSP16_Q(0.00550133),
  DSP16_Q(-0.01082223),
  DSP16_Q(0.02061107),
  DSP16_Q(-0.04542406),
  DSP16_Q(0.48839548),
  DSP16_Q(0.05762671),
  DSP16_Q(-0.02393637),
  DSP16_Q(0.01243465),
  DSP16_Q(-0.00642872),
  DSP16_Q(0.00293442),
  DSP16_Q(-0.00098579),
  DSP16_Q(0.00012439),
  DSP16_Q(-0.00004941),
  DSP16_Q(0.00070562),
  DSP16_Q(-0.00235555),
  DSP16_Q(0.00540002),
  DSP16_Q(-0.01062077),
  DSP16_Q(0.02022884),
  DSP16_Q(-0.04461499),
  DSP16_Q(0.48880159),
  DSP16_Q(0.05631841),
  DSP16_Q(-0.02341928),
  DSP16_Q(0.01216790),
  DSP16_Q(-0.00628987),
  DSP16_Q(0.00286980),
  DSP16_Q(-0.00096304),
  DSP16_Q(0.00012096),
  DSP16_Q(-0.00004897),
  DSP16_Q(0.00069360),
  DSP16_Q(-0.00231229),
  DSP16_Q(0.00529808),
  DSP16_Q(-0.01041817),
  DSP16_Q(0.01984439),
  DSP16_Q(-0.04379989),
  DSP16_Q(0.48919934),
  DSP16_Q(0.05501428),
  DSP16_Q(-0.02290260),
  DSP16_Q(0.01190127),
  DSP16_Q(-0.00615112),
  DSP16_Q(0.00280527),
  DSP16_Q(-0.00094037),
  DSP16_Q(0.00011756),
  DSP16_Q(-0.00004851),
  DSP16_Q(0.00068145),
  DSP16_Q(-0.00226871),
  DSP16_Q(0.00519551),
  DSP16_Q(-0.01021442),
  DSP16_Q(0.01945771),
  DSP16_Q(-0.04297878),
  DSP16_Q(0.48958873),
  DSP16_Q(0.05371434),
  DSP16_Q(-0.02238638),
  DSP16_Q(0.01163478),
  DSP16_Q(-0.00601249),
  DSP16_Q(0.00274084),
  DSP16_Q(-0.00091779),
  DSP16_Q(0.00011420),
  DSP16_Q(-0.00004803),
  DSP16_Q(0.00066916),
  DSP16_Q(-0.00222481),
  DSP16_Q(0.00509232),
  DSP16_Q(-0.01000954),
  DSP16_Q(0.01906883),
  DSP16_Q(-0.04215167),
  DSP16_Q(0.48996975),
  DSP16_Q(0.05241862),
  DSP16_Q(-0.02187063),
  DSP16_Q(0.01136845),
  DSP16_Q(-0.00587397),
  DSP16_Q(0.00267652),
  DSP16_Q(-0.00089528),
  DSP16_Q(0.00011087),
  DSP16_Q(-0.00004752),
  DSP16_Q(0.00065674),
  DSP16_Q(-0.00218058),
  DSP16_Q(0.00498852),
  DSP16_Q(-0.00980352),
  DSP16_Q(0.01867776),
  DSP16_Q(-0.04131857),
  DSP16_Q(0.49034239),
  DSP16_Q(0.05112715),
  DSP16_Q(-0.02135537),
  DSP16_Q(0.01110228),
  DSP16_Q(-0.00573558),
  DSP16_Q(0.00261232),
  DSP16_Q(-0.00087286),
  DSP16_Q(0.00010758),
  DSP16_Q(-0.00004699),
  DSP16_Q(0.00064419),
  DSP16_Q(-0.00213605),
  DSP16_Q(0.00488410),
  DSP16_Q(-0.00959639),
  DSP16_Q(0.01828451),
  DSP16_Q(-0.04047948),
  DSP16_Q(0.49070663),
  DSP16_Q(0.04983996),
  DSP16_Q(-0.02084064),
  DSP16_Q(0.01083629),
  DSP16_Q(-0.00559731),
  DSP16_Q(0.00254822),
  DSP16_Q(-0.00085052),
  DSP16_Q(0.00010432),
  DSP16_Q(-0.00004644),
  DSP16_Q(0.00063151),
  DSP16_Q(-0.00209119),
  DSP16_Q(0.00477907),
  DSP16_Q(-0.00938815),
  DSP16_Q(0.01788910),
  DSP16_Q(-0.03963442),
  DSP16_Q(0.49106246),
  DSP16_Q(0.04855709),
  DSP16_Q(-0.02032644),
  DSP16_Q(0.01057050),
  DSP16_Q(-0.00545919),
  DSP16_Q(0.00248424),
  DSP16_Q(-0.00082826),
  DSP16_Q(0.00010111),
  DSP16_Q(-0.00004586),
  DSP16_Q(0.00061870),
  DSP16_Q(-0.00204602),
  DSP16_Q(0.00467343),
  DSP16_Q(-0.00917880),
  DSP16_Q(0.01749153),
  DSP16_Q(-0.03878340),
  DSP16_Q(0.49140987),
  DSP16_Q(0.04727855),
  DSP16_Q(-0.01981282),
  DSP16_Q(0.01030491),
  DSP16_Q(-0.00532121),
  DSP16_Q(0.00242039),
  DSP16_Q(-0.00080609),
  DSP16_Q(0.00009793),
  DSP16_Q(-0.00004525),
  DSP16_Q(0.00060575),
  DSP16_Q(-0.00200054),
  DSP16_Q(0.00456718),
  DSP16_Q(-0.00896835),
  DSP16_Q(0.01709183),
  DSP16_Q(-0.03792642),
  DSP16_Q(0.49174884),
  DSP16_Q(0.04600438),
  DSP16_Q(-0.01929980),
  DSP16_Q(0.01003955),
  DSP16_Q(-0.00518339),
  DSP16_Q(0.00235665),
  DSP16_Q(-0.00078401),
  DSP16_Q(0.00009478),
  DSP16_Q(-0.00004462),
  DSP16_Q(0.00059267),
  DSP16_Q(-0.00195474),
  DSP16_Q(0.00446034),
  DSP16_Q(-0.00875682),
  DSP16_Q(0.01669000),
  DSP16_Q(-0.03706351),
  DSP16_Q(0.49207938),
  DSP16_Q(0.04473460),
  DSP16_Q(-0.01878739),
  DSP16_Q(0.00977442),
  DSP16_Q(-0.00504572),
  DSP16_Q(0.00229305),
  DSP16_Q(-0.00076201),
  DSP16_Q(0.00009167),
  DSP16_Q(-0.00004397),
  DSP16_Q(0.00057946),
  DSP16_Q(-0.00190864),
  DSP16_Q(0.00435291),
  DSP16_Q(-0.00854421),
  DSP16_Q(0.01628607),
  DSP16_Q(-0.03619466),
  DSP16_Q(0.49240146),
  DSP16_Q(0.04346925),
  DSP16_Q(-0.01827562),
  DSP16_Q(0.00950954),
  DSP16_Q(-0.00490823),
  DSP16_Q(0.00222957),
  DSP16_Q(-0.00074010),
  DSP16_Q(0.00008860),
  DSP16_Q(-0.00004329),
  DSP16_Q(0.00056611),
  DSP16_Q(-0.00186222),
  DSP16_Q(0.00424488),
  DSP16_Q(-0.00833052),
  DSP16_Q(0.01588004),
  DSP16_Q(-0.03531989),
  DSP16_Q(0.49271508),
  DSP16_Q(0.04220835),
  DSP16_Q(-0.01776451),
  DSP16_Q(0.00924491),
  DSP16_Q(-0.00477090),
  DSP16_Q(0.00216623),
  DSP16_Q(-0.00071828),
  DSP16_Q(0.00008556),
  DSP16_Q(-0.00004258),
  DSP16_Q(0.00055264),
  DSP16_Q(-0.00181550),
  DSP16_Q(0.00413626),
  DSP16_Q(-0.00811578),
  DSP16_Q(0.01547193),
  DSP16_Q(-0.03443922),
  DSP16_Q(0.49302022),
  DSP16_Q(0.04095193),
  DSP16_Q(-0.01725410),
  DSP16_Q(0.00898057),
  DSP16_Q(-0.00463376),
  DSP16_Q(0.00210302),
  DSP16_Q(-0.00069656),
  DSP16_Q(0.00008256),
  DSP16_Q(-0.00004185),
  DSP16_Q(0.00053903),
  DSP16_Q(-0.00176847),
  DSP16_Q(0.00402707),
  DSP16_Q(-0.00789997),
  DSP16_Q(0.01506176),
  DSP16_Q(-0.03355264),
  DSP16_Q(0.49331688),
  DSP16_Q(0.03970001),
  DSP16_Q(-0.01674440),
  DSP16_Q(0.00871651),
  DSP16_Q(-0.00449681),
  DSP16_Q(0.00203995),
  DSP16_Q(-0.00067492),
  DSP16_Q(0.00007960),
  DSP16_Q(-0.00004109),
  DSP16_Q(0.00052529),
  DSP16_Q(-0.00172114),
  DSP16_Q(0.00391729),
  DSP16_Q(-0.00768312),
  DSP16_Q(0.01464953),
  DSP16_Q(-0.03266019),
  DSP16_Q(0.49360505),
  DSP16_Q(0.03845264),
  DSP16_Q(-0.01623543),
  DSP16_Q(0.00845275),
  DSP16_Q(-0.00436005),
  DSP16_Q(0.00197703),
  DSP16_Q(-0.00065338),
  DSP16_Q(0.00007667),
  DSP16_Q(-0.00004031),
  DSP16_Q(0.00051142),
  DSP16_Q(-0.00167351),
  DSP16_Q(0.00380694),
  DSP16_Q(-0.00746524),
  DSP16_Q(0.01423527),
  DSP16_Q(-0.03176186),
  DSP16_Q(0.49388472),
  DSP16_Q(0.03720982),
  DSP16_Q(-0.01572723),
  DSP16_Q(0.00818930),
  DSP16_Q(-0.00422350),
  DSP16_Q(0.00191425),
  DSP16_Q(-0.00063192),
  DSP16_Q(0.00007378),
  DSP16_Q(-0.00003950),
  DSP16_Q(0.00049742),
  DSP16_Q(-0.00162557),
  DSP16_Q(0.00369602),
  DSP16_Q(-0.00724632),
  DSP16_Q(0.01381899),
  DSP16_Q(-0.03085767),
  DSP16_Q(0.49415587),
  DSP16_Q(0.03597159),
  DSP16_Q(-0.01521980),
  DSP16_Q(0.00792618),
  DSP16_Q(-0.00408715),
  DSP16_Q(0.00185162),
  DSP16_Q(-0.00061057),
  DSP16_Q(0.00007093),
  DSP16_Q(-0.00003866),
  DSP16_Q(0.00048329),
  DSP16_Q(-0.00157733),
  DSP16_Q(0.00358453),
  DSP16_Q(-0.00702638),
  DSP16_Q(0.01340070),
  DSP16_Q(-0.02994764),
  DSP16_Q(0.49441850),
  DSP16_Q(0.03473798),
  DSP16_Q(-0.01471319),
  DSP16_Q(0.00766340),
  DSP16_Q(-0.00395102),
  DSP16_Q(0.00178914),
  DSP16_Q(-0.00058931),
  DSP16_Q(0.00006811),
  DSP16_Q(-0.00003780),
  DSP16_Q(0.00046902),
  DSP16_Q(-0.00152880),
  DSP16_Q(0.00347248),
  DSP16_Q(-0.00680543),
  DSP16_Q(0.01298042),
  DSP16_Q(-0.02903177),
  DSP16_Q(0.49467261),
  DSP16_Q(0.03350901),
  DSP16_Q(-0.01420740),
  DSP16_Q(0.00740097),
  DSP16_Q(-0.00381511),
  DSP16_Q(0.00172682),
  DSP16_Q(-0.00056814),
  DSP16_Q(0.00006533),
  DSP16_Q(-0.00003690),
  DSP16_Q(0.00045463),
  DSP16_Q(-0.00147997),
  DSP16_Q(0.00335988),
  DSP16_Q(-0.00658348),
  DSP16_Q(0.01255816),
  DSP16_Q(-0.02811008),
  DSP16_Q(0.49491817),
  DSP16_Q(0.03228471),
  DSP16_Q(-0.01370246),
  DSP16_Q(0.00713891),
  DSP16_Q(-0.00367944),
  DSP16_Q(0.00166466),
  DSP16_Q(-0.00054708),
  DSP16_Q(0.00006258),
  DSP16_Q(-0.00003599),
  DSP16_Q(0.00044011),
  DSP16_Q(-0.00143085),
  DSP16_Q(0.00324672),
  DSP16_Q(-0.00636053),
  DSP16_Q(0.01213395),
  DSP16_Q(-0.02718258),
  DSP16_Q(0.49515520),
  DSP16_Q(0.03106510),
  DSP16_Q(-0.01319840),
  DSP16_Q(0.00687723),
  DSP16_Q(-0.00354399),
  DSP16_Q(0.00160265),
  DSP16_Q(-0.00052611),
  DSP16_Q(0.00005987),
  DSP16_Q(-0.00003504),
  DSP16_Q(0.00042545),
  DSP16_Q(-0.00138143),
  DSP16_Q(0.00313301),
  DSP16_Q(-0.00613660),
  DSP16_Q(0.01170779),
  DSP16_Q(-0.02624929),
  DSP16_Q(0.49538367),
  DSP16_Q(0.02985021),
  DSP16_Q(-0.01269524),
  DSP16_Q(0.00661593),
  DSP16_Q(-0.00340879),
  DSP16_Q(0.00154082),
  DSP16_Q(-0.00050524),
  DSP16_Q(0.00005720),
  DSP16_Q(-0.00003406),
  DSP16_Q(0.00041067),
  DSP16_Q(-0.00133172),
  DSP16_Q(0.00301876),
  DSP16_Q(-0.00591169),
  DSP16_Q(0.01127970),
  DSP16_Q(-0.02531022),
  DSP16_Q(0.49560358),
  DSP16_Q(0.02864007),
  DSP16_Q(-0.01219300),
  DSP16_Q(0.00635504),
  DSP16_Q(-0.00327385),
  DSP16_Q(0.00147914),
  DSP16_Q(-0.00048447),
  DSP16_Q(0.00005456),
  DSP16_Q(-0.00003306),
  DSP16_Q(0.00039576),
  DSP16_Q(-0.00128172),
  DSP16_Q(0.00290397),
  DSP16_Q(-0.00568582),
  DSP16_Q(0.01084970),
  DSP16_Q(-0.02436538),
  DSP16_Q(0.49581492),
  DSP16_Q(0.02743470),
  DSP16_Q(-0.01169170),
  DSP16_Q(0.00609457),
  DSP16_Q(-0.00313915),
  DSP16_Q(0.00141764),
  DSP16_Q(-0.00046380),
  DSP16_Q(0.00005196),
  DSP16_Q(-0.00003203),
  DSP16_Q(0.00038072),
  DSP16_Q(-0.00123144),
  DSP16_Q(0.00278865),
  DSP16_Q(-0.00545898),
  DSP16_Q(0.01041780),
  DSP16_Q(-0.02341479),
  DSP16_Q(0.49601769),
  DSP16_Q(0.02623413),
  DSP16_Q(-0.01119137),
  DSP16_Q(0.00583453),
  DSP16_Q(-0.00300472),
  DSP16_Q(0.00135632),
  DSP16_Q(-0.00044323),
  DSP16_Q(0.00004939),
  DSP16_Q(-0.00003097),
  DSP16_Q(0.00036555),
  DSP16_Q(-0.00118086),
  DSP16_Q(0.00267279),
  DSP16_Q(-0.00523120),
  DSP16_Q(0.00998403),
  DSP16_Q(-0.02245846),
  DSP16_Q(0.49621188),
  DSP16_Q(0.02503838),
  DSP16_Q(-0.01069202),
  DSP16_Q(0.00557493),
  DSP16_Q(-0.00287056),
  DSP16_Q(0.00129516),
  DSP16_Q(-0.00042276),
  DSP16_Q(0.00004686),
  DSP16_Q(-0.00002988),
  DSP16_Q(0.00035025),
  DSP16_Q(-0.00113001),
  DSP16_Q(0.00255642),
  DSP16_Q(-0.00500248),
  DSP16_Q(0.00954839),
  DSP16_Q(-0.02149641),
  DSP16_Q(0.49639748),
  DSP16_Q(0.02384748),
  DSP16_Q(-0.01019369),
  DSP16_Q(0.00531578),
  DSP16_Q(-0.00273668),
  DSP16_Q(0.00123419),
  DSP16_Q(-0.00040240),
  DSP16_Q(0.00004436),
  DSP16_Q(-0.00002876),
  DSP16_Q(0.00033483),
  DSP16_Q(-0.00107887),
  DSP16_Q(0.00243952),
  DSP16_Q(-0.00477284),
  DSP16_Q(0.00911090),
  DSP16_Q(-0.02052865),
  DSP16_Q(0.49657449),
  DSP16_Q(0.02266145),
  DSP16_Q(-0.00969638),
  DSP16_Q(0.00505710),
  DSP16_Q(-0.00260307),
  DSP16_Q(0.00117340),
  DSP16_Q(-0.00038214),
  DSP16_Q(0.00004190),
  DSP16_Q(-0.00002762),
  DSP16_Q(0.00031927),
  DSP16_Q(-0.00102745),
  DSP16_Q(0.00232210),
  DSP16_Q(-0.00454227),
  DSP16_Q(0.00867159),
  DSP16_Q(-0.01955520),
  DSP16_Q(0.49674290),
  DSP16_Q(0.02148032),
  DSP16_Q(-0.00920013),
  DSP16_Q(0.00479889),
  DSP16_Q(-0.00246976),
  DSP16_Q(0.00111279),
  DSP16_Q(-0.00036199),
  DSP16_Q(0.00003948),
  DSP16_Q(-0.00002644),
  DSP16_Q(0.00030359),
  DSP16_Q(-0.00097576),
  DSP16_Q(0.00220418),
  DSP16_Q(-0.00431079),
  DSP16_Q(0.00823045),
  DSP16_Q(-0.01857607),
  DSP16_Q(0.49690271),
  DSP16_Q(0.02030410),
  DSP16_Q(-0.00870496),
  DSP16_Q(0.00454118),
  DSP16_Q(-0.00233674),
  DSP16_Q(0.00105237),
  DSP16_Q(-0.00034194),
  DSP16_Q(0.00003709),
  DSP16_Q(-0.00002523),
  DSP16_Q(0.00028778),
  DSP16_Q(-0.00092379),
  DSP16_Q(0.00208575),
  DSP16_Q(-0.00407841),
  DSP16_Q(0.00778753),
  DSP16_Q(-0.01759128),
  DSP16_Q(0.49705391),
  DSP16_Q(0.01913283),
  DSP16_Q(-0.00821088),
  DSP16_Q(0.00428397),
  DSP16_Q(-0.00220402),
  DSP16_Q(0.00099215),
  DSP16_Q(-0.00032200),
  DSP16_Q(0.00003474),
  DSP16_Q(-0.00002400),
  DSP16_Q(0.00027185),
  DSP16_Q(-0.00087154),
  DSP16_Q(0.00196681),
  DSP16_Q(-0.00384514),
  DSP16_Q(0.00734282),
  DSP16_Q(-0.01660085),
  DSP16_Q(0.49719650),
  DSP16_Q(0.01796653),
  DSP16_Q(-0.00771793),
  DSP16_Q(0.00402728),
  DSP16_Q(-0.00207161),
  DSP16_Q(0.00093211),
  DSP16_Q(-0.00030217),
  DSP16_Q(0.00003242),
  DSP16_Q(-0.00002273),
  DSP16_Q(0.00025579),
  DSP16_Q(-0.00081902),
  DSP16_Q(0.00184739),
  DSP16_Q(-0.00361099),
  DSP16_Q(0.00689635),
  DSP16_Q(-0.01560478),
  DSP16_Q(0.49733046),
  DSP16_Q(0.01680522),
  DSP16_Q(-0.00722611),
  DSP16_Q(0.00377111),
  DSP16_Q(-0.00193952),
  DSP16_Q(0.00087227),
  DSP16_Q(-0.00028244),
  DSP16_Q(0.00003013),
  DSP16_Q(-0.00002143),
  DSP16_Q(0.00023960),
  DSP16_Q(-0.00076623),
  DSP16_Q(0.00172747),
  DSP16_Q(-0.00337597),
  DSP16_Q(0.00644814),
  DSP16_Q(-0.01460311),
  DSP16_Q(0.49745581),
  DSP16_Q(0.01564893),
  DSP16_Q(-0.00673546),
  DSP16_Q(0.00351549),
  DSP16_Q(-0.00180774),
  DSP16_Q(0.00081263),
  DSP16_Q(-0.00026282),
  DSP16_Q(0.00002788),
  DSP16_Q(-0.00002011),
  DSP16_Q(0.00022329),
  DSP16_Q(-0.00071318),
  DSP16_Q(0.00160706),
  DSP16_Q(-0.00314009),
  DSP16_Q(0.00599820),
  DSP16_Q(-0.01359583),
  DSP16_Q(0.49757253),
  DSP16_Q(0.01449768),
  DSP16_Q(-0.00624598),
  DSP16_Q(0.00326041),
  DSP16_Q(-0.00167630),
  DSP16_Q(0.00075319),
  DSP16_Q(-0.00024331),
  DSP16_Q(0.00002567),
  DSP16_Q(-0.00001875),
  DSP16_Q(0.00020685),
  DSP16_Q(-0.00065985),
  DSP16_Q(0.00148618),
  DSP16_Q(-0.00290336),
  DSP16_Q(0.00554655),
  DSP16_Q(-0.01258298),
  DSP16_Q(0.49768061),
  DSP16_Q(0.01335148),
  DSP16_Q(-0.00575772),
  DSP16_Q(0.00300590),
  DSP16_Q(-0.00154518),
  DSP16_Q(0.00069396),
  DSP16_Q(-0.00022392),
  DSP16_Q(0.00002349),
  DSP16_Q(-0.00001736),
  DSP16_Q(0.00019029),
  DSP16_Q(-0.00060627),
  DSP16_Q(0.00136482),
  DSP16_Q(-0.00266579),
  DSP16_Q(0.00509321),
  DSP16_Q(-0.01156457),
  DSP16_Q(0.49778006),
  DSP16_Q(0.01221037),
  DSP16_Q(-0.00527068),
  DSP16_Q(0.00275197),
  DSP16_Q(-0.00141441),
  DSP16_Q(0.00063493),
  DSP16_Q(-0.00020463),
  DSP16_Q(0.00002135),
  DSP16_Q(-0.00001594),
  DSP16_Q(0.00017360),
  DSP16_Q(-0.00055242),
  DSP16_Q(0.00124299),
  DSP16_Q(-0.00242738),
  DSP16_Q(0.00463819),
  DSP16_Q(-0.01054061),
  DSP16_Q(0.49787088),
  DSP16_Q(0.01107437),
  DSP16_Q(-0.00478488),
  DSP16_Q(0.00249862),
  DSP16_Q(-0.00128398),
  DSP16_Q(0.00057611),
  DSP16_Q(-0.00018546),
  DSP16_Q(0.00001924),
  DSP16_Q(-0.00001449),
  DSP16_Q(0.00015679),
  DSP16_Q(-0.00049831),
  DSP16_Q(0.00112069),
  DSP16_Q(-0.00218816),
  DSP16_Q(0.00418152),
  DSP16_Q(-0.00951112),
  DSP16_Q(0.49795305),
  DSP16_Q(0.00994350),
  DSP16_Q(-0.00430036),
  DSP16_Q(0.00224587),
  DSP16_Q(-0.00115390),
  DSP16_Q(0.00051750),
  DSP16_Q(-0.00016639),
  DSP16_Q(0.00001716),
  DSP16_Q(-0.00001301),
  DSP16_Q(0.00013985),
  DSP16_Q(-0.00044394),
  DSP16_Q(0.00099794),
  DSP16_Q(-0.00194813),
  DSP16_Q(0.00372321),
  DSP16_Q(-0.00847612),
  DSP16_Q(0.49802659),
  DSP16_Q(0.00881777),
  DSP16_Q(-0.00381712),
  DSP16_Q(0.00199373),
  DSP16_Q(-0.00102418),
  DSP16_Q(0.00045911),
  DSP16_Q(-0.00014745),
  DSP16_Q(0.00001512),
  DSP16_Q(-0.00001150),
  DSP16_Q(0.00012280),
  DSP16_Q(-0.00038932),
  DSP16_Q(0.00087473),
  DSP16_Q(-0.00170730),
  DSP16_Q(0.00326328),
  DSP16_Q(-0.00743563),
  DSP16_Q(0.49809147),
  DSP16_Q(0.00769722),
  DSP16_Q(-0.00333519),
  DSP16_Q(0.00174222),
  DSP16_Q(-0.00089482),
  DSP16_Q(0.00040093),
  DSP16_Q(-0.00012861),
  DSP16_Q(0.00001311),
  DSP16_Q(-0.00000995),
  DSP16_Q(0.00010562),
  DSP16_Q(-0.00033444),
  DSP16_Q(0.00075107),
  DSP16_Q(-0.00146568),
  DSP16_Q(0.00280175),
  DSP16_Q(-0.00638967),
  DSP16_Q(0.49814771),
  DSP16_Q(0.00658187),
  DSP16_Q(-0.00285458),
  DSP16_Q(0.00149134),
  DSP16_Q(-0.00076584),
  DSP16_Q(0.00034298),
  DSP16_Q(-0.00010989),
  DSP16_Q(0.00001114),
  DSP16_Q(-0.00000837),
  DSP16_Q(0.00008832),
  DSP16_Q(-0.00027932),
  DSP16_Q(0.00062697),
  DSP16_Q(-0.00122328),
  DSP16_Q(0.00233864),
  DSP16_Q(-0.00533825),
  DSP16_Q(0.49819530),
  DSP16_Q(0.00547173),
  DSP16_Q(-0.00237533),
  DSP16_Q(0.00124110),
  DSP16_Q(-0.00063722),
  DSP16_Q(0.00028524),
  DSP16_Q(-0.00009128),
  DSP16_Q(0.00000920),
  DSP16_Q(-0.00000676),
  DSP16_Q(0.00007089),
  DSP16_Q(-0.00022394),
  DSP16_Q(0.00050243),
  DSP16_Q(-0.00098012),
  DSP16_Q(0.00187396),
  DSP16_Q(-0.00428140),
  DSP16_Q(0.49823424),
  DSP16_Q(0.00436683),
  DSP16_Q(-0.00189745),
  DSP16_Q(0.00099152),
  DSP16_Q(-0.00050899),
  DSP16_Q(0.00022774),
  DSP16_Q(-0.00007279),
  DSP16_Q(0.00000729),
  DSP16_Q(-0.00000512),
  DSP16_Q(0.00005335),
  DSP16_Q(-0.00016832),
  DSP16_Q(0.00037746),
  DSP16_Q(-0.00073620),
  DSP16_Q(0.00140774),
  DSP16_Q(-0.00321913),
  DSP16_Q(0.49826453),
  DSP16_Q(0.00326718),
  DSP16_Q(-0.00142095),
  DSP16_Q(0.00074261),
  DSP16_Q(-0.00038115),
  DSP16_Q(0.00017045),
  DSP16_Q(-0.00005442),
  DSP16_Q(0.00000542),
  DSP16_Q(-0.00000345),
  DSP16_Q(0.00003569),
  DSP16_Q(-0.00011245),
  DSP16_Q(0.00025206),
  DSP16_Q(-0.00049153),
  DSP16_Q(0.00093999),
  DSP16_Q(-0.00215146),
  DSP16_Q(0.49828617),
  DSP16_Q(0.00217281),
  DSP16_Q(-0.00094587),
  DSP16_Q(0.00049438),
  DSP16_Q(-0.00025370),
  DSP16_Q(0.00011340),
  DSP16_Q(-0.00003616),
  DSP16_Q(0.00000358),
  DSP16_Q(-0.00000174),
  DSP16_Q(0.00001790),
  DSP16_Q(-0.00005635),
  DSP16_Q(0.00012624),
  DSP16_Q(-0.00024613),
  DSP16_Q(0.00047074),
  DSP16_Q(-0.00107841),
  DSP16_Q(0.49829915),
  DSP16_Q(0.00108375),
  DSP16_Q(-0.00047221),
  DSP16_Q(0.00024684),
  DSP16_Q(-0.00012665),
  DSP16_Q(0.00005658),
  DSP16_Q(-0.00001802),
  DSP16_Q(0.00000177),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00000000),
  DSP16_Q(0.49830347),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000177),
  DSP16_Q(-0.00001802),
  DSP16_Q(0.00005658),
  DSP16_Q(-0.00012665),
  DSP16_Q(0.00024684),
  DSP16_Q(-0.00047221),
  DSP16_Q(0.00108375),
  DSP16_Q(0.49829915),
  DSP16_Q(-0.00107841),
  DSP16_Q(0.00047074),
  DSP16_Q(-0.00024613),
  DSP16_Q(0.00012624),
  DSP16_Q(-0.00005635),
  DSP16_Q(0.00001790),
  DSP16_Q(-0.00000174),
  DSP16_Q(0.00000358),
  DSP16_Q(-0.00003616),
  DSP16_Q(0.00011340),
  DSP16_Q(-0.00025370),
  DSP16_Q(0.00049438),
  DSP16_Q(-0.00094587),
  DSP16_Q(0.00217281),
  DSP16_Q(0.49828617),
  DSP16_Q(-0.00215146),
  DSP16_Q(0.00093999),
  DSP16_Q(-0.00049153),
  DSP16_Q(0.00025206),
  DSP16_Q(-0.00011245),
  DSP16_Q(0.00003569),
  DSP16_Q(-0.00000345),
  DSP16_Q(0.00000542),
  DSP16_Q(-0.00005442),
  DSP16_Q(0.00017045),
  DSP16_Q(-0.00038115),
  DSP16_Q(0.00074261),
  DSP16_Q(-0.00142095),
  DSP16_Q(0.00326718),
  DSP16_Q(0.49826453),
  DSP16_Q(-0.00321913),
  DSP16_Q(0.00140774),
  DSP16_Q(-0.00073620),
  DSP16_Q(0.00037746),
  DSP16_Q(-0.00016832),
  DSP16_Q(0.00005335),
  DSP16_Q(-0.00000512),
  DSP16_Q(0.00000729),
  DSP16_Q(-0.00007279),
  DSP16_Q(0.00022774),
  DSP16_Q(-0.00050899),
  DSP16_Q(0.00099152),
  DSP16_Q(-0.00189745),
  DSP16_Q(0.00436683),
  DSP16_Q(0.49823424),
  DSP16_Q(-0.00428140),
  DSP16_Q(0.00187396),
  DSP16_Q(-0.00098012),
  DSP16_Q(0.00050243),
  DSP16_Q(-0.00022394),
  DSP16_Q(0.00007089),
  DSP16_Q(-0.00000676),
  DSP16_Q(0.00000920),
  DSP16_Q(-0.00009128),
  DSP16_Q(0.00028524),
  DSP16_Q(-0.00063722),
  DSP16_Q(0.00124110),
  DSP16_Q(-0.00237533),
  DSP16_Q(0.00547173),
  DSP16_Q(0.49819530),
  DSP16_Q(-0.00533825),
  DSP16_Q(0.00233864),
  DSP16_Q(-0.00122328),
  DSP16_Q(0.00062697),
  DSP16_Q(-0.00027932),
  DSP16_Q(0.00008832),
  DSP16_Q(-0.00000837),
  DSP16_Q(0.00001114),
  DSP16_Q(-0.00010989),
  DSP16_Q(0.00034298),
  DSP16_Q(-0.00076584),
  DSP16_Q(0.00149134),
  DSP16_Q(-0.00285458),
  DSP16_Q(0.00658187),
  DSP16_Q(0.49814771),
  DSP16_Q(-0.00638967),
  DSP16_Q(0.00280175),
  DSP16_Q(-0.00146568),
  DSP16_Q(0.00075107),
  DSP16_Q(-0.00033444),
  DSP16_Q(0.00010562),
  DSP16_Q(-0.00000995),
  DSP16_Q(0.00001311),
  DSP16_Q(-0.00012861),
  DSP16_Q(0.00040093),
  DSP16_Q(-0.00089482),
  DSP16_Q(0.00174222),
  DSP16_Q(-0.00333519),
  DSP16_Q(0.00769722),
  DSP16_Q(0.49809147),
  DSP16_Q(-0.00743563),
  DSP16_Q(0.00326328),
  DSP16_Q(-0.00170730),
  DSP16_Q(0.00087473),
  DSP16_Q(-0.00038932),
  DSP16_Q(0.00012280),
  DSP16_Q(-0.00001150),
  DSP16_Q(0.00001512),
  DSP16_Q(-0.00014745),
  DSP16_Q(0.00045911),
  DSP16_Q(-0.00102418),
  DSP16_Q(0.00199373),
  DSP16_Q(-0.00381712),
  DSP16_Q(0.00881777),
  DSP16_Q(0.49802659),
  DSP16_Q(-0.00847612),
  DSP16_Q(0.00372321),
  DSP16_Q(-0.00194813),
  DSP16_Q(0.00099794),
  DSP16_Q(-0.00044394),
  DSP16_Q(0.00013985),
  DSP16_Q(-0.00001301),
  DSP16_Q(0.00001716),
  DSP16_Q(-0.00016639),
  DSP16_Q(0.00051750),
  DSP16_Q(-0.00115390),
  DSP16_Q(0.00224587),
  DSP16_Q(-0.00430036),
  DSP16_Q(0.00994350),
  DSP16_Q(0.49795305),
  DSP16_Q(-0.00951112),
  DSP16_Q(0.00418152),
  DSP16_Q(-0.00218816),
  DSP16_Q(0.00112069),
  DSP16_Q(-0.00049831),
  DSP16_Q(0.00015679),
  DSP16_Q(-0.00001449),
  DSP16_Q(0.00001924),
  DSP16_Q(-0.00018546),
  DSP16_Q(0.00057611),
  DSP16_Q(-0.00128398),
  DSP16_Q(0.00249862),
  DSP16_Q(-0.00478488),
  DSP16_Q(0.01107437),
  DSP16_Q(0.49787088),
  DSP16_Q(-0.01054061),
  DSP16_Q(0.00463819),
  DSP16_Q(-0.00242738),
  DSP16_Q(0.00124299),
  DSP16_Q(-0.00055242),
  DSP16_Q(0.00017360),
  DSP16_Q(-0.00001594),
  DSP16_Q(0.00002135),
  DSP16_Q(-0.00020463),
  DSP16_Q(0.00063493),
  DSP16_Q(-0.00141441),
  DSP16_Q(0.00275197),
  DSP16_Q(-0.00527068),
  DSP16_Q(0.01221037),
  DSP16_Q(0.49778006),
  DSP16_Q(-0.01156457),
  DSP16_Q(0.00509321),
  DSP16_Q(-0.00266579),
  DSP16_Q(0.00136482),
  DSP16_Q(-0.00060627),
  DSP16_Q(0.00019029),
  DSP16_Q(-0.00001736),
  DSP16_Q(0.00002349),
  DSP16_Q(-0.00022392),
  DSP16_Q(0.00069396),
  DSP16_Q(-0.00154518),
  DSP16_Q(0.00300590),
  DSP16_Q(-0.00575772),
  DSP16_Q(0.01335148),
  DSP16_Q(0.49768061),
  DSP16_Q(-0.01258298),
  DSP16_Q(0.00554655),
  DSP16_Q(-0.00290336),
  DSP16_Q(0.00148618),
  DSP16_Q(-0.00065985),
  DSP16_Q(0.00020685),
  DSP16_Q(-0.00001875),
  DSP16_Q(0.00002567),
  DSP16_Q(-0.00024331),
  DSP16_Q(0.00075319),
  DSP16_Q(-0.00167630),
  DSP16_Q(0.00326041),
  DSP16_Q(-0.00624598),
  DSP16_Q(0.01449768),
  DSP16_Q(0.49757253),
  DSP16_Q(-0.01359583),
  DSP16_Q(0.00599820),
  DSP16_Q(-0.00314009),
  DSP16_Q(0.00160706),
  DSP16_Q(-0.00071318),
  DSP16_Q(0.00022329),
  DSP16_Q(-0.00002011),
  DSP16_Q(0.00002788),
  DSP16_Q(-0.00026282),
  DSP16_Q(0.00081263),
  DSP16_Q(-0.00180774),
  DSP16_Q(0.00351549),
  DSP16_Q(-0.00673546),
  DSP16_Q(0.01564893),
  DSP16_Q(0.49745581),
  DSP16_Q(-0.01460311),
  DSP16_Q(0.00644814),
  DSP16_Q(-0.00337597),
  DSP16_Q(0.00172747),
  DSP16_Q(-0.00076623),
  DSP16_Q(0.00023960),
  DSP16_Q(-0.00002143),
  DSP16_Q(0.00003013),
  DSP16_Q(-0.00028244),
  DSP16_Q(0.00087227),
  DSP16_Q(-0.00193952),
  DSP16_Q(0.00377111),
  DSP16_Q(-0.00722611),
  DSP16_Q(0.01680522),
  DSP16_Q(0.49733046),
  DSP16_Q(-0.01560478),
  DSP16_Q(0.00689635),
  DSP16_Q(-0.00361099),
  DSP16_Q(0.00184739),
  DSP16_Q(-0.00081902),
  DSP16_Q(0.00025579),
  DSP16_Q(-0.00002273),
  DSP16_Q(0.00003242),
  DSP16_Q(-0.00030217),
  DSP16_Q(0.00093211),
  DSP16_Q(-0.00207161),
  DSP16_Q(0.00402728),
  DSP16_Q(-0.00771793),
  DSP16_Q(0.01796653),
  DSP16_Q(0.49719650),
  DSP16_Q(-0.01660085),
  DSP16_Q(0.00734282),
  DSP16_Q(-0.00384514),
  DSP16_Q(0.00196681),
  DSP16_Q(-0.00087154),
  DSP16_Q(0.00027185),
  DSP16_Q(-0.00002400),
  DSP16_Q(0.00003474),
  DSP16_Q(-0.00032200),
  DSP16_Q(0.00099215),
  DSP16_Q(-0.00220402),
  DSP16_Q(0.00428397),
  DSP16_Q(-0.00821088),
  DSP16_Q(0.01913283),
  DSP16_Q(0.49705391),
  DSP16_Q(-0.01759128),
  DSP16_Q(0.00778753),
  DSP16_Q(-0.00407841),
  DSP16_Q(0.00208575),
  DSP16_Q(-0.00092379),
  DSP16_Q(0.00028778),
  DSP16_Q(-0.00002523),
  DSP16_Q(0.00003709),
  DSP16_Q(-0.00034194),
  DSP16_Q(0.00105237),
  DSP16_Q(-0.00233674),
  DSP16_Q(0.00454118),
  DSP16_Q(-0.00870496),
  DSP16_Q(0.02030410),
  DSP16_Q(0.49690271),
  DSP16_Q(-0.01857607),
  DSP16_Q(0.00823045),
  DSP16_Q(-0.00431079),
  DSP16_Q(0.00220418),
  DSP16_Q(-0.00097576),
  DSP16_Q(0.00030359),
  DSP16_Q(-0.00002644),
  DSP16_Q(0.00003948),
  DSP16_Q(-0.00036199),
  DSP16_Q(0.00111279),
  DSP16_Q(-0.00246976),
  DSP16_Q(0.00479889),
  DSP16_Q(-0.00920013),
  DSP16_Q(0.02148032),
  DSP16_Q(0.49674290),
  DSP16_Q(-0.01955520),
  DSP16_Q(0.00867159),
  DSP16_Q(-0.00454227),
  DSP16_Q(0.00232210),
  DSP16_Q(-0.00102745),
  DSP16_Q(0.00031927),
  DSP16_Q(-0.00002762),
  DSP16_Q(0.00004190),
  DSP16_Q(-0.00038214),
  DSP16_Q(0.00117340),
  DSP16_Q(-0.00260307),
  DSP16_Q(0.00505710),
  DSP16_Q(-0.00969638),
  DSP16_Q(0.02266145),
  DSP16_Q(0.49657449),
  DSP16_Q(-0.02052865),
  DSP16_Q(0.00911090),
  DSP16_Q(-0.00477284),
  DSP16_Q(0.00243952),
  DSP16_Q(-0.00107887),
  DSP16_Q(0.00033483),
  DSP16_Q(-0.00002876),
  DSP16_Q(0.00004436),
  DSP16_Q(-0.00040240),
  DSP16_Q(0.00123419),
  DSP16_Q(-0.00273668),
  DSP16_Q(0.00531578),
  DSP16_Q(-0.01019369),
  DSP16_Q(0.02384748),
  DSP16_Q(0.49639748),
  DSP16_Q(-0.02149641),
  DSP16_Q(0.00954839),
  DSP16_Q(-0.00500248),
  DSP16_Q(0.00255642),
  DSP16_Q(-0.00113001),
  DSP16_Q(0.00035025),
  DSP16_Q(-0.00002988),
  DSP16_Q(0.00004686),
  DSP16_Q(-0.00042276),
  DSP16_Q(0.00129516),
  DSP16_Q(-0.00287056),
  DSP16_Q(0.00557493),
  DSP16_Q(-0.01069202),
  DSP16_Q(0.02503838),
  DSP16_Q(0.49621188),
  DSP16_Q(-0.02245846),
  DSP16_Q(0.00998403),
  DSP16_Q(-0.00523120),
  DSP16_Q(0.00267279),
  DSP16_Q(-0.00118086),
  DSP16_Q(0.00036555),
  DSP16_Q(-0.00003097),
  DSP16_Q(0.00004939),
  DSP16_Q(-0.00044323),
  DSP16_Q(0.00135632),
  DSP16_Q(-0.00300472),
  DSP16_Q(0.00583453),
  DSP16_Q(-0.01119137),
  DSP16_Q(0.02623413),
  DSP16_Q(0.49601769),
  DSP16_Q(-0.02341479),
  DSP16_Q(0.01041780),
  DSP16_Q(-0.00545898),
  DSP16_Q(0.00278865),
  DSP16_Q(-0.00123144),
  DSP16_Q(0.00038072),
  DSP16_Q(-0.00003203),
  DSP16_Q(0.00005196),
  DSP16_Q(-0.00046380),
  DSP16_Q(0.00141764),
  DSP16_Q(-0.00313915),
  DSP16_Q(0.00609457),
  DSP16_Q(-0.01169170),
  DSP16_Q(0.02743470),
  DSP16_Q(0.49581492),
  DSP16_Q(-0.02436538),
  DSP16_Q(0.01084970),
  DSP16_Q(-0.00568582),
  DSP16_Q(0.00290397),
  DSP16_Q(-0.00128172),
  DSP16_Q(0.00039576),
  DSP16_Q(-0.00003306),
  DSP16_Q(0.00005456),
  DSP16_Q(-0.00048447),
  DSP16_Q(0.00147914),
  DSP16_Q(-0.00327385),
  DSP16_Q(0.00635504),
  DSP16_Q(-0.01219300),
  DSP16_Q(0.02864007),
  DSP16_Q(0.49560358),
  DSP16_Q(-0.02531022),
  DSP16_Q(0.01127970),
  DSP16_Q(-0.00591169),
  DSP16_Q(0.00301876),
  DSP16_Q(-0.00133172),
  DSP16_Q(0.00041067),
  DSP16_Q(-0.00003406),
  DSP16_Q(0.00005720),
  DSP16_Q(-0.00050524),
  DSP16_Q(0.00154082),
  DSP16_Q(-0.00340879),
  DSP16_Q(0.00661593),
  DSP16_Q(-0.01269524),
  DSP16_Q(0.02985021),
  DSP16_Q(0.49538367),
  DSP16_Q(-0.02624929),
  DSP16_Q(0.01170779),
  DSP16_Q(-0.00613660),
  DSP16_Q(0.00313301),
  DSP16_Q(-0.00138143),
  DSP16_Q(0.00042545),
  DSP16_Q(-0.00003504),
  DSP16_Q(0.00005987),
  DSP16_Q(-0.00052611),
  DSP16_Q(0.00160265),
  DSP16_Q(-0.00354399),
  DSP16_Q(0.00687723),
  DSP16_Q(-0.01319840),
  DSP16_Q(0.03106510),
  DSP16_Q(0.49515520),
  DSP16_Q(-0.02718258),
  DSP16_Q(0.01213395),
  DSP16_Q(-0.00636053),
  DSP16_Q(0.00324672),
  DSP16_Q(-0.00143085),
  DSP16_Q(0.00044011),
  DSP16_Q(-0.00003599),
  DSP16_Q(0.00006258),
  DSP16_Q(-0.00054708),
  DSP16_Q(0.00166466),
  DSP16_Q(-0.00367944),
  DSP16_Q(0.00713891),
  DSP16_Q(-0.01370246),
  DSP16_Q(0.03228471),
  DSP16_Q(0.49491817),
  DSP16_Q(-0.02811008),
  DSP16_Q(0.01255816),
  DSP16_Q(-0.00658348),
  DSP16_Q(0.00335988),
  DSP16_Q(-0.00147997),
  DSP16_Q(0.00045463),
  DSP16_Q(-0.00003690),
  DSP16_Q(0.00006533),
  DSP16_Q(-0.00056814),
  DSP16_Q(0.00172682),
  DSP16_Q(-0.00381511),
  DSP16_Q(0.00740097),
  DSP16_Q(-0.01420740),
  DSP16_Q(0.03350901),
  DSP16_Q(0.49467261),
  DSP16_Q(-0.02903177),
  DSP16_Q(0.01298042),
  DSP16_Q(-0.00680543),
  DSP16_Q(0.00347248),
  DSP16_Q(-0.00152880),
  DSP16_Q(0.00046902),
  DSP16_Q(-0.00003780),
  DSP16_Q(0.00006811),
  DSP16_Q(-0.00058931),
  DSP16_Q(0.00178914),
  DSP16_Q(-0.00395102),
  DSP16_Q(0.00766340),
  DSP16_Q(-0.01471319),
  DSP16_Q(0.03473798),
  DSP16_Q(0.49441850),
  DSP16_Q(-0.02994764),
  DSP16_Q(0.01340070),
  DSP16_Q(-0.00702638),
  DSP16_Q(0.00358453),
  DSP16_Q(-0.00157733),
  DSP16_Q(0.00048329),
  DSP16_Q(-0.00003866),
  DSP16_Q(0.00007093),
  DSP16_Q(-0.00061057),
  DSP16_Q(0.00185162),
  DSP16_Q(-0.00408715),
  DSP16_Q(0.00792618),
  DSP16_Q(-0.01521980),
  DSP16_Q(0.03597159),
  DSP16_Q(0.49415587),
  DSP16_Q(-0.03085767),
  DSP16_Q(0.01381899),
  DSP16_Q(-0.00724632),
  DSP16_Q(0.00369602),
  DSP16_Q(-0.00162557),
  DSP16_Q(0.00049742),
  DSP16_Q(-0.00003950),
  DSP16_Q(0.00007378),
  DSP16_Q(-0.00063192),
  DSP16_Q(0.00191425),
  DSP16_Q(-0.00422350),
  DSP16_Q(0.00818930),
  DSP16_Q(-0.01572723),
  DSP16_Q(0.03720982),
  DSP16_Q(0.49388472),
  DSP16_Q(-0.03176186),
  DSP16_Q(0.01423527),
  DSP16_Q(-0.00746524),
  DSP16_Q(0.00380694),
  DSP16_Q(-0.00167351),
  DSP16_Q(0.00051142),
  DSP16_Q(-0.00004031),
  DSP16_Q(0.00007667),
  DSP16_Q(-0.00065338),
  DSP16_Q(0.00197703),
  DSP16_Q(-0.00436005),
  DSP16_Q(0.00845275),
  DSP16_Q(-0.01623543),
  DSP16_Q(0.03845264),
  DSP16_Q(0.49360505),
  DSP16_Q(-0.03266019),
  DSP16_Q(0.01464953),
  DSP16_Q(-0.00768312),
  DSP16_Q(0.00391729),
  DSP16_Q(-0.00172114),
  DSP16_Q(0.00052529),
  DSP16_Q(-0.00004109),
  DSP16_Q(0.00007960),
  DSP16_Q(-0.00067492),
  DSP16_Q(0.00203995),
  DSP16_Q(-0.00449681),
  DSP16_Q(0.00871651),
  DSP16_Q(-0.01674440),
  DSP16_Q(0.03970001),
  DSP16_Q(0.49331688),
  DSP16_Q(-0.03355264),
  DSP16_Q(0.01506176),
  DSP16_Q(-0.00789997),
  DSP16_Q(0.00402707),
  DSP16_Q(-0.00176847),
  DSP16_Q(0.00053903),
  DSP16_Q(-0.00004185),
  DSP16_Q(0.00008256),
  DSP16_Q(-0.00069656),
  DSP16_Q(0.00210302),
  DSP16_Q(-0.00463376),
  DSP16_Q(0.00898057),
  DSP16_Q(-0.01725410),
  DSP16_Q(0.04095193),
  DSP16_Q(0.49302022),
  DSP16_Q(-0.03443922),
  DSP16_Q(0.01547193),
  DSP16_Q(-0.00811578),
  DSP16_Q(0.00413626),
  DSP16_Q(-0.00181550),
  DSP16_Q(0.00055264),
  DSP16_Q(-0.00004258),
  DSP16_Q(0.00008556),
  DSP16_Q(-0.00071828),
  DSP16_Q(0.00216623),
  DSP16_Q(-0.00477090),
  DSP16_Q(0.00924491),
  DSP16_Q(-0.01776451),
  DSP16_Q(0.04220835),
  DSP16_Q(0.49271508),
  DSP16_Q(-0.03531989),
  DSP16_Q(0.01588004),
  DSP16_Q(-0.00833052),
  DSP16_Q(0.00424488),
  DSP16_Q(-0.00186222),
  DSP16_Q(0.00056611),
  DSP16_Q(-0.00004329),
  DSP16_Q(0.00008860),
  DSP16_Q(-0.00074010),
  DSP16_Q(0.00222957),
  DSP16_Q(-0.00490823),
  DSP16_Q(0.00950954),
  DSP16_Q(-0.01827562),
  DSP16_Q(0.04346925),
  DSP16_Q(0.49240146),
  DSP16_Q(-0.03619466),
  DSP16_Q(0.01628607),
  DSP16_Q(-0.00854421),
  DSP16_Q(0.00435291),
  DSP16_Q(-0.00190864),
  DSP16_Q(0.00057946),
  DSP16_Q(-0.00004397),
  DSP16_Q(0.00009167),
  DSP16_Q(-0.00076201),
  DSP16_Q(0.00229305),
  DSP16_Q(-0.00504572),
  DSP16_Q(0.00977442),
  DSP16_Q(-0.01878739),
  DSP16_Q(0.04473460),
  DSP16_Q(0.49207938),
  DSP16_Q(-0.03706351),
  DSP16_Q(0.01669000),
  DSP16_Q(-0.00875682),
  DSP16_Q(0.00446034),
  DSP16_Q(-0.00195474),
  DSP16_Q(0.00059267),
  DSP16_Q(-0.00004462),
  DSP16_Q(0.00009478),
  DSP16_Q(-0.00078401),
  DSP16_Q(0.00235665),
  DSP16_Q(-0.00518339),
  DSP16_Q(0.01003955),
  DSP16_Q(-0.01929980),
  DSP16_Q(0.04600438),
  DSP16_Q(0.49174884),
  DSP16_Q(-0.03792642),
  DSP16_Q(0.01709183),
  DSP16_Q(-0.00896835),
  DSP16_Q(0.00456718),
  DSP16_Q(-0.00200054),
  DSP16_Q(0.00060575),
  DSP16_Q(-0.00004525),
  DSP16_Q(0.00009793),
  DSP16_Q(-0.00080609),
  DSP16_Q(0.00242039),
  DSP16_Q(-0.00532121),
  DSP16_Q(0.01030491),
  DSP16_Q(-0.01981282),
  DSP16_Q(0.04727855),
  DSP16_Q(0.49140987),
  DSP16_Q(-0.03878340),
  DSP16_Q(0.01749153),
  DSP16_Q(-0.00917880),
  DSP16_Q(0.00467343),
  DSP16_Q(-0.00204602),
  DSP16_Q(0.00061870),
  DSP16_Q(-0.00004586),
  DSP16_Q(0.00010111),
  DSP16_Q(-0.00082826),
  DSP16_Q(0.00248424),
  DSP16_Q(-0.00545919),
  DSP16_Q(0.01057050),
  DSP16_Q(-0.02032644),
  DSP16_Q(0.04855709),
  DSP16_Q(0.49106246),
  DSP16_Q(-0.03963442),
  DSP16_Q(0.01788910),
  DSP16_Q(-0.00938815),
  DSP16_Q(0.00477907),
  DSP16_Q(-0.00209119),
  DSP16_Q(0.00063151),
  DSP16_Q(-0.00004644),
  DSP16_Q(0.00010432),
  DSP16_Q(-0.00085052),
  DSP16_Q(0.00254822),
  DSP16_Q(-0.00559731),
  DSP16_Q(0.01083629),
  DSP16_Q(-0.02084064),
  DSP16_Q(0.04983996),
  DSP16_Q(0.49070663),
  DSP16_Q(-0.04047948),
  DSP16_Q(0.01828451),
  DSP16_Q(-0.00959639),
  DSP16_Q(0.00488410),
  DSP16_Q(-0.00213605),
  DSP16_Q(0.00064419),
  DSP16_Q(-0.00004699),
  DSP16_Q(0.00010758),
  DSP16_Q(-0.00087286),
  DSP16_Q(0.00261232),
  DSP16_Q(-0.00573558),
  DSP16_Q(0.01110228),
  DSP16_Q(-0.02135537),
  DSP16_Q(0.05112715),
  DSP16_Q(0.49034239),
  DSP16_Q(-0.04131857),
  DSP16_Q(0.01867776),
  DSP16_Q(-0.00980352),
  DSP16_Q(0.00498852),
  DSP16_Q(-0.00218058),
  DSP16_Q(0.00065674),
  DSP16_Q(-0.00004752),
  DSP16_Q(0.00011087),
  DSP16_Q(-0.00089528),
  DSP16_Q(0.00267652),
  DSP16_Q(-0.00587397),
  DSP16_Q(0.01136845),
  DSP16_Q(-0.02187063),
  DSP16_Q(0.05241862),
  DSP16_Q(0.48996975),
  DSP16_Q(-0.04215167),
  DSP16_Q(0.01906883),
  DSP16_Q(-0.01000954),
  DSP16_Q(0.00509232),
  DSP16_Q(-0.00222481),
  DSP16_Q(0.00066916),
  DSP16_Q(-0.00004803),
  DSP16_Q(0.00011420),
  DSP16_Q(-0.00091779),
  DSP16_Q(0.00274084),
  DSP16_Q(-0.00601249),
  DSP16_Q(0.01163478),
  DSP16_Q(-0.02238638),
  DSP16_Q(0.05371434),
  DSP16_Q(0.48958873),
  DSP16_Q(-0.04297878),
  DSP16_Q(0.01945771),
  DSP16_Q(-0.01021442),
  DSP16_Q(0.00519551),
  DSP16_Q(-0.00226871),
  DSP16_Q(0.00068145),
  DSP16_Q(-0.00004851),
  DSP16_Q(0.00011756),
  DSP16_Q(-0.00094037),
  DSP16_Q(0.00280527),
  DSP16_Q(-0.00615112),
  DSP16_Q(0.01190127),
  DSP16_Q(-0.02290260),
  DSP16_Q(0.05501428),
  DSP16_Q(0.48919934),
  DSP16_Q(-0.04379989),
  DSP16_Q(0.01984439),
  DSP16_Q(-0.01041817),
  DSP16_Q(0.00529808),
  DSP16_Q(-0.00231229),
  DSP16_Q(0.00069360),
  DSP16_Q(-0.00004897),
  DSP16_Q(0.00012096),
  DSP16_Q(-0.00096304),
  DSP16_Q(0.00286980),
  DSP16_Q(-0.00628987),
  DSP16_Q(0.01216790),
  DSP16_Q(-0.02341928),
  DSP16_Q(0.05631841),
  DSP16_Q(0.48880159),
  DSP16_Q(-0.04461499),
  DSP16_Q(0.02022884),
  DSP16_Q(-0.01062077),
  DSP16_Q(0.00540002),
  DSP16_Q(-0.00235555),
  DSP16_Q(0.00070562),
  DSP16_Q(-0.00004941),
  DSP16_Q(0.00012439),
  DSP16_Q(-0.00098579),
  DSP16_Q(0.00293442),
  DSP16_Q(-0.00642872),
  DSP16_Q(0.01243465),
  DSP16_Q(-0.02393637),
  DSP16_Q(0.05762671),
  DSP16_Q(0.48839548),
  DSP16_Q(-0.04542406),
  DSP16_Q(0.02061107),
  DSP16_Q(-0.01082223),
  DSP16_Q(0.00550133),
  DSP16_Q(-0.00239849),
  DSP16_Q(0.00071751),
  DSP16_Q(-0.00004983),
  DSP16_Q(0.00012787),
  DSP16_Q(-0.00100861),
  DSP16_Q(0.00299915),
  DSP16_Q(-0.00656766),
  DSP16_Q(0.01270151),
  DSP16_Q(-0.02445386),
  DSP16_Q(0.05893914),
  DSP16_Q(0.48798105),
  DSP16_Q(-0.04622711),
  DSP16_Q(0.02099106),
  DSP16_Q(-0.01102253),
  DSP16_Q(0.00560200),
  DSP16_Q(-0.00244110),
  DSP16_Q(0.00072926),
  DSP16_Q(-0.00005022),
  DSP16_Q(0.00013138),
  DSP16_Q(-0.00103151),
  DSP16_Q(0.00306397),
  DSP16_Q(-0.00670670),
  DSP16_Q(0.01296848),
  DSP16_Q(-0.02497173),
  DSP16_Q(0.06025567),
  DSP16_Q(0.48755829),
  DSP16_Q(-0.04702412),
  DSP16_Q(0.02136878),
  DSP16_Q(-0.01122166),
  DSP16_Q(0.00570204),
  DSP16_Q(-0.00248339),
  DSP16_Q(0.00074088),
  DSP16_Q(-0.00005059),
  DSP16_Q(0.00013492),
  DSP16_Q(-0.00105448),
  DSP16_Q(0.00312888),
  DSP16_Q(-0.00684581),
  DSP16_Q(0.01323552),
  DSP16_Q(-0.02548994),
  DSP16_Q(0.06157628),
  DSP16_Q(0.48712723),
  DSP16_Q(-0.04781508),
  DSP16_Q(0.02174424),
  DSP16_Q(-0.01141962),
  DSP16_Q(0.00580144),
  DSP16_Q(-0.00252536),
  DSP16_Q(0.00075237),
  DSP16_Q(-0.00005094),
  DSP16_Q(0.00013850),
  DSP16_Q(-0.00107753),
  DSP16_Q(0.00319388),
  DSP16_Q(-0.00698500),
  DSP16_Q(0.01350264),
  DSP16_Q(-0.02600847),
  DSP16_Q(0.06290093),
  DSP16_Q(0.48668787),
  DSP16_Q(-0.04859998),
  DSP16_Q(0.02211742),
  DSP16_Q(-0.01161640),
  DSP16_Q(0.00590020),
  DSP16_Q(-0.00256699),
  DSP16_Q(0.00076372),
  DSP16_Q(-0.00005126),
  DSP16_Q(0.00014212),
  DSP16_Q(-0.00110066),
  DSP16_Q(0.00325895),
  DSP16_Q(-0.00712425),
  DSP16_Q(0.01376981),
  DSP16_Q(-0.02652730),
  DSP16_Q(0.06422958),
  DSP16_Q(0.48624023),
  DSP16_Q(-0.04937882),
  DSP16_Q(0.02248831),
  DSP16_Q(-0.01181199),
  DSP16_Q(0.00599831),
  DSP16_Q(-0.00260830),
  DSP16_Q(0.00077494),
  DSP16_Q(-0.00005157),
  DSP16_Q(0.00014577),
  DSP16_Q(-0.00112385),
  DSP16_Q(0.00332411),
  DSP16_Q(-0.00726356),
  DSP16_Q(0.01403703),
  DSP16_Q(-0.02704641),
  DSP16_Q(0.06556222),
  DSP16_Q(0.48578433),
  DSP16_Q(-0.05015159),
  DSP16_Q(0.02285689),
  DSP16_Q(-0.01200639),
  DSP16_Q(0.00609577),
  DSP16_Q(-0.00264928),
  DSP16_Q(0.00078603),
  DSP16_Q(-0.00005185),
  DSP16_Q(0.00014946),
  DSP16_Q(-0.00114712),
  DSP16_Q(0.00338935),
  DSP16_Q(-0.00740292),
  DSP16_Q(0.01430427),
  DSP16_Q(-0.02756576),
  DSP16_Q(0.06689881),
  DSP16_Q(0.48532018),
  DSP16_Q(-0.05091829),
  DSP16_Q(0.02322315),
  DSP16_Q(-0.01219959),
  DSP16_Q(0.00619257),
  DSP16_Q(-0.00268993),
  DSP16_Q(0.00079699),
  DSP16_Q(-0.00005211),
  DSP16_Q(0.00015318),
  DSP16_Q(-0.00117045),
  DSP16_Q(0.00345466),
  DSP16_Q(-0.00754233),
  DSP16_Q(0.01457153),
  DSP16_Q(-0.02808533),
  DSP16_Q(0.06823931),
  DSP16_Q(0.48484779),
  DSP16_Q(-0.05167889),
  DSP16_Q(0.02358708),
  DSP16_Q(-0.01239158),
  DSP16_Q(0.00628872),
  DSP16_Q(-0.00273024),
  DSP16_Q(0.00080781),
  DSP16_Q(-0.00005235),
  DSP16_Q(0.00015695),
  DSP16_Q(-0.00119386),
  DSP16_Q(0.00352003),
  DSP16_Q(-0.00768177),
  DSP16_Q(0.01483879),
  DSP16_Q(-0.02860510),
  DSP16_Q(0.06958371),
  DSP16_Q(0.48436718),
  DSP16_Q(-0.05243341),
  DSP16_Q(0.02394868),
  DSP16_Q(-0.01258236),
  DSP16_Q(0.00638421),
  DSP16_Q(-0.00277022),
  DSP16_Q(0.00081850),
  DSP16_Q(-0.00005257),
  DSP16_Q(0.00016074),
  DSP16_Q(-0.00121733),
  DSP16_Q(0.00358547),
  DSP16_Q(-0.00782124),
  DSP16_Q(0.01510604),
  DSP16_Q(-0.02912503),
  DSP16_Q(0.07093195),
  DSP16_Q(0.48387837),
  DSP16_Q(-0.05318183),
  DSP16_Q(0.02430792),
  DSP16_Q(-0.01277191),
  DSP16_Q(0.00647904),
  DSP16_Q(-0.00280987),
  DSP16_Q(0.00082906),
  DSP16_Q(-0.00005277),
  DSP16_Q(0.00016457),
  DSP16_Q(-0.00124087),
  DSP16_Q(0.00365098),
  DSP16_Q(-0.00796073),
  DSP16_Q(0.01537326),
  DSP16_Q(-0.02964511),
  DSP16_Q(0.07228402),
  DSP16_Q(0.48338136),
  DSP16_Q(-0.05392414),
  DSP16_Q(0.02466480),
  DSP16_Q(-0.01296024),
  DSP16_Q(0.00657319),
  DSP16_Q(-0.00284919),
  DSP16_Q(0.00083948),
  DSP16_Q(-0.00005295),
  DSP16_Q(0.00016844),
  DSP16_Q(-0.00126447),
  DSP16_Q(0.00371654),
  DSP16_Q(-0.00810023),
  DSP16_Q(0.01564043),
  DSP16_Q(-0.03016531),
  DSP16_Q(0.07363988),
  DSP16_Q(0.48287619),
  DSP16_Q(-0.05466034),
  DSP16_Q(0.02501930),
  DSP16_Q(-0.01314733),
  DSP16_Q(0.00666668),
  DSP16_Q(-0.00288816),
  DSP16_Q(0.00084977),
  DSP16_Q(-0.00005312),
  DSP16_Q(0.00017235),
  DSP16_Q(-0.00128813),
  DSP16_Q(0.00378215),
  DSP16_Q(-0.00823974),
  DSP16_Q(0.01590755),
  DSP16_Q(-0.03068561),
  DSP16_Q(0.07499950),
  DSP16_Q(0.48236286),
  DSP16_Q(-0.05539042),
  DSP16_Q(0.02537142),
  DSP16_Q(-0.01333319),
  DSP16_Q(0.00675950),
  DSP16_Q(-0.00292680),
  DSP16_Q(0.00085993),
  DSP16_Q(-0.00005326),
  DSP16_Q(0.00017629),
  DSP16_Q(-0.00131186),
  DSP16_Q(0.00384782),
  DSP16_Q(-0.00837925),
  DSP16_Q(0.01617460),
  DSP16_Q(-0.03120597),
  DSP16_Q(0.07636284),
  DSP16_Q(0.48184138),
  DSP16_Q(-0.05611438),
  DSP16_Q(0.02572114),
  DSP16_Q(-0.01351779),
  DSP16_Q(0.00685164),
  DSP16_Q(-0.00296511),
  DSP16_Q(0.00086996),
  DSP16_Q(-0.00005338),
  DSP16_Q(0.00018026),
  DSP16_Q(-0.00133565),
  DSP16_Q(0.00391354),
  DSP16_Q(-0.00851874),
  DSP16_Q(0.01644156),
  DSP16_Q(-0.03172637),
  DSP16_Q(0.07772987),
  DSP16_Q(0.48131179),
  DSP16_Q(-0.05683220),
  DSP16_Q(0.02606846),
  DSP16_Q(-0.01370115),
  DSP16_Q(0.00694311),
  DSP16_Q(-0.00300307),
  DSP16_Q(0.00087985),
  DSP16_Q(-0.00005348),
  DSP16_Q(0.00018427),
  DSP16_Q(-0.00135949),
  DSP16_Q(0.00397930),
  DSP16_Q(-0.00865822),
  DSP16_Q(0.01670842),
  DSP16_Q(-0.03224678),
  DSP16_Q(0.07910057),
  DSP16_Q(0.48077409),
  DSP16_Q(-0.05754390),
  DSP16_Q(0.02641336),
  DSP16_Q(-0.01388324),
  DSP16_Q(0.00703389),
  DSP16_Q(-0.00304070),
  DSP16_Q(0.00088961),
  DSP16_Q(-0.00005357),
  DSP16_Q(0.00018832),
  DSP16_Q(-0.00138340),
  DSP16_Q(0.00404509),
  DSP16_Q(-0.00879768),
  DSP16_Q(0.01697517),
  DSP16_Q(-0.03276718),
  DSP16_Q(0.08047490),
  DSP16_Q(0.48022830),
  DSP16_Q(-0.05824945),
  DSP16_Q(0.02675583),
  DSP16_Q(-0.01406407),
  DSP16_Q(0.00712399),
  DSP16_Q(-0.00307799),
  DSP16_Q(0.00089924),
  DSP16_Q(-0.00005363),
  DSP16_Q(0.00019240),
  DSP16_Q(-0.00140736),
  DSP16_Q(0.00411093),
  DSP16_Q(-0.00893710),
  DSP16_Q(0.01724179),
  DSP16_Q(-0.03328755),
  DSP16_Q(0.08185282),
  DSP16_Q(0.47967443),
  DSP16_Q(-0.05894886),
  DSP16_Q(0.02709586),
  DSP16_Q(-0.01424363),
  DSP16_Q(0.00721340),
  DSP16_Q(-0.00311493),
  DSP16_Q(0.00090874),
  DSP16_Q(-0.00005368),
  DSP16_Q(0.00019651),
  DSP16_Q(-0.00143138),
  DSP16_Q(0.00417680),
  DSP16_Q(-0.00907648),
  DSP16_Q(0.01750827),
  DSP16_Q(-0.03380785),
  DSP16_Q(0.08323430),
  DSP16_Q(0.47911252),
  DSP16_Q(-0.05964212),
  DSP16_Q(0.02743345),
  DSP16_Q(-0.01442191),
  DSP16_Q(0.00730212),
  DSP16_Q(-0.00315153),
  DSP16_Q(0.00091810),
  DSP16_Q(-0.00005371),
  DSP16_Q(0.00020066),
  DSP16_Q(-0.00145545),
  DSP16_Q(0.00424269),
  DSP16_Q(-0.00921581),
  DSP16_Q(0.01777459),
  DSP16_Q(-0.03432805),
  DSP16_Q(0.08461931),
  DSP16_Q(0.47854257),
  DSP16_Q(-0.06032923),
  DSP16_Q(0.02776858),
  DSP16_Q(-0.01459890),
  DSP16_Q(0.00739015),
  DSP16_Q(-0.00318780),
  DSP16_Q(0.00092734),
  DSP16_Q(-0.00005373),
  DSP16_Q(0.00020485),
  DSP16_Q(-0.00147958),
  DSP16_Q(0.00430861),
  DSP16_Q(-0.00935509),
  DSP16_Q(0.01804074),
  DSP16_Q(-0.03484815),
  DSP16_Q(0.08600781),
  DSP16_Q(0.47796460),
  DSP16_Q(-0.06101018),
  DSP16_Q(0.02810124),
  DSP16_Q(-0.01477461),
  DSP16_Q(0.00747749),
  DSP16_Q(-0.00322371),
  DSP16_Q(0.00093644),
  DSP16_Q(-0.00005372),
  DSP16_Q(0.00020907),
  DSP16_Q(-0.00150376),
  DSP16_Q(0.00437456),
  DSP16_Q(-0.00949430),
  DSP16_Q(0.01830670),
  DSP16_Q(-0.03536809),
  DSP16_Q(0.08739977),
  DSP16_Q(0.47737863),
  DSP16_Q(-0.06168497),
  DSP16_Q(0.02843142),
  DSP16_Q(-0.01494902),
  DSP16_Q(0.00756413),
  DSP16_Q(-0.00325929),
  DSP16_Q(0.00094541),
  DSP16_Q(-0.00005370),
  DSP16_Q(0.00021332),
  DSP16_Q(-0.00152799),
  DSP16_Q(0.00444052),
  DSP16_Q(-0.00963344),
  DSP16_Q(0.01857246),
  DSP16_Q(-0.03588787),
  DSP16_Q(0.08879516),
  DSP16_Q(0.47678468),
  DSP16_Q(-0.06235360),
  DSP16_Q(0.02875911),
  DSP16_Q(-0.01512214),
  DSP16_Q(0.00765006),
  DSP16_Q(-0.00329452),
  DSP16_Q(0.00095425),
  DSP16_Q(-0.00005366),
  DSP16_Q(0.00021761),
  DSP16_Q(-0.00155226),
  DSP16_Q(0.00450649),
  DSP16_Q(-0.00977250),
  DSP16_Q(0.01883801),
  DSP16_Q(-0.03640745),
  DSP16_Q(0.09019394),
  DSP16_Q(0.47618277),
  DSP16_Q(-0.06301605),
  DSP16_Q(0.02908431),
  DSP16_Q(-0.01529394),
  DSP16_Q(0.00773530),
  DSP16_Q(-0.00332940),
  DSP16_Q(0.00096296),
  DSP16_Q(-0.00005361),
  DSP16_Q(0.00022193),
  DSP16_Q(-0.00157659),
  DSP16_Q(0.00457248),
  DSP16_Q(-0.00991147),
  DSP16_Q(0.01910332),
  DSP16_Q(-0.03692680),
  DSP16_Q(0.09159608),
  DSP16_Q(0.47557292),
  DSP16_Q(-0.06367233),
  DSP16_Q(0.02940700),
  DSP16_Q(-0.01546444),
  DSP16_Q(0.00781983),
  DSP16_Q(-0.00336394),
  DSP16_Q(0.00097153),
  DSP16_Q(-0.00005354),
  DSP16_Q(0.00022629),
  DSP16_Q(-0.00160096),
  DSP16_Q(0.00463847),
  DSP16_Q(-0.01005035),
  DSP16_Q(0.01936839),
  DSP16_Q(-0.03744590),
  DSP16_Q(0.09300154),
  DSP16_Q(0.47495515),
  DSP16_Q(-0.06432244),
  DSP16_Q(0.02972718),
  DSP16_Q(-0.01563362),
  DSP16_Q(0.00790365),
  DSP16_Q(-0.00339813),
  DSP16_Q(0.00097998),
  DSP16_Q(-0.00005345),
  DSP16_Q(0.00023068),
  DSP16_Q(-0.00162537),
  DSP16_Q(0.00470446),
  DSP16_Q(-0.01018913),
  DSP16_Q(0.01963320),
  DSP16_Q(-0.03796473),
  DSP16_Q(0.09441029),
  DSP16_Q(0.47432947),
  DSP16_Q(-0.06496637),
  DSP16_Q(0.03004484),
  DSP16_Q(-0.01580148),
  DSP16_Q(0.00798677),
  DSP16_Q(-0.00343197),
  DSP16_Q(0.00098829),
  DSP16_Q(-0.00005335),
  DSP16_Q(0.00023510),
  DSP16_Q(-0.00164983),
  DSP16_Q(0.00477045),
  DSP16_Q(-0.01032779),
  DSP16_Q(0.01989774),
  DSP16_Q(-0.03848325),
  DSP16_Q(0.09582230),
  DSP16_Q(0.47369592),
  DSP16_Q(-0.06560413),
  DSP16_Q(0.03035996),
  DSP16_Q(-0.01596801),
  DSP16_Q(0.00806917),
  DSP16_Q(-0.00346547),
  DSP16_Q(0.00099648),
  DSP16_Q(-0.00005324),
  DSP16_Q(0.00023956),
  DSP16_Q(-0.00167433),
  DSP16_Q(0.00483644),
  DSP16_Q(-0.01046633),
  DSP16_Q(0.02016198),
  DSP16_Q(-0.03900143),
  DSP16_Q(0.09723752),
  DSP16_Q(0.47305450),
  DSP16_Q(-0.06623569),
  DSP16_Q(0.03067254),
  DSP16_Q(-0.01613321),
  DSP16_Q(0.00815086),
  DSP16_Q(-0.00349862),
  DSP16_Q(0.00100453),
  DSP16_Q(-0.00005310),
  DSP16_Q(0.00024405),
  DSP16_Q(-0.00169887),
  DSP16_Q(0.00490241),
  DSP16_Q(-0.01060475),
  DSP16_Q(0.02042592),
  DSP16_Q(-0.03951926),
  DSP16_Q(0.09865593),
  DSP16_Q(0.47240524),
  DSP16_Q(-0.06686108),
  DSP16_Q(0.03098258),
  DSP16_Q(-0.01629707),
  DSP16_Q(0.00823183),
  DSP16_Q(-0.00353142),
  DSP16_Q(0.00101246),
  DSP16_Q(-0.00005296),
  DSP16_Q(0.00024858),
  DSP16_Q(-0.00172345),
  DSP16_Q(0.00496838),
  DSP16_Q(-0.01074303),
  DSP16_Q(0.02068955),
  DSP16_Q(-0.04003670),
  DSP16_Q(0.10007749),
  DSP16_Q(0.47174816),
  DSP16_Q(-0.06748028),
  DSP16_Q(0.03129005),
  DSP16_Q(-0.01645960),
  DSP16_Q(0.00831208),
  DSP16_Q(-0.00356387),
  DSP16_Q(0.00102025),
  DSP16_Q(-0.00005280),
  DSP16_Q(0.00025314),
  DSP16_Q(-0.00174807),
  DSP16_Q(0.00503432),
  DSP16_Q(-0.01088116),
  DSP16_Q(0.02095284),
  DSP16_Q(-0.04055373),
  DSP16_Q(0.10150216),
  DSP16_Q(0.47108328),
  DSP16_Q(-0.06809329),
  DSP16_Q(0.03159496),
  DSP16_Q(-0.01662077),
  DSP16_Q(0.00839162),
  DSP16_Q(-0.00359597),
  DSP16_Q(0.00102792),
  DSP16_Q(-0.00005262),
  DSP16_Q(0.00025773),
  DSP16_Q(-0.00177272),
  DSP16_Q(0.00510025),
  DSP16_Q(-0.01101915),
  DSP16_Q(0.02121578),
  DSP16_Q(-0.04107031),
  DSP16_Q(0.10292990),
  DSP16_Q(0.47041062),
  DSP16_Q(-0.06870011),
  DSP16_Q(0.03189730),
  DSP16_Q(-0.01678060),
  DSP16_Q(0.00847042),
  DSP16_Q(-0.00362772),
  DSP16_Q(0.00103546),
  DSP16_Q(-0.00005243),
  DSP16_Q(0.00026235),
  DSP16_Q(-0.00179741),
  DSP16_Q(0.00516615),
  DSP16_Q(-0.01115697),
  DSP16_Q(0.02147836),
  DSP16_Q(-0.04158643),
  DSP16_Q(0.10436069),
  DSP16_Q(0.46973021),
  DSP16_Q(-0.06930074),
  DSP16_Q(0.03219705),
  DSP16_Q(-0.01693906),
  DSP16_Q(0.00854851),
  DSP16_Q(-0.00365912),
  DSP16_Q(0.00104287),
  DSP16_Q(-0.00005223),
  DSP16_Q(0.00026701),
  DSP16_Q(-0.00182213),
  DSP16_Q(0.00523202),
  DSP16_Q(-0.01129463),
  DSP16_Q(0.02174055),
  DSP16_Q(-0.04210204),
  DSP16_Q(0.10579448),
  DSP16_Q(0.46904206),
  DSP16_Q(-0.06989518),
  DSP16_Q(0.03249422),
  DSP16_Q(-0.01709617),
  DSP16_Q(0.00862587),
  DSP16_Q(-0.00369016),
  DSP16_Q(0.00105015),
  DSP16_Q(-0.00005201),
  DSP16_Q(0.00027169),
  DSP16_Q(-0.00184688),
  DSP16_Q(0.00529786),
  DSP16_Q(-0.01143212),
  DSP16_Q(0.02200236),
  DSP16_Q(-0.04261714),
  DSP16_Q(0.10723124),
  DSP16_Q(0.46834620),
  DSP16_Q(-0.07048343),
  DSP16_Q(0.03278879),
  DSP16_Q(-0.01725191),
  DSP16_Q(0.00870250),
  DSP16_Q(-0.00372086),
  DSP16_Q(0.00105730),
  DSP16_Q(-0.00005178),
  DSP16_Q(0.00027641),
  DSP16_Q(-0.00187166),
  DSP16_Q(0.00536366),
  DSP16_Q(-0.01156942),
  DSP16_Q(0.02226376),
  DSP16_Q(-0.04313168),
  DSP16_Q(0.10867094),
  DSP16_Q(0.46764265),
  DSP16_Q(-0.07106549),
  DSP16_Q(0.03308076),
  DSP16_Q(-0.01740629),
  DSP16_Q(0.00877840),
  DSP16_Q(-0.00375121),
  DSP16_Q(0.00106432),
  DSP16_Q(-0.00005154),
  DSP16_Q(0.00028117),
  DSP16_Q(-0.00189647),
  DSP16_Q(0.00542943),
  DSP16_Q(-0.01170652),
  DSP16_Q(0.02252473),
  DSP16_Q(-0.04364565),
  DSP16_Q(0.11011353),
  DSP16_Q(0.46693143),
  DSP16_Q(-0.07164135),
  DSP16_Q(0.03337011),
  DSP16_Q(-0.01755929),
  DSP16_Q(0.00885356),
  DSP16_Q(-0.00378120),
  DSP16_Q(0.00107122),
  DSP16_Q(-0.00005129),
  DSP16_Q(0.00028595),
  DSP16_Q(-0.00192131),
  DSP16_Q(0.00549514),
  DSP16_Q(-0.01184343),
  DSP16_Q(0.02278527),
  DSP16_Q(-0.04415900),
  DSP16_Q(0.11155898),
  DSP16_Q(0.46621257),
  DSP16_Q(-0.07221102),
  DSP16_Q(0.03365685),
  DSP16_Q(-0.01771091),
  DSP16_Q(0.00892800),
  DSP16_Q(-0.00381084),
  DSP16_Q(0.00107798),
  DSP16_Q(-0.00005102),
  DSP16_Q(0.00029077),
  DSP16_Q(-0.00194617),
  DSP16_Q(0.00556081),
  DSP16_Q(-0.01198013),
  DSP16_Q(0.02304535),
  DSP16_Q(-0.04467172),
  DSP16_Q(0.11300726),
  DSP16_Q(0.46548608),
  DSP16_Q(-0.07277450),
  DSP16_Q(0.03394096),
  DSP16_Q(-0.01786115),
  DSP16_Q(0.00900170),
  DSP16_Q(-0.00384013),
  DSP16_Q(0.00108463),
  DSP16_Q(-0.00005074),
  DSP16_Q(0.00029561),
  DSP16_Q(-0.00197106),
  DSP16_Q(0.00562643),
  DSP16_Q(-0.01211662),
  DSP16_Q(0.02330496),
  DSP16_Q(-0.04518378),
  DSP16_Q(0.11445832),
  DSP16_Q(0.46475200),
  DSP16_Q(-0.07333179),
  DSP16_Q(0.03422244),
  DSP16_Q(-0.01801001),
  DSP16_Q(0.00907466),
  DSP16_Q(-0.00386906),
  DSP16_Q(0.00109114),
  DSP16_Q(-0.00005045),
  DSP16_Q(0.00030049),
  DSP16_Q(-0.00199597),
  DSP16_Q(0.00569199),
  DSP16_Q(-0.01225288),
  DSP16_Q(0.02356409),
  DSP16_Q(-0.04569515),
  DSP16_Q(0.11591213),
  DSP16_Q(0.46401034),
  DSP16_Q(-0.07388289),
  DSP16_Q(0.03450128),
  DSP16_Q(-0.01815747),
  DSP16_Q(0.00914688),
  DSP16_Q(-0.00389765),
  DSP16_Q(0.00109753),
  DSP16_Q(-0.00005015),
  DSP16_Q(0.00030540),
  DSP16_Q(-0.00202090),
  DSP16_Q(0.00575749),
  DSP16_Q(-0.01238890),
  DSP16_Q(0.02382273),
  DSP16_Q(-0.04620580),
  DSP16_Q(0.11736865),
  DSP16_Q(0.46326113),
  DSP16_Q(-0.07442780),
  DSP16_Q(0.03477748),
  DSP16_Q(-0.01830354),
  DSP16_Q(0.00921836),
  DSP16_Q(-0.00392587),
  DSP16_Q(0.00110379),
  DSP16_Q(-0.00004983),
  DSP16_Q(0.00031034),
  DSP16_Q(-0.00204585),
  DSP16_Q(0.00582292),
  DSP16_Q(-0.01252469),
  DSP16_Q(0.02408085),
  DSP16_Q(-0.04671570),
  DSP16_Q(0.11882785),
  DSP16_Q(0.46250439),
  DSP16_Q(-0.07496652),
  DSP16_Q(0.03505102),
  DSP16_Q(-0.01844822),
  DSP16_Q(0.00928909),
  DSP16_Q(-0.00395375),
  DSP16_Q(0.00110993),
  DSP16_Q(-0.00004951),
  DSP16_Q(0.00031531),
  DSP16_Q(-0.00207082),
  DSP16_Q(0.00588829),
  DSP16_Q(-0.01266023),
  DSP16_Q(0.02433844),
  DSP16_Q(-0.04722483),
  DSP16_Q(0.12028968),
  DSP16_Q(0.46174015),
  DSP16_Q(-0.07549905),
  DSP16_Q(0.03532191),
  DSP16_Q(-0.01859149),
  DSP16_Q(0.00935909),
  DSP16_Q(-0.00398127),
  DSP16_Q(0.00111594),
  DSP16_Q(-0.00004918),
  DSP16_Q(0.00032031),
  DSP16_Q(-0.00209581),
  DSP16_Q(0.00595358),
  DSP16_Q(-0.01279551),
  DSP16_Q(0.02459548),
  DSP16_Q(-0.04773316),
  DSP16_Q(0.12175412),
  DSP16_Q(0.46096843),
  DSP16_Q(-0.07602539),
  DSP16_Q(0.03559013),
  DSP16_Q(-0.01873335),
  DSP16_Q(0.00942834),
  DSP16_Q(-0.00400844),
  DSP16_Q(0.00112183),
  DSP16_Q(-0.00004883),
  DSP16_Q(0.00032534),
  DSP16_Q(-0.00212081),
  DSP16_Q(0.00601879),
  DSP16_Q(-0.01293053),
  DSP16_Q(0.02485197),
  DSP16_Q(-0.04824065),
  DSP16_Q(0.12322111),
  DSP16_Q(0.46018926),
  DSP16_Q(-0.07654556),
  DSP16_Q(0.03585569),
  DSP16_Q(-0.01887381),
  DSP16_Q(0.00949684),
  DSP16_Q(-0.00403525),
  DSP16_Q(0.00112759),
  DSP16_Q(-0.00004848),
  DSP16_Q(0.00033039),
  DSP16_Q(-0.00214582),
  DSP16_Q(0.00608393),
  DSP16_Q(-0.01306527),
  DSP16_Q(0.02510788),
  DSP16_Q(-0.04874729),
  DSP16_Q(0.12469063),
  DSP16_Q(0.45940265),
  DSP16_Q(-0.07705954),
  DSP16_Q(0.03611857),
  DSP16_Q(-0.01901286),
  DSP16_Q(0.00956459),
  DSP16_Q(-0.00406171),
  DSP16_Q(0.00113323),
  DSP16_Q(-0.00004811),
  DSP16_Q(0.00033548),
  DSP16_Q(-0.00217084),
  DSP16_Q(0.00614898),
  DSP16_Q(-0.01319973),
  DSP16_Q(0.02536321),
  DSP16_Q(-0.04925304),
  DSP16_Q(0.12616264),
  DSP16_Q(0.45860864),
  DSP16_Q(-0.07756734),
  DSP16_Q(0.03637877),
  DSP16_Q(-0.01915049),
  DSP16_Q(0.00963160),
  DSP16_Q(-0.00408782),
  DSP16_Q(0.00113874),
  DSP16_Q(-0.00004774),
  DSP16_Q(0.00034060),
  DSP16_Q(-0.00219588),
  DSP16_Q(0.00621394),
  DSP16_Q(-0.01333390),
  DSP16_Q(0.02561793),
  DSP16_Q(-0.04975787),
  DSP16_Q(0.12763710),
  DSP16_Q(0.45780726),
  DSP16_Q(-0.07806896),
  DSP16_Q(0.03663628),
  DSP16_Q(-0.01928671),
  DSP16_Q(0.00969785),
  DSP16_Q(-0.00411357),
  DSP16_Q(0.00114413),
  DSP16_Q(-0.00004735),
  DSP16_Q(0.00034575),
  DSP16_Q(-0.00222092),
  DSP16_Q(0.00627881),
  DSP16_Q(-0.01346778),
  DSP16_Q(0.02587203),
  DSP16_Q(-0.05026176),
  DSP16_Q(0.12911396),
  DSP16_Q(0.45699852),
  DSP16_Q(-0.07856441),
  DSP16_Q(0.03689110),
  DSP16_Q(-0.01942150),
  DSP16_Q(0.00976336),
  DSP16_Q(-0.00413896),
  DSP16_Q(0.00114940),
  DSP16_Q(-0.00004696),
  DSP16_Q(0.00035092),
  DSP16_Q(-0.00224597),
  DSP16_Q(0.00634357),
  DSP16_Q(-0.01360134),
  DSP16_Q(0.02612550),
  DSP16_Q(-0.05076468),
  DSP16_Q(0.13059319),
  DSP16_Q(0.45618245),
  DSP16_Q(-0.07905369),
  DSP16_Q(0.03714323),
  DSP16_Q(-0.01955487),
  DSP16_Q(0.00982811),
  DSP16_Q(-0.00416401),
  DSP16_Q(0.00115455),
  DSP16_Q(-0.00004656),
  DSP16_Q(0.00035612),
  DSP16_Q(-0.00227102),
  DSP16_Q(0.00640824),
  DSP16_Q(-0.01373460),
  DSP16_Q(0.02637831),
  DSP16_Q(-0.05126659),
  DSP16_Q(0.13207476),
  DSP16_Q(0.45535908),
  DSP16_Q(-0.07953680),
  DSP16_Q(0.03739266),
  DSP16_Q(-0.01968681),
  DSP16_Q(0.00989210),
  DSP16_Q(-0.00418869),
  DSP16_Q(0.00115957),
  DSP16_Q(-0.00004615),
  DSP16_Q(0.00036135),
  DSP16_Q(-0.00229607),
  DSP16_Q(0.00647280),
  DSP16_Q(-0.01386753),
  DSP16_Q(0.02663047),
  DSP16_Q(-0.05176748),
  DSP16_Q(0.13355862),
  DSP16_Q(0.45452844),
  DSP16_Q(-0.08001375),
  DSP16_Q(0.03763937),
  DSP16_Q(-0.01981732),
  DSP16_Q(0.00995534),
  DSP16_Q(-0.00421303),
  DSP16_Q(0.00116447),
  DSP16_Q(-0.00004573),
  DSP16_Q(0.00036661),
  DSP16_Q(-0.00232113),
  DSP16_Q(0.00653726),
  DSP16_Q(-0.01400013),
  DSP16_Q(0.02688194),
  DSP16_Q(-0.05226731),
  DSP16_Q(0.13504474),
  DSP16_Q(0.45369055),
  DSP16_Q(-0.08048453),
  DSP16_Q(0.03788338),
  DSP16_Q(-0.01994639),
  DSP16_Q(0.01001783),
  DSP16_Q(-0.00423701),
  DSP16_Q(0.00116925),
  DSP16_Q(-0.00004530),
  DSP16_Q(0.00037189),
  DSP16_Q(-0.00234619),
  DSP16_Q(0.00660160),
  DSP16_Q(-0.01413239),
  DSP16_Q(0.02713271),
  DSP16_Q(-0.05276605),
  DSP16_Q(0.13653307),
  DSP16_Q(0.45284543),
  DSP16_Q(-0.08094916),
  DSP16_Q(0.03812467),
  DSP16_Q(-0.02007403),
  DSP16_Q(0.01007956),
  DSP16_Q(-0.00426063),
  DSP16_Q(0.00117391),
  DSP16_Q(-0.00004487),
  DSP16_Q(0.00037721),
  DSP16_Q(-0.00237125),
  DSP16_Q(0.00666582),
  DSP16_Q(-0.01426430),
  DSP16_Q(0.02738278),
  DSP16_Q(-0.05326368),
  DSP16_Q(0.13802358),
  DSP16_Q(0.45199313),
  DSP16_Q(-0.08140763),
  DSP16_Q(0.03836325),
  DSP16_Q(-0.02020023),
  DSP16_Q(0.01014053),
  DSP16_Q(-0.00428390),
  DSP16_Q(0.00117845),
  DSP16_Q(-0.00004443),
  DSP16_Q(0.00038255),
  DSP16_Q(-0.00239630),
  DSP16_Q(0.00672991),
  DSP16_Q(-0.01439585),
  DSP16_Q(0.02763212),
  DSP16_Q(-0.05376016),
  DSP16_Q(0.13951622),
  DSP16_Q(0.45113365),
  DSP16_Q(-0.08185996),
  DSP16_Q(0.03859910),
  DSP16_Q(-0.02032499),
  DSP16_Q(0.01020074),
  DSP16_Q(-0.00430682),
  DSP16_Q(0.00118287),
  DSP16_Q(-0.00004398),
  DSP16_Q(0.00038791),
  DSP16_Q(-0.00242135),
  DSP16_Q(0.00679388),
  DSP16_Q(-0.01452705),
  DSP16_Q(0.02788072),
  DSP16_Q(-0.05425547),
  DSP16_Q(0.14101097),
  DSP16_Q(0.45026703),
  DSP16_Q(-0.08230614),
  DSP16_Q(0.03883222),
  DSP16_Q(-0.02044830),
  DSP16_Q(0.01026019),
  DSP16_Q(-0.00432938),
  DSP16_Q(0.00118717),
  DSP16_Q(-0.00004353),
  DSP16_Q(0.00039330),
  DSP16_Q(-0.00244639),
  DSP16_Q(0.00685772),
  DSP16_Q(-0.01465787),
  DSP16_Q(0.02812856),
  DSP16_Q(-0.05474958),
  DSP16_Q(0.14250777),
  DSP16_Q(0.44939331),
  DSP16_Q(-0.08274619),
  DSP16_Q(0.03906261),
  DSP16_Q(-0.02057017),
  DSP16_Q(0.01031888),
  DSP16_Q(-0.00435159),
  DSP16_Q(0.00119135),
  DSP16_Q(-0.00004306),
  DSP16_Q(0.00039872),
  DSP16_Q(-0.00247142),
  DSP16_Q(0.00692143),
  DSP16_Q(-0.01478831),
  DSP16_Q(0.02837563),
  DSP16_Q(-0.05524246),
  DSP16_Q(0.14400659),
  DSP16_Q(0.44851249),
  DSP16_Q(-0.08318009),
  DSP16_Q(0.03929026),
  DSP16_Q(-0.02069059),
  DSP16_Q(0.01037681),
  DSP16_Q(-0.00437345),
  DSP16_Q(0.00119541),
  DSP16_Q(-0.00004260),
  DSP16_Q(0.00040416),
  DSP16_Q(-0.00249644),
  DSP16_Q(0.00698500),
  DSP16_Q(-0.01491836),
  DSP16_Q(0.02862191),
  DSP16_Q(-0.05573409),
  DSP16_Q(0.14550739),
  DSP16_Q(0.44762462),
  DSP16_Q(-0.08360787),
  DSP16_Q(0.03951518),
  DSP16_Q(-0.02080956),
  DSP16_Q(0.01043398),
  DSP16_Q(-0.00439495),
  DSP16_Q(0.00119936),
  DSP16_Q(-0.00004212),
  DSP16_Q(0.00040963),
  DSP16_Q(-0.00252145),
  DSP16_Q(0.00704842),
  DSP16_Q(-0.01504801),
  DSP16_Q(0.02886740),
  DSP16_Q(-0.05622442),
  DSP16_Q(0.14701013),
  DSP16_Q(0.44672972),
  DSP16_Q(-0.08402953),
  DSP16_Q(0.03973735),
  DSP16_Q(-0.02092708),
  DSP16_Q(0.01049038),
  DSP16_Q(-0.00441610),
  DSP16_Q(0.00120319),
  DSP16_Q(-0.00004164),
  DSP16_Q(0.00041512),
  DSP16_Q(-0.00254644),
  DSP16_Q(0.00711169),
  DSP16_Q(-0.01517726),
  DSP16_Q(0.02911206),
  DSP16_Q(-0.05671344),
  DSP16_Q(0.14851477),
  DSP16_Q(0.44582782),
  DSP16_Q(-0.08444507),
  DSP16_Q(0.03995677),
  DSP16_Q(-0.02104314),
  DSP16_Q(0.01054602),
  DSP16_Q(-0.00443690),
  DSP16_Q(0.00120690),
  DSP16_Q(-0.00004116),
  DSP16_Q(0.00042063),
  DSP16_Q(-0.00257142),
  DSP16_Q(0.00717482),
  DSP16_Q(-0.01530609),
  DSP16_Q(0.02935589),
  DSP16_Q(-0.05720112),
  DSP16_Q(0.15002126),
  DSP16_Q(0.44491895),
  DSP16_Q(-0.08485449),
  DSP16_Q(0.04017345),
  DSP16_Q(-0.02115774),
  DSP16_Q(0.01060090),
  DSP16_Q(-0.00445735),
  DSP16_Q(0.00121049),
  DSP16_Q(-0.00004067),
  DSP16_Q(0.00042617),
  DSP16_Q(-0.00259639),
  DSP16_Q(0.00723779),
  DSP16_Q(-0.01543450),
  DSP16_Q(0.02959888),
  DSP16_Q(-0.05768742),
  DSP16_Q(0.15152958),
  DSP16_Q(0.44400314),
  DSP16_Q(-0.08525781),
  DSP16_Q(0.04038737),
  DSP16_Q(-0.02127088),
  DSP16_Q(0.01065501),
  DSP16_Q(-0.00447744),
  DSP16_Q(0.00121397),
  DSP16_Q(-0.00004017),
  DSP16_Q(0.00043174),
  DSP16_Q(-0.00262133),
  DSP16_Q(0.00730059),
  DSP16_Q(-0.01556248),
  DSP16_Q(0.02984100),
  DSP16_Q(-0.05817232),
  DSP16_Q(0.15303967),
  DSP16_Q(0.44308041),
  DSP16_Q(-0.08565503),
  DSP16_Q(0.04059854),
  DSP16_Q(-0.02138257),
  DSP16_Q(0.01070836),
  DSP16_Q(-0.00449718),
  DSP16_Q(0.00121733),
  DSP16_Q(-0.00003967),
  DSP16_Q(0.00043733),
  DSP16_Q(-0.00264625),
  DSP16_Q(0.00736324),
  DSP16_Q(-0.01569002),
  DSP16_Q(0.03008224),
  DSP16_Q(-0.05865578),
  DSP16_Q(0.15455151),
  DSP16_Q(0.44215080),
  DSP16_Q(-0.08604615),
  DSP16_Q(0.04080696),
  DSP16_Q(-0.02149279),
  DSP16_Q(0.01076094),
  DSP16_Q(-0.00451657),
  DSP16_Q(0.00122058),
  DSP16_Q(-0.00003916),
  DSP16_Q(0.00044293),
  DSP16_Q(-0.00267115),
  DSP16_Q(0.00742571),
  DSP16_Q(-0.01581712),
  DSP16_Q(0.03032259),
  DSP16_Q(-0.05913779),
  DSP16_Q(0.15606504),
  DSP16_Q(0.44121434),
  DSP16_Q(-0.08643119),
  DSP16_Q(0.04101261),
  DSP16_Q(-0.02160154),
  DSP16_Q(0.01081276),
  DSP16_Q(-0.00453561),
  DSP16_Q(0.00122371),
  DSP16_Q(-0.00003865),
  DSP16_Q(0.00044857),
  DSP16_Q(-0.00269603),
  DSP16_Q(0.00748801),
  DSP16_Q(-0.01594376),
  DSP16_Q(0.03056204),
  DSP16_Q(-0.05961831),
  DSP16_Q(0.15758022),
  DSP16_Q(0.44027105),
  DSP16_Q(-0.08681015),
  DSP16_Q(0.04121550),
  DSP16_Q(-0.02170883),
  DSP16_Q(0.01086381),
  DSP16_Q(-0.00455430),
  DSP16_Q(0.00122673),
  DSP16_Q(-0.00003814),
  DSP16_Q(0.00045422),
  DSP16_Q(-0.00272088),
  DSP16_Q(0.00755014),
  DSP16_Q(-0.01606993),
  DSP16_Q(0.03080055),
  DSP16_Q(-0.06009731),
  DSP16_Q(0.15909703),
  DSP16_Q(0.43932096),
  DSP16_Q(-0.08718304),
  DSP16_Q(0.04141562),
  DSP16_Q(-0.02181465),
  DSP16_Q(0.01091410),
  DSP16_Q(-0.00457264),
  DSP16_Q(0.00122963),
  DSP16_Q(-0.00003762),
  DSP16_Q(0.00045990),
  DSP16_Q(-0.00274570),
  DSP16_Q(0.00761208),
  DSP16_Q(-0.01619563),
  DSP16_Q(0.03103813),
  DSP16_Q(-0.06057476),
  DSP16_Q(0.16061541),
  DSP16_Q(0.43836411),
  DSP16_Q(-0.08754986),
  DSP16_Q(0.04161298),
  DSP16_Q(-0.02191901),
  DSP16_Q(0.01096362),
  DSP16_Q(-0.00459062),
  DSP16_Q(0.00123243),
  DSP16_Q(-0.00003710),
  DSP16_Q(0.00046559),
  DSP16_Q(-0.00277050),
  DSP16_Q(0.00767383),
  DSP16_Q(-0.01632086),
  DSP16_Q(0.03127476),
  DSP16_Q(-0.06105064),
  DSP16_Q(0.16213532),
  DSP16_Q(0.43740053),
  DSP16_Q(-0.08791062),
  DSP16_Q(0.04180756),
  DSP16_Q(-0.02202189),
  DSP16_Q(0.01101237),
  DSP16_Q(-0.00460826),
  DSP16_Q(0.00123511),
  DSP16_Q(-0.00003658),
  DSP16_Q(0.00047131),
  DSP16_Q(-0.00279526),
  DSP16_Q(0.00773540),
  DSP16_Q(-0.01644559),
  DSP16_Q(0.03151041),
  DSP16_Q(-0.06152491),
  DSP16_Q(0.16365672),
  DSP16_Q(0.43643024),
  DSP16_Q(-0.08826533),
  DSP16_Q(0.04199938),
  DSP16_Q(-0.02212330),
  DSP16_Q(0.01106035),
  DSP16_Q(-0.00462555),
  DSP16_Q(0.00123768),
  DSP16_Q(-0.00003605),
  DSP16_Q(0.00047705),
  DSP16_Q(-0.00281999),
  DSP16_Q(0.00779677),
  DSP16_Q(-0.01656983),
  DSP16_Q(0.03174509),
  DSP16_Q(-0.06199754),
  DSP16_Q(0.16517958),
  DSP16_Q(0.43545328),
  DSP16_Q(-0.08861400),
  DSP16_Q(0.04218842),
  DSP16_Q(-0.02222324),
  DSP16_Q(0.01110757),
  DSP16_Q(-0.00464249),
  DSP16_Q(0.00124013),
  DSP16_Q(-0.00003552),
  DSP16_Q(0.00048281),
  DSP16_Q(-0.00284468),
  DSP16_Q(0.00785795),
  DSP16_Q(-0.01669356),
  DSP16_Q(0.03197876),
  DSP16_Q(-0.06246851),
  DSP16_Q(0.16670384),
  DSP16_Q(0.43446968),
  DSP16_Q(-0.08895664),
  DSP16_Q(0.04237469),
  DSP16_Q(-0.02232170),
  DSP16_Q(0.01115402),
  DSP16_Q(-0.00465908),
  DSP16_Q(0.00124248),
  DSP16_Q(-0.00003498),
  DSP16_Q(0.00048859),
  DSP16_Q(-0.00286934),
  DSP16_Q(0.00791892),
  DSP16_Q(-0.01681678),
  DSP16_Q(0.03221141),
  DSP16_Q(-0.06293779),
  DSP16_Q(0.16822948),
  DSP16_Q(0.43347947),
  DSP16_Q(-0.08929325),
  DSP16_Q(0.04255818),
  DSP16_Q(-0.02241869),
  DSP16_Q(0.01119971),
  DSP16_Q(-0.00467533),
  DSP16_Q(0.00124472),
  DSP16_Q(-0.00003445),
  DSP16_Q(0.00049439),
  DSP16_Q(-0.00289395),
  DSP16_Q(0.00797968),
  DSP16_Q(-0.01693947),
  DSP16_Q(0.03244304),
  DSP16_Q(-0.06340535),
  DSP16_Q(0.16975644),
  DSP16_Q(0.43248268),
  DSP16_Q(-0.08962384),
  DSP16_Q(0.04273890),
  DSP16_Q(-0.02251421),
  DSP16_Q(0.01124462),
  DSP16_Q(-0.00469122),
  DSP16_Q(0.00124685),
  DSP16_Q(-0.00003391),
  DSP16_Q(0.00050020),
  DSP16_Q(-0.00291853),
  DSP16_Q(0.00804024),
  DSP16_Q(-0.01706164),
  DSP16_Q(0.03267362),
  DSP16_Q(-0.06387116),
  DSP16_Q(0.17128469),
  DSP16_Q(0.43147934),
  DSP16_Q(-0.08994843),
  DSP16_Q(0.04291683),
  DSP16_Q(-0.02260825),
  DSP16_Q(0.01128877),
  DSP16_Q(-0.00470677),
  DSP16_Q(0.00124886),
  DSP16_Q(-0.00003337),
  DSP16_Q(0.00050604),
  DSP16_Q(-0.00294307),
  DSP16_Q(0.00810057),
  DSP16_Q(-0.01718327),
  DSP16_Q(0.03290314),
  DSP16_Q(-0.06433519),
  DSP16_Q(0.17281418),
  DSP16_Q(0.43046948),
  DSP16_Q(-0.09026702),
  DSP16_Q(0.04309199),
  DSP16_Q(-0.02270081),
  DSP16_Q(0.01133215),
  DSP16_Q(-0.00472198),
  DSP16_Q(0.00125078),
  DSP16_Q(-0.00003283),
  DSP16_Q(0.00051189),
  DSP16_Q(-0.00296756),
  DSP16_Q(0.00816069),
  DSP16_Q(-0.01730435),
  DSP16_Q(0.03313159),
  DSP16_Q(-0.06479740),
  DSP16_Q(0.17434488),
  DSP16_Q(0.42945314),
  DSP16_Q(-0.09057961),
  DSP16_Q(0.04326437),
  DSP16_Q(-0.02279189),
  DSP16_Q(0.01137477),
  DSP16_Q(-0.00473684),
  DSP16_Q(0.00125258),
  DSP16_Q(-0.00003229),
  DSP16_Q(0.00051776),
  DSP16_Q(-0.00299200),
  DSP16_Q(0.00822058),
  DSP16_Q(-0.01742487),
  DSP16_Q(0.03335894),
  DSP16_Q(-0.06525779),
  DSP16_Q(0.17587673),
  DSP16_Q(0.42843035),
  DSP16_Q(-0.09088623),
  DSP16_Q(0.04343397),
  DSP16_Q(-0.02288149),
  DSP16_Q(0.01141662),
  DSP16_Q(-0.00475135),
  DSP16_Q(0.00125427),
  DSP16_Q(-0.00003174),
  DSP16_Q(0.00052365),
  DSP16_Q(-0.00301640),
  DSP16_Q(0.00828025),
  DSP16_Q(-0.01754483),
  DSP16_Q(0.03358519),
  DSP16_Q(-0.06571630),
  DSP16_Q(0.17740970),
  DSP16_Q(0.42740114),
  DSP16_Q(-0.09118688),
  DSP16_Q(0.04360078),
  DSP16_Q(-0.02296962),
  DSP16_Q(0.01145770),
  DSP16_Q(-0.00476552),
  DSP16_Q(0.00125586),
  DSP16_Q(-0.00003120),
  DSP16_Q(0.00052956),
  DSP16_Q(-0.00304074),
  DSP16_Q(0.00833968),
  DSP16_Q(-0.01766423),
  DSP16_Q(0.03381032),
  DSP16_Q(-0.06617291),
  DSP16_Q(0.17894375),
  DSP16_Q(0.42636554),
  DSP16_Q(-0.09148156),
  DSP16_Q(0.04376482),
  DSP16_Q(-0.02305626),
  DSP16_Q(0.01149802),
  DSP16_Q(-0.00477935),
  DSP16_Q(0.00125735),
  DSP16_Q(-0.00003065),
  DSP16_Q(0.00053548),
  DSP16_Q(-0.00306504),
  DSP16_Q(0.00839887),
  DSP16_Q(-0.01778304),
  DSP16_Q(0.03403431),
  DSP16_Q(-0.06662761),
  DSP16_Q(0.18047883),
  DSP16_Q(0.42532359),
  DSP16_Q(-0.09177029),
  DSP16_Q(0.04392607),
  DSP16_Q(-0.02314143),
  DSP16_Q(0.01153757),
  DSP16_Q(-0.00479284),
  DSP16_Q(0.00125873),
  DSP16_Q(-0.00003010),
  DSP16_Q(0.00054142),
  DSP16_Q(-0.00308928),
  DSP16_Q(0.00845782),
  DSP16_Q(-0.01790126),
  DSP16_Q(0.03425715),
  DSP16_Q(-0.06708034),
  DSP16_Q(0.18201491),
  DSP16_Q(0.42427531),
  DSP16_Q(-0.09205309),
  DSP16_Q(0.04408454),
  DSP16_Q(-0.02322512),
  DSP16_Q(0.01157635),
  DSP16_Q(-0.00480598),
  DSP16_Q(0.00126000),
  DSP16_Q(-0.00002956),
  DSP16_Q(0.00054737),
  DSP16_Q(-0.00311347),
  DSP16_Q(0.00851653),
  DSP16_Q(-0.01801889),
  DSP16_Q(0.03447883),
  DSP16_Q(-0.06753109),
  DSP16_Q(0.18355193),
  DSP16_Q(0.42322075),
  DSP16_Q(-0.09232995),
  DSP16_Q(0.04424022),
  DSP16_Q(-0.02330732),
  DSP16_Q(0.01161437),
  DSP16_Q(-0.00481878),
  DSP16_Q(0.00126117),
  DSP16_Q(-0.00002901),
  DSP16_Q(0.00055334),
  DSP16_Q(-0.00313760),
  DSP16_Q(0.00857499),
  DSP16_Q(-0.01813591),
  DSP16_Q(0.03469932),
  DSP16_Q(-0.06797983),
  DSP16_Q(0.18508986),
  DSP16_Q(0.42215993),
  DSP16_Q(-0.09260089),
  DSP16_Q(0.04439313),
  DSP16_Q(-0.02338805),
  DSP16_Q(0.01165163),
  DSP16_Q(-0.00483124),
  DSP16_Q(0.00126224),
  DSP16_Q(-0.00002846),
  DSP16_Q(0.00055932),
  DSP16_Q(-0.00316167),
  DSP16_Q(0.00863319),
  DSP16_Q(-0.01825232),
  DSP16_Q(0.03491862),
  DSP16_Q(-0.06842653),
  DSP16_Q(0.18662865),
  DSP16_Q(0.42109289),
  DSP16_Q(-0.09286592),
  DSP16_Q(0.04454325),
  DSP16_Q(-0.02346729),
  DSP16_Q(0.01168812),
  DSP16_Q(-0.00484336),
  DSP16_Q(0.00126320),
  DSP16_Q(-0.00002792),
  DSP16_Q(0.00056531),
  DSP16_Q(-0.00318567),
  DSP16_Q(0.00869113),
  DSP16_Q(-0.01836810),
  DSP16_Q(0.03513671),
  DSP16_Q(-0.06887116),
  DSP16_Q(0.18816826),
  DSP16_Q(0.42001967),
  DSP16_Q(-0.09312506),
  DSP16_Q(0.04469059),
  DSP16_Q(-0.02354506),
  DSP16_Q(0.01172384),
  DSP16_Q(-0.00485514),
  DSP16_Q(0.00126406),
  DSP16_Q(-0.00002737),
  DSP16_Q(0.00057132),
  DSP16_Q(-0.00320962),
  DSP16_Q(0.00874881),
  DSP16_Q(-0.01848326),
  DSP16_Q(0.03535357),
  DSP16_Q(-0.06931368),
  DSP16_Q(0.18970866),
  DSP16_Q(0.41894028),
  DSP16_Q(-0.09337831),
  DSP16_Q(0.04483515),
  DSP16_Q(-0.02362134),
  DSP16_Q(0.01175881),
  DSP16_Q(-0.00486659),
  DSP16_Q(0.00126483),
  DSP16_Q(-0.00002682),
  DSP16_Q(0.00057734),
  DSP16_Q(-0.00323350),
  DSP16_Q(0.00880623),
  DSP16_Q(-0.01859778),
  DSP16_Q(0.03556920),
  DSP16_Q(-0.06975408),
  DSP16_Q(0.19124979),
  DSP16_Q(0.41785478),
  DSP16_Q(-0.09362568),
  DSP16_Q(0.04497693),
  DSP16_Q(-0.02369614),
  DSP16_Q(0.01179301),
  DSP16_Q(-0.00487769),
  DSP16_Q(0.00126549),
  DSP16_Q(-0.00002628),
  DSP16_Q(0.00058338),
  DSP16_Q(-0.00325732),
  DSP16_Q(0.00886337),
  DSP16_Q(-0.01871166),
  DSP16_Q(0.03578356),
  DSP16_Q(-0.07019231),
  DSP16_Q(0.19279161),
  DSP16_Q(0.41676320),
  DSP16_Q(-0.09386720),
  DSP16_Q(0.04511594),
  DSP16_Q(-0.02376947),
  DSP16_Q(0.01182645),
  DSP16_Q(-0.00488846),
  DSP16_Q(0.00126605),
  DSP16_Q(-0.00002574),
  DSP16_Q(0.00058942),
  DSP16_Q(-0.00328106),
  DSP16_Q(0.00892023),
  DSP16_Q(-0.01882488),
  DSP16_Q(0.03599666),
  DSP16_Q(-0.07062836),
  DSP16_Q(0.19433408),
  DSP16_Q(0.41566556),
  DSP16_Q(-0.09410286),
  DSP16_Q(0.04525216),
  DSP16_Q(-0.02384131),
  DSP16_Q(0.01185913),
  DSP16_Q(-0.00489890),
  DSP16_Q(0.00126651),
  DSP16_Q(-0.00002519),
  DSP16_Q(0.00059548),
  DSP16_Q(-0.00330474),
  DSP16_Q(0.00897682),
  DSP16_Q(-0.01893744),
  DSP16_Q(0.03620847),
  DSP16_Q(-0.07106220),
  DSP16_Q(0.19587716),
  DSP16_Q(0.41456191),
  DSP16_Q(-0.09433268),
  DSP16_Q(0.04538561),
  DSP16_Q(-0.02391168),
  DSP16_Q(0.01189105),
  DSP16_Q(-0.00490899),
  DSP16_Q(0.00126687),
  DSP16_Q(-0.00002465),
  DSP16_Q(0.00060155),
  DSP16_Q(-0.00332834),
  DSP16_Q(0.00903312),
  DSP16_Q(-0.01904933),
  DSP16_Q(0.03641898),
  DSP16_Q(-0.07149378),
  DSP16_Q(0.19742080),
  DSP16_Q(0.41345227),
  DSP16_Q(-0.09455667),
  DSP16_Q(0.04551628),
  DSP16_Q(-0.02398057),
  DSP16_Q(0.01192221),
  DSP16_Q(-0.00491876),
  DSP16_Q(0.00126713),
  DSP16_Q(-0.00002412),
  DSP16_Q(0.00060763),
  DSP16_Q(-0.00335187),
  DSP16_Q(0.00908913),
  DSP16_Q(-0.01916055),
  DSP16_Q(0.03662818),
  DSP16_Q(-0.07192309),
  DSP16_Q(0.19896496),
  DSP16_Q(0.41233669),
  DSP16_Q(-0.09477485),
  DSP16_Q(0.04564417),
  DSP16_Q(-0.02404798),
  DSP16_Q(0.01195261),
  DSP16_Q(-0.00492819),
  DSP16_Q(0.00126730),
  DSP16_Q(-0.00002358),
  DSP16_Q(0.00061372),
  DSP16_Q(-0.00337532),
  DSP16_Q(0.00914485),
  DSP16_Q(-0.01927107),
  DSP16_Q(0.03683604),
  DSP16_Q(-0.07235010),
  DSP16_Q(0.20050960),
  DSP16_Q(0.41121519),
  DSP16_Q(-0.09498722),
  DSP16_Q(0.04576929),
  DSP16_Q(-0.02411391),
  DSP16_Q(0.01198225),
  DSP16_Q(-0.00493729),
  DSP16_Q(0.00126737),
  DSP16_Q(-0.00002304),
  DSP16_Q(0.00061982),
  DSP16_Q(-0.00339869),
  DSP16_Q(0.00920028),
  DSP16_Q(-0.01938090),
  DSP16_Q(0.03704257),
  DSP16_Q(-0.07277477),
  DSP16_Q(0.20205468),
  DSP16_Q(0.41008782),
  DSP16_Q(-0.09519381),
  DSP16_Q(0.04589164),
  DSP16_Q(-0.02417836),
  DSP16_Q(0.01201113),
  DSP16_Q(-0.00494606),
  DSP16_Q(0.00126734),
  DSP16_Q(-0.00002251),
  DSP16_Q(0.00062593),
  DSP16_Q(-0.00342199),
  DSP16_Q(0.00925540),
  DSP16_Q(-0.01949003),
  DSP16_Q(0.03724773),
  DSP16_Q(-0.07319709),
  DSP16_Q(0.20360014),
  DSP16_Q(0.40895460),
  DSP16_Q(-0.09539462),
  DSP16_Q(0.04601123),
  DSP16_Q(-0.02424135),
  DSP16_Q(0.01203926),
  DSP16_Q(-0.00495449),
  DSP16_Q(0.00126722),
  DSP16_Q(-0.00002198),
  DSP16_Q(0.00063204),
  DSP16_Q(-0.00344520),
  DSP16_Q(0.00931021),
  DSP16_Q(-0.01959845),
  DSP16_Q(0.03745152),
  DSP16_Q(-0.07361701),
  DSP16_Q(0.20514595),
  DSP16_Q(0.40781558),
  DSP16_Q(-0.09558966),
  DSP16_Q(0.04612804),
  DSP16_Q(-0.02430285),
  DSP16_Q(0.01206664),
  DSP16_Q(-0.00496260),
  DSP16_Q(0.00126700),
  DSP16_Q(-0.00002146),
  DSP16_Q(0.00063817),
  DSP16_Q(-0.00346833),
  DSP16_Q(0.00936472),
  DSP16_Q(-0.01970615),
  DSP16_Q(0.03765392),
  DSP16_Q(-0.07403451),
  DSP16_Q(0.20669207),
  DSP16_Q(0.40667079),
  DSP16_Q(-0.09577896),
  DSP16_Q(0.04624209),
  DSP16_Q(-0.02436288),
  DSP16_Q(0.01209326),
  DSP16_Q(-0.00497038),
  DSP16_Q(0.00126669),
  DSP16_Q(-0.00002093),
  DSP16_Q(0.00064430),
  DSP16_Q(-0.00349137),
  DSP16_Q(0.00941891),
  DSP16_Q(-0.01981313),
  DSP16_Q(0.03785492),
  DSP16_Q(-0.07444956),
  DSP16_Q(0.20823845),
  DSP16_Q(0.40552027),
  DSP16_Q(-0.09596252),
  DSP16_Q(0.04635337),
  DSP16_Q(-0.02442144),
  DSP16_Q(0.01211912),
  DSP16_Q(-0.00497783),
  DSP16_Q(0.00126629),
  DSP16_Q(-0.00002041),
  DSP16_Q(0.00065044),
  DSP16_Q(-0.00351432),
  DSP16_Q(0.00947278),
  DSP16_Q(-0.01991936),
  DSP16_Q(0.03805450),
  DSP16_Q(-0.07486213),
  DSP16_Q(0.20978504),
  DSP16_Q(0.40436405),
  DSP16_Q(-0.09614035),
  DSP16_Q(0.04646190),
  DSP16_Q(-0.02447853),
  DSP16_Q(0.01214424),
  DSP16_Q(-0.00498496),
  DSP16_Q(0.00126579),
  DSP16_Q(-0.00001989),
  DSP16_Q(0.00065658),
  DSP16_Q(-0.00353718),
  DSP16_Q(0.00952633),
  DSP16_Q(-0.02002486),
  DSP16_Q(0.03825265),
  DSP16_Q(-0.07527219),
  DSP16_Q(0.21133180),
  DSP16_Q(0.40320217),
  DSP16_Q(-0.09631248),
  DSP16_Q(0.04656766),
  DSP16_Q(-0.02453415),
  DSP16_Q(0.01216860),
  DSP16_Q(-0.00499176),
  DSP16_Q(0.00126520),
  DSP16_Q(-0.00001938),
  DSP16_Q(0.00066273),
  DSP16_Q(-0.00355996),
  DSP16_Q(0.00957955),
  DSP16_Q(-0.02012961),
  DSP16_Q(0.03844935),
  DSP16_Q(-0.07567972),
  DSP16_Q(0.21287870),
  DSP16_Q(0.40203466),
  DSP16_Q(-0.09647892),
  DSP16_Q(0.04667067),
  DSP16_Q(-0.02458830),
  DSP16_Q(0.01219222),
  DSP16_Q(-0.00499823),
  DSP16_Q(0.00126453),
  DSP16_Q(-0.00001887),
  DSP16_Q(0.00066889),
  DSP16_Q(-0.00358263),
  DSP16_Q(0.00963244),
  DSP16_Q(-0.02023359),
  DSP16_Q(0.03864459),
  DSP16_Q(-0.07608469),
  DSP16_Q(0.21442568),
  DSP16_Q(0.40086156),
  DSP16_Q(-0.09663967),
  DSP16_Q(0.04677093),
  DSP16_Q(-0.02464098),
  DSP16_Q(0.01221508),
  DSP16_Q(-0.00500438),
  DSP16_Q(0.00126376),
  DSP16_Q(-0.00001836),
  DSP16_Q(0.00067505),
  DSP16_Q(-0.00360522),
  DSP16_Q(0.00968499),
  DSP16_Q(-0.02033681),
  DSP16_Q(0.03883836),
  DSP16_Q(-0.07648706),
  DSP16_Q(0.21597270),
  DSP16_Q(0.39968291),
  DSP16_Q(-0.09679476),
  DSP16_Q(0.04686843),
  DSP16_Q(-0.02469220),
  DSP16_Q(0.01223720),
  DSP16_Q(-0.00501021),
  DSP16_Q(0.00126290),
  DSP16_Q(-0.00001786),
  DSP16_Q(0.00068121),
  DSP16_Q(-0.00362770),
  DSP16_Q(0.00973721),
  DSP16_Q(-0.02043926),
  DSP16_Q(0.03903063),
  DSP16_Q(-0.07688680),
  DSP16_Q(0.21751972),
  DSP16_Q(0.39849875),
  DSP16_Q(-0.09694419),
  DSP16_Q(0.04696319),
  DSP16_Q(-0.02474195),
  DSP16_Q(0.01225857),
  DSP16_Q(-0.00501572),
  DSP16_Q(0.00126195),
  DSP16_Q(-0.00001736),
  DSP16_Q(0.00068738),
  DSP16_Q(-0.00365009),
  DSP16_Q(0.00978908),
  DSP16_Q(-0.02054092),
  DSP16_Q(0.03922140),
  DSP16_Q(-0.07728390),
  DSP16_Q(0.21906669),
  DSP16_Q(0.39730911),
  DSP16_Q(-0.09708799),
  DSP16_Q(0.04705520),
  DSP16_Q(-0.02479024),
  DSP16_Q(0.01227920),
  DSP16_Q(-0.00502091),
  DSP16_Q(0.00126091),
  DSP16_Q(-0.00001687),
  DSP16_Q(0.00069355),
  DSP16_Q(-0.00367237),
  DSP16_Q(0.00984060),
  DSP16_Q(-0.02064180),
  DSP16_Q(0.03941065),
  DSP16_Q(-0.07767831),
  DSP16_Q(0.22061357),
  DSP16_Q(0.39611402),
  DSP16_Q(-0.09722617),
  DSP16_Q(0.04714448),
  DSP16_Q(-0.02483707),
  DSP16_Q(0.01229909),
  DSP16_Q(-0.00502578),
  DSP16_Q(0.00125978),
  DSP16_Q(-0.00001638),
  DSP16_Q(0.00069972),
  DSP16_Q(-0.00369455),
  DSP16_Q(0.00989177),
  DSP16_Q(-0.02074187),
  DSP16_Q(0.03959837),
  DSP16_Q(-0.07807002),
  DSP16_Q(0.22216032),
  DSP16_Q(0.39491354),
  DSP16_Q(-0.09735875),
  DSP16_Q(0.04723101),
  DSP16_Q(-0.02488244),
  DSP16_Q(0.01231823),
  DSP16_Q(-0.00503033),
  DSP16_Q(0.00125857),
  DSP16_Q(-0.00001589),
  DSP16_Q(0.00070590),
  DSP16_Q(-0.00371662),
  DSP16_Q(0.00994258),
  DSP16_Q(-0.02084114),
  DSP16_Q(0.03978454),
  DSP16_Q(-0.07845899),
  DSP16_Q(0.22370689),
  DSP16_Q(0.39370768),
  DSP16_Q(-0.09748573),
  DSP16_Q(0.04731481),
  DSP16_Q(-0.02492635),
  DSP16_Q(0.01233664),
  DSP16_Q(-0.00503456),
  DSP16_Q(0.00125728),
  DSP16_Q(-0.00001541),
  DSP16_Q(0.00071208),
  DSP16_Q(-0.00373859),
  DSP16_Q(0.00999303),
  DSP16_Q(-0.02093960),
  DSP16_Q(0.03996916),
  DSP16_Q(-0.07884519),
  DSP16_Q(0.22525323),
  DSP16_Q(0.39249650),
  DSP16_Q(-0.09760714),
  DSP16_Q(0.04739588),
  DSP16_Q(-0.02496880),
  DSP16_Q(0.01235430),
  DSP16_Q(-0.00503848),
  DSP16_Q(0.00125589),
  DSP16_Q(-0.00001494),
  DSP16_Q(0.00071825),
  DSP16_Q(-0.00376045),
  DSP16_Q(0.01004312),
  DSP16_Q(-0.02103723),
  DSP16_Q(0.04015219),
  DSP16_Q(-0.07922860),
  DSP16_Q(0.22679931),
  DSP16_Q(0.39128003),
  DSP16_Q(-0.09772298),
  DSP16_Q(0.04747423),
  DSP16_Q(-0.02500980),
  DSP16_Q(0.01237123),
  DSP16_Q(-0.00504209),
  DSP16_Q(0.00125442),
  DSP16_Q(-0.00001447),
  DSP16_Q(0.00072443),
  DSP16_Q(-0.00378219),
  DSP16_Q(0.01009283),
  DSP16_Q(-0.02113404),
  DSP16_Q(0.04033364),
  DSP16_Q(-0.07960918),
  DSP16_Q(0.22834508),
  DSP16_Q(0.39005831),
  DSP16_Q(-0.09783329),
  DSP16_Q(0.04754985),
  DSP16_Q(-0.02504935),
  DSP16_Q(0.01238742),
  DSP16_Q(-0.00504538),
  DSP16_Q(0.00125287),
  DSP16_Q(-0.00001400),
  DSP16_Q(0.00073060),
  DSP16_Q(-0.00380383),
  DSP16_Q(0.01014218),
  DSP16_Q(-0.02123000),
  DSP16_Q(0.04051348),
  DSP16_Q(-0.07998691),
  DSP16_Q(0.22989049),
  DSP16_Q(0.38883137),
  DSP16_Q(-0.09793806),
  DSP16_Q(0.04762275),
  DSP16_Q(-0.02508745),
  DSP16_Q(0.01240288),
  DSP16_Q(-0.00504836),
  DSP16_Q(0.00125124),
  DSP16_Q(-0.00001354),
  DSP16_Q(0.00073678),
  DSP16_Q(-0.00382534),
  DSP16_Q(0.01019114),
  DSP16_Q(-0.02132512),
  DSP16_Q(0.04069170),
  DSP16_Q(-0.08036176),
  DSP16_Q(0.23143550),
  DSP16_Q(0.38759926),
  DSP16_Q(-0.09803733),
  DSP16_Q(0.04769294),
  DSP16_Q(-0.02512410),
  DSP16_Q(0.01241760),
  DSP16_Q(-0.00505103),
  DSP16_Q(0.00124952),
  DSP16_Q(-0.00001309),
  DSP16_Q(0.00074295),
  DSP16_Q(-0.00384674),
  DSP16_Q(0.01023972),
  DSP16_Q(-0.02141939),
  DSP16_Q(0.04086829),
  DSP16_Q(-0.08073369),
  DSP16_Q(0.23298006),
  DSP16_Q(0.38636201),
  DSP16_Q(-0.09813110),
  DSP16_Q(0.04776041),
  DSP16_Q(-0.02515931),
  DSP16_Q(0.01243160),
  DSP16_Q(-0.00505339),
  DSP16_Q(0.00124772),
  DSP16_Q(-0.00001264),
  DSP16_Q(0.00074912),
  DSP16_Q(-0.00386802),
  DSP16_Q(0.01028792),
  DSP16_Q(-0.02151280),
  DSP16_Q(0.04104324),
  DSP16_Q(-0.08110270),
  DSP16_Q(0.23452414),
  DSP16_Q(0.38511966),
  DSP16_Q(-0.09821940),
  DSP16_Q(0.04782518),
  DSP16_Q(-0.02519307),
  DSP16_Q(0.01244486),
  DSP16_Q(-0.00505544),
  DSP16_Q(0.00124584),
  DSP16_Q(-0.00001220),
  DSP16_Q(0.00075529),
  DSP16_Q(-0.00388918),
  DSP16_Q(0.01033572),
  DSP16_Q(-0.02160534),
  DSP16_Q(0.04121652),
  DSP16_Q(-0.08146873),
  DSP16_Q(0.23606768),
  DSP16_Q(0.38387225),
  DSP16_Q(-0.09830223),
  DSP16_Q(0.04788725),
  DSP16_Q(-0.02522540),
  DSP16_Q(0.01245740),
  DSP16_Q(-0.00505719),
  DSP16_Q(0.00124388),
  DSP16_Q(-0.00001177),
  DSP16_Q(0.00076145),
  DSP16_Q(-0.00391022),
  DSP16_Q(0.01038313),
  DSP16_Q(-0.02169701),
  DSP16_Q(0.04138814),
  DSP16_Q(-0.08183177),
  DSP16_Q(0.23761065),
  DSP16_Q(0.38261982),
  DSP16_Q(-0.09837962),
  DSP16_Q(0.04794663),
  DSP16_Q(-0.02525628),
  DSP16_Q(0.01246921),
  DSP16_Q(-0.00505863),
  DSP16_Q(0.00124184),
  DSP16_Q(-0.00001134),
  DSP16_Q(0.00076761),
  DSP16_Q(-0.00393113),
  DSP16_Q(0.01043015),
  DSP16_Q(-0.02178779),
  DSP16_Q(0.04155806),
  DSP16_Q(-0.08219179),
  DSP16_Q(0.23915299),
  DSP16_Q(0.38136240),
  DSP16_Q(-0.09845158),
  DSP16_Q(0.04800331),
  DSP16_Q(-0.02528573),
  DSP16_Q(0.01248030),
  DSP16_Q(-0.00505976),
  DSP16_Q(0.00123972),
  DSP16_Q(-0.00001091),
  DSP16_Q(0.00077376),
  DSP16_Q(-0.00395191),
  DSP16_Q(0.01047675),
  DSP16_Q(-0.02187768),
  DSP16_Q(0.04172629),
  DSP16_Q(-0.08254875),
  DSP16_Q(0.24069467),
  DSP16_Q(0.38010005),
  DSP16_Q(-0.09851813),
  DSP16_Q(0.04805730),
  DSP16_Q(-0.02531375),
  DSP16_Q(0.01249067),
  DSP16_Q(-0.00506059),
  DSP16_Q(0.00123752),
  DSP16_Q(-0.00001050),
  DSP16_Q(0.00077991),
  DSP16_Q(-0.00397257),
  DSP16_Q(0.01052296),
  DSP16_Q(-0.02196668),
  DSP16_Q(0.04189280),
  DSP16_Q(-0.08290264),
  DSP16_Q(0.24223564),
  DSP16_Q(0.37883278),
  DSP16_Q(-0.09857929),
  DSP16_Q(0.04810861),
  DSP16_Q(-0.02534034),
  DSP16_Q(0.01250031),
  DSP16_Q(-0.00506113),
  DSP16_Q(0.00123525),
  DSP16_Q(-0.00001009),
  DSP16_Q(0.00078606),
  DSP16_Q(-0.00399309),
  DSP16_Q(0.01056875),
  DSP16_Q(-0.02205476),
  DSP16_Q(0.04205758),
  DSP16_Q(-0.08325342),
  DSP16_Q(0.24377585),
  DSP16_Q(0.37756066),
  DSP16_Q(-0.09863508),
  DSP16_Q(0.04815725),
  DSP16_Q(-0.02536550),
  DSP16_Q(0.01250924),
  DSP16_Q(-0.00506136),
  DSP16_Q(0.00123289),
  DSP16_Q(-0.00000968),
  DSP16_Q(0.00079219),
  DSP16_Q(-0.00401348),
  DSP16_Q(0.01061412),
  DSP16_Q(-0.02214194),
  DSP16_Q(0.04222061),
  DSP16_Q(-0.08360106),
  DSP16_Q(0.24531526),
  DSP16_Q(0.37628370),
  DSP16_Q(-0.09868550),
  DSP16_Q(0.04820321),
  DSP16_Q(-0.02538923),
  DSP16_Q(0.01251746),
  DSP16_Q(-0.00506129),
  DSP16_Q(0.00123047),
  DSP16_Q(-0.00000929),
  DSP16_Q(0.00079832),
  DSP16_Q(-0.00403373),
  DSP16_Q(0.01065908),
  DSP16_Q(-0.02222819),
  DSP16_Q(0.04238190),
  DSP16_Q(-0.08394554),
  DSP16_Q(0.24685382),
  DSP16_Q(0.37500197),
  DSP16_Q(-0.09873059),
  DSP16_Q(0.04824651),
  DSP16_Q(-0.02541155),
  DSP16_Q(0.01252495),
  DSP16_Q(-0.00506092),
  DSP16_Q(0.00122797),
  DSP16_Q(-0.00000890),
  DSP16_Q(0.00080444),
  DSP16_Q(-0.00405385),
  DSP16_Q(0.01070361),
  DSP16_Q(-0.02231351),
  DSP16_Q(0.04254141),
  DSP16_Q(-0.08428682),
  DSP16_Q(0.24839150),
  DSP16_Q(0.37371548),
  DSP16_Q(-0.09877036),
  DSP16_Q(0.04828715),
  DSP16_Q(-0.02543244),
  DSP16_Q(0.01253174),
  DSP16_Q(-0.00506026),
  DSP16_Q(0.00122539),
  DSP16_Q(-0.00000851),
  DSP16_Q(0.00081055),
  DSP16_Q(-0.00407383),
  DSP16_Q(0.01074771),
  DSP16_Q(-0.02239790),
  DSP16_Q(0.04269914),
  DSP16_Q(-0.08462489),
  DSP16_Q(0.24992823),
  DSP16_Q(0.37242429),
  DSP16_Q(-0.09880483),
  DSP16_Q(0.04832513),
  DSP16_Q(-0.02545192),
  DSP16_Q(0.01253782),
  DSP16_Q(-0.00505930),
  DSP16_Q(0.00122274),
  DSP16_Q(-0.00000814),
  DSP16_Q(0.00081665),
  DSP16_Q(-0.00409366),
  DSP16_Q(0.01079139),
  DSP16_Q(-0.02248134),
  DSP16_Q(0.04285508),
  DSP16_Q(-0.08495971),
  DSP16_Q(0.25146400),
  DSP16_Q(0.37112843),
  DSP16_Q(-0.09883401),
  DSP16_Q(0.04836046),
  DSP16_Q(-0.02546999),
  DSP16_Q(0.01254319),
  DSP16_Q(-0.00505805),
  DSP16_Q(0.00122002),
  DSP16_Q(-0.00000777),
  DSP16_Q(0.00082274),
  DSP16_Q(-0.00411335),
  DSP16_Q(0.01083462),
  DSP16_Q(-0.02256384),
  DSP16_Q(0.04300920),
  DSP16_Q(-0.08529125),
  DSP16_Q(0.25299873),
  DSP16_Q(0.36982795),
  DSP16_Q(-0.09885793),
  DSP16_Q(0.04839315),
  DSP16_Q(-0.02548664),
  DSP16_Q(0.01254785),
  DSP16_Q(-0.00505651),
  DSP16_Q(0.00121722),
  DSP16_Q(-0.00000741),
  DSP16_Q(0.00082883),
  DSP16_Q(-0.00413290),
  DSP16_Q(0.01087742),
  DSP16_Q(-0.02264537),
  DSP16_Q(0.04316151),
  DSP16_Q(-0.08561949),
  DSP16_Q(0.25453240),
  DSP16_Q(0.36852288),
  DSP16_Q(-0.09887660),
  DSP16_Q(0.04842320),
  DSP16_Q(-0.02550189),
  DSP16_Q(0.01255181),
  DSP16_Q(-0.00505468),
  DSP16_Q(0.00121436),
  DSP16_Q(-0.00000706),
  DSP16_Q(0.00083490),
  DSP16_Q(-0.00415230),
  DSP16_Q(0.01091978),
  DSP16_Q(-0.02272595),
  DSP16_Q(0.04331197),
  DSP16_Q(-0.08594439),
  DSP16_Q(0.25606496),
  DSP16_Q(0.36721327),
  DSP16_Q(-0.09889004),
  DSP16_Q(0.04845062),
  DSP16_Q(-0.02551574),
  DSP16_Q(0.01255507),
  DSP16_Q(-0.00505256),
  DSP16_Q(0.00121142),
  DSP16_Q(-0.00000671),
  DSP16_Q(0.00084095),
  DSP16_Q(-0.00417156),
  DSP16_Q(0.01096168),
  DSP16_Q(-0.02280554),
  DSP16_Q(0.04346059),
  DSP16_Q(-0.08626594),
  DSP16_Q(0.25759635),
  DSP16_Q(0.36589915),
  DSP16_Q(-0.09889827),
  DSP16_Q(0.04847542),
  DSP16_Q(-0.02552819),
  DSP16_Q(0.01255762),
  DSP16_Q(-0.00505015),
  DSP16_Q(0.00120842),
  DSP16_Q(-0.00000637),
  DSP16_Q(0.00084700),
  DSP16_Q(-0.00419066),
  DSP16_Q(0.01100314),
  DSP16_Q(-0.02288416),
  DSP16_Q(0.04360735),
  DSP16_Q(-0.08658410),
  DSP16_Q(0.25912655),
  DSP16_Q(0.36458057),
  DSP16_Q(-0.09890132),
  DSP16_Q(0.04849759),
  DSP16_Q(-0.02553924),
  DSP16_Q(0.01255949),
  DSP16_Q(-0.00504745),
  DSP16_Q(0.00120534),
  DSP16_Q(-0.00000604),
  DSP16_Q(0.00085303),
  DSP16_Q(-0.00420960),
  DSP16_Q(0.01104413),
  DSP16_Q(-0.02296179),
  DSP16_Q(0.04375223),
  DSP16_Q(-0.08689885),
  DSP16_Q(0.26065549),
  DSP16_Q(0.36325756),
  DSP16_Q(-0.09889919),
  DSP16_Q(0.04851716),
  DSP16_Q(-0.02554890),
  DSP16_Q(0.01256065),
  DSP16_Q(-0.00504447),
  DSP16_Q(0.00120220),
  DSP16_Q(-0.00000572),
  DSP16_Q(0.00085905),
  DSP16_Q(-0.00422840),
  DSP16_Q(0.01108467),
  DSP16_Q(-0.02303843),
  DSP16_Q(0.04389522),
  DSP16_Q(-0.08721015),
  DSP16_Q(0.26218315),
  DSP16_Q(0.36193017),
  DSP16_Q(-0.09889192),
  DSP16_Q(0.04853412),
  DSP16_Q(-0.02555717),
  DSP16_Q(0.01256113),
  DSP16_Q(-0.00504121),
  DSP16_Q(0.00119899),
  DSP16_Q(-0.00000541),
  DSP16_Q(0.00086505),
  DSP16_Q(-0.00424703),
  DSP16_Q(0.01112475),
  DSP16_Q(-0.02311407),
  DSP16_Q(0.04403631),
  DSP16_Q(-0.08751799),
  DSP16_Q(0.26370946),
  DSP16_Q(0.36059844),
  DSP16_Q(-0.09887951),
  DSP16_Q(0.04854848),
  DSP16_Q(-0.02556406),
  DSP16_Q(0.01256091),
  DSP16_Q(-0.00503767),
  DSP16_Q(0.00119571),
  DSP16_Q(-0.00000510),
  DSP16_Q(0.00087104),
  DSP16_Q(-0.00426551),
  DSP16_Q(0.01116435),
  DSP16_Q(-0.02318870),
  DSP16_Q(0.04417549),
  DSP16_Q(-0.08782232),
  DSP16_Q(0.26523440),
  DSP16_Q(0.35926240),
  DSP16_Q(-0.09886199),
  DSP16_Q(0.04856024),
  DSP16_Q(-0.02556956),
  DSP16_Q(0.01256001),
  DSP16_Q(-0.00503384),
  DSP16_Q(0.00119237),
  DSP16_Q(-0.00000480),
  DSP16_Q(0.00087701),
  DSP16_Q(-0.00428383),
  DSP16_Q(0.01120349),
  DSP16_Q(-0.02326231),
  DSP16_Q(0.04431274),
  DSP16_Q(-0.08812314),
  DSP16_Q(0.26675790),
  DSP16_Q(0.35792211),
  DSP16_Q(-0.09883938),
  DSP16_Q(0.04856942),
  DSP16_Q(-0.02557369),
  DSP16_Q(0.01255842),
  DSP16_Q(-0.00502974),
  DSP16_Q(0.00118896),
  DSP16_Q(-0.00000451),
  DSP16_Q(0.00088296),
  DSP16_Q(-0.00430198),
  DSP16_Q(0.01124215),
  DSP16_Q(-0.02333490),
  DSP16_Q(0.04444805),
  DSP16_Q(-0.08842040),
  DSP16_Q(0.26827994),
  DSP16_Q(0.35657760),
  DSP16_Q(-0.09881171),
  DSP16_Q(0.04857603),
  DSP16_Q(-0.02557644),
  DSP16_Q(0.01255615),
  DSP16_Q(-0.00502536),
  DSP16_Q(0.00118549),
  DSP16_Q(-0.00000423),
  DSP16_Q(0.00088890),
  DSP16_Q(-0.00431997),
  DSP16_Q(0.01128033),
  DSP16_Q(-0.02340646),
  DSP16_Q(0.04458141),
  DSP16_Q(-0.08871409),
  DSP16_Q(0.26980046),
  DSP16_Q(0.35522892),
  DSP16_Q(-0.09877898),
  DSP16_Q(0.04858006),
  DSP16_Q(-0.02557782),
  DSP16_Q(0.01255320),
  DSP16_Q(-0.00502071),
  DSP16_Q(0.00118196),
  DSP16_Q(-0.00000396),
  DSP16_Q(0.00089482),
  DSP16_Q(-0.00433779),
  DSP16_Q(0.01131802),
  DSP16_Q(-0.02347699),
  DSP16_Q(0.04471281),
  DSP16_Q(-0.08900417),
  DSP16_Q(0.27131942),
  DSP16_Q(0.35387609),
  DSP16_Q(-0.09874122),
  DSP16_Q(0.04858153),
  DSP16_Q(-0.02557783),
  DSP16_Q(0.01254957),
  DSP16_Q(-0.00501578),
  DSP16_Q(0.00117836),
  DSP16_Q(-0.00000370),
  DSP16_Q(0.00090072),
  DSP16_Q(-0.00435544),
  DSP16_Q(0.01135523),
  DSP16_Q(-0.02354647),
  DSP16_Q(0.04484222),
  DSP16_Q(-0.08929061),
  DSP16_Q(0.27283677),
  DSP16_Q(0.35251918),
  DSP16_Q(-0.09869845),
  DSP16_Q(0.04858044),
  DSP16_Q(-0.02557649),
  DSP16_Q(0.01254527),
  DSP16_Q(-0.00501058),
  DSP16_Q(0.00117470),
  DSP16_Q(-0.00000344),
  DSP16_Q(0.00090660),
  DSP16_Q(-0.00437292),
  DSP16_Q(0.01139195),
  DSP16_Q(-0.02361490),
  DSP16_Q(0.04496965),
  DSP16_Q(-0.08957340),
  DSP16_Q(0.27435248),
  DSP16_Q(0.35115821),
  DSP16_Q(-0.09865069),
  DSP16_Q(0.04857680),
  DSP16_Q(-0.02557378),
  DSP16_Q(0.01254029),
  DSP16_Q(-0.00500511),
  DSP16_Q(0.00117098),
  DSP16_Q(-0.00000319),
  DSP16_Q(0.00091246),
  DSP16_Q(-0.00439023),
  DSP16_Q(0.01142817),
  DSP16_Q(-0.02368227),
  DSP16_Q(0.04509508),
  DSP16_Q(-0.08985250),
  DSP16_Q(0.27586648),
  DSP16_Q(0.34979323),
  DSP16_Q(-0.09859797),
  DSP16_Q(0.04857062),
  DSP16_Q(-0.02556972),
  DSP16_Q(0.01253464),
  DSP16_Q(-0.00499936),
  DSP16_Q(0.00116720),
  DSP16_Q(-0.00000296),
  DSP16_Q(0.00091830),
  DSP16_Q(-0.00440736),
  DSP16_Q(0.01146390),
  DSP16_Q(-0.02374858),
  DSP16_Q(0.04521849),
  DSP16_Q(-0.09012789),
  DSP16_Q(0.27737875),
  DSP16_Q(0.34842428),
  DSP16_Q(-0.09854030),
  DSP16_Q(0.04856191),
  DSP16_Q(-0.02556431),
  DSP16_Q(0.01252833),
  DSP16_Q(-0.00499336),
  DSP16_Q(0.00116336),
  DSP16_Q(-0.00000273),
  DSP16_Q(0.00092412),
  DSP16_Q(-0.00442432),
  DSP16_Q(0.01149912),
  DSP16_Q(-0.02381382),
  DSP16_Q(0.04533987),
  DSP16_Q(-0.09039954),
  DSP16_Q(0.27888923),
  DSP16_Q(0.34705141),
  DSP16_Q(-0.09847770),
  DSP16_Q(0.04855067),
  DSP16_Q(-0.02555756),
  DSP16_Q(0.01252135),
  DSP16_Q(-0.00498708),
  DSP16_Q(0.00115946),
  DSP16_Q(-0.00000251),
  DSP16_Q(0.00092991),
  DSP16_Q(-0.00444110),
  DSP16_Q(0.01153383),
  DSP16_Q(-0.02387798),
  DSP16_Q(0.04545921),
  DSP16_Q(-0.09066742),
  DSP16_Q(0.28039789),
  DSP16_Q(0.34567465),
  DSP16_Q(-0.09841020),
  DSP16_Q(0.04853691),
  DSP16_Q(-0.02554946),
  DSP16_Q(0.01251371),
  DSP16_Q(-0.00498054),
  DSP16_Q(0.00115550),
  DSP16_Q(-0.00000230),
  DSP16_Q(0.00093568),
  DSP16_Q(-0.00445770),
  DSP16_Q(0.01156804),
  DSP16_Q(-0.02394106),
  DSP16_Q(0.04557651),
  DSP16_Q(-0.09093151),
  DSP16_Q(0.28190466),
  DSP16_Q(0.34429405),
  DSP16_Q(-0.09833782),
  DSP16_Q(0.04852064),
  DSP16_Q(-0.02554003),
  DSP16_Q(0.01250541),
  DSP16_Q(-0.00497374),
  DSP16_Q(0.00115149),
  DSP16_Q(-0.00000209),
  DSP16_Q(0.00094143),
  DSP16_Q(-0.00447412),
  DSP16_Q(0.01160173),
  DSP16_Q(-0.02400305),
  DSP16_Q(0.04569174),
  DSP16_Q(-0.09119178),
  DSP16_Q(0.28340952),
  DSP16_Q(0.34290965),
  DSP16_Q(-0.09826057),
  DSP16_Q(0.04850188),
  DSP16_Q(-0.02552926),
  DSP16_Q(0.01249646),
  DSP16_Q(-0.00496668),
  DSP16_Q(0.00114742),
  DSP16_Q(-0.00000190),
  DSP16_Q(0.00094716),
  DSP16_Q(-0.00449035),
  DSP16_Q(0.01163490),
  DSP16_Q(-0.02406394),
  DSP16_Q(0.04580490),
  DSP16_Q(-0.09144820),
  DSP16_Q(0.28491242),
  DSP16_Q(0.34152149),
  DSP16_Q(-0.09817849),
  DSP16_Q(0.04848061),
  DSP16_Q(-0.02551717),
  DSP16_Q(0.01248685),
  DSP16_Q(-0.00495936),
  DSP16_Q(0.00114329),
  DSP16_Q(-0.00000172),
  DSP16_Q(0.00095285),
  DSP16_Q(-0.00450639),
  DSP16_Q(0.01166755),
  DSP16_Q(-0.02412372),
  DSP16_Q(0.04591596),
  DSP16_Q(-0.09170076),
  DSP16_Q(0.28641331),
  DSP16_Q(0.34012961),
  DSP16_Q(-0.09809159),
  DSP16_Q(0.04845686),
  DSP16_Q(-0.02550375),
  DSP16_Q(0.01247659),
  DSP16_Q(-0.00495178),
  DSP16_Q(0.00113911),
  DSP16_Q(-0.00000154),
  DSP16_Q(0.00095853),
  DSP16_Q(-0.00452225),
  DSP16_Q(0.01169968),
  DSP16_Q(-0.02418240),
  DSP16_Q(0.04602493),
  DSP16_Q(-0.09194941),
  DSP16_Q(0.28791214),
  DSP16_Q(0.33873407),
  DSP16_Q(-0.09799989),
  DSP16_Q(0.04843064),
  DSP16_Q(-0.02548901),
  DSP16_Q(0.01246568),
  DSP16_Q(-0.00494395),
  DSP16_Q(0.00113487),
  DSP16_Q(-0.00000138),
  DSP16_Q(0.00096417),
  DSP16_Q(-0.00453792),
  DSP16_Q(0.01173127),
  DSP16_Q(-0.02423995),
  DSP16_Q(0.04613179),
  DSP16_Q(-0.09219414),
  DSP16_Q(0.28940888),
  DSP16_Q(0.33733489),
  DSP16_Q(-0.09790342),
  DSP16_Q(0.04840194),
  DSP16_Q(-0.02547296),
  DSP16_Q(0.01245412),
  DSP16_Q(-0.00493586),
  DSP16_Q(0.00113058),
  DSP16_Q(-0.00000122),
  DSP16_Q(0.00096979),
  DSP16_Q(-0.00455339),
  DSP16_Q(0.01176234),
  DSP16_Q(-0.02429639),
  DSP16_Q(0.04623653),
  DSP16_Q(-0.09243492),
  DSP16_Q(0.29090348),
  DSP16_Q(0.33593213),
  DSP16_Q(-0.09780220),
  DSP16_Q(0.04837079),
  DSP16_Q(-0.02545560),
  DSP16_Q(0.01244193),
  DSP16_Q(-0.00492752),
  DSP16_Q(0.00112624),
  DSP16_Q(-0.00000107),
  DSP16_Q(0.00097538),
  DSP16_Q(-0.00456867),
  DSP16_Q(0.01179287),
  DSP16_Q(-0.02435169),
  DSP16_Q(0.04633913),
  DSP16_Q(-0.09267172),
  DSP16_Q(0.29239589),
  DSP16_Q(0.33452582),
  DSP16_Q(-0.09769624),
  DSP16_Q(0.04833718),
  DSP16_Q(-0.02543694),
  DSP16_Q(0.01242909),
  DSP16_Q(-0.00491893),
  DSP16_Q(0.00112185),
  DSP16_Q(-0.00000093),
  DSP16_Q(0.00098094),
  DSP16_Q(-0.00458375),
  DSP16_Q(0.01182285),
  DSP16_Q(-0.02440586),
  DSP16_Q(0.04643959),
  DSP16_Q(-0.09290452),
  DSP16_Q(0.29388607),
  DSP16_Q(0.33311601),
  DSP16_Q(-0.09758559),
  DSP16_Q(0.04830114),
  DSP16_Q(-0.02541697),
  DSP16_Q(0.01241562),
  DSP16_Q(-0.00491009),
  DSP16_Q(0.00111740),
  DSP16_Q(-0.00000081),
  DSP16_Q(0.00098647),
  DSP16_Q(-0.00459864),
  DSP16_Q(0.01185230),
  DSP16_Q(-0.02445889),
  DSP16_Q(0.04653789),
  DSP16_Q(-0.09313329),
  DSP16_Q(0.29537397),
  DSP16_Q(0.33170274),
  DSP16_Q(-0.09747025),
  DSP16_Q(0.04826266),
  DSP16_Q(-0.02539572),
  DSP16_Q(0.01240152),
  DSP16_Q(-0.00490100),
  DSP16_Q(0.00111291),
  DSP16_Q(-0.00000069),
  DSP16_Q(0.00099197),
  DSP16_Q(-0.00461333),
  DSP16_Q(0.01188119),
  DSP16_Q(-0.02451077),
  DSP16_Q(0.04663402),
  DSP16_Q(-0.09335801),
  DSP16_Q(0.29685955),
  DSP16_Q(0.33028606),
  DSP16_Q(-0.09735025),
  DSP16_Q(0.04822175),
  DSP16_Q(-0.02537317),
  DSP16_Q(0.01238678),
  DSP16_Q(-0.00489167),
  DSP16_Q(0.00110836),
  DSP16_Q(-0.00000058),
  DSP16_Q(0.00099744),
  DSP16_Q(-0.00462781),
  DSP16_Q(0.01190954),
  DSP16_Q(-0.02456149),
  DSP16_Q(0.04672798),
  DSP16_Q(-0.09357865),
  DSP16_Q(0.29834277),
  DSP16_Q(0.32886600),
  DSP16_Q(-0.09722561),
  DSP16_Q(0.04817843),
  DSP16_Q(-0.02534933),
  DSP16_Q(0.01237142),
  DSP16_Q(-0.00488209),
  DSP16_Q(0.00110377),
  DSP16_Q(-0.00000048),
  DSP16_Q(0.00100288),
  DSP16_Q(-0.00464209),
  DSP16_Q(0.01193733),
  DSP16_Q(-0.02461105),
  DSP16_Q(0.04681974),
  DSP16_Q(-0.09379519),
  DSP16_Q(0.29982358),
  DSP16_Q(0.32744261),
  DSP16_Q(-0.09709635),
  DSP16_Q(0.04813270),
  DSP16_Q(-0.02532422),
  DSP16_Q(0.01235543),
  DSP16_Q(-0.00487227),
  DSP16_Q(0.00109913),
  DSP16_Q(-0.00000039),
  DSP16_Q(0.00100828),
  DSP16_Q(-0.00465617),
  DSP16_Q(0.01196456),
  DSP16_Q(-0.02465945),
  DSP16_Q(0.04690930),
  DSP16_Q(-0.09400759),
  DSP16_Q(0.30130194),
  DSP16_Q(0.32601594),
  DSP16_Q(-0.09696251),
  DSP16_Q(0.04808458),
  DSP16_Q(-0.02529783),
  DSP16_Q(0.01233883),
  DSP16_Q(-0.00486221),
  DSP16_Q(0.00109444),
  DSP16_Q(-0.00000031),
  DSP16_Q(0.00101366),
  DSP16_Q(-0.00467004),
  DSP16_Q(0.01199123),
  DSP16_Q(-0.02470667),
  DSP16_Q(0.04699665),
  DSP16_Q(-0.09421584),
  DSP16_Q(0.30277780),
  DSP16_Q(0.32458603),
  DSP16_Q(-0.09682409),
  DSP16_Q(0.04803407),
  DSP16_Q(-0.02527018),
  DSP16_Q(0.01232160),
  DSP16_Q(-0.00485191),
  DSP16_Q(0.00108971),
  DSP16_Q(-0.00000023),
  DSP16_Q(0.00101899),
  DSP16_Q(-0.00468370),
  DSP16_Q(0.01201734),
  DSP16_Q(-0.02475271),
  DSP16_Q(0.04708177),
  DSP16_Q(-0.09441991),
  DSP16_Q(0.30425112),
  DSP16_Q(0.32315291),
  DSP16_Q(-0.09668113),
  DSP16_Q(0.04798118),
  DSP16_Q(-0.02524125),
  DSP16_Q(0.01230376),
  DSP16_Q(-0.00484138),
  DSP16_Q(0.00108493),
  DSP16_Q(-0.00000017),
  DSP16_Q(0.00102430),
  DSP16_Q(-0.00469715),
  DSP16_Q(0.01204288),
  DSP16_Q(-0.02479756),
  DSP16_Q(0.04716466),
  DSP16_Q(-0.09461978),
  DSP16_Q(0.30572185),
  DSP16_Q(0.32171664),
  DSP16_Q(-0.09653365),
  DSP16_Q(0.04792593),
  DSP16_Q(-0.02521107),
  DSP16_Q(0.01228531),
  DSP16_Q(-0.00483061),
  DSP16_Q(0.00108010),
  DSP16_Q(-0.00000012),
  DSP16_Q(0.00102956),
  DSP16_Q(-0.00471038),
  DSP16_Q(0.01206785),
  DSP16_Q(-0.02484123),
  DSP16_Q(0.04724530),
  DSP16_Q(-0.09481541),
  DSP16_Q(0.30718995),
  DSP16_Q(0.32027726),
  DSP16_Q(-0.09638167),
  DSP16_Q(0.04786831),
  DSP16_Q(-0.02517964),
  DSP16_Q(0.01226624),
  DSP16_Q(-0.00481960),
  DSP16_Q(0.00107524),
  DSP16_Q(-0.00000008),
  DSP16_Q(0.00103479),
  DSP16_Q(-0.00472340),
  DSP16_Q(0.01209224),
  DSP16_Q(-0.02488370),
  DSP16_Q(0.04732369),
  DSP16_Q(-0.09500679),
  DSP16_Q(0.30865538),
  DSP16_Q(0.31883480),
  DSP16_Q(-0.09622522),
  DSP16_Q(0.04780835),
  DSP16_Q(-0.02514696),
  DSP16_Q(0.01224658),
  DSP16_Q(-0.00480837),
  DSP16_Q(0.00107032),
  DSP16_Q(-0.00000004),
  DSP16_Q(0.00103999),
  DSP16_Q(-0.00473620),
  DSP16_Q(0.01211605),
  DSP16_Q(-0.02492496),
  DSP16_Q(0.04739981),
  DSP16_Q(-0.09519389),
  DSP16_Q(0.31011809),
  DSP16_Q(0.31738933),
  DSP16_Q(-0.09606432),
  DSP16_Q(0.04774605),
  DSP16_Q(-0.02511303),
  DSP16_Q(0.01222631),
  DSP16_Q(-0.00479690),
  DSP16_Q(0.00106537),
  DSP16_Q(-0.00000002),
  DSP16_Q(0.00104514),
  DSP16_Q(-0.00474879),
  DSP16_Q(0.01213928),
  DSP16_Q(-0.02496502),
  DSP16_Q(0.04747365),
  DSP16_Q(-0.09537668),
  DSP16_Q(0.31157804),
  DSP16_Q(0.31594087),
  DSP16_Q(-0.09589899),
  DSP16_Q(0.04768142),
  DSP16_Q(-0.02507787),
  DSP16_Q(0.01220544),
  DSP16_Q(-0.00478521),
  DSP16_Q(0.00106037),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00105026),
  DSP16_Q(-0.00476115),
  DSP16_Q(0.01216192),
  DSP16_Q(-0.02500386),
  DSP16_Q(0.04754521),
  DSP16_Q(-0.09555514),
  DSP16_Q(0.31303518),
  DSP16_Q(0.31448947),
  DSP16_Q(-0.09572925),
  DSP16_Q(0.04761447),
  DSP16_Q(-0.02504148),
  DSP16_Q(0.01218398),
  DSP16_Q(-0.00477330),
  DSP16_Q(0.00105534),
  DSP16_Q(-0.00000000)
};
