/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 32000 Hz
 *          - Output sampling frequency: 44100 Hz
 *          - Re-sampling order: 30
 *          - Coefficients are normalized
 *          - Memory foot print: 26460 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 16000
 *          - Sampling frequency (fs_hz): 14112000
 *          - Actual FIR filter order (order): 13230
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord30_32000_44100_norm[] = {
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000036),
  DSP16_Q(0.00000154),
  DSP16_Q(-0.00000368),
  DSP16_Q(0.00000696),
  DSP16_Q(-0.00001158),
  DSP16_Q(0.00001778),
  DSP16_Q(-0.00002592),
  DSP16_Q(0.00003654),
  DSP16_Q(-0.00005052),
  DSP16_Q(0.00006947),
  DSP16_Q(-0.00009663),
  DSP16_Q(0.00013964),
  DSP16_Q(-0.00022161),
  DSP16_Q(0.00045843),
  DSP16_Q(0.40832822),
  DSP16_Q(-0.00045737),
  DSP16_Q(0.00022133),
  DSP16_Q(-0.00013952),
  DSP16_Q(0.00009655),
  DSP16_Q(-0.00006942),
  DSP16_Q(0.00005048),
  DSP16_Q(-0.00003651),
  DSP16_Q(0.00002590),
  DSP16_Q(-0.00001776),
  DSP16_Q(0.00001156),
  DSP16_Q(-0.00000696),
  DSP16_Q(0.00000368),
  DSP16_Q(-0.00000154),
  DSP16_Q(0.00000036),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000109),
  DSP16_Q(0.00000463),
  DSP16_Q(-0.00001107),
  DSP16_Q(0.00002092),
  DSP16_Q(-0.00003477),
  DSP16_Q(0.00005338),
  DSP16_Q(-0.00007781),
  DSP16_Q(0.00010969),
  DSP16_Q(-0.00015166),
  DSP16_Q(0.00020855),
  DSP16_Q(-0.00029010),
  DSP16_Q(0.00041931),
  DSP16_Q(-0.00066563),
  DSP16_Q(0.00137846),
  DSP16_Q(0.40832127),
  DSP16_Q(-0.00136891),
  DSP16_Q(0.00066317),
  DSP16_Q(-0.00041816),
  DSP16_Q(0.00028942),
  DSP16_Q(-0.00020809),
  DSP16_Q(0.00015133),
  DSP16_Q(-0.00010944),
  DSP16_Q(0.00007762),
  DSP16_Q(-0.00005323),
  DSP16_Q(0.00003466),
  DSP16_Q(-0.00002084),
  DSP16_Q(0.00001102),
  DSP16_Q(-0.00000460),
  DSP16_Q(0.00000107),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000182),
  DSP16_Q(0.00000774),
  DSP16_Q(-0.00001848),
  DSP16_Q(0.00003491),
  DSP16_Q(-0.00005800),
  DSP16_Q(0.00008904),
  DSP16_Q(-0.00012979),
  DSP16_Q(0.00018294),
  DSP16_Q(-0.00025293),
  DSP16_Q(0.00034782),
  DSP16_Q(-0.00048386),
  DSP16_Q(0.00069946),
  DSP16_Q(-0.00111073),
  DSP16_Q(0.00230271),
  DSP16_Q(0.40830736),
  DSP16_Q(-0.00227618),
  DSP16_Q(0.00110389),
  DSP16_Q(-0.00069628),
  DSP16_Q(0.00048198),
  DSP16_Q(-0.00034655),
  DSP16_Q(0.00025202),
  DSP16_Q(-0.00018225),
  DSP16_Q(0.00012926),
  DSP16_Q(-0.00008864),
  DSP16_Q(0.00005770),
  DSP16_Q(-0.00003469),
  DSP16_Q(0.00001833),
  DSP16_Q(-0.00000764),
  DSP16_Q(0.00000178),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000257),
  DSP16_Q(0.00001086),
  DSP16_Q(-0.00002592),
  DSP16_Q(0.00004893),
  DSP16_Q(-0.00008128),
  DSP16_Q(0.00012476),
  DSP16_Q(-0.00018184),
  DSP16_Q(0.00025630),
  DSP16_Q(-0.00035435),
  DSP16_Q(0.00048727),
  DSP16_Q(-0.00067790),
  DSP16_Q(0.00098009),
  DSP16_Q(-0.00155686),
  DSP16_Q(0.00323116),
  DSP16_Q(0.40828650),
  DSP16_Q(-0.00317917),
  DSP16_Q(0.00154347),
  DSP16_Q(-0.00097386),
  DSP16_Q(0.00067422),
  DSP16_Q(-0.00048480),
  DSP16_Q(0.00035256),
  DSP16_Q(-0.00025495),
  DSP16_Q(0.00018081),
  DSP16_Q(-0.00012397),
  DSP16_Q(0.00008069),
  DSP16_Q(-0.00004850),
  DSP16_Q(0.00002562),
  DSP16_Q(-0.00001067),
  DSP16_Q(0.00000248),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000331),
  DSP16_Q(0.00001399),
  DSP16_Q(-0.00003338),
  DSP16_Q(0.00006299),
  DSP16_Q(-0.00010461),
  DSP16_Q(0.00016054),
  DSP16_Q(-0.00023397),
  DSP16_Q(0.00032975),
  DSP16_Q(-0.00045589),
  DSP16_Q(0.00062691),
  DSP16_Q(-0.00087221),
  DSP16_Q(0.00126117),
  DSP16_Q(-0.00200403),
  DSP16_Q(0.00416379),
  DSP16_Q(0.40825869),
  DSP16_Q(-0.00407784),
  DSP16_Q(0.00198188),
  DSP16_Q(-0.00125089),
  DSP16_Q(0.00086612),
  DSP16_Q(-0.00062282),
  DSP16_Q(0.00045293),
  DSP16_Q(-0.00032753),
  DSP16_Q(0.00023227),
  DSP16_Q(-0.00015924),
  DSP16_Q(0.00010363),
  DSP16_Q(-0.00006227),
  DSP16_Q(0.00003289),
  DSP16_Q(-0.00001369),
  DSP16_Q(0.00000318),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000407),
  DSP16_Q(0.00001714),
  DSP16_Q(-0.00004086),
  DSP16_Q(0.00007708),
  DSP16_Q(-0.00012798),
  DSP16_Q(0.00019638),
  DSP16_Q(-0.00028617),
  DSP16_Q(0.00040330),
  DSP16_Q(-0.00055755),
  DSP16_Q(0.00076671),
  DSP16_Q(-0.00106677),
  DSP16_Q(0.00154271),
  DSP16_Q(-0.00245220),
  DSP16_Q(0.00510059),
  DSP16_Q(0.40822393),
  DSP16_Q(-0.00497220),
  DSP16_Q(0.00241912),
  DSP16_Q(-0.00152734),
  DSP16_Q(0.00105768),
  DSP16_Q(-0.00076060),
  DSP16_Q(0.00055313),
  DSP16_Q(-0.00039997),
  DSP16_Q(0.00028363),
  DSP16_Q(-0.00019443),
  DSP16_Q(0.00012651),
  DSP16_Q(-0.00007600),
  DSP16_Q(0.00004012),
  DSP16_Q(-0.00001669),
  DSP16_Q(0.00000386),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000483),
  DSP16_Q(0.00002030),
  DSP16_Q(-0.00004836),
  DSP16_Q(0.00009120),
  DSP16_Q(-0.00015139),
  DSP16_Q(0.00023227),
  DSP16_Q(-0.00033845),
  DSP16_Q(0.00047693),
  DSP16_Q(-0.00065933),
  DSP16_Q(0.00090668),
  DSP16_Q(-0.00126159),
  DSP16_Q(0.00182469),
  DSP16_Q(-0.00290136),
  DSP16_Q(0.00604152),
  DSP16_Q(0.40818222),
  DSP16_Q(-0.00586221),
  DSP16_Q(0.00285516),
  DSP16_Q(-0.00180322),
  DSP16_Q(0.00124888),
  DSP16_Q(-0.00089815),
  DSP16_Q(0.00065316),
  DSP16_Q(-0.00047229),
  DSP16_Q(0.00033490),
  DSP16_Q(-0.00022955),
  DSP16_Q(0.00014934),
  DSP16_Q(-0.00008970),
  DSP16_Q(0.00004734),
  DSP16_Q(-0.00001967),
  DSP16_Q(0.00000454),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000560),
  DSP16_Q(0.00002348),
  DSP16_Q(-0.00005589),
  DSP16_Q(0.00010535),
  DSP16_Q(-0.00017485),
  DSP16_Q(0.00026822),
  DSP16_Q(-0.00039078),
  DSP16_Q(0.00055065),
  DSP16_Q(-0.00076123),
  DSP16_Q(0.00104681),
  DSP16_Q(-0.00145664),
  DSP16_Q(0.00210708),
  DSP16_Q(-0.00335149),
  DSP16_Q(0.00698659),
  DSP16_Q(0.40813356),
  DSP16_Q(-0.00674787),
  DSP16_Q(0.00328999),
  DSP16_Q(-0.00207851),
  DSP16_Q(0.00143973),
  DSP16_Q(-0.00103545),
  DSP16_Q(0.00075302),
  DSP16_Q(-0.00054448),
  DSP16_Q(0.00038606),
  DSP16_Q(-0.00026460),
  DSP16_Q(0.00017212),
  DSP16_Q(-0.00010336),
  DSP16_Q(0.00005452),
  DSP16_Q(-0.00002264),
  DSP16_Q(0.00000522),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000637),
  DSP16_Q(0.00002667),
  DSP16_Q(-0.00006344),
  DSP16_Q(0.00011953),
  DSP16_Q(-0.00019834),
  DSP16_Q(0.00030421),
  DSP16_Q(-0.00044319),
  DSP16_Q(0.00062446),
  DSP16_Q(-0.00086323),
  DSP16_Q(0.00118709),
  DSP16_Q(-0.00165192),
  DSP16_Q(0.00238988),
  DSP16_Q(-0.00380257),
  DSP16_Q(0.00793575),
  DSP16_Q(0.40807795),
  DSP16_Q(-0.00762915),
  DSP16_Q(0.00372358),
  DSP16_Q(-0.00235319),
  DSP16_Q(0.00163021),
  DSP16_Q(-0.00117249),
  DSP16_Q(0.00085269),
  DSP16_Q(-0.00061653),
  DSP16_Q(0.00043712),
  DSP16_Q(-0.00029956),
  DSP16_Q(0.00019483),
  DSP16_Q(-0.00011697),
  DSP16_Q(0.00006168),
  DSP16_Q(-0.00002560),
  DSP16_Q(0.00000588),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000715),
  DSP16_Q(0.00002987),
  DSP16_Q(-0.00007100),
  DSP16_Q(0.00013374),
  DSP16_Q(-0.00022187),
  DSP16_Q(0.00034026),
  DSP16_Q(-0.00049565),
  DSP16_Q(0.00069834),
  DSP16_Q(-0.00096534),
  DSP16_Q(0.00132751),
  DSP16_Q(-0.00184743),
  DSP16_Q(0.00267308),
  DSP16_Q(-0.00425458),
  DSP16_Q(0.00888901),
  DSP16_Q(0.40801539),
  DSP16_Q(-0.00850604),
  DSP16_Q(0.00415593),
  DSP16_Q(-0.00262725),
  DSP16_Q(0.00182030),
  DSP16_Q(-0.00130928),
  DSP16_Q(0.00095217),
  DSP16_Q(-0.00068844),
  DSP16_Q(0.00048807),
  DSP16_Q(-0.00033445),
  DSP16_Q(0.00021749),
  DSP16_Q(-0.00013055),
  DSP16_Q(0.00006881),
  DSP16_Q(-0.00002853),
  DSP16_Q(0.00000654),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000794),
  DSP16_Q(0.00003309),
  DSP16_Q(-0.00007859),
  DSP16_Q(0.00014798),
  DSP16_Q(-0.00024544),
  DSP16_Q(0.00037635),
  DSP16_Q(-0.00054818),
  DSP16_Q(0.00077230),
  DSP16_Q(-0.00106755),
  DSP16_Q(0.00146807),
  DSP16_Q(-0.00204314),
  DSP16_Q(0.00295666),
  DSP16_Q(-0.00470750),
  DSP16_Q(0.00984633),
  DSP16_Q(0.40794589),
  DSP16_Q(-0.00937852),
  DSP16_Q(0.00458700),
  DSP16_Q(-0.00290069),
  DSP16_Q(0.00201001),
  DSP16_Q(-0.00144581),
  DSP16_Q(0.00105146),
  DSP16_Q(-0.00076021),
  DSP16_Q(0.00053892),
  DSP16_Q(-0.00036926),
  DSP16_Q(0.00024009),
  DSP16_Q(-0.00014408),
  DSP16_Q(0.00007592),
  DSP16_Q(-0.00003146),
  DSP16_Q(0.00000720),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00000874),
  DSP16_Q(0.00003632),
  DSP16_Q(-0.00008620),
  DSP16_Q(0.00016225),
  DSP16_Q(-0.00026905),
  DSP16_Q(0.00041249),
  DSP16_Q(-0.00060076),
  DSP16_Q(0.00084633),
  DSP16_Q(-0.00116984),
  DSP16_Q(0.00160876),
  DSP16_Q(-0.00223905),
  DSP16_Q(0.00324061),
  DSP16_Q(-0.00516131),
  DSP16_Q(0.01080770),
  DSP16_Q(0.40786945),
  DSP16_Q(-0.01024658),
  DSP16_Q(0.00501679),
  DSP16_Q(-0.00317348),
  DSP16_Q(0.00219933),
  DSP16_Q(-0.00158206),
  DSP16_Q(0.00115055),
  DSP16_Q(-0.00083183),
  DSP16_Q(0.00058966),
  DSP16_Q(-0.00040398),
  DSP16_Q(0.00026263),
  DSP16_Q(-0.00015757),
  DSP16_Q(0.00008299),
  DSP16_Q(-0.00003436),
  DSP16_Q(0.00000784),
  DSP16_Q(0.00000001),
  DSP16_Q(-0.00000954),
  DSP16_Q(0.00003956),
  DSP16_Q(-0.00009383),
  DSP16_Q(0.00017655),
  DSP16_Q(-0.00029269),
  DSP16_Q(0.00044867),
  DSP16_Q(-0.00065339),
  DSP16_Q(0.00092043),
  DSP16_Q(-0.00127223),
  DSP16_Q(0.00174957),
  DSP16_Q(-0.00243516),
  DSP16_Q(0.00352492),
  DSP16_Q(-0.00561599),
  DSP16_Q(0.01177309),
  DSP16_Q(0.40778608),
  DSP16_Q(-0.01111020),
  DSP16_Q(0.00544527),
  DSP16_Q(-0.00344561),
  DSP16_Q(0.00238823),
  DSP16_Q(-0.00171803),
  DSP16_Q(0.00124944),
  DSP16_Q(-0.00090329),
  DSP16_Q(0.00064028),
  DSP16_Q(-0.00043862),
  DSP16_Q(0.00028511),
  DSP16_Q(-0.00017102),
  DSP16_Q(0.00009004),
  DSP16_Q(-0.00003725),
  DSP16_Q(0.00000848),
  DSP16_Q(0.00000001),
  DSP16_Q(-0.00001035),
  DSP16_Q(0.00004282),
  DSP16_Q(-0.00010148),
  DSP16_Q(0.00019087),
  DSP16_Q(-0.00031637),
  DSP16_Q(0.00048489),
  DSP16_Q(-0.00070608),
  DSP16_Q(0.00099459),
  DSP16_Q(-0.00137470),
  DSP16_Q(0.00189050),
  DSP16_Q(-0.00263145),
  DSP16_Q(0.00380956),
  DSP16_Q(-0.00607152),
  DSP16_Q(0.01274250),
  DSP16_Q(0.40769576),
  DSP16_Q(-0.01196937),
  DSP16_Q(0.00587243),
  DSP16_Q(-0.00371708),
  DSP16_Q(0.00257672),
  DSP16_Q(-0.00185371),
  DSP16_Q(0.00134812),
  DSP16_Q(-0.00097461),
  DSP16_Q(0.00069079),
  DSP16_Q(-0.00047318),
  DSP16_Q(0.00030753),
  DSP16_Q(-0.00018442),
  DSP16_Q(0.00009706),
  DSP16_Q(-0.00004012),
  DSP16_Q(0.00000912),
  DSP16_Q(0.00000001),
  DSP16_Q(-0.00001116),
  DSP16_Q(0.00004609),
  DSP16_Q(-0.00010915),
  DSP16_Q(0.00020522),
  DSP16_Q(-0.00034008),
  DSP16_Q(0.00052116),
  DSP16_Q(-0.00075882),
  DSP16_Q(0.00106881),
  DSP16_Q(-0.00147725),
  DSP16_Q(0.00203153),
  DSP16_Q(-0.00282791),
  DSP16_Q(0.00409453),
  DSP16_Q(-0.00652789),
  DSP16_Q(0.01371589),
  DSP16_Q(0.40759851),
  DSP16_Q(-0.01282407),
  DSP16_Q(0.00629825),
  DSP16_Q(-0.00398786),
  DSP16_Q(0.00276479),
  DSP16_Q(-0.00198911),
  DSP16_Q(0.00144659),
  DSP16_Q(-0.00104577),
  DSP16_Q(0.00074118),
  DSP16_Q(-0.00050765),
  DSP16_Q(0.00032988),
  DSP16_Q(-0.00019778),
  DSP16_Q(0.00010405),
  DSP16_Q(-0.00004298),
  DSP16_Q(0.00000974),
  DSP16_Q(0.00000001),
  DSP16_Q(-0.00001198),
  DSP16_Q(0.00004937),
  DSP16_Q(-0.00011684),
  DSP16_Q(0.00021959),
  DSP16_Q(-0.00036382),
  DSP16_Q(0.00055746),
  DSP16_Q(-0.00081160),
  DSP16_Q(0.00114309),
  DSP16_Q(-0.00157987),
  DSP16_Q(0.00217267),
  DSP16_Q(-0.00302453),
  DSP16_Q(0.00437982),
  DSP16_Q(-0.00698506),
  DSP16_Q(0.01469324),
  DSP16_Q(0.40749433),
  DSP16_Q(-0.01367428),
  DSP16_Q(0.00672272),
  DSP16_Q(-0.00425796),
  DSP16_Q(0.00295242),
  DSP16_Q(-0.00212420),
  DSP16_Q(0.00154485),
  DSP16_Q(-0.00111676),
  DSP16_Q(0.00079145),
  DSP16_Q(-0.00054202),
  DSP16_Q(0.00035217),
  DSP16_Q(-0.00021110),
  DSP16_Q(0.00011101),
  DSP16_Q(-0.00004582),
  DSP16_Q(0.00001036),
  DSP16_Q(0.00000001),
  DSP16_Q(-0.00001281),
  DSP16_Q(0.00005267),
  DSP16_Q(-0.00012455),
  DSP16_Q(0.00023399),
  DSP16_Q(-0.00038759),
  DSP16_Q(0.00059380),
  DSP16_Q(-0.00086443),
  DSP16_Q(0.00121742),
  DSP16_Q(-0.00168255),
  DSP16_Q(0.00231390),
  DSP16_Q(-0.00322131),
  DSP16_Q(0.00466540),
  DSP16_Q(-0.00744302),
  DSP16_Q(0.01567455),
  DSP16_Q(0.40738322),
  DSP16_Q(-0.01451998),
  DSP16_Q(0.00714580),
  DSP16_Q(-0.00452735),
  DSP16_Q(0.00313962),
  DSP16_Q(-0.00225899),
  DSP16_Q(0.00164288),
  DSP16_Q(-0.00118760),
  DSP16_Q(0.00084160),
  DSP16_Q(-0.00057631),
  DSP16_Q(0.00037440),
  DSP16_Q(-0.00022437),
  DSP16_Q(0.00011795),
  DSP16_Q(-0.00004864),
  DSP16_Q(0.00001097),
  DSP16_Q(0.00000002),
  DSP16_Q(-0.00001364),
  DSP16_Q(0.00005598),
  DSP16_Q(-0.00013228),
  DSP16_Q(0.00024842),
  DSP16_Q(-0.00041139),
  DSP16_Q(0.00063017),
  DSP16_Q(-0.00091729),
  DSP16_Q(0.00129180),
  DSP16_Q(-0.00178530),
  DSP16_Q(0.00245522),
  DSP16_Q(-0.00341823),
  DSP16_Q(0.00495127),
  DSP16_Q(-0.00790175),
  DSP16_Q(0.01665978),
  DSP16_Q(0.40726519),
  DSP16_Q(-0.01536118),
  DSP16_Q(0.00756750),
  DSP16_Q(-0.00479602),
  DSP16_Q(0.00332636),
  DSP16_Q(-0.00239347),
  DSP16_Q(0.00174069),
  DSP16_Q(-0.00125826),
  DSP16_Q(0.00089162),
  DSP16_Q(-0.00061051),
  DSP16_Q(0.00039655),
  DSP16_Q(-0.00023759),
  DSP16_Q(0.00012485),
  DSP16_Q(-0.00005145),
  DSP16_Q(0.00001158),
  DSP16_Q(0.00000002),
  DSP16_Q(-0.00001448),
  DSP16_Q(0.00005930),
  DSP16_Q(-0.00014002),
  DSP16_Q(0.00026286),
  DSP16_Q(-0.00043522),
  DSP16_Q(0.00066658),
  DSP16_Q(-0.00097020),
  DSP16_Q(0.00136623),
  DSP16_Q(-0.00188811),
  DSP16_Q(0.00259662),
  DSP16_Q(-0.00361528),
  DSP16_Q(0.00523741),
  DSP16_Q(-0.00836123),
  DSP16_Q(0.01764892),
  DSP16_Q(0.40714024),
  DSP16_Q(-0.01619784),
  DSP16_Q(0.00798778),
  DSP16_Q(-0.00506396),
  DSP16_Q(0.00351264),
  DSP16_Q(-0.00252763),
  DSP16_Q(0.00183827),
  DSP16_Q(-0.00132875),
  DSP16_Q(0.00094152),
  DSP16_Q(-0.00064461),
  DSP16_Q(0.00041864),
  DSP16_Q(-0.00025077),
  DSP16_Q(0.00013172),
  DSP16_Q(-0.00005424),
  DSP16_Q(0.00001218),
  DSP16_Q(0.00000002),
  DSP16_Q(-0.00001533),
  DSP16_Q(0.00006263),
  DSP16_Q(-0.00014778),
  DSP16_Q(0.00027733),
  DSP16_Q(-0.00045908),
  DSP16_Q(0.00070302),
  DSP16_Q(-0.00102314),
  DSP16_Q(0.00144069),
  DSP16_Q(-0.00199096),
  DSP16_Q(0.00273809),
  DSP16_Q(-0.00381245),
  DSP16_Q(0.00552381),
  DSP16_Q(-0.00882144),
  DSP16_Q(0.01864194),
  DSP16_Q(0.40700837),
  DSP16_Q(-0.01702995),
  DSP16_Q(0.00840664),
  DSP16_Q(-0.00533116),
  DSP16_Q(0.00369845),
  DSP16_Q(-0.00266147),
  DSP16_Q(0.00193561),
  DSP16_Q(-0.00139907),
  DSP16_Q(0.00099128),
  DSP16_Q(-0.00067862),
  DSP16_Q(0.00044066),
  DSP16_Q(-0.00026390),
  DSP16_Q(0.00013857),
  DSP16_Q(-0.00005701),
  DSP16_Q(0.00001277),
  DSP16_Q(0.00000003),
  DSP16_Q(-0.00001618),
  DSP16_Q(0.00006598),
  DSP16_Q(-0.00015556),
  DSP16_Q(0.00029182),
  DSP16_Q(-0.00048296),
  DSP16_Q(0.00073949),
  DSP16_Q(-0.00107611),
  DSP16_Q(0.00151520),
  DSP16_Q(-0.00209387),
  DSP16_Q(0.00287963),
  DSP16_Q(-0.00400974),
  DSP16_Q(0.00581046),
  DSP16_Q(-0.00928235),
  DSP16_Q(0.01963882),
  DSP16_Q(0.40686959),
  DSP16_Q(-0.01785750),
  DSP16_Q(0.00882406),
  DSP16_Q(-0.00559760),
  DSP16_Q(0.00388379),
  DSP16_Q(-0.00279497),
  DSP16_Q(0.00203271),
  DSP16_Q(-0.00146921),
  DSP16_Q(0.00104092),
  DSP16_Q(-0.00071253),
  DSP16_Q(0.00046262),
  DSP16_Q(-0.00027698),
  DSP16_Q(0.00014538),
  DSP16_Q(-0.00005977),
  DSP16_Q(0.00001335),
  DSP16_Q(0.00000003),
  DSP16_Q(-0.00001704),
  DSP16_Q(0.00006934),
  DSP16_Q(-0.00016336),
  DSP16_Q(0.00030634),
  DSP16_Q(-0.00050686),
  DSP16_Q(0.00077598),
  DSP16_Q(-0.00112911),
  DSP16_Q(0.00158974),
  DSP16_Q(-0.00219681),
  DSP16_Q(0.00302123),
  DSP16_Q(-0.00420713),
  DSP16_Q(0.00609733),
  DSP16_Q(-0.00974396),
  DSP16_Q(0.02063955),
  DSP16_Q(0.40672390),
  DSP16_Q(-0.01868048),
  DSP16_Q(0.00924001),
  DSP16_Q(-0.00586329),
  DSP16_Q(0.00406864),
  DSP16_Q(-0.00292814),
  DSP16_Q(0.00212956),
  DSP16_Q(-0.00153918),
  DSP16_Q(0.00109041),
  DSP16_Q(-0.00074634),
  DSP16_Q(0.00048450),
  DSP16_Q(-0.00029002),
  DSP16_Q(0.00015216),
  DSP16_Q(-0.00006251),
  DSP16_Q(0.00001393),
  DSP16_Q(0.00000004),
  DSP16_Q(-0.00001791),
  DSP16_Q(0.00007270),
  DSP16_Q(-0.00017117),
  DSP16_Q(0.00032087),
  DSP16_Q(-0.00053079),
  DSP16_Q(0.00081250),
  DSP16_Q(-0.00118214),
  DSP16_Q(0.00166430),
  DSP16_Q(-0.00229980),
  DSP16_Q(0.00316288),
  DSP16_Q(-0.00440461),
  DSP16_Q(0.00638442),
  DSP16_Q(-0.01020623),
  DSP16_Q(0.02164410),
  DSP16_Q(0.40657130),
  DSP16_Q(-0.01949887),
  DSP16_Q(0.00965449),
  DSP16_Q(-0.00612819),
  DSP16_Q(0.00425300),
  DSP16_Q(-0.00306097),
  DSP16_Q(0.00222617),
  DSP16_Q(-0.00160895),
  DSP16_Q(0.00113978),
  DSP16_Q(-0.00078005),
  DSP16_Q(0.00050631),
  DSP16_Q(-0.00030300),
  DSP16_Q(0.00015891),
  DSP16_Q(-0.00006523),
  DSP16_Q(0.00001450),
  DSP16_Q(0.00000004),
  DSP16_Q(-0.00001878),
  DSP16_Q(0.00007608),
  DSP16_Q(-0.00017900),
  DSP16_Q(0.00033542),
  DSP16_Q(-0.00055475),
  DSP16_Q(0.00084905),
  DSP16_Q(-0.00123520),
  DSP16_Q(0.00173890),
  DSP16_Q(-0.00240281),
  DSP16_Q(0.00330457),
  DSP16_Q(-0.00460218),
  DSP16_Q(0.00667172),
  DSP16_Q(-0.01066914),
  DSP16_Q(0.02265244),
  DSP16_Q(0.40641181),
  DSP16_Q(-0.02031266),
  DSP16_Q(0.01006747),
  DSP16_Q(-0.00639230),
  DSP16_Q(0.00443685),
  DSP16_Q(-0.00319345),
  DSP16_Q(0.00232252),
  DSP16_Q(-0.00167854),
  DSP16_Q(0.00118900),
  DSP16_Q(-0.00081366),
  DSP16_Q(0.00052804),
  DSP16_Q(-0.00031594),
  DSP16_Q(0.00016563),
  DSP16_Q(-0.00006793),
  DSP16_Q(0.00001506),
  DSP16_Q(0.00000005),
  DSP16_Q(-0.00001966),
  DSP16_Q(0.00007948),
  DSP16_Q(-0.00018685),
  DSP16_Q(0.00034999),
  DSP16_Q(-0.00057872),
  DSP16_Q(0.00088561),
  DSP16_Q(-0.00128827),
  DSP16_Q(0.00181351),
  DSP16_Q(-0.00250585),
  DSP16_Q(0.00344630),
  DSP16_Q(-0.00479983),
  DSP16_Q(0.00695920),
  DSP16_Q(-0.01113268),
  DSP16_Q(0.02366457),
  DSP16_Q(0.40624543),
  DSP16_Q(-0.02112183),
  DSP16_Q(0.01047895),
  DSP16_Q(-0.00665561),
  DSP16_Q(0.00462020),
  DSP16_Q(-0.00332557),
  DSP16_Q(0.00241862),
  DSP16_Q(-0.00174794),
  DSP16_Q(0.00123808),
  DSP16_Q(-0.00084717),
  DSP16_Q(0.00054971),
  DSP16_Q(-0.00032882),
  DSP16_Q(0.00017232),
  DSP16_Q(-0.00007062),
  DSP16_Q(0.00001562),
  DSP16_Q(0.00000006),
  DSP16_Q(-0.00002054),
  DSP16_Q(0.00008288),
  DSP16_Q(-0.00019470),
  DSP16_Q(0.00036458),
  DSP16_Q(-0.00060271),
  DSP16_Q(0.00092220),
  DSP16_Q(-0.00134137),
  DSP16_Q(0.00188815),
  DSP16_Q(-0.00260890),
  DSP16_Q(0.00358806),
  DSP16_Q(-0.00499753),
  DSP16_Q(0.00724685),
  DSP16_Q(-0.01159683),
  DSP16_Q(0.02468045),
  DSP16_Q(0.40607215),
  DSP16_Q(-0.02192637),
  DSP16_Q(0.01088889),
  DSP16_Q(-0.00691811),
  DSP16_Q(0.00480302),
  DSP16_Q(-0.00345732),
  DSP16_Q(0.00251445),
  DSP16_Q(-0.00181714),
  DSP16_Q(0.00128702),
  DSP16_Q(-0.00088057),
  DSP16_Q(0.00057130),
  DSP16_Q(-0.00034166),
  DSP16_Q(0.00017898),
  DSP16_Q(-0.00007329),
  DSP16_Q(0.00001617),
  DSP16_Q(0.00000006),
  DSP16_Q(-0.00002143),
  DSP16_Q(0.00008629),
  DSP16_Q(-0.00020258),
  DSP16_Q(0.00037919),
  DSP16_Q(-0.00062672),
  DSP16_Q(0.00095880),
  DSP16_Q(-0.00139448),
  DSP16_Q(0.00196280),
  DSP16_Q(-0.00271198),
  DSP16_Q(0.00372984),
  DSP16_Q(-0.00519529),
  DSP16_Q(0.00753467),
  DSP16_Q(-0.01206156),
  DSP16_Q(0.02570006),
  DSP16_Q(0.40589199),
  DSP16_Q(-0.02272626),
  DSP16_Q(0.01129730),
  DSP16_Q(-0.00717978),
  DSP16_Q(0.00498532),
  DSP16_Q(-0.00358871),
  DSP16_Q(0.00261001),
  DSP16_Q(-0.00188614),
  DSP16_Q(0.00133581),
  DSP16_Q(-0.00091386),
  DSP16_Q(0.00059281),
  DSP16_Q(-0.00035444),
  DSP16_Q(0.00018560),
  DSP16_Q(-0.00007594),
  DSP16_Q(0.00001671),
  DSP16_Q(0.00000007),
  DSP16_Q(-0.00002233),
  DSP16_Q(0.00008972),
  DSP16_Q(-0.00021047),
  DSP16_Q(0.00039381),
  DSP16_Q(-0.00065075),
  DSP16_Q(0.00099542),
  DSP16_Q(-0.00144761),
  DSP16_Q(0.00203746),
  DSP16_Q(-0.00281506),
  DSP16_Q(0.00387164),
  DSP16_Q(-0.00539310),
  DSP16_Q(0.00782263),
  DSP16_Q(-0.01252685),
  DSP16_Q(0.02672339),
  DSP16_Q(0.40570495),
  DSP16_Q(-0.02352150),
  DSP16_Q(0.01170414),
  DSP16_Q(-0.00744062),
  DSP16_Q(0.00516708),
  DSP16_Q(-0.00371973),
  DSP16_Q(0.00270531),
  DSP16_Q(-0.00195495),
  DSP16_Q(0.00138446),
  DSP16_Q(-0.00094705),
  DSP16_Q(0.00061425),
  DSP16_Q(-0.00036718),
  DSP16_Q(0.00019219),
  DSP16_Q(-0.00007858),
  DSP16_Q(0.00001725),
  DSP16_Q(0.00000008),
  DSP16_Q(-0.00002323),
  DSP16_Q(0.00009316),
  DSP16_Q(-0.00021837),
  DSP16_Q(0.00040845),
  DSP16_Q(-0.00067479),
  DSP16_Q(0.00103206),
  DSP16_Q(-0.00150075),
  DSP16_Q(0.00211213),
  DSP16_Q(-0.00291815),
  DSP16_Q(0.00401345),
  DSP16_Q(-0.00559094),
  DSP16_Q(0.00811072),
  DSP16_Q(-0.01299268),
  DSP16_Q(0.02775040),
  DSP16_Q(0.40551104),
  DSP16_Q(-0.02431206),
  DSP16_Q(0.01210941),
  DSP16_Q(-0.00770061),
  DSP16_Q(0.00534829),
  DSP16_Q(-0.00385037),
  DSP16_Q(0.00280032),
  DSP16_Q(-0.00202355),
  DSP16_Q(0.00143295),
  DSP16_Q(-0.00098012),
  DSP16_Q(0.00063561),
  DSP16_Q(-0.00037986),
  DSP16_Q(0.00019875),
  DSP16_Q(-0.00008119),
  DSP16_Q(0.00001778),
  DSP16_Q(0.00000009),
  DSP16_Q(-0.00002414),
  DSP16_Q(0.00009660),
  DSP16_Q(-0.00022629),
  DSP16_Q(0.00042311),
  DSP16_Q(-0.00069885),
  DSP16_Q(0.00106870),
  DSP16_Q(-0.00155389),
  DSP16_Q(0.00218680),
  DSP16_Q(-0.00302123),
  DSP16_Q(0.00415526),
  DSP16_Q(-0.00578880),
  DSP16_Q(0.00839893),
  DSP16_Q(-0.01345903),
  DSP16_Q(0.02878108),
  DSP16_Q(0.40531027),
  DSP16_Q(-0.02509794),
  DSP16_Q(0.01251308),
  DSP16_Q(-0.00795974),
  DSP16_Q(0.00552895),
  DSP16_Q(-0.00398061),
  DSP16_Q(0.00289506),
  DSP16_Q(-0.00209194),
  DSP16_Q(0.00148129),
  DSP16_Q(-0.00101309),
  DSP16_Q(0.00065689),
  DSP16_Q(-0.00039248),
  DSP16_Q(0.00020528),
  DSP16_Q(-0.00008379),
  DSP16_Q(0.00001830),
  DSP16_Q(0.00000010),
  DSP16_Q(-0.00002506),
  DSP16_Q(0.00010006),
  DSP16_Q(-0.00023422),
  DSP16_Q(0.00043777),
  DSP16_Q(-0.00072292),
  DSP16_Q(0.00110536),
  DSP16_Q(-0.00160705),
  DSP16_Q(0.00226147),
  DSP16_Q(-0.00312432),
  DSP16_Q(0.00429707),
  DSP16_Q(-0.00598668),
  DSP16_Q(0.00868725),
  DSP16_Q(-0.01392587),
  DSP16_Q(0.02981541),
  DSP16_Q(0.40510263),
  DSP16_Q(-0.02587913),
  DSP16_Q(0.01291515),
  DSP16_Q(-0.00821799),
  DSP16_Q(0.00570905),
  DSP16_Q(-0.00411047),
  DSP16_Q(0.00298951),
  DSP16_Q(-0.00216012),
  DSP16_Q(0.00152947),
  DSP16_Q(-0.00104594),
  DSP16_Q(0.00067809),
  DSP16_Q(-0.00040506),
  DSP16_Q(0.00021177),
  DSP16_Q(-0.00008637),
  DSP16_Q(0.00001882),
  DSP16_Q(0.00000010),
  DSP16_Q(-0.00002598),
  DSP16_Q(0.00010353),
  DSP16_Q(-0.00024216),
  DSP16_Q(0.00045246),
  DSP16_Q(-0.00074701),
  DSP16_Q(0.00114203),
  DSP16_Q(-0.00166020),
  DSP16_Q(0.00233614),
  DSP16_Q(-0.00322739),
  DSP16_Q(0.00443886),
  DSP16_Q(-0.00618456),
  DSP16_Q(0.00897565),
  DSP16_Q(-0.01439320),
  DSP16_Q(0.03085335),
  DSP16_Q(0.40488814),
  DSP16_Q(-0.02665560),
  DSP16_Q(0.01331560),
  DSP16_Q(-0.00847537),
  DSP16_Q(0.00588858),
  DSP16_Q(-0.00423993),
  DSP16_Q(0.00308367),
  DSP16_Q(-0.00222809),
  DSP16_Q(0.00157750),
  DSP16_Q(-0.00107868),
  DSP16_Q(0.00069921),
  DSP16_Q(-0.00041758),
  DSP16_Q(0.00021823),
  DSP16_Q(-0.00008894),
  DSP16_Q(0.00001933),
  DSP16_Q(0.00000012),
  DSP16_Q(-0.00002691),
  DSP16_Q(0.00010700),
  DSP16_Q(-0.00025012),
  DSP16_Q(0.00046715),
  DSP16_Q(-0.00077110),
  DSP16_Q(0.00117870),
  DSP16_Q(-0.00171335),
  DSP16_Q(0.00241080),
  DSP16_Q(-0.00333044),
  DSP16_Q(0.00458063),
  DSP16_Q(-0.00638244),
  DSP16_Q(0.00926413),
  DSP16_Q(-0.01486098),
  DSP16_Q(0.03189490),
  DSP16_Q(0.40466680),
  DSP16_Q(-0.02742736),
  DSP16_Q(0.01371440),
  DSP16_Q(-0.00873185),
  DSP16_Q(0.00606753),
  DSP16_Q(-0.00436898),
  DSP16_Q(0.00317753),
  DSP16_Q(-0.00229584),
  DSP16_Q(0.00162537),
  DSP16_Q(-0.00111130),
  DSP16_Q(0.00072025),
  DSP16_Q(-0.00043004),
  DSP16_Q(0.00022466),
  DSP16_Q(-0.00009148),
  DSP16_Q(0.00001983),
  DSP16_Q(0.00000013),
  DSP16_Q(-0.00002784),
  DSP16_Q(0.00011049),
  DSP16_Q(-0.00025809),
  DSP16_Q(0.00048186),
  DSP16_Q(-0.00079521),
  DSP16_Q(0.00121538),
  DSP16_Q(-0.00176651),
  DSP16_Q(0.00248544),
  DSP16_Q(-0.00343347),
  DSP16_Q(0.00472237),
  DSP16_Q(-0.00658029),
  DSP16_Q(0.00955267),
  DSP16_Q(-0.01532919),
  DSP16_Q(0.03294002),
  DSP16_Q(0.40443863),
  DSP16_Q(-0.02819438),
  DSP16_Q(0.01411155),
  DSP16_Q(-0.00898742),
  DSP16_Q(0.00624589),
  DSP16_Q(-0.00449762),
  DSP16_Q(0.00327110),
  DSP16_Q(-0.00236337),
  DSP16_Q(0.00167308),
  DSP16_Q(-0.00114381),
  DSP16_Q(0.00074121),
  DSP16_Q(-0.00044246),
  DSP16_Q(0.00023105),
  DSP16_Q(-0.00009401),
  DSP16_Q(0.00002033),
  DSP16_Q(0.00000014),
  DSP16_Q(-0.00002878),
  DSP16_Q(0.00011399),
  DSP16_Q(-0.00026607),
  DSP16_Q(0.00049658),
  DSP16_Q(-0.00081932),
  DSP16_Q(0.00125206),
  DSP16_Q(-0.00181965),
  DSP16_Q(0.00256007),
  DSP16_Q(-0.00353647),
  DSP16_Q(0.00486408),
  DSP16_Q(-0.00677813),
  DSP16_Q(0.00984125),
  DSP16_Q(-0.01579781),
  DSP16_Q(0.03398869),
  DSP16_Q(0.40420362),
  DSP16_Q(-0.02895666),
  DSP16_Q(0.01450703),
  DSP16_Q(-0.00924208),
  DSP16_Q(0.00642366),
  DSP16_Q(-0.00462584),
  DSP16_Q(0.00336436),
  DSP16_Q(-0.00243068),
  DSP16_Q(0.00172062),
  DSP16_Q(-0.00117620),
  DSP16_Q(0.00076208),
  DSP16_Q(-0.00045481),
  DSP16_Q(0.00023741),
  DSP16_Q(-0.00009652),
  DSP16_Q(0.00002082),
  DSP16_Q(0.00000015),
  DSP16_Q(-0.00002973),
  DSP16_Q(0.00011750),
  DSP16_Q(-0.00027406),
  DSP16_Q(0.00051131),
  DSP16_Q(-0.00084344),
  DSP16_Q(0.00128874),
  DSP16_Q(-0.00187279),
  DSP16_Q(0.00263468),
  DSP16_Q(-0.00363944),
  DSP16_Q(0.00500574),
  DSP16_Q(-0.00697593),
  DSP16_Q(0.01012986),
  DSP16_Q(-0.01626682),
  DSP16_Q(0.03504089),
  DSP16_Q(0.40396178),
  DSP16_Q(-0.02971417),
  DSP16_Q(0.01490083),
  DSP16_Q(-0.00949581),
  DSP16_Q(0.00660082),
  DSP16_Q(-0.00475364),
  DSP16_Q(0.00345731),
  DSP16_Q(-0.00249776),
  DSP16_Q(0.00176799),
  DSP16_Q(-0.00120846),
  DSP16_Q(0.00078287),
  DSP16_Q(-0.00046711),
  DSP16_Q(0.00024373),
  DSP16_Q(-0.00009901),
  DSP16_Q(0.00002130),
  DSP16_Q(0.00000016),
  DSP16_Q(-0.00003068),
  DSP16_Q(0.00012101),
  DSP16_Q(-0.00028206),
  DSP16_Q(0.00052605),
  DSP16_Q(-0.00086757),
  DSP16_Q(0.00132542),
  DSP16_Q(-0.00192592),
  DSP16_Q(0.00270927),
  DSP16_Q(-0.00374238),
  DSP16_Q(0.00514736),
  DSP16_Q(-0.00717368),
  DSP16_Q(0.01041850),
  DSP16_Q(-0.01673621),
  DSP16_Q(0.03609659),
  DSP16_Q(0.40371313),
  DSP16_Q(-0.03046692),
  DSP16_Q(0.01529292),
  DSP16_Q(-0.00974861),
  DSP16_Q(0.00677738),
  DSP16_Q(-0.00488102),
  DSP16_Q(0.00354996),
  DSP16_Q(-0.00256461),
  DSP16_Q(0.00181520),
  DSP16_Q(-0.00124061),
  DSP16_Q(0.00080357),
  DSP16_Q(-0.00047935),
  DSP16_Q(0.00025002),
  DSP16_Q(-0.00010148),
  DSP16_Q(0.00002177),
  DSP16_Q(0.00000018),
  DSP16_Q(-0.00003164),
  DSP16_Q(0.00012454),
  DSP16_Q(-0.00029007),
  DSP16_Q(0.00054079),
  DSP16_Q(-0.00089170),
  DSP16_Q(0.00136209),
  DSP16_Q(-0.00197903),
  DSP16_Q(0.00278383),
  DSP16_Q(-0.00384526),
  DSP16_Q(0.00528891),
  DSP16_Q(-0.00737137),
  DSP16_Q(0.01070713),
  DSP16_Q(-0.01720593),
  DSP16_Q(0.03715578),
  DSP16_Q(0.40345766),
  DSP16_Q(-0.03121489),
  DSP16_Q(0.01568330),
  DSP16_Q(-0.01000045),
  DSP16_Q(0.00695332),
  DSP16_Q(-0.00500795),
  DSP16_Q(0.00364229),
  DSP16_Q(-0.00263123),
  DSP16_Q(0.00186224),
  DSP16_Q(-0.00127263),
  DSP16_Q(0.00082419),
  DSP16_Q(-0.00049154),
  DSP16_Q(0.00025628),
  DSP16_Q(-0.00010393),
  DSP16_Q(0.00002224),
  DSP16_Q(0.00000019),
  DSP16_Q(-0.00003260),
  DSP16_Q(0.00012807),
  DSP16_Q(-0.00029809),
  DSP16_Q(0.00055555),
  DSP16_Q(-0.00091583),
  DSP16_Q(0.00139877),
  DSP16_Q(-0.00203213),
  DSP16_Q(0.00285835),
  DSP16_Q(-0.00394811),
  DSP16_Q(0.00543041),
  DSP16_Q(-0.00756900),
  DSP16_Q(0.01099575),
  DSP16_Q(-0.01767598),
  DSP16_Q(0.03821842),
  DSP16_Q(0.40319539),
  DSP16_Q(-0.03195807),
  DSP16_Q(0.01607195),
  DSP16_Q(-0.01025133),
  DSP16_Q(0.00712862),
  DSP16_Q(-0.00513445),
  DSP16_Q(0.00373429),
  DSP16_Q(-0.00269761),
  DSP16_Q(0.00190910),
  DSP16_Q(-0.00130453),
  DSP16_Q(0.00084473),
  DSP16_Q(-0.00050366),
  DSP16_Q(0.00026249),
  DSP16_Q(-0.00010637),
  DSP16_Q(0.00002271),
  DSP16_Q(0.00000021),
  DSP16_Q(-0.00003357),
  DSP16_Q(0.00013162),
  DSP16_Q(-0.00030612),
  DSP16_Q(0.00057031),
  DSP16_Q(-0.00093997),
  DSP16_Q(0.00143543),
  DSP16_Q(-0.00208520),
  DSP16_Q(0.00293284),
  DSP16_Q(-0.00405089),
  DSP16_Q(0.00557183),
  DSP16_Q(-0.00776655),
  DSP16_Q(0.01128435),
  DSP16_Q(-0.01814634),
  DSP16_Q(0.03928450),
  DSP16_Q(0.40292633),
  DSP16_Q(-0.03269644),
  DSP16_Q(0.01645885),
  DSP16_Q(-0.01050124),
  DSP16_Q(0.00730330),
  DSP16_Q(-0.00526050),
  DSP16_Q(0.00382598),
  DSP16_Q(-0.00276375),
  DSP16_Q(0.00195579),
  DSP16_Q(-0.00133630),
  DSP16_Q(0.00086517),
  DSP16_Q(-0.00051573),
  DSP16_Q(0.00026868),
  DSP16_Q(-0.00010879),
  DSP16_Q(0.00002316),
  DSP16_Q(0.00000022),
  DSP16_Q(-0.00003454),
  DSP16_Q(0.00013517),
  DSP16_Q(-0.00031416),
  DSP16_Q(0.00058508),
  DSP16_Q(-0.00096411),
  DSP16_Q(0.00147209),
  DSP16_Q(-0.00213826),
  DSP16_Q(0.00300730),
  DSP16_Q(-0.00415362),
  DSP16_Q(0.00571317),
  DSP16_Q(-0.00796401),
  DSP16_Q(0.01157290),
  DSP16_Q(-0.01861697),
  DSP16_Q(0.04035398),
  DSP16_Q(0.40265048),
  DSP16_Q(-0.03343000),
  DSP16_Q(0.01684399),
  DSP16_Q(-0.01075017),
  DSP16_Q(0.00747733),
  DSP16_Q(-0.00538610),
  DSP16_Q(0.00391733),
  DSP16_Q(-0.00282966),
  DSP16_Q(0.00200230),
  DSP16_Q(-0.00136794),
  DSP16_Q(0.00088553),
  DSP16_Q(-0.00052774),
  DSP16_Q(0.00027482),
  DSP16_Q(-0.00011118),
  DSP16_Q(0.00002361),
  DSP16_Q(0.00000024),
  DSP16_Q(-0.00003552),
  DSP16_Q(0.00013873),
  DSP16_Q(-0.00032221),
  DSP16_Q(0.00059986),
  DSP16_Q(-0.00098825),
  DSP16_Q(0.00150873),
  DSP16_Q(-0.00219129),
  DSP16_Q(0.00308171),
  DSP16_Q(-0.00425628),
  DSP16_Q(0.00585443),
  DSP16_Q(-0.00816138),
  DSP16_Q(0.01186140),
  DSP16_Q(-0.01908786),
  DSP16_Q(0.04142685),
  DSP16_Q(0.40236785),
  DSP16_Q(-0.03415873),
  DSP16_Q(0.01722736),
  DSP16_Q(-0.01099810),
  DSP16_Q(0.00765071),
  DSP16_Q(-0.00551124),
  DSP16_Q(0.00400835),
  DSP16_Q(-0.00289531),
  DSP16_Q(0.00204863),
  DSP16_Q(-0.00139946),
  DSP16_Q(0.00090579),
  DSP16_Q(-0.00053970),
  DSP16_Q(0.00028094),
  DSP16_Q(-0.00011356),
  DSP16_Q(0.00002405),
  DSP16_Q(0.00000026),
  DSP16_Q(-0.00003651),
  DSP16_Q(0.00014230),
  DSP16_Q(-0.00033027),
  DSP16_Q(0.00061464),
  DSP16_Q(-0.00101238),
  DSP16_Q(0.00154537),
  DSP16_Q(-0.00224429),
  DSP16_Q(0.00315607),
  DSP16_Q(-0.00435887),
  DSP16_Q(0.00599560),
  DSP16_Q(-0.00835864),
  DSP16_Q(0.01214983),
  DSP16_Q(-0.01955899),
  DSP16_Q(0.04250308),
  DSP16_Q(0.40207846),
  DSP16_Q(-0.03488263),
  DSP16_Q(0.01760894),
  DSP16_Q(-0.01124503),
  DSP16_Q(0.00782344),
  DSP16_Q(-0.00563592),
  DSP16_Q(0.00409903),
  DSP16_Q(-0.00296072),
  DSP16_Q(0.00209478),
  DSP16_Q(-0.00143084),
  DSP16_Q(0.00092597),
  DSP16_Q(-0.00055159),
  DSP16_Q(0.00028701),
  DSP16_Q(-0.00011592),
  DSP16_Q(0.00002449),
  DSP16_Q(0.00000028),
  DSP16_Q(-0.00003750),
  DSP16_Q(0.00014588),
  DSP16_Q(-0.00033834),
  DSP16_Q(0.00062943),
  DSP16_Q(-0.00103651),
  DSP16_Q(0.00158199),
  DSP16_Q(-0.00229726),
  DSP16_Q(0.00323038),
  DSP16_Q(-0.00446139),
  DSP16_Q(0.00613666),
  DSP16_Q(-0.00855578),
  DSP16_Q(0.01243817),
  DSP16_Q(-0.02003033),
  DSP16_Q(0.04358264),
  DSP16_Q(0.40178230),
  DSP16_Q(-0.03560169),
  DSP16_Q(0.01798871),
  DSP16_Q(-0.01149094),
  DSP16_Q(0.00799549),
  DSP16_Q(-0.00576013),
  DSP16_Q(0.00418938),
  DSP16_Q(-0.00302588),
  DSP16_Q(0.00214075),
  DSP16_Q(-0.00146210),
  DSP16_Q(0.00094605),
  DSP16_Q(-0.00056342),
  DSP16_Q(0.00029305),
  DSP16_Q(-0.00011826),
  DSP16_Q(0.00002491),
  DSP16_Q(0.00000030),
  DSP16_Q(-0.00003850),
  DSP16_Q(0.00014946),
  DSP16_Q(-0.00034641),
  DSP16_Q(0.00064422),
  DSP16_Q(-0.00106064),
  DSP16_Q(0.00161859),
  DSP16_Q(-0.00235020),
  DSP16_Q(0.00330463),
  DSP16_Q(-0.00456383),
  DSP16_Q(0.00627761),
  DSP16_Q(-0.00875280),
  DSP16_Q(0.01272642),
  DSP16_Q(-0.02050187),
  DSP16_Q(0.04466552),
  DSP16_Q(0.40147939),
  DSP16_Q(-0.03631588),
  DSP16_Q(0.01836666),
  DSP16_Q(-0.01173583),
  DSP16_Q(0.00816688),
  DSP16_Q(-0.00588386),
  DSP16_Q(0.00427937),
  DSP16_Q(-0.00309078),
  DSP16_Q(0.00218653),
  DSP16_Q(-0.00149322),
  DSP16_Q(0.00096604),
  DSP16_Q(-0.00057519),
  DSP16_Q(0.00029905),
  DSP16_Q(-0.00012059),
  DSP16_Q(0.00002534),
  DSP16_Q(0.00000032),
  DSP16_Q(-0.00003950),
  DSP16_Q(0.00015305),
  DSP16_Q(-0.00035449),
  DSP16_Q(0.00065901),
  DSP16_Q(-0.00108476),
  DSP16_Q(0.00165517),
  DSP16_Q(-0.00240310),
  DSP16_Q(0.00337883),
  DSP16_Q(-0.00466618),
  DSP16_Q(0.00641845),
  DSP16_Q(-0.00894967),
  DSP16_Q(0.01301455),
  DSP16_Q(-0.02097357),
  DSP16_Q(0.04575168),
  DSP16_Q(0.40116974),
  DSP16_Q(-0.03702521),
  DSP16_Q(0.01874278),
  DSP16_Q(-0.01197969),
  DSP16_Q(0.00833758),
  DSP16_Q(-0.00600711),
  DSP16_Q(0.00436902),
  DSP16_Q(-0.00315543),
  DSP16_Q(0.00223212),
  DSP16_Q(-0.00152420),
  DSP16_Q(0.00098594),
  DSP16_Q(-0.00058690),
  DSP16_Q(0.00030502),
  DSP16_Q(-0.00012289),
  DSP16_Q(0.00002575),
  DSP16_Q(0.00000034),
  DSP16_Q(-0.00004051),
  DSP16_Q(0.00015666),
  DSP16_Q(-0.00036258),
  DSP16_Q(0.00067380),
  DSP16_Q(-0.00110888),
  DSP16_Q(0.00169174),
  DSP16_Q(-0.00245597),
  DSP16_Q(0.00345296),
  DSP16_Q(-0.00476843),
  DSP16_Q(0.00655917),
  DSP16_Q(-0.00914640),
  DSP16_Q(0.01330255),
  DSP16_Q(-0.02144542),
  DSP16_Q(0.04684110),
  DSP16_Q(0.40085336),
  DSP16_Q(-0.03772967),
  DSP16_Q(0.01911706),
  DSP16_Q(-0.01222250),
  DSP16_Q(0.00850759),
  DSP16_Q(-0.00612988),
  DSP16_Q(0.00445831),
  DSP16_Q(-0.00321982),
  DSP16_Q(0.00227753),
  DSP16_Q(-0.00155505),
  DSP16_Q(0.00100574),
  DSP16_Q(-0.00059855),
  DSP16_Q(0.00031095),
  DSP16_Q(-0.00012518),
  DSP16_Q(0.00002616),
  DSP16_Q(0.00000036),
  DSP16_Q(-0.00004153),
  DSP16_Q(0.00016026),
  DSP16_Q(-0.00037067),
  DSP16_Q(0.00068860),
  DSP16_Q(-0.00113299),
  DSP16_Q(0.00172828),
  DSP16_Q(-0.00250879),
  DSP16_Q(0.00352703),
  DSP16_Q(-0.00487060),
  DSP16_Q(0.00669975),
  DSP16_Q(-0.00934297),
  DSP16_Q(0.01359041),
  DSP16_Q(-0.02191739),
  DSP16_Q(0.04793376),
  DSP16_Q(0.40053026),
  DSP16_Q(-0.03842924),
  DSP16_Q(0.01948947),
  DSP16_Q(-0.01246425),
  DSP16_Q(0.00867691),
  DSP16_Q(-0.00625215),
  DSP16_Q(0.00454725),
  DSP16_Q(-0.00328394),
  DSP16_Q(0.00232274),
  DSP16_Q(-0.00158577),
  DSP16_Q(0.00102545),
  DSP16_Q(-0.00061014),
  DSP16_Q(0.00031684),
  DSP16_Q(-0.00012744),
  DSP16_Q(0.00002656),
  DSP16_Q(0.00000038),
  DSP16_Q(-0.00004254),
  DSP16_Q(0.00016388),
  DSP16_Q(-0.00037877),
  DSP16_Q(0.00070339),
  DSP16_Q(-0.00115708),
  DSP16_Q(0.00176479),
  DSP16_Q(-0.00256156),
  DSP16_Q(0.00360103),
  DSP16_Q(-0.00497265),
  DSP16_Q(0.00684020),
  DSP16_Q(-0.00953938),
  DSP16_Q(0.01387811),
  DSP16_Q(-0.02238946),
  DSP16_Q(0.04902963),
  DSP16_Q(0.40020044),
  DSP16_Q(-0.03912392),
  DSP16_Q(0.01986001),
  DSP16_Q(-0.01270493),
  DSP16_Q(0.00884552),
  DSP16_Q(-0.00637393),
  DSP16_Q(0.00463582),
  DSP16_Q(-0.00334780),
  DSP16_Q(0.00236776),
  DSP16_Q(-0.00161634),
  DSP16_Q(0.00104507),
  DSP16_Q(-0.00062166),
  DSP16_Q(0.00032269),
  DSP16_Q(-0.00012969),
  DSP16_Q(0.00002696),
  DSP16_Q(0.00000041),
  DSP16_Q(-0.00004357),
  DSP16_Q(0.00016750),
  DSP16_Q(-0.00038687),
  DSP16_Q(0.00071819),
  DSP16_Q(-0.00118117),
  DSP16_Q(0.00180129),
  DSP16_Q(-0.00261429),
  DSP16_Q(0.00367495),
  DSP16_Q(-0.00507461),
  DSP16_Q(0.00698050),
  DSP16_Q(-0.00973560),
  DSP16_Q(0.01416564),
  DSP16_Q(-0.02286161),
  DSP16_Q(0.05012868),
  DSP16_Q(0.39986392),
  DSP16_Q(-0.03981369),
  DSP16_Q(0.02022866),
  DSP16_Q(-0.01294454),
  DSP16_Q(0.00901342),
  DSP16_Q(-0.00649520),
  DSP16_Q(0.00472402),
  DSP16_Q(-0.00341139),
  DSP16_Q(0.00241258),
  DSP16_Q(-0.00164678),
  DSP16_Q(0.00106459),
  DSP16_Q(-0.00063312),
  DSP16_Q(0.00032851),
  DSP16_Q(-0.00013192),
  DSP16_Q(0.00002735),
  DSP16_Q(0.00000043),
  DSP16_Q(-0.00004460),
  DSP16_Q(0.00017113),
  DSP16_Q(-0.00039498),
  DSP16_Q(0.00073298),
  DSP16_Q(-0.00120525),
  DSP16_Q(0.00183775),
  DSP16_Q(-0.00266697),
  DSP16_Q(0.00374879),
  DSP16_Q(-0.00517644),
  DSP16_Q(0.00712065),
  DSP16_Q(-0.00993163),
  DSP16_Q(0.01445298),
  DSP16_Q(-0.02333382),
  DSP16_Q(0.05123089),
  DSP16_Q(0.39952071),
  DSP16_Q(-0.04049855),
  DSP16_Q(0.02059541),
  DSP16_Q(-0.01318306),
  DSP16_Q(0.00918060),
  DSP16_Q(-0.00661597),
  DSP16_Q(0.00481186),
  DSP16_Q(-0.00347471),
  DSP16_Q(0.00245721),
  DSP16_Q(-0.00167707),
  DSP16_Q(0.00108401),
  DSP16_Q(-0.00064452),
  DSP16_Q(0.00033429),
  DSP16_Q(-0.00013412),
  DSP16_Q(0.00002773),
  DSP16_Q(0.00000046),
  DSP16_Q(-0.00004564),
  DSP16_Q(0.00017477),
  DSP16_Q(-0.00040310),
  DSP16_Q(0.00074778),
  DSP16_Q(-0.00122931),
  DSP16_Q(0.00187418),
  DSP16_Q(-0.00271960),
  DSP16_Q(0.00382255),
  DSP16_Q(-0.00527816),
  DSP16_Q(0.00726064),
  DSP16_Q(-0.01012747),
  DSP16_Q(0.01474011),
  DSP16_Q(-0.02380606),
  DSP16_Q(0.05233623),
  DSP16_Q(0.39917082),
  DSP16_Q(-0.04117849),
  DSP16_Q(0.02096024),
  DSP16_Q(-0.01342049),
  DSP16_Q(0.00934705),
  DSP16_Q(-0.00673622),
  DSP16_Q(0.00489932),
  DSP16_Q(-0.00353776),
  DSP16_Q(0.00250163),
  DSP16_Q(-0.00170722),
  DSP16_Q(0.00110333),
  DSP16_Q(-0.00065585),
  DSP16_Q(0.00034003),
  DSP16_Q(-0.00013631),
  DSP16_Q(0.00002810),
  DSP16_Q(0.00000049),
  DSP16_Q(-0.00004668),
  DSP16_Q(0.00017841),
  DSP16_Q(-0.00041121),
  DSP16_Q(0.00076256),
  DSP16_Q(-0.00125336),
  DSP16_Q(0.00191058),
  DSP16_Q(-0.00277217),
  DSP16_Q(0.00389623),
  DSP16_Q(-0.00537976),
  DSP16_Q(0.00740046),
  DSP16_Q(-0.01032310),
  DSP16_Q(0.01502703),
  DSP16_Q(-0.02427831),
  DSP16_Q(0.05344468),
  DSP16_Q(0.39881425),
  DSP16_Q(-0.04185349),
  DSP16_Q(0.02132315),
  DSP16_Q(-0.01365680),
  DSP16_Q(0.00951277),
  DSP16_Q(-0.00685595),
  DSP16_Q(0.00498641),
  DSP16_Q(-0.00360052),
  DSP16_Q(0.00254586),
  DSP16_Q(-0.00173723),
  DSP16_Q(0.00112255),
  DSP16_Q(-0.00066712),
  DSP16_Q(0.00034573),
  DSP16_Q(-0.00013848),
  DSP16_Q(0.00002847),
  DSP16_Q(0.00000051),
  DSP16_Q(-0.00004772),
  DSP16_Q(0.00018206),
  DSP16_Q(-0.00041934),
  DSP16_Q(0.00077735),
  DSP16_Q(-0.00127739),
  DSP16_Q(0.00194695),
  DSP16_Q(-0.00282468),
  DSP16_Q(0.00396981),
  DSP16_Q(-0.00548122),
  DSP16_Q(0.00754011),
  DSP16_Q(-0.01051850),
  DSP16_Q(0.01531372),
  DSP16_Q(-0.02475055),
  DSP16_Q(0.05455622),
  DSP16_Q(0.39845103),
  DSP16_Q(-0.04252356),
  DSP16_Q(0.02168411),
  DSP16_Q(-0.01389200),
  DSP16_Q(0.00967775),
  DSP16_Q(-0.00697516),
  DSP16_Q(0.00507311),
  DSP16_Q(-0.00366301),
  DSP16_Q(0.00258987),
  DSP16_Q(-0.00176709),
  DSP16_Q(0.00114167),
  DSP16_Q(-0.00067832),
  DSP16_Q(0.00035139),
  DSP16_Q(-0.00014063),
  DSP16_Q(0.00002884),
  DSP16_Q(0.00000054),
  DSP16_Q(-0.00004877),
  DSP16_Q(0.00018571),
  DSP16_Q(-0.00042746),
  DSP16_Q(0.00079213),
  DSP16_Q(-0.00130140),
  DSP16_Q(0.00198328),
  DSP16_Q(-0.00287713),
  DSP16_Q(0.00404330),
  DSP16_Q(-0.00558255),
  DSP16_Q(0.00767958),
  DSP16_Q(-0.01071368),
  DSP16_Q(0.01560016),
  DSP16_Q(-0.02522276),
  DSP16_Q(0.05567081),
  DSP16_Q(0.39808116),
  DSP16_Q(-0.04318868),
  DSP16_Q(0.02204312),
  DSP16_Q(-0.01412608),
  DSP16_Q(0.00984198),
  DSP16_Q(-0.00709384),
  DSP16_Q(0.00515943),
  DSP16_Q(-0.00372522),
  DSP16_Q(0.00263369),
  DSP16_Q(-0.00179680),
  DSP16_Q(0.00116070),
  DSP16_Q(-0.00068946),
  DSP16_Q(0.00035702),
  DSP16_Q(-0.00014276),
  DSP16_Q(0.00002919),
  DSP16_Q(0.00000057),
  DSP16_Q(-0.00004983),
  DSP16_Q(0.00018937),
  DSP16_Q(-0.00043559),
  DSP16_Q(0.00080691),
  DSP16_Q(-0.00132540),
  DSP16_Q(0.00201957),
  DSP16_Q(-0.00292952),
  DSP16_Q(0.00411669),
  DSP16_Q(-0.00568374),
  DSP16_Q(0.00781885),
  DSP16_Q(-0.01090861),
  DSP16_Q(0.01588634),
  DSP16_Q(-0.02569490),
  DSP16_Q(0.05678842),
  DSP16_Q(0.39770465),
  DSP16_Q(-0.04384884),
  DSP16_Q(0.02240016),
  DSP16_Q(-0.01435901),
  DSP16_Q(0.01000546),
  DSP16_Q(-0.00721198),
  DSP16_Q(0.00524536),
  DSP16_Q(-0.00378713),
  DSP16_Q(0.00267730),
  DSP16_Q(-0.00182637),
  DSP16_Q(0.00117962),
  DSP16_Q(-0.00070054),
  DSP16_Q(0.00036260),
  DSP16_Q(-0.00014487),
  DSP16_Q(0.00002954),
  DSP16_Q(0.00000061),
  DSP16_Q(-0.00005089),
  DSP16_Q(0.00019304),
  DSP16_Q(-0.00044371),
  DSP16_Q(0.00082168),
  DSP16_Q(-0.00134937),
  DSP16_Q(0.00205582),
  DSP16_Q(-0.00298184),
  DSP16_Q(0.00418998),
  DSP16_Q(-0.00578479),
  DSP16_Q(0.00795793),
  DSP16_Q(-0.01110330),
  DSP16_Q(0.01617224),
  DSP16_Q(-0.02616696),
  DSP16_Q(0.05790904),
  DSP16_Q(0.39732152),
  DSP16_Q(-0.04450404),
  DSP16_Q(0.02275522),
  DSP16_Q(-0.01459081),
  DSP16_Q(0.01016817),
  DSP16_Q(-0.00732959),
  DSP16_Q(0.00533089),
  DSP16_Q(-0.00384876),
  DSP16_Q(0.00272069),
  DSP16_Q(-0.00185579),
  DSP16_Q(0.00119844),
  DSP16_Q(-0.00071154),
  DSP16_Q(0.00036815),
  DSP16_Q(-0.00014697),
  DSP16_Q(0.00002988),
  DSP16_Q(0.00000064),
  DSP16_Q(-0.00005196),
  DSP16_Q(0.00019671),
  DSP16_Q(-0.00045185),
  DSP16_Q(0.00083644),
  DSP16_Q(-0.00137333),
  DSP16_Q(0.00209204),
  DSP16_Q(-0.00303409),
  DSP16_Q(0.00426317),
  DSP16_Q(-0.00588568),
  DSP16_Q(0.00809681),
  DSP16_Q(-0.01129772),
  DSP16_Q(0.01645786),
  DSP16_Q(-0.02663892),
  DSP16_Q(0.05903264),
  DSP16_Q(0.39693177),
  DSP16_Q(-0.04515427),
  DSP16_Q(0.02310829),
  DSP16_Q(-0.01482144),
  DSP16_Q(0.01033011),
  DSP16_Q(-0.00744664),
  DSP16_Q(0.00541603),
  DSP16_Q(-0.00391010),
  DSP16_Q(0.00276388),
  DSP16_Q(-0.00188506),
  DSP16_Q(0.00121715),
  DSP16_Q(-0.00072248),
  DSP16_Q(0.00037366),
  DSP16_Q(-0.00014904),
  DSP16_Q(0.00003022),
  DSP16_Q(0.00000067),
  DSP16_Q(-0.00005303),
  DSP16_Q(0.00020039),
  DSP16_Q(-0.00045998),
  DSP16_Q(0.00085119),
  DSP16_Q(-0.00139726),
  DSP16_Q(0.00212820),
  DSP16_Q(-0.00308627),
  DSP16_Q(0.00433624),
  DSP16_Q(-0.00598642),
  DSP16_Q(0.00823547),
  DSP16_Q(-0.01149188),
  DSP16_Q(0.01674316),
  DSP16_Q(-0.02711075),
  DSP16_Q(0.06015918),
  DSP16_Q(0.39653542),
  DSP16_Q(-0.04579952),
  DSP16_Q(0.02345934),
  DSP16_Q(-0.01505091),
  DSP16_Q(0.01049128),
  DSP16_Q(-0.00756315),
  DSP16_Q(0.00550077),
  DSP16_Q(-0.00397115),
  DSP16_Q(0.00280685),
  DSP16_Q(-0.00191417),
  DSP16_Q(0.00123576),
  DSP16_Q(-0.00073336),
  DSP16_Q(0.00037913),
  DSP16_Q(-0.00015109),
  DSP16_Q(0.00003055),
  DSP16_Q(0.00000071),
  DSP16_Q(-0.00005410),
  DSP16_Q(0.00020407),
  DSP16_Q(-0.00046811),
  DSP16_Q(0.00086594),
  DSP16_Q(-0.00142117),
  DSP16_Q(0.00216432),
  DSP16_Q(-0.00313837),
  DSP16_Q(0.00440920),
  DSP16_Q(-0.00608700),
  DSP16_Q(0.00837392),
  DSP16_Q(-0.01168575),
  DSP16_Q(0.01702815),
  DSP16_Q(-0.02758243),
  DSP16_Q(0.06128865),
  DSP16_Q(0.39613248),
  DSP16_Q(-0.04643979),
  DSP16_Q(0.02380838),
  DSP16_Q(-0.01527920),
  DSP16_Q(0.01065166),
  DSP16_Q(-0.00767910),
  DSP16_Q(0.00558510),
  DSP16_Q(-0.00403190),
  DSP16_Q(0.00284961),
  DSP16_Q(-0.00194314),
  DSP16_Q(0.00125427),
  DSP16_Q(-0.00074416),
  DSP16_Q(0.00038456),
  DSP16_Q(-0.00015312),
  DSP16_Q(0.00003088),
  DSP16_Q(0.00000074),
  DSP16_Q(-0.00005518),
  DSP16_Q(0.00020776),
  DSP16_Q(-0.00047624),
  DSP16_Q(0.00088068),
  DSP16_Q(-0.00144505),
  DSP16_Q(0.00220040),
  DSP16_Q(-0.00319039),
  DSP16_Q(0.00448204),
  DSP16_Q(-0.00618741),
  DSP16_Q(0.00851213),
  DSP16_Q(-0.01187933),
  DSP16_Q(0.01731279),
  DSP16_Q(-0.02805394),
  DSP16_Q(0.06242101),
  DSP16_Q(0.39572297),
  DSP16_Q(-0.04707506),
  DSP16_Q(0.02415539),
  DSP16_Q(-0.01550631),
  DSP16_Q(0.01081125),
  DSP16_Q(-0.00779449),
  DSP16_Q(0.00566902),
  DSP16_Q(-0.00409235),
  DSP16_Q(0.00289215),
  DSP16_Q(-0.00197195),
  DSP16_Q(0.00127267),
  DSP16_Q(-0.00075490),
  DSP16_Q(0.00038994),
  DSP16_Q(-0.00015514),
  DSP16_Q(0.00003119),
  DSP16_Q(0.00000078),
  DSP16_Q(-0.00005627),
  DSP16_Q(0.00021145),
  DSP16_Q(-0.00048438),
  DSP16_Q(0.00089540),
  DSP16_Q(-0.00146891),
  DSP16_Q(0.00223642),
  DSP16_Q(-0.00324233),
  DSP16_Q(0.00455476),
  DSP16_Q(-0.00628764),
  DSP16_Q(0.00865012),
  DSP16_Q(-0.01207261),
  DSP16_Q(0.01759709),
  DSP16_Q(-0.02852525),
  DSP16_Q(0.06355624),
  DSP16_Q(0.39530689),
  DSP16_Q(-0.04770533),
  DSP16_Q(0.02450036),
  DSP16_Q(-0.01573223),
  DSP16_Q(0.01097004),
  DSP16_Q(-0.00790932),
  DSP16_Q(0.00575253),
  DSP16_Q(-0.00415250),
  DSP16_Q(0.00293447),
  DSP16_Q(-0.00200060),
  DSP16_Q(0.00129097),
  DSP16_Q(-0.00076557),
  DSP16_Q(0.00039529),
  DSP16_Q(-0.00015713),
  DSP16_Q(0.00003151),
  DSP16_Q(0.00000082),
  DSP16_Q(-0.00005736),
  DSP16_Q(0.00021514),
  DSP16_Q(-0.00049251),
  DSP16_Q(0.00091012),
  DSP16_Q(-0.00149274),
  DSP16_Q(0.00227239),
  DSP16_Q(-0.00329419),
  DSP16_Q(0.00462736),
  DSP16_Q(-0.00638770),
  DSP16_Q(0.00878786),
  DSP16_Q(-0.01226557),
  DSP16_Q(0.01788102),
  DSP16_Q(-0.02899633),
  DSP16_Q(0.06469431),
  DSP16_Q(0.39488425),
  DSP16_Q(-0.04833059),
  DSP16_Q(0.02484327),
  DSP16_Q(-0.01595694),
  DSP16_Q(0.01112803),
  DSP16_Q(-0.00802357),
  DSP16_Q(0.00583562),
  DSP16_Q(-0.00421234),
  DSP16_Q(0.00297657),
  DSP16_Q(-0.00202910),
  DSP16_Q(0.00130916),
  DSP16_Q(-0.00077617),
  DSP16_Q(0.00040060),
  DSP16_Q(-0.00015911),
  DSP16_Q(0.00003181),
  DSP16_Q(0.00000086),
  DSP16_Q(-0.00005846),
  DSP16_Q(0.00021884),
  DSP16_Q(-0.00050064),
  DSP16_Q(0.00092483),
  DSP16_Q(-0.00151654),
  DSP16_Q(0.00230831),
  DSP16_Q(-0.00334596),
  DSP16_Q(0.00469982),
  DSP16_Q(-0.00648758),
  DSP16_Q(0.00892535),
  DSP16_Q(-0.01245822),
  DSP16_Q(0.01816457),
  DSP16_Q(-0.02946718),
  DSP16_Q(0.06583519),
  DSP16_Q(0.39445508),
  DSP16_Q(-0.04895084),
  DSP16_Q(0.02518411),
  DSP16_Q(-0.01618044),
  DSP16_Q(0.01128521),
  DSP16_Q(-0.00813724),
  DSP16_Q(0.00591830),
  DSP16_Q(-0.00427188),
  DSP16_Q(0.00301844),
  DSP16_Q(-0.00205744),
  DSP16_Q(0.00132724),
  DSP16_Q(-0.00078670),
  DSP16_Q(0.00040587),
  DSP16_Q(-0.00016106),
  DSP16_Q(0.00003211),
  DSP16_Q(0.00000090),
  DSP16_Q(-0.00005956),
  DSP16_Q(0.00022255),
  DSP16_Q(-0.00050877),
  DSP16_Q(0.00093952),
  DSP16_Q(-0.00154031),
  DSP16_Q(0.00234417),
  DSP16_Q(-0.00339764),
  DSP16_Q(0.00477215),
  DSP16_Q(-0.00658726),
  DSP16_Q(0.00906259),
  DSP16_Q(-0.01265053),
  DSP16_Q(0.01844773),
  DSP16_Q(-0.02993775),
  DSP16_Q(0.06697886),
  DSP16_Q(0.39401939),
  DSP16_Q(-0.04956606),
  DSP16_Q(0.02552287),
  DSP16_Q(-0.01640272),
  DSP16_Q(0.01144157),
  DSP16_Q(-0.00825034),
  DSP16_Q(0.00600055),
  DSP16_Q(-0.00433110),
  DSP16_Q(0.00306010),
  DSP16_Q(-0.00208562),
  DSP16_Q(0.00134522),
  DSP16_Q(-0.00079717),
  DSP16_Q(0.00041110),
  DSP16_Q(-0.00016299),
  DSP16_Q(0.00003240),
  DSP16_Q(0.00000094),
  DSP16_Q(-0.00006066),
  DSP16_Q(0.00022625),
  DSP16_Q(-0.00051690),
  DSP16_Q(0.00095420),
  DSP16_Q(-0.00156405),
  DSP16_Q(0.00237998),
  DSP16_Q(-0.00344923),
  DSP16_Q(0.00484435),
  DSP16_Q(-0.00668676),
  DSP16_Q(0.00919956),
  DSP16_Q(-0.01284249),
  DSP16_Q(0.01873047),
  DSP16_Q(-0.03040804),
  DSP16_Q(0.06812529),
  DSP16_Q(0.39357718),
  DSP16_Q(-0.05017626),
  DSP16_Q(0.02585954),
  DSP16_Q(-0.01662377),
  DSP16_Q(0.01159710),
  DSP16_Q(-0.00836285),
  DSP16_Q(0.00608237),
  DSP16_Q(-0.00439002),
  DSP16_Q(0.00310152),
  DSP16_Q(-0.00211364),
  DSP16_Q(0.00136308),
  DSP16_Q(-0.00080756),
  DSP16_Q(0.00041629),
  DSP16_Q(-0.00016491),
  DSP16_Q(0.00003269),
  DSP16_Q(0.00000098),
  DSP16_Q(-0.00006177),
  DSP16_Q(0.00022997),
  DSP16_Q(-0.00052502),
  DSP16_Q(0.00096886),
  DSP16_Q(-0.00158775),
  DSP16_Q(0.00241572),
  DSP16_Q(-0.00350072),
  DSP16_Q(0.00491640),
  DSP16_Q(-0.00678605),
  DSP16_Q(0.00933627),
  DSP16_Q(-0.01303411),
  DSP16_Q(0.01901279),
  DSP16_Q(-0.03087801),
  DSP16_Q(0.06927444),
  DSP16_Q(0.39312848),
  DSP16_Q(-0.05078143),
  DSP16_Q(0.02619411),
  DSP16_Q(-0.01684358),
  DSP16_Q(0.01175181),
  DSP16_Q(-0.00847476),
  DSP16_Q(0.00616377),
  DSP16_Q(-0.00444862),
  DSP16_Q(0.00314272),
  DSP16_Q(-0.00214150),
  DSP16_Q(0.00138084),
  DSP16_Q(-0.00081788),
  DSP16_Q(0.00042143),
  DSP16_Q(-0.00016680),
  DSP16_Q(0.00003297),
  DSP16_Q(0.00000103),
  DSP16_Q(-0.00006288),
  DSP16_Q(0.00023368),
  DSP16_Q(-0.00053315),
  DSP16_Q(0.00098351),
  DSP16_Q(-0.00161142),
  DSP16_Q(0.00245141),
  DSP16_Q(-0.00355212),
  DSP16_Q(0.00498831),
  DSP16_Q(-0.00688514),
  DSP16_Q(0.00947269),
  DSP16_Q(-0.01322536),
  DSP16_Q(0.01929467),
  DSP16_Q(-0.03134764),
  DSP16_Q(0.07042630),
  DSP16_Q(0.39267329),
  DSP16_Q(-0.05138156),
  DSP16_Q(0.02652656),
  DSP16_Q(-0.01706214),
  DSP16_Q(0.01190567),
  DSP16_Q(-0.00858609),
  DSP16_Q(0.00624473),
  DSP16_Q(-0.00450690),
  DSP16_Q(0.00318369),
  DSP16_Q(-0.00216920),
  DSP16_Q(0.00139848),
  DSP16_Q(-0.00082813),
  DSP16_Q(0.00042654),
  DSP16_Q(-0.00016868),
  DSP16_Q(0.00003324),
  DSP16_Q(0.00000107),
  DSP16_Q(-0.00006400),
  DSP16_Q(0.00023740),
  DSP16_Q(-0.00054126),
  DSP16_Q(0.00099814),
  DSP16_Q(-0.00163506),
  DSP16_Q(0.00248703),
  DSP16_Q(-0.00360341),
  DSP16_Q(0.00506006),
  DSP16_Q(-0.00698401),
  DSP16_Q(0.00960883),
  DSP16_Q(-0.01341623),
  DSP16_Q(0.01957609),
  DSP16_Q(-0.03181691),
  DSP16_Q(0.07158084),
  DSP16_Q(0.39221163),
  DSP16_Q(-0.05197664),
  DSP16_Q(0.02685689),
  DSP16_Q(-0.01727945),
  DSP16_Q(0.01205869),
  DSP16_Q(-0.00869681),
  DSP16_Q(0.00632525),
  DSP16_Q(-0.00456486),
  DSP16_Q(0.00322443),
  DSP16_Q(-0.00219673),
  DSP16_Q(0.00141602),
  DSP16_Q(-0.00083831),
  DSP16_Q(0.00043160),
  DSP16_Q(-0.00017053),
  DSP16_Q(0.00003351),
  DSP16_Q(0.00000112),
  DSP16_Q(-0.00006512),
  DSP16_Q(0.00024112),
  DSP16_Q(-0.00054938),
  DSP16_Q(0.00101276),
  DSP16_Q(-0.00165866),
  DSP16_Q(0.00252258),
  DSP16_Q(-0.00365460),
  DSP16_Q(0.00513167),
  DSP16_Q(-0.00708268),
  DSP16_Q(0.00974468),
  DSP16_Q(-0.01360673),
  DSP16_Q(0.01985704),
  DSP16_Q(-0.03228579),
  DSP16_Q(0.07273802),
  DSP16_Q(0.39174351),
  DSP16_Q(-0.05256668),
  DSP16_Q(0.02718508),
  DSP16_Q(-0.01749549),
  DSP16_Q(0.01221086),
  DSP16_Q(-0.00880692),
  DSP16_Q(0.00640533),
  DSP16_Q(-0.00462250),
  DSP16_Q(0.00326493),
  DSP16_Q(-0.00222410),
  DSP16_Q(0.00143344),
  DSP16_Q(-0.00084842),
  DSP16_Q(0.00043663),
  DSP16_Q(-0.00017237),
  DSP16_Q(0.00003377),
  DSP16_Q(0.00000116),
  DSP16_Q(-0.00006625),
  DSP16_Q(0.00024484),
  DSP16_Q(-0.00055749),
  DSP16_Q(0.00102736),
  DSP16_Q(-0.00168222),
  DSP16_Q(0.00255807),
  DSP16_Q(-0.00370569),
  DSP16_Q(0.00520312),
  DSP16_Q(-0.00718112),
  DSP16_Q(0.00988023),
  DSP16_Q(-0.01379682),
  DSP16_Q(0.02013751),
  DSP16_Q(-0.03275427),
  DSP16_Q(0.07389782),
  DSP16_Q(0.39126895),
  DSP16_Q(-0.05315166),
  DSP16_Q(0.02751112),
  DSP16_Q(-0.01771025),
  DSP16_Q(0.01236218),
  DSP16_Q(-0.00891643),
  DSP16_Q(0.00648497),
  DSP16_Q(-0.00467981),
  DSP16_Q(0.00330520),
  DSP16_Q(-0.00225131),
  DSP16_Q(0.00145075),
  DSP16_Q(-0.00085846),
  DSP16_Q(0.00044161),
  DSP16_Q(-0.00017418),
  DSP16_Q(0.00003403),
  DSP16_Q(0.00000121),
  DSP16_Q(-0.00006738),
  DSP16_Q(0.00024857),
  DSP16_Q(-0.00056560),
  DSP16_Q(0.00104194),
  DSP16_Q(-0.00170574),
  DSP16_Q(0.00259349),
  DSP16_Q(-0.00375666),
  DSP16_Q(0.00527440),
  DSP16_Q(-0.00727933),
  DSP16_Q(0.01001546),
  DSP16_Q(-0.01398651),
  DSP16_Q(0.02041747),
  DSP16_Q(-0.03322231),
  DSP16_Q(0.07506021),
  DSP16_Q(0.39078797),
  DSP16_Q(-0.05373157),
  DSP16_Q(0.02783501),
  DSP16_Q(-0.01792373),
  DSP16_Q(0.01251262),
  DSP16_Q(-0.00902532),
  DSP16_Q(0.00656416),
  DSP16_Q(-0.00473680),
  DSP16_Q(0.00334523),
  DSP16_Q(-0.00227834),
  DSP16_Q(0.00146794),
  DSP16_Q(-0.00086843),
  DSP16_Q(0.00044655),
  DSP16_Q(-0.00017598),
  DSP16_Q(0.00003428),
  DSP16_Q(0.00000126),
  DSP16_Q(-0.00006851),
  DSP16_Q(0.00025230),
  DSP16_Q(-0.00057370),
  DSP16_Q(0.00105650),
  DSP16_Q(-0.00172922),
  DSP16_Q(0.00262883),
  DSP16_Q(-0.00380752),
  DSP16_Q(0.00534552),
  DSP16_Q(-0.00737731),
  DSP16_Q(0.01015039),
  DSP16_Q(-0.01417579),
  DSP16_Q(0.02069692),
  DSP16_Q(-0.03368990),
  DSP16_Q(0.07622516),
  DSP16_Q(0.39030057),
  DSP16_Q(-0.05430643),
  DSP16_Q(0.02815672),
  DSP16_Q(-0.01813593),
  DSP16_Q(0.01266220),
  DSP16_Q(-0.00913359),
  DSP16_Q(0.00664289),
  DSP16_Q(-0.00479346),
  DSP16_Q(0.00338502),
  DSP16_Q(-0.00230521),
  DSP16_Q(0.00148503),
  DSP16_Q(-0.00087832),
  DSP16_Q(0.00045145),
  DSP16_Q(-0.00017775),
  DSP16_Q(0.00003452),
  DSP16_Q(0.00000132),
  DSP16_Q(-0.00006965),
  DSP16_Q(0.00025603),
  DSP16_Q(-0.00058180),
  DSP16_Q(0.00107104),
  DSP16_Q(-0.00175265),
  DSP16_Q(0.00266410),
  DSP16_Q(-0.00385827),
  DSP16_Q(0.00541647),
  DSP16_Q(-0.00747506),
  DSP16_Q(0.01028499),
  DSP16_Q(-0.01436464),
  DSP16_Q(0.02097584),
  DSP16_Q(-0.03415700),
  DSP16_Q(0.07739264),
  DSP16_Q(0.38980678),
  DSP16_Q(-0.05487621),
  DSP16_Q(0.02847625),
  DSP16_Q(-0.01834682),
  DSP16_Q(0.01281090),
  DSP16_Q(-0.00924123),
  DSP16_Q(0.00672118),
  DSP16_Q(-0.00484978),
  DSP16_Q(0.00342458),
  DSP16_Q(-0.00233191),
  DSP16_Q(0.00150199),
  DSP16_Q(-0.00088814),
  DSP16_Q(0.00045631),
  DSP16_Q(-0.00017951),
  DSP16_Q(0.00003476),
  DSP16_Q(0.00000137),
  DSP16_Q(-0.00007079),
  DSP16_Q(0.00025976),
  DSP16_Q(-0.00058989),
  DSP16_Q(0.00108556),
  DSP16_Q(-0.00177605),
  DSP16_Q(0.00269930),
  DSP16_Q(-0.00390890),
  DSP16_Q(0.00548725),
  DSP16_Q(-0.00757256),
  DSP16_Q(0.01041926),
  DSP16_Q(-0.01455306),
  DSP16_Q(0.02125422),
  DSP16_Q(-0.03462360),
  DSP16_Q(0.07856262),
  DSP16_Q(0.38930660),
  DSP16_Q(-0.05544092),
  DSP16_Q(0.02879359),
  DSP16_Q(-0.01855640),
  DSP16_Q(0.01295872),
  DSP16_Q(-0.00934825),
  DSP16_Q(0.00679900),
  DSP16_Q(-0.00490577),
  DSP16_Q(0.00346389),
  DSP16_Q(-0.00235844),
  DSP16_Q(0.00151885),
  DSP16_Q(-0.00089789),
  DSP16_Q(0.00046112),
  DSP16_Q(-0.00018124),
  DSP16_Q(0.00003499),
  DSP16_Q(0.00000142),
  DSP16_Q(-0.00007194),
  DSP16_Q(0.00026349),
  DSP16_Q(-0.00059797),
  DSP16_Q(0.00110006),
  DSP16_Q(-0.00179939),
  DSP16_Q(0.00273442),
  DSP16_Q(-0.00395941),
  DSP16_Q(0.00555786),
  DSP16_Q(-0.00766982),
  DSP16_Q(0.01055319),
  DSP16_Q(-0.01474103),
  DSP16_Q(0.02153203),
  DSP16_Q(-0.03508967),
  DSP16_Q(0.07973508),
  DSP16_Q(0.38880005),
  DSP16_Q(-0.05600054),
  DSP16_Q(0.02910872),
  DSP16_Q(-0.01876467),
  DSP16_Q(0.01310565),
  DSP16_Q(-0.00945463),
  DSP16_Q(0.00687636),
  DSP16_Q(-0.00496142),
  DSP16_Q(0.00350296),
  DSP16_Q(-0.00238480),
  DSP16_Q(0.00153558),
  DSP16_Q(-0.00090756),
  DSP16_Q(0.00046589),
  DSP16_Q(-0.00018296),
  DSP16_Q(0.00003521),
  DSP16_Q(0.00000148),
  DSP16_Q(-0.00007309),
  DSP16_Q(0.00026723),
  DSP16_Q(-0.00060605),
  DSP16_Q(0.00111453),
  DSP16_Q(-0.00182270),
  DSP16_Q(0.00276946),
  DSP16_Q(-0.00400979),
  DSP16_Q(0.00562828),
  DSP16_Q(-0.00776682),
  DSP16_Q(0.01068678),
  DSP16_Q(-0.01492854),
  DSP16_Q(0.02180927),
  DSP16_Q(-0.03555519),
  DSP16_Q(0.08090999),
  DSP16_Q(0.38828716),
  DSP16_Q(-0.05655509),
  DSP16_Q(0.02942165),
  DSP16_Q(-0.01897161),
  DSP16_Q(0.01325169),
  DSP16_Q(-0.00956038),
  DSP16_Q(0.00695326),
  DSP16_Q(-0.00501674),
  DSP16_Q(0.00354178),
  DSP16_Q(-0.00241098),
  DSP16_Q(0.00155220),
  DSP16_Q(-0.00091716),
  DSP16_Q(0.00047062),
  DSP16_Q(-0.00018465),
  DSP16_Q(0.00003543),
  DSP16_Q(0.00000154),
  DSP16_Q(-0.00007424),
  DSP16_Q(0.00027096),
  DSP16_Q(-0.00061411),
  DSP16_Q(0.00112898),
  DSP16_Q(-0.00184595),
  DSP16_Q(0.00280442),
  DSP16_Q(-0.00406005),
  DSP16_Q(0.00569852),
  DSP16_Q(-0.00786356),
  DSP16_Q(0.01082002),
  DSP16_Q(-0.01511559),
  DSP16_Q(0.02208592),
  DSP16_Q(-0.03602014),
  DSP16_Q(0.08208731),
  DSP16_Q(0.38776793),
  DSP16_Q(-0.05710454),
  DSP16_Q(0.02973235),
  DSP16_Q(-0.01917722),
  DSP16_Q(0.01339682),
  DSP16_Q(-0.00966548),
  DSP16_Q(0.00702969),
  DSP16_Q(-0.00507171),
  DSP16_Q(0.00358036),
  DSP16_Q(-0.00243699),
  DSP16_Q(0.00156871),
  DSP16_Q(-0.00092669),
  DSP16_Q(0.00047531),
  DSP16_Q(-0.00018633),
  DSP16_Q(0.00003565),
  DSP16_Q(0.00000160),
  DSP16_Q(-0.00007540),
  DSP16_Q(0.00027470),
  DSP16_Q(-0.00062217),
  DSP16_Q(0.00114341),
  DSP16_Q(-0.00186916),
  DSP16_Q(0.00283930),
  DSP16_Q(-0.00411018),
  DSP16_Q(0.00576857),
  DSP16_Q(-0.00796004),
  DSP16_Q(0.01095290),
  DSP16_Q(-0.01530216),
  DSP16_Q(0.02236196),
  DSP16_Q(-0.03648448),
  DSP16_Q(0.08326702),
  DSP16_Q(0.38724238),
  DSP16_Q(-0.05764891),
  DSP16_Q(0.03004082),
  DSP16_Q(-0.01938149),
  DSP16_Q(0.01354105),
  DSP16_Q(-0.00976994),
  DSP16_Q(0.00710565),
  DSP16_Q(-0.00512634),
  DSP16_Q(0.00361868),
  DSP16_Q(-0.00246283),
  DSP16_Q(0.00158509),
  DSP16_Q(-0.00093614),
  DSP16_Q(0.00047996),
  DSP16_Q(-0.00018798),
  DSP16_Q(0.00003585),
  DSP16_Q(0.00000166),
  DSP16_Q(-0.00007656),
  DSP16_Q(0.00027844),
  DSP16_Q(-0.00063023),
  DSP16_Q(0.00115782),
  DSP16_Q(-0.00189231),
  DSP16_Q(0.00287409),
  DSP16_Q(-0.00416018),
  DSP16_Q(0.00583842),
  DSP16_Q(-0.00805625),
  DSP16_Q(0.01108541),
  DSP16_Q(-0.01548825),
  DSP16_Q(0.02263738),
  DSP16_Q(-0.03694820),
  DSP16_Q(0.08444909),
  DSP16_Q(0.38671052),
  DSP16_Q(-0.05818818),
  DSP16_Q(0.03034704),
  DSP16_Q(-0.01958441),
  DSP16_Q(0.01368436),
  DSP16_Q(-0.00987374),
  DSP16_Q(0.00718113),
  DSP16_Q(-0.00518062),
  DSP16_Q(0.00365676),
  DSP16_Q(-0.00248849),
  DSP16_Q(0.00160136),
  DSP16_Q(-0.00094552),
  DSP16_Q(0.00048456),
  DSP16_Q(-0.00018962),
  DSP16_Q(0.00003606),
  DSP16_Q(0.00000172),
  DSP16_Q(-0.00007773),
  DSP16_Q(0.00028218),
  DSP16_Q(-0.00063827),
  DSP16_Q(0.00117219),
  DSP16_Q(-0.00191542),
  DSP16_Q(0.00290879),
  DSP16_Q(-0.00421004),
  DSP16_Q(0.00590808),
  DSP16_Q(-0.00815219),
  DSP16_Q(0.01121755),
  DSP16_Q(-0.01567383),
  DSP16_Q(0.02291217),
  DSP16_Q(-0.03741127),
  DSP16_Q(0.08563349),
  DSP16_Q(0.38617238),
  DSP16_Q(-0.05872235),
  DSP16_Q(0.03065102),
  DSP16_Q(-0.01978598),
  DSP16_Q(0.01382676),
  DSP16_Q(-0.00997689),
  DSP16_Q(0.00725614),
  DSP16_Q(-0.00523455),
  DSP16_Q(0.00369459),
  DSP16_Q(-0.00251397),
  DSP16_Q(0.00161751),
  DSP16_Q(-0.00095482),
  DSP16_Q(0.00048912),
  DSP16_Q(-0.00019123),
  DSP16_Q(0.00003625),
  DSP16_Q(0.00000178),
  DSP16_Q(-0.00007890),
  DSP16_Q(0.00028592),
  DSP16_Q(-0.00064630),
  DSP16_Q(0.00118654),
  DSP16_Q(-0.00193847),
  DSP16_Q(0.00294340),
  DSP16_Q(-0.00425977),
  DSP16_Q(0.00597754),
  DSP16_Q(-0.00824784),
  DSP16_Q(0.01134931),
  DSP16_Q(-0.01585891),
  DSP16_Q(0.02318631),
  DSP16_Q(-0.03787367),
  DSP16_Q(0.08682018),
  DSP16_Q(0.38562797),
  DSP16_Q(-0.05925142),
  DSP16_Q(0.03095272),
  DSP16_Q(-0.01998618),
  DSP16_Q(0.01396823),
  DSP16_Q(-0.01007938),
  DSP16_Q(0.00733066),
  DSP16_Q(-0.00528813),
  DSP16_Q(0.00373216),
  DSP16_Q(-0.00253928),
  DSP16_Q(0.00163354),
  DSP16_Q(-0.00096405),
  DSP16_Q(0.00049364),
  DSP16_Q(-0.00019283),
  DSP16_Q(0.00003644),
  DSP16_Q(0.00000184),
  DSP16_Q(-0.00008007),
  DSP16_Q(0.00028966),
  DSP16_Q(-0.00065433),
  DSP16_Q(0.00120087),
  DSP16_Q(-0.00196146),
  DSP16_Q(0.00297793),
  DSP16_Q(-0.00430935),
  DSP16_Q(0.00604680),
  DSP16_Q(-0.00834321),
  DSP16_Q(0.01148068),
  DSP16_Q(-0.01604347),
  DSP16_Q(0.02345978),
  DSP16_Q(-0.03833537),
  DSP16_Q(0.08800915),
  DSP16_Q(0.38507730),
  DSP16_Q(-0.05977538),
  DSP16_Q(0.03125216),
  DSP16_Q(-0.02018501),
  DSP16_Q(0.01410877),
  DSP16_Q(-0.01018120),
  DSP16_Q(0.00740470),
  DSP16_Q(-0.00534136),
  DSP16_Q(0.00376948),
  DSP16_Q(-0.00256441),
  DSP16_Q(0.00164945),
  DSP16_Q(-0.00097320),
  DSP16_Q(0.00049812),
  DSP16_Q(-0.00019440),
  DSP16_Q(0.00003663),
  DSP16_Q(0.00000191),
  DSP16_Q(-0.00008124),
  DSP16_Q(0.00029339),
  DSP16_Q(-0.00066234),
  DSP16_Q(0.00121516),
  DSP16_Q(-0.00198441),
  DSP16_Q(0.00301235),
  DSP16_Q(-0.00435879),
  DSP16_Q(0.00611585),
  DSP16_Q(-0.00843829),
  DSP16_Q(0.01161165),
  DSP16_Q(-0.01622751),
  DSP16_Q(0.02373257),
  DSP16_Q(-0.03879635),
  DSP16_Q(0.08920035),
  DSP16_Q(0.38452040),
  DSP16_Q(-0.06029424),
  DSP16_Q(0.03154932),
  DSP16_Q(-0.02038245),
  DSP16_Q(0.01424837),
  DSP16_Q(-0.01028236),
  DSP16_Q(0.00747826),
  DSP16_Q(-0.00539423),
  DSP16_Q(0.00380655),
  DSP16_Q(-0.00258936),
  DSP16_Q(0.00166524),
  DSP16_Q(-0.00098227),
  DSP16_Q(0.00050255),
  DSP16_Q(-0.00019596),
  DSP16_Q(0.00003681),
  DSP16_Q(0.00000198),
  DSP16_Q(-0.00008242),
  DSP16_Q(0.00029713),
  DSP16_Q(-0.00067034),
  DSP16_Q(0.00122943),
  DSP16_Q(-0.00200729),
  DSP16_Q(0.00304669),
  DSP16_Q(-0.00440809),
  DSP16_Q(0.00618469),
  DSP16_Q(-0.00853308),
  DSP16_Q(0.01174222),
  DSP16_Q(-0.01641101),
  DSP16_Q(0.02400467),
  DSP16_Q(-0.03925659),
  DSP16_Q(0.09039376),
  DSP16_Q(0.38395728),
  DSP16_Q(-0.06080798),
  DSP16_Q(0.03184418),
  DSP16_Q(-0.02057852),
  DSP16_Q(0.01438704),
  DSP16_Q(-0.01038284),
  DSP16_Q(0.00755132),
  DSP16_Q(-0.00544675),
  DSP16_Q(0.00384335),
  DSP16_Q(-0.00261413),
  DSP16_Q(0.00168090),
  DSP16_Q(-0.00099127),
  DSP16_Q(0.00050694),
  DSP16_Q(-0.00019749),
  DSP16_Q(0.00003698),
  DSP16_Q(0.00000205),
  DSP16_Q(-0.00008360),
  DSP16_Q(0.00030087),
  DSP16_Q(-0.00067833),
  DSP16_Q(0.00124366),
  DSP16_Q(-0.00203012),
  DSP16_Q(0.00308093),
  DSP16_Q(-0.00445724),
  DSP16_Q(0.00625331),
  DSP16_Q(-0.00862756),
  DSP16_Q(0.01187238),
  DSP16_Q(-0.01659395),
  DSP16_Q(0.02427605),
  DSP16_Q(-0.03971605),
  DSP16_Q(0.09158935),
  DSP16_Q(0.38338795),
  DSP16_Q(-0.06131661),
  DSP16_Q(0.03213674),
  DSP16_Q(-0.02077319),
  DSP16_Q(0.01452475),
  DSP16_Q(-0.01048265),
  DSP16_Q(0.00762389),
  DSP16_Q(-0.00549890),
  DSP16_Q(0.00387990),
  DSP16_Q(-0.00263872),
  DSP16_Q(0.00169645),
  DSP16_Q(-0.00100019),
  DSP16_Q(0.00051128),
  DSP16_Q(-0.00019901),
  DSP16_Q(0.00003715),
  DSP16_Q(0.00000212),
  DSP16_Q(-0.00008479),
  DSP16_Q(0.00030461),
  DSP16_Q(-0.00068631),
  DSP16_Q(0.00125786),
  DSP16_Q(-0.00205288),
  DSP16_Q(0.00311506),
  DSP16_Q(-0.00450623),
  DSP16_Q(0.00632171),
  DSP16_Q(-0.00872173),
  DSP16_Q(0.01200213),
  DSP16_Q(-0.01677634),
  DSP16_Q(0.02454671),
  DSP16_Q(-0.04017473),
  DSP16_Q(0.09278710),
  DSP16_Q(0.38281244),
  DSP16_Q(-0.06182013),
  DSP16_Q(0.03242700),
  DSP16_Q(-0.02096645),
  DSP16_Q(0.01466151),
  DSP16_Q(-0.01058177),
  DSP16_Q(0.00769597),
  DSP16_Q(-0.00555069),
  DSP16_Q(0.00391619),
  DSP16_Q(-0.00266312),
  DSP16_Q(0.00171187),
  DSP16_Q(-0.00100904),
  DSP16_Q(0.00051558),
  DSP16_Q(-0.00020050),
  DSP16_Q(0.00003731),
  DSP16_Q(0.00000219),
  DSP16_Q(-0.00008598),
  DSP16_Q(0.00030834),
  DSP16_Q(-0.00069428),
  DSP16_Q(0.00127204),
  DSP16_Q(-0.00207559),
  DSP16_Q(0.00314910),
  DSP16_Q(-0.00455507),
  DSP16_Q(0.00638989),
  DSP16_Q(-0.00881560),
  DSP16_Q(0.01213144),
  DSP16_Q(-0.01695817),
  DSP16_Q(0.02481663),
  DSP16_Q(-0.04063258),
  DSP16_Q(0.09398696),
  DSP16_Q(0.38223076),
  DSP16_Q(-0.06231853),
  DSP16_Q(0.03271493),
  DSP16_Q(-0.02115831),
  DSP16_Q(0.01479732),
  DSP16_Q(-0.01068021),
  DSP16_Q(0.00776754),
  DSP16_Q(-0.00560212),
  DSP16_Q(0.00395221),
  DSP16_Q(-0.00268734),
  DSP16_Q(0.00172717),
  DSP16_Q(-0.00101781),
  DSP16_Q(0.00051984),
  DSP16_Q(-0.00020197),
  DSP16_Q(0.00003746),
  DSP16_Q(0.00000226),
  DSP16_Q(-0.00008717),
  DSP16_Q(0.00031208),
  DSP16_Q(-0.00070223),
  DSP16_Q(0.00128618),
  DSP16_Q(-0.00209823),
  DSP16_Q(0.00318304),
  DSP16_Q(-0.00460376),
  DSP16_Q(0.00645784),
  DSP16_Q(-0.00890915),
  DSP16_Q(0.01226033),
  DSP16_Q(-0.01713941),
  DSP16_Q(0.02508580),
  DSP16_Q(-0.04108960),
  DSP16_Q(0.09518891),
  DSP16_Q(0.38164294),
  DSP16_Q(-0.06281181),
  DSP16_Q(0.03300054),
  DSP16_Q(-0.02134875),
  DSP16_Q(0.01493216),
  DSP16_Q(-0.01077796),
  DSP16_Q(0.00783861),
  DSP16_Q(-0.00565319),
  DSP16_Q(0.00398798),
  DSP16_Q(-0.00271138),
  DSP16_Q(0.00174235),
  DSP16_Q(-0.00102650),
  DSP16_Q(0.00052406),
  DSP16_Q(-0.00020343),
  DSP16_Q(0.00003762),
  DSP16_Q(0.00000234),
  DSP16_Q(-0.00008836),
  DSP16_Q(0.00031581),
  DSP16_Q(-0.00071017),
  DSP16_Q(0.00130028),
  DSP16_Q(-0.00212081),
  DSP16_Q(0.00321686),
  DSP16_Q(-0.00465228),
  DSP16_Q(0.00652556),
  DSP16_Q(-0.00900237),
  DSP16_Q(0.01238878),
  DSP16_Q(-0.01732006),
  DSP16_Q(0.02535419),
  DSP16_Q(-0.04154574),
  DSP16_Q(0.09639291),
  DSP16_Q(0.38104898),
  DSP16_Q(-0.06329996),
  DSP16_Q(0.03328381),
  DSP16_Q(-0.02153777),
  DSP16_Q(0.01506603),
  DSP16_Q(-0.01087502),
  DSP16_Q(0.00790918),
  DSP16_Q(-0.00570388),
  DSP16_Q(0.00402347),
  DSP16_Q(-0.00273523),
  DSP16_Q(0.00175740),
  DSP16_Q(-0.00103511),
  DSP16_Q(0.00052823),
  DSP16_Q(-0.00020486),
  DSP16_Q(0.00003776),
  DSP16_Q(0.00000241),
  DSP16_Q(-0.00008956),
  DSP16_Q(0.00031954),
  DSP16_Q(-0.00071810),
  DSP16_Q(0.00131435),
  DSP16_Q(-0.00214333),
  DSP16_Q(0.00325059),
  DSP16_Q(-0.00470064),
  DSP16_Q(0.00659305),
  DSP16_Q(-0.00909527),
  DSP16_Q(0.01251678),
  DSP16_Q(-0.01750012),
  DSP16_Q(0.02562180),
  DSP16_Q(-0.04200100),
  DSP16_Q(0.09759895),
  DSP16_Q(0.38044891),
  DSP16_Q(-0.06378300),
  DSP16_Q(0.03356474),
  DSP16_Q(-0.02172536),
  DSP16_Q(0.01519892),
  DSP16_Q(-0.01097138),
  DSP16_Q(0.00797924),
  DSP16_Q(-0.00575421),
  DSP16_Q(0.00405870),
  DSP16_Q(-0.00275890),
  DSP16_Q(0.00177233),
  DSP16_Q(-0.00104364),
  DSP16_Q(0.00053236),
  DSP16_Q(-0.00020627),
  DSP16_Q(0.00003790),
  DSP16_Q(0.00000249),
  DSP16_Q(-0.00009076),
  DSP16_Q(0.00032327),
  DSP16_Q(-0.00072601),
  DSP16_Q(0.00132839),
  DSP16_Q(-0.00216578),
  DSP16_Q(0.00328420),
  DSP16_Q(-0.00474884),
  DSP16_Q(0.00666030),
  DSP16_Q(-0.00918784),
  DSP16_Q(0.01264433),
  DSP16_Q(-0.01767957),
  DSP16_Q(0.02588861),
  DSP16_Q(-0.04245534),
  DSP16_Q(0.09880698),
  DSP16_Q(0.37984274),
  DSP16_Q(-0.06426091),
  DSP16_Q(0.03384331),
  DSP16_Q(-0.02191151),
  DSP16_Q(0.01533084),
  DSP16_Q(-0.01106704),
  DSP16_Q(0.00804879),
  DSP16_Q(-0.00580416),
  DSP16_Q(0.00409367),
  DSP16_Q(-0.00278237),
  DSP16_Q(0.00178713),
  DSP16_Q(-0.00105210),
  DSP16_Q(0.00053644),
  DSP16_Q(-0.00020767),
  DSP16_Q(0.00003803),
  DSP16_Q(0.00000257),
  DSP16_Q(-0.00009197),
  DSP16_Q(0.00032700),
  DSP16_Q(-0.00073391),
  DSP16_Q(0.00134239),
  DSP16_Q(-0.00218816),
  DSP16_Q(0.00331770),
  DSP16_Q(-0.00479687),
  DSP16_Q(0.00672730),
  DSP16_Q(-0.00928006),
  DSP16_Q(0.01277141),
  DSP16_Q(-0.01785840),
  DSP16_Q(0.02615461),
  DSP16_Q(-0.04290875),
  DSP16_Q(0.10001698),
  DSP16_Q(0.37923050),
  DSP16_Q(-0.06473369),
  DSP16_Q(0.03411952),
  DSP16_Q(-0.02209621),
  DSP16_Q(0.01546177),
  DSP16_Q(-0.01116199),
  DSP16_Q(0.00811782),
  DSP16_Q(-0.00585374),
  DSP16_Q(0.00412836),
  DSP16_Q(-0.00280566),
  DSP16_Q(0.00180180),
  DSP16_Q(-0.00106048),
  DSP16_Q(0.00054048),
  DSP16_Q(-0.00020904),
  DSP16_Q(0.00003816),
  DSP16_Q(0.00000265),
  DSP16_Q(-0.00009317),
  DSP16_Q(0.00033072),
  DSP16_Q(-0.00074179),
  DSP16_Q(0.00135635),
  DSP16_Q(-0.00221047),
  DSP16_Q(0.00335109),
  DSP16_Q(-0.00484473),
  DSP16_Q(0.00679406),
  DSP16_Q(-0.00937195),
  DSP16_Q(0.01289803),
  DSP16_Q(-0.01803660),
  DSP16_Q(0.02641978),
  DSP16_Q(-0.04336119),
  DSP16_Q(0.10122891),
  DSP16_Q(0.37861219),
  DSP16_Q(-0.06520134),
  DSP16_Q(0.03439336),
  DSP16_Q(-0.02227947),
  DSP16_Q(0.01559171),
  DSP16_Q(-0.01125624),
  DSP16_Q(0.00818634),
  DSP16_Q(-0.00590294),
  DSP16_Q(0.00416278),
  DSP16_Q(-0.00282877),
  DSP16_Q(0.00181635),
  DSP16_Q(-0.00106878),
  DSP16_Q(0.00054447),
  DSP16_Q(-0.00021039),
  DSP16_Q(0.00003829),
  DSP16_Q(0.00000273),
  DSP16_Q(-0.00009438),
  DSP16_Q(0.00033444),
  DSP16_Q(-0.00074966),
  DSP16_Q(0.00137028),
  DSP16_Q(-0.00223272),
  DSP16_Q(0.00338437),
  DSP16_Q(-0.00489241),
  DSP16_Q(0.00686057),
  DSP16_Q(-0.00946348),
  DSP16_Q(0.01302418),
  DSP16_Q(-0.01821416),
  DSP16_Q(0.02668410),
  DSP16_Q(-0.04381264),
  DSP16_Q(0.10244275),
  DSP16_Q(0.37798785),
  DSP16_Q(-0.06566387),
  DSP16_Q(0.03466483),
  DSP16_Q(-0.02246127),
  DSP16_Q(0.01572066),
  DSP16_Q(-0.01134977),
  DSP16_Q(0.00825434),
  DSP16_Q(-0.00595176),
  DSP16_Q(0.00419694),
  DSP16_Q(-0.00285168),
  DSP16_Q(0.00183078),
  DSP16_Q(-0.00107700),
  DSP16_Q(0.00054843),
  DSP16_Q(-0.00021173),
  DSP16_Q(0.00003840),
  DSP16_Q(0.00000281),
  DSP16_Q(-0.00009559),
  DSP16_Q(0.00033816),
  DSP16_Q(-0.00075751),
  DSP16_Q(0.00138417),
  DSP16_Q(-0.00225489),
  DSP16_Q(0.00341753),
  DSP16_Q(-0.00493992),
  DSP16_Q(0.00692682),
  DSP16_Q(-0.00955467),
  DSP16_Q(0.01314984),
  DSP16_Q(-0.01839107),
  DSP16_Q(0.02694756),
  DSP16_Q(-0.04426308),
  DSP16_Q(0.10365846),
  DSP16_Q(0.37735749),
  DSP16_Q(-0.06612127),
  DSP16_Q(0.03493391),
  DSP16_Q(-0.02264160),
  DSP16_Q(0.01584860),
  DSP16_Q(-0.01144259),
  DSP16_Q(0.00832182),
  DSP16_Q(-0.00600020),
  DSP16_Q(0.00423082),
  DSP16_Q(-0.00287440),
  DSP16_Q(0.00184508),
  DSP16_Q(-0.00108514),
  DSP16_Q(0.00055233),
  DSP16_Q(-0.00021304),
  DSP16_Q(0.00003852),
  DSP16_Q(0.00000290),
  DSP16_Q(-0.00009680),
  DSP16_Q(0.00034187),
  DSP16_Q(-0.00076534),
  DSP16_Q(0.00139801),
  DSP16_Q(-0.00227699),
  DSP16_Q(0.00345057),
  DSP16_Q(-0.00498725),
  DSP16_Q(0.00699282),
  DSP16_Q(-0.00964549),
  DSP16_Q(0.01327501),
  DSP16_Q(-0.01856732),
  DSP16_Q(0.02721015),
  DSP16_Q(-0.04471248),
  DSP16_Q(0.10487601),
  DSP16_Q(0.37672113),
  DSP16_Q(-0.06657354),
  DSP16_Q(0.03520059),
  DSP16_Q(-0.02282046),
  DSP16_Q(0.01597554),
  DSP16_Q(-0.01153468),
  DSP16_Q(0.00838877),
  DSP16_Q(-0.00604826),
  DSP16_Q(0.00426442),
  DSP16_Q(-0.00289693),
  DSP16_Q(0.00185924),
  DSP16_Q(-0.00109320),
  DSP16_Q(0.00055620),
  DSP16_Q(-0.00021433),
  DSP16_Q(0.00003863),
  DSP16_Q(0.00000299),
  DSP16_Q(-0.00009802),
  DSP16_Q(0.00034559),
  DSP16_Q(-0.00077316),
  DSP16_Q(0.00141182),
  DSP16_Q(-0.00229901),
  DSP16_Q(0.00348349),
  DSP16_Q(-0.00503439),
  DSP16_Q(0.00705856),
  DSP16_Q(-0.00973595),
  DSP16_Q(0.01339969),
  DSP16_Q(-0.01874290),
  DSP16_Q(0.02747185),
  DSP16_Q(-0.04516082),
  DSP16_Q(0.10609538),
  DSP16_Q(0.37607879),
  DSP16_Q(-0.06702068),
  DSP16_Q(0.03546487),
  DSP16_Q(-0.02299785),
  DSP16_Q(0.01610147),
  DSP16_Q(-0.01162606),
  DSP16_Q(0.00845519),
  DSP16_Q(-0.00609594),
  DSP16_Q(0.00429775),
  DSP16_Q(-0.00291927),
  DSP16_Q(0.00187328),
  DSP16_Q(-0.00110118),
  DSP16_Q(0.00056002),
  DSP16_Q(-0.00021561),
  DSP16_Q(0.00003873),
  DSP16_Q(0.00000307),
  DSP16_Q(-0.00009924),
  DSP16_Q(0.00034929),
  DSP16_Q(-0.00078096),
  DSP16_Q(0.00142559),
  DSP16_Q(-0.00232096),
  DSP16_Q(0.00351628),
  DSP16_Q(-0.00508135),
  DSP16_Q(0.00712403),
  DSP16_Q(-0.00982604),
  DSP16_Q(0.01352386),
  DSP16_Q(-0.01891781),
  DSP16_Q(0.02773265),
  DSP16_Q(-0.04560807),
  DSP16_Q(0.10731652),
  DSP16_Q(0.37543049),
  DSP16_Q(-0.06746269),
  DSP16_Q(0.03572675),
  DSP16_Q(-0.02317375),
  DSP16_Q(0.01622638),
  DSP16_Q(-0.01171670),
  DSP16_Q(0.00852109),
  DSP16_Q(-0.00614323),
  DSP16_Q(0.00433080),
  DSP16_Q(-0.00294141),
  DSP16_Q(0.00188720),
  DSP16_Q(-0.00110908),
  DSP16_Q(0.00056379),
  DSP16_Q(-0.00021686),
  DSP16_Q(0.00003882),
  DSP16_Q(0.00000316),
  DSP16_Q(-0.00010046),
  DSP16_Q(0.00035300),
  DSP16_Q(-0.00078874),
  DSP16_Q(0.00143931),
  DSP16_Q(-0.00234283),
  DSP16_Q(0.00354896),
  DSP16_Q(-0.00512813),
  DSP16_Q(0.00718923),
  DSP16_Q(-0.00991576),
  DSP16_Q(0.01364753),
  DSP16_Q(-0.01909202),
  DSP16_Q(0.02799252),
  DSP16_Q(-0.04605421),
  DSP16_Q(0.10853941),
  DSP16_Q(0.37477625),
  DSP16_Q(-0.06789957),
  DSP16_Q(0.03598621),
  DSP16_Q(-0.02334816),
  DSP16_Q(0.01635028),
  DSP16_Q(-0.01180662),
  DSP16_Q(0.00858645),
  DSP16_Q(-0.00619013),
  DSP16_Q(0.00436358),
  DSP16_Q(-0.00296336),
  DSP16_Q(0.00190098),
  DSP16_Q(-0.00111691),
  DSP16_Q(0.00056752),
  DSP16_Q(-0.00021809),
  DSP16_Q(0.00003892),
  DSP16_Q(0.00000326),
  DSP16_Q(-0.00010168),
  DSP16_Q(0.00035670),
  DSP16_Q(-0.00079650),
  DSP16_Q(0.00145300),
  DSP16_Q(-0.00236463),
  DSP16_Q(0.00358150),
  DSP16_Q(-0.00517471),
  DSP16_Q(0.00725415),
  DSP16_Q(-0.01000509),
  DSP16_Q(0.01377067),
  DSP16_Q(-0.01926554),
  DSP16_Q(0.02825147),
  DSP16_Q(-0.04649922),
  DSP16_Q(0.10976401),
  DSP16_Q(0.37411608),
  DSP16_Q(-0.06833132),
  DSP16_Q(0.03624324),
  DSP16_Q(-0.02352108),
  DSP16_Q(0.01647314),
  DSP16_Q(-0.01189580),
  DSP16_Q(0.00865128),
  DSP16_Q(-0.00623665),
  DSP16_Q(0.00439607),
  DSP16_Q(-0.00298512),
  DSP16_Q(0.00191463),
  DSP16_Q(-0.00112465),
  DSP16_Q(0.00057121),
  DSP16_Q(-0.00021931),
  DSP16_Q(0.00003900),
  DSP16_Q(0.00000335),
  DSP16_Q(-0.00010290),
  DSP16_Q(0.00036039),
  DSP16_Q(-0.00080425),
  DSP16_Q(0.00146663),
  DSP16_Q(-0.00238634),
  DSP16_Q(0.00361392),
  DSP16_Q(-0.00522110),
  DSP16_Q(0.00731881),
  DSP16_Q(-0.01009405),
  DSP16_Q(0.01389329),
  DSP16_Q(-0.01943835),
  DSP16_Q(0.02850946),
  DSP16_Q(-0.04694307),
  DSP16_Q(0.11099031),
  DSP16_Q(0.37345002),
  DSP16_Q(-0.06875794),
  DSP16_Q(0.03649784),
  DSP16_Q(-0.02369249),
  DSP16_Q(0.01659498),
  DSP16_Q(-0.01198424),
  DSP16_Q(0.00871557),
  DSP16_Q(-0.00628277),
  DSP16_Q(0.00442828),
  DSP16_Q(-0.00300668),
  DSP16_Q(0.00192816),
  DSP16_Q(-0.00113231),
  DSP16_Q(0.00057485),
  DSP16_Q(-0.00022050),
  DSP16_Q(0.00003908),
  DSP16_Q(0.00000344),
  DSP16_Q(-0.00010413),
  DSP16_Q(0.00036408),
  DSP16_Q(-0.00081197),
  DSP16_Q(0.00148023),
  DSP16_Q(-0.00240798),
  DSP16_Q(0.00364621),
  DSP16_Q(-0.00526730),
  DSP16_Q(0.00738318),
  DSP16_Q(-0.01018261),
  DSP16_Q(0.01401538),
  DSP16_Q(-0.01961044),
  DSP16_Q(0.02876650),
  DSP16_Q(-0.04738574),
  DSP16_Q(0.11221825),
  DSP16_Q(0.37277807),
  DSP16_Q(-0.06917943),
  DSP16_Q(0.03675001),
  DSP16_Q(-0.02386239),
  DSP16_Q(0.01671579),
  DSP16_Q(-0.01207194),
  DSP16_Q(0.00877931),
  DSP16_Q(-0.00632850),
  DSP16_Q(0.00446022),
  DSP16_Q(-0.00302805),
  DSP16_Q(0.00194155),
  DSP16_Q(-0.00113989),
  DSP16_Q(0.00057844),
  DSP16_Q(-0.00022167),
  DSP16_Q(0.00003916),
  DSP16_Q(0.00000354),
  DSP16_Q(-0.00010536),
  DSP16_Q(0.00036777),
  DSP16_Q(-0.00081967),
  DSP16_Q(0.00149378),
  DSP16_Q(-0.00242953),
  DSP16_Q(0.00367837),
  DSP16_Q(-0.00531330),
  DSP16_Q(0.00744727),
  DSP16_Q(-0.01027078),
  DSP16_Q(0.01413693),
  DSP16_Q(-0.01978180),
  DSP16_Q(0.02902255),
  DSP16_Q(-0.04782719),
  DSP16_Q(0.11344781),
  DSP16_Q(0.37210027),
  DSP16_Q(-0.06959580),
  DSP16_Q(0.03699973),
  DSP16_Q(-0.02403079),
  DSP16_Q(0.01683556),
  DSP16_Q(-0.01215889),
  DSP16_Q(0.00884252),
  DSP16_Q(-0.00637383),
  DSP16_Q(0.00449187),
  DSP16_Q(-0.00304921),
  DSP16_Q(0.00195481),
  DSP16_Q(-0.00114739),
  DSP16_Q(0.00058199),
  DSP16_Q(-0.00022283),
  DSP16_Q(0.00003923),
  DSP16_Q(0.00000364),
  DSP16_Q(-0.00010659),
  DSP16_Q(0.00037145),
  DSP16_Q(-0.00082735),
  DSP16_Q(0.00150728),
  DSP16_Q(-0.00245100),
  DSP16_Q(0.00371039),
  DSP16_Q(-0.00535909),
  DSP16_Q(0.00751107),
  DSP16_Q(-0.01035855),
  DSP16_Q(0.01425793),
  DSP16_Q(-0.01995242),
  DSP16_Q(0.02927761),
  DSP16_Q(-0.04826742),
  DSP16_Q(0.11467897),
  DSP16_Q(0.37141662),
  DSP16_Q(-0.07000704),
  DSP16_Q(0.03724700),
  DSP16_Q(-0.02419766),
  DSP16_Q(0.01695428),
  DSP16_Q(-0.01224510),
  DSP16_Q(0.00890518),
  DSP16_Q(-0.00641877),
  DSP16_Q(0.00452323),
  DSP16_Q(-0.00307018),
  DSP16_Q(0.00196794),
  DSP16_Q(-0.00115481),
  DSP16_Q(0.00058550),
  DSP16_Q(-0.00022396),
  DSP16_Q(0.00003930),
  DSP16_Q(0.00000374),
  DSP16_Q(-0.00010782),
  DSP16_Q(0.00037513),
  DSP16_Q(-0.00083502),
  DSP16_Q(0.00152074),
  DSP16_Q(-0.00247239),
  DSP16_Q(0.00374228),
  DSP16_Q(-0.00540469),
  DSP16_Q(0.00757457),
  DSP16_Q(-0.01044591),
  DSP16_Q(0.01437839),
  DSP16_Q(-0.02012229),
  DSP16_Q(0.02953167),
  DSP16_Q(-0.04870638),
  DSP16_Q(0.11591168),
  DSP16_Q(0.37072716),
  DSP16_Q(-0.07041315),
  DSP16_Q(0.03749181),
  DSP16_Q(-0.02436300),
  DSP16_Q(0.01707196),
  DSP16_Q(-0.01233056),
  DSP16_Q(0.00896729),
  DSP16_Q(-0.00646330),
  DSP16_Q(0.00455431),
  DSP16_Q(-0.00309096),
  DSP16_Q(0.00198094),
  DSP16_Q(-0.00116214),
  DSP16_Q(0.00058896),
  DSP16_Q(-0.00022507),
  DSP16_Q(0.00003936),
  DSP16_Q(0.00000384),
  DSP16_Q(-0.00010905),
  DSP16_Q(0.00037879),
  DSP16_Q(-0.00084266),
  DSP16_Q(0.00153414),
  DSP16_Q(-0.00249369),
  DSP16_Q(0.00377403),
  DSP16_Q(-0.00545007),
  DSP16_Q(0.00763779),
  DSP16_Q(-0.01053286),
  DSP16_Q(0.01449828),
  DSP16_Q(-0.02029141),
  DSP16_Q(0.02978470),
  DSP16_Q(-0.04914407),
  DSP16_Q(0.11714591),
  DSP16_Q(0.37003190),
  DSP16_Q(-0.07081414),
  DSP16_Q(0.03773415),
  DSP16_Q(-0.02452682),
  DSP16_Q(0.01718858),
  DSP16_Q(-0.01241526),
  DSP16_Q(0.00902885),
  DSP16_Q(-0.00650744),
  DSP16_Q(0.00458511),
  DSP16_Q(-0.00311153),
  DSP16_Q(0.00199381),
  DSP16_Q(-0.00116940),
  DSP16_Q(0.00059238),
  DSP16_Q(-0.00022617),
  DSP16_Q(0.00003942),
  DSP16_Q(0.00000394),
  DSP16_Q(-0.00011029),
  DSP16_Q(0.00038246),
  DSP16_Q(-0.00085027),
  DSP16_Q(0.00154750),
  DSP16_Q(-0.00251490),
  DSP16_Q(0.00380563),
  DSP16_Q(-0.00549525),
  DSP16_Q(0.00770070),
  DSP16_Q(-0.01061940),
  DSP16_Q(0.01461760),
  DSP16_Q(-0.02045976),
  DSP16_Q(0.03003670),
  DSP16_Q(-0.04958044),
  DSP16_Q(0.11838164),
  DSP16_Q(0.36933086),
  DSP16_Q(-0.07121000),
  DSP16_Q(0.03797403),
  DSP16_Q(-0.02468909),
  DSP16_Q(0.01730415),
  DSP16_Q(-0.01249920),
  DSP16_Q(0.00908986),
  DSP16_Q(-0.00655118),
  DSP16_Q(0.00461561),
  DSP16_Q(-0.00313190),
  DSP16_Q(0.00200655),
  DSP16_Q(-0.00117657),
  DSP16_Q(0.00059575),
  DSP16_Q(-0.00022724),
  DSP16_Q(0.00003947),
  DSP16_Q(0.00000405),
  DSP16_Q(-0.00011152),
  DSP16_Q(0.00038612),
  DSP16_Q(-0.00085787),
  DSP16_Q(0.00156081),
  DSP16_Q(-0.00253602),
  DSP16_Q(0.00383710),
  DSP16_Q(-0.00554022),
  DSP16_Q(0.00776331),
  DSP16_Q(-0.01070552),
  DSP16_Q(0.01473636),
  DSP16_Q(-0.02062733),
  DSP16_Q(0.03028765),
  DSP16_Q(-0.05001549),
  DSP16_Q(0.11961883),
  DSP16_Q(0.36862407),
  DSP16_Q(-0.07160074),
  DSP16_Q(0.03821142),
  DSP16_Q(-0.02484983),
  DSP16_Q(0.01741865),
  DSP16_Q(-0.01258238),
  DSP16_Q(0.00915032),
  DSP16_Q(-0.00659451),
  DSP16_Q(0.00464583),
  DSP16_Q(-0.00315207),
  DSP16_Q(0.00201915),
  DSP16_Q(-0.00118366),
  DSP16_Q(0.00059908),
  DSP16_Q(-0.00022830),
  DSP16_Q(0.00003952),
  DSP16_Q(0.00000415),
  DSP16_Q(-0.00011276),
  DSP16_Q(0.00038977),
  DSP16_Q(-0.00086544),
  DSP16_Q(0.00157407),
  DSP16_Q(-0.00255706),
  DSP16_Q(0.00386843),
  DSP16_Q(-0.00558497),
  DSP16_Q(0.00782562),
  DSP16_Q(-0.01079121),
  DSP16_Q(0.01485453),
  DSP16_Q(-0.02079411),
  DSP16_Q(0.03053753),
  DSP16_Q(-0.05044918),
  DSP16_Q(0.12085744),
  DSP16_Q(0.36791154),
  DSP16_Q(-0.07198637),
  DSP16_Q(0.03844634),
  DSP16_Q(-0.02500901),
  DSP16_Q(0.01753210),
  DSP16_Q(-0.01266480),
  DSP16_Q(0.00921022),
  DSP16_Q(-0.00663744),
  DSP16_Q(0.00467576),
  DSP16_Q(-0.00317205),
  DSP16_Q(0.00203162),
  DSP16_Q(-0.00119067),
  DSP16_Q(0.00060236),
  DSP16_Q(-0.00022933),
  DSP16_Q(0.00003956),
  DSP16_Q(0.00000426),
  DSP16_Q(-0.00011400),
  DSP16_Q(0.00039341),
  DSP16_Q(-0.00087299),
  DSP16_Q(0.00158728),
  DSP16_Q(-0.00257800),
  DSP16_Q(0.00389961),
  DSP16_Q(-0.00562950),
  DSP16_Q(0.00788761),
  DSP16_Q(-0.01087648),
  DSP16_Q(0.01497211),
  DSP16_Q(-0.02096010),
  DSP16_Q(0.03078633),
  DSP16_Q(-0.05088148),
  DSP16_Q(0.12209745),
  DSP16_Q(0.36719330),
  DSP16_Q(-0.07236687),
  DSP16_Q(0.03867876),
  DSP16_Q(-0.02516665),
  DSP16_Q(0.01764447),
  DSP16_Q(-0.01274645),
  DSP16_Q(0.00926955),
  DSP16_Q(-0.00667996),
  DSP16_Q(0.00470539),
  DSP16_Q(-0.00319181),
  DSP16_Q(0.00204395),
  DSP16_Q(-0.00119760),
  DSP16_Q(0.00060560),
  DSP16_Q(-0.00023035),
  DSP16_Q(0.00003960),
  DSP16_Q(0.00000437),
  DSP16_Q(-0.00011524),
  DSP16_Q(0.00039705),
  DSP16_Q(-0.00088051),
  DSP16_Q(0.00160044),
  DSP16_Q(-0.00259885),
  DSP16_Q(0.00393064),
  DSP16_Q(-0.00567382),
  DSP16_Q(0.00794930),
  DSP16_Q(-0.01096130),
  DSP16_Q(0.01508910),
  DSP16_Q(-0.02112528),
  DSP16_Q(0.03103404),
  DSP16_Q(-0.05131239),
  DSP16_Q(0.12333883),
  DSP16_Q(0.36646938),
  DSP16_Q(-0.07274226),
  DSP16_Q(0.03890869),
  DSP16_Q(-0.02532272),
  DSP16_Q(0.01775577),
  DSP16_Q(-0.01282733),
  DSP16_Q(0.00932833),
  DSP16_Q(-0.00672207),
  DSP16_Q(0.00473474),
  DSP16_Q(-0.00321138),
  DSP16_Q(0.00205615),
  DSP16_Q(-0.00120444),
  DSP16_Q(0.00060879),
  DSP16_Q(-0.00023134),
  DSP16_Q(0.00003963),
  DSP16_Q(0.00000448),
  DSP16_Q(-0.00011648),
  DSP16_Q(0.00040068),
  DSP16_Q(-0.00088801),
  DSP16_Q(0.00161354),
  DSP16_Q(-0.00261961),
  DSP16_Q(0.00396152),
  DSP16_Q(-0.00571791),
  DSP16_Q(0.00801066),
  DSP16_Q(-0.01104569),
  DSP16_Q(0.01520549),
  DSP16_Q(-0.02128964),
  DSP16_Q(0.03128064),
  DSP16_Q(-0.05174186),
  DSP16_Q(0.12458153),
  DSP16_Q(0.36573978),
  DSP16_Q(-0.07311254),
  DSP16_Q(0.03913611),
  DSP16_Q(-0.02547723),
  DSP16_Q(0.01786599),
  DSP16_Q(-0.01290743),
  DSP16_Q(0.00938654),
  DSP16_Q(-0.00676377),
  DSP16_Q(0.00476379),
  DSP16_Q(-0.00323074),
  DSP16_Q(0.00206822),
  DSP16_Q(-0.00121121),
  DSP16_Q(0.00061194),
  DSP16_Q(-0.00023232),
  DSP16_Q(0.00003966),
  DSP16_Q(0.00000459),
  DSP16_Q(-0.00011772),
  DSP16_Q(0.00040430),
  DSP16_Q(-0.00089549),
  DSP16_Q(0.00162659),
  DSP16_Q(-0.00264027),
  DSP16_Q(0.00399225),
  DSP16_Q(-0.00576178),
  DSP16_Q(0.00807171),
  DSP16_Q(-0.01112963),
  DSP16_Q(0.01532127),
  DSP16_Q(-0.02145317),
  DSP16_Q(0.03152611),
  DSP16_Q(-0.05216988),
  DSP16_Q(0.12582553),
  DSP16_Q(0.36500454),
  DSP16_Q(-0.07347771),
  DSP16_Q(0.03936103),
  DSP16_Q(-0.02563017),
  DSP16_Q(0.01797514),
  DSP16_Q(-0.01298676),
  DSP16_Q(0.00944419),
  DSP16_Q(-0.00680506),
  DSP16_Q(0.00479254),
  DSP16_Q(-0.00324990),
  DSP16_Q(0.00208015),
  DSP16_Q(-0.00121788),
  DSP16_Q(0.00061504),
  DSP16_Q(-0.00023327),
  DSP16_Q(0.00003968),
  DSP16_Q(0.00000470),
  DSP16_Q(-0.00011897),
  DSP16_Q(0.00040792),
  DSP16_Q(-0.00090294),
  DSP16_Q(0.00163959),
  DSP16_Q(-0.00266084),
  DSP16_Q(0.00402283),
  DSP16_Q(-0.00580542),
  DSP16_Q(0.00813243),
  DSP16_Q(-0.01121313),
  DSP16_Q(0.01543644),
  DSP16_Q(-0.02161588),
  DSP16_Q(0.03177045),
  DSP16_Q(-0.05259642),
  DSP16_Q(0.12707080),
  DSP16_Q(0.36426368),
  DSP16_Q(-0.07383777),
  DSP16_Q(0.03958344),
  DSP16_Q(-0.02578154),
  DSP16_Q(0.01808319),
  DSP16_Q(-0.01306531),
  DSP16_Q(0.00950127),
  DSP16_Q(-0.00684594),
  DSP16_Q(0.00482101),
  DSP16_Q(-0.00326886),
  DSP16_Q(0.00209195),
  DSP16_Q(-0.00122448),
  DSP16_Q(0.00061810),
  DSP16_Q(-0.00023421),
  DSP16_Q(0.00003970),
  DSP16_Q(0.00000482),
  DSP16_Q(-0.00012021),
  DSP16_Q(0.00041153),
  DSP16_Q(-0.00091036),
  DSP16_Q(0.00165253),
  DSP16_Q(-0.00268131),
  DSP16_Q(0.00405325),
  DSP16_Q(-0.00584883),
  DSP16_Q(0.00819282),
  DSP16_Q(-0.01129616),
  DSP16_Q(0.01555098),
  DSP16_Q(-0.02177773),
  DSP16_Q(0.03201364),
  DSP16_Q(-0.05302145),
  DSP16_Q(0.12831730),
  DSP16_Q(0.36351722),
  DSP16_Q(-0.07419272),
  DSP16_Q(0.03980333),
  DSP16_Q(-0.02593133),
  DSP16_Q(0.01819016),
  DSP16_Q(-0.01314308),
  DSP16_Q(0.00955778),
  DSP16_Q(-0.00688641),
  DSP16_Q(0.00484917),
  DSP16_Q(-0.00328761),
  DSP16_Q(0.00210361),
  DSP16_Q(-0.00123099),
  DSP16_Q(0.00062111),
  DSP16_Q(-0.00023512),
  DSP16_Q(0.00003972),
  DSP16_Q(0.00000494),
  DSP16_Q(-0.00012145),
  DSP16_Q(0.00041512),
  DSP16_Q(-0.00091776),
  DSP16_Q(0.00166541),
  DSP16_Q(-0.00270168),
  DSP16_Q(0.00408352),
  DSP16_Q(-0.00589201),
  DSP16_Q(0.00825288),
  DSP16_Q(-0.01137874),
  DSP16_Q(0.01566490),
  DSP16_Q(-0.02193873),
  DSP16_Q(0.03225565),
  DSP16_Q(-0.05344496),
  DSP16_Q(0.12956499),
  DSP16_Q(0.36276518),
  DSP16_Q(-0.07454258),
  DSP16_Q(0.04002070),
  DSP16_Q(-0.02607954),
  DSP16_Q(0.01829604),
  DSP16_Q(-0.01322006),
  DSP16_Q(0.00961371),
  DSP16_Q(-0.00692645),
  DSP16_Q(0.00487704),
  DSP16_Q(-0.00330615),
  DSP16_Q(0.00211514),
  DSP16_Q(-0.00123743),
  DSP16_Q(0.00062408),
  DSP16_Q(-0.00023602),
  DSP16_Q(0.00003973),
  DSP16_Q(0.00000506),
  DSP16_Q(-0.00012270),
  DSP16_Q(0.00041872),
  DSP16_Q(-0.00092513),
  DSP16_Q(0.00167824),
  DSP16_Q(-0.00272195),
  DSP16_Q(0.00411363),
  DSP16_Q(-0.00593495),
  DSP16_Q(0.00831260),
  DSP16_Q(-0.01146086),
  DSP16_Q(0.01577818),
  DSP16_Q(-0.02209887),
  DSP16_Q(0.03249649),
  DSP16_Q(-0.05386692),
  DSP16_Q(0.13081385),
  DSP16_Q(0.36200759),
  DSP16_Q(-0.07488733),
  DSP16_Q(0.04023554),
  DSP16_Q(-0.02622615),
  DSP16_Q(0.01840082),
  DSP16_Q(-0.01329625),
  DSP16_Q(0.00966907),
  DSP16_Q(-0.00696609),
  DSP16_Q(0.00490461),
  DSP16_Q(-0.00332449),
  DSP16_Q(0.00212653),
  DSP16_Q(-0.00124377),
  DSP16_Q(0.00062700),
  DSP16_Q(-0.00023690),
  DSP16_Q(0.00003973),
  DSP16_Q(0.00000518),
  DSP16_Q(-0.00012395),
  DSP16_Q(0.00042230),
  DSP16_Q(-0.00093247),
  DSP16_Q(0.00169101),
  DSP16_Q(-0.00274212),
  DSP16_Q(0.00414358),
  DSP16_Q(-0.00597766),
  DSP16_Q(0.00837199),
  DSP16_Q(-0.01154250),
  DSP16_Q(0.01589082),
  DSP16_Q(-0.02225813),
  DSP16_Q(0.03273613),
  DSP16_Q(-0.05428729),
  DSP16_Q(0.13206385),
  DSP16_Q(0.36124446),
  DSP16_Q(-0.07522699),
  DSP16_Q(0.04044785),
  DSP16_Q(-0.02637118),
  DSP16_Q(0.01850450),
  DSP16_Q(-0.01337165),
  DSP16_Q(0.00972386),
  DSP16_Q(-0.00700530),
  DSP16_Q(0.00493189),
  DSP16_Q(-0.00334262),
  DSP16_Q(0.00213778),
  DSP16_Q(-0.00125004),
  DSP16_Q(0.00062988),
  DSP16_Q(-0.00023776),
  DSP16_Q(0.00003973),
  DSP16_Q(0.00000530),
  DSP16_Q(-0.00012519),
  DSP16_Q(0.00042587),
  DSP16_Q(-0.00093978),
  DSP16_Q(0.00170372),
  DSP16_Q(-0.00276219),
  DSP16_Q(0.00417337),
  DSP16_Q(-0.00602012),
  DSP16_Q(0.00843103),
  DSP16_Q(-0.01162367),
  DSP16_Q(0.01600281),
  DSP16_Q(-0.02241651),
  DSP16_Q(0.03297456),
  DSP16_Q(-0.05470607),
  DSP16_Q(0.13331494),
  DSP16_Q(0.36047583),
  DSP16_Q(-0.07556156),
  DSP16_Q(0.04065761),
  DSP16_Q(-0.02651460),
  DSP16_Q(0.01860707),
  DSP16_Q(-0.01344626),
  DSP16_Q(0.00977807),
  DSP16_Q(-0.00704409),
  DSP16_Q(0.00495886),
  DSP16_Q(-0.00336055),
  DSP16_Q(0.00214890),
  DSP16_Q(-0.00125622),
  DSP16_Q(0.00063271),
  DSP16_Q(-0.00023860),
  DSP16_Q(0.00003973),
  DSP16_Q(0.00000542),
  DSP16_Q(-0.00012644),
  DSP16_Q(0.00042944),
  DSP16_Q(-0.00094707),
  DSP16_Q(0.00171637),
  DSP16_Q(-0.00278215),
  DSP16_Q(0.00420299),
  DSP16_Q(-0.00606234),
  DSP16_Q(0.00848973),
  DSP16_Q(-0.01170436),
  DSP16_Q(0.01611415),
  DSP16_Q(-0.02257399),
  DSP16_Q(0.03321177),
  DSP16_Q(-0.05512322),
  DSP16_Q(0.13456710),
  DSP16_Q(0.35970171),
  DSP16_Q(-0.07589104),
  DSP16_Q(0.04086484),
  DSP16_Q(-0.02665643),
  DSP16_Q(0.01870854),
  DSP16_Q(-0.01352007),
  DSP16_Q(0.00983169),
  DSP16_Q(-0.00708246),
  DSP16_Q(0.00498553),
  DSP16_Q(-0.00337827),
  DSP16_Q(0.00215988),
  DSP16_Q(-0.00126231),
  DSP16_Q(0.00063550),
  DSP16_Q(-0.00023942),
  DSP16_Q(0.00003972),
  DSP16_Q(0.00000555),
  DSP16_Q(-0.00012769),
  DSP16_Q(0.00043299),
  DSP16_Q(-0.00095432),
  DSP16_Q(0.00172896),
  DSP16_Q(-0.00280201),
  DSP16_Q(0.00423245),
  DSP16_Q(-0.00610432),
  DSP16_Q(0.00854808),
  DSP16_Q(-0.01178456),
  DSP16_Q(0.01622482),
  DSP16_Q(-0.02273057),
  DSP16_Q(0.03344774),
  DSP16_Q(-0.05553872),
  DSP16_Q(0.13582030),
  DSP16_Q(0.35892213),
  DSP16_Q(-0.07621543),
  DSP16_Q(0.04106952),
  DSP16_Q(-0.02679665),
  DSP16_Q(0.01880890),
  DSP16_Q(-0.01359309),
  DSP16_Q(0.00988474),
  DSP16_Q(-0.00712041),
  DSP16_Q(0.00501190),
  DSP16_Q(-0.00339577),
  DSP16_Q(0.00217072),
  DSP16_Q(-0.00126833),
  DSP16_Q(0.00063824),
  DSP16_Q(-0.00024022),
  DSP16_Q(0.00003971),
  DSP16_Q(0.00000568),
  DSP16_Q(-0.00012893),
  DSP16_Q(0.00043654),
  DSP16_Q(-0.00096155),
  DSP16_Q(0.00174150),
  DSP16_Q(-0.00282176),
  DSP16_Q(0.00426174),
  DSP16_Q(-0.00614604),
  DSP16_Q(0.00860607),
  DSP16_Q(-0.01186428),
  DSP16_Q(0.01633483),
  DSP16_Q(-0.02288625),
  DSP16_Q(0.03368245),
  DSP16_Q(-0.05595254),
  DSP16_Q(0.13707449),
  DSP16_Q(0.35813711),
  DSP16_Q(-0.07653475),
  DSP16_Q(0.04127165),
  DSP16_Q(-0.02693526),
  DSP16_Q(0.01890814),
  DSP16_Q(-0.01366530),
  DSP16_Q(0.00993720),
  DSP16_Q(-0.00715793),
  DSP16_Q(0.00503797),
  DSP16_Q(-0.00341307),
  DSP16_Q(0.00218142),
  DSP16_Q(-0.00127426),
  DSP16_Q(0.00064094),
  DSP16_Q(-0.00024100),
  DSP16_Q(0.00003969),
  DSP16_Q(0.00000580),
  DSP16_Q(-0.00013018),
  DSP16_Q(0.00044007),
  DSP16_Q(-0.00096875),
  DSP16_Q(0.00175396),
  DSP16_Q(-0.00284141),
  DSP16_Q(0.00429086),
  DSP16_Q(-0.00618752),
  DSP16_Q(0.00866371),
  DSP16_Q(-0.01194350),
  DSP16_Q(0.01644416),
  DSP16_Q(-0.02304100),
  DSP16_Q(0.03391590),
  DSP16_Q(-0.05636466),
  DSP16_Q(0.13832965),
  DSP16_Q(0.35734668),
  DSP16_Q(-0.07684899),
  DSP16_Q(0.04147122),
  DSP16_Q(-0.02707225),
  DSP16_Q(0.01900627),
  DSP16_Q(-0.01373671),
  DSP16_Q(0.00998907),
  DSP16_Q(-0.00719503),
  DSP16_Q(0.00506373),
  DSP16_Q(-0.00343016),
  DSP16_Q(0.00219199),
  DSP16_Q(-0.00128010),
  DSP16_Q(0.00064359),
  DSP16_Q(-0.00024176),
  DSP16_Q(0.00003967),
  DSP16_Q(0.00000593),
  DSP16_Q(-0.00013143),
  DSP16_Q(0.00044360),
  DSP16_Q(-0.00097591),
  DSP16_Q(0.00176637),
  DSP16_Q(-0.00286094),
  DSP16_Q(0.00431981),
  DSP16_Q(-0.00622874),
  DSP16_Q(0.00872099),
  DSP16_Q(-0.01202223),
  DSP16_Q(0.01655281),
  DSP16_Q(-0.02319482),
  DSP16_Q(0.03414807),
  DSP16_Q(-0.05677506),
  DSP16_Q(0.13958574),
  DSP16_Q(0.35655086),
  DSP16_Q(-0.07715816),
  DSP16_Q(0.04166823),
  DSP16_Q(-0.02720762),
  DSP16_Q(0.01910328),
  DSP16_Q(-0.01380731),
  DSP16_Q(0.01004036),
  DSP16_Q(-0.00723170),
  DSP16_Q(0.00508919),
  DSP16_Q(-0.00344704),
  DSP16_Q(0.00220242),
  DSP16_Q(-0.00128586),
  DSP16_Q(0.00064619),
  DSP16_Q(-0.00024250),
  DSP16_Q(0.00003965),
  DSP16_Q(0.00000607),
  DSP16_Q(-0.00013267),
  DSP16_Q(0.00044711),
  DSP16_Q(-0.00098305),
  DSP16_Q(0.00177871),
  DSP16_Q(-0.00288037),
  DSP16_Q(0.00434858),
  DSP16_Q(-0.00626971),
  DSP16_Q(0.00877790),
  DSP16_Q(-0.01210045),
  DSP16_Q(0.01666077),
  DSP16_Q(-0.02334770),
  DSP16_Q(0.03437894),
  DSP16_Q(-0.05718371),
  DSP16_Q(0.14084273),
  DSP16_Q(0.35574968),
  DSP16_Q(-0.07746226),
  DSP16_Q(0.04186268),
  DSP16_Q(-0.02734137),
  DSP16_Q(0.01919916),
  DSP16_Q(-0.01387710),
  DSP16_Q(0.01009105),
  DSP16_Q(-0.00726795),
  DSP16_Q(0.00511435),
  DSP16_Q(-0.00346371),
  DSP16_Q(0.00221271),
  DSP16_Q(-0.00129154),
  DSP16_Q(0.00064875),
  DSP16_Q(-0.00024322),
  DSP16_Q(0.00003962),
  DSP16_Q(0.00000620),
  DSP16_Q(-0.00013392),
  DSP16_Q(0.00045061),
  DSP16_Q(-0.00099015),
  DSP16_Q(0.00179099),
  DSP16_Q(-0.00289968),
  DSP16_Q(0.00437718),
  DSP16_Q(-0.00631042),
  DSP16_Q(0.00883445),
  DSP16_Q(-0.01217816),
  DSP16_Q(0.01676804),
  DSP16_Q(-0.02349963),
  DSP16_Q(0.03460851),
  DSP16_Q(-0.05759058),
  DSP16_Q(0.14210059),
  DSP16_Q(0.35494315),
  DSP16_Q(-0.07776131),
  DSP16_Q(0.04205456),
  DSP16_Q(-0.02747350),
  DSP16_Q(0.01929391),
  DSP16_Q(-0.01394608),
  DSP16_Q(0.01014116),
  DSP16_Q(-0.00730376),
  DSP16_Q(0.00513920),
  DSP16_Q(-0.00348017),
  DSP16_Q(0.00222287),
  DSP16_Q(-0.00129713),
  DSP16_Q(0.00065127),
  DSP16_Q(-0.00024393),
  DSP16_Q(0.00003959),
  DSP16_Q(0.00000633),
  DSP16_Q(-0.00013517),
  DSP16_Q(0.00045411),
  DSP16_Q(-0.00099722),
  DSP16_Q(0.00180320),
  DSP16_Q(-0.00291888),
  DSP16_Q(0.00440561),
  DSP16_Q(-0.00635086),
  DSP16_Q(0.00889063),
  DSP16_Q(-0.01225536),
  DSP16_Q(0.01687461),
  DSP16_Q(-0.02365060),
  DSP16_Q(0.03483675),
  DSP16_Q(-0.05799566),
  DSP16_Q(0.14335927),
  DSP16_Q(0.35413131),
  DSP16_Q(-0.07805529),
  DSP16_Q(0.04224387),
  DSP16_Q(-0.02760399),
  DSP16_Q(0.01938754),
  DSP16_Q(-0.01401425),
  DSP16_Q(0.01019067),
  DSP16_Q(-0.00733915),
  DSP16_Q(0.00516374),
  DSP16_Q(-0.00349641),
  DSP16_Q(0.00223288),
  DSP16_Q(-0.00130264),
  DSP16_Q(0.00065374),
  DSP16_Q(-0.00024461),
  DSP16_Q(0.00003955),
  DSP16_Q(0.00000647),
  DSP16_Q(-0.00013641),
  DSP16_Q(0.00045759),
  DSP16_Q(-0.00100426),
  DSP16_Q(0.00181535),
  DSP16_Q(-0.00293797),
  DSP16_Q(0.00443385),
  DSP16_Q(-0.00639105),
  DSP16_Q(0.00894643),
  DSP16_Q(-0.01233204),
  DSP16_Q(0.01698046),
  DSP16_Q(-0.02380061),
  DSP16_Q(0.03506365),
  DSP16_Q(-0.05839891),
  DSP16_Q(0.14461876),
  DSP16_Q(0.35331417),
  DSP16_Q(-0.07834423),
  DSP16_Q(0.04243060),
  DSP16_Q(-0.02773285),
  DSP16_Q(0.01948003),
  DSP16_Q(-0.01408160),
  DSP16_Q(0.01023959),
  DSP16_Q(-0.00737410),
  DSP16_Q(0.00518798),
  DSP16_Q(-0.00351244),
  DSP16_Q(0.00224275),
  DSP16_Q(-0.00130806),
  DSP16_Q(0.00065617),
  DSP16_Q(-0.00024528),
  DSP16_Q(0.00003951),
  DSP16_Q(0.00000661),
  DSP16_Q(-0.00013766),
  DSP16_Q(0.00046106),
  DSP16_Q(-0.00101127),
  DSP16_Q(0.00182743),
  DSP16_Q(-0.00295695),
  DSP16_Q(0.00446192),
  DSP16_Q(-0.00643097),
  DSP16_Q(0.00900186),
  DSP16_Q(-0.01240820),
  DSP16_Q(0.01708561),
  DSP16_Q(-0.02394963),
  DSP16_Q(0.03528920),
  DSP16_Q(-0.05880032),
  DSP16_Q(0.14587901),
  DSP16_Q(0.35249177),
  DSP16_Q(-0.07862812),
  DSP16_Q(0.04261476),
  DSP16_Q(-0.02786007),
  DSP16_Q(0.01957138),
  DSP16_Q(-0.01414813),
  DSP16_Q(0.01028791),
  DSP16_Q(-0.00740862),
  DSP16_Q(0.00521190),
  DSP16_Q(-0.00352827),
  DSP16_Q(0.00225249),
  DSP16_Q(-0.00131340),
  DSP16_Q(0.00065855),
  DSP16_Q(-0.00024593),
  DSP16_Q(0.00003947),
  DSP16_Q(0.00000675),
  DSP16_Q(-0.00013891),
  DSP16_Q(0.00046452),
  DSP16_Q(-0.00101824),
  DSP16_Q(0.00183944),
  DSP16_Q(-0.00297580),
  DSP16_Q(0.00448980),
  DSP16_Q(-0.00647062),
  DSP16_Q(0.00905690),
  DSP16_Q(-0.01248383),
  DSP16_Q(0.01719003),
  DSP16_Q(-0.02409768),
  DSP16_Q(0.03551339),
  DSP16_Q(-0.05919985),
  DSP16_Q(0.14713998),
  DSP16_Q(0.35166413),
  DSP16_Q(-0.07890697),
  DSP16_Q(0.04279633),
  DSP16_Q(-0.02798565),
  DSP16_Q(0.01966160),
  DSP16_Q(-0.01421385),
  DSP16_Q(0.01033563),
  DSP16_Q(-0.00744271),
  DSP16_Q(0.00523552),
  DSP16_Q(-0.00354388),
  DSP16_Q(0.00226209),
  DSP16_Q(-0.00131866),
  DSP16_Q(0.00066088),
  DSP16_Q(-0.00024656),
  DSP16_Q(0.00003942),
  DSP16_Q(0.00000689),
  DSP16_Q(-0.00014015),
  DSP16_Q(0.00046797),
  DSP16_Q(-0.00102518),
  DSP16_Q(0.00185139),
  DSP16_Q(-0.00299454),
  DSP16_Q(0.00451750),
  DSP16_Q(-0.00650999),
  DSP16_Q(0.00911157),
  DSP16_Q(-0.01255894),
  DSP16_Q(0.01729373),
  DSP16_Q(-0.02424473),
  DSP16_Q(0.03573620),
  DSP16_Q(-0.05959749),
  DSP16_Q(0.14840166),
  DSP16_Q(0.35083127),
  DSP16_Q(-0.07918078),
  DSP16_Q(0.04297532),
  DSP16_Q(-0.02810958),
  DSP16_Q(0.01975067),
  DSP16_Q(-0.01427874),
  DSP16_Q(0.01038275),
  DSP16_Q(-0.00747636),
  DSP16_Q(0.00525883),
  DSP16_Q(-0.00355927),
  DSP16_Q(0.00227154),
  DSP16_Q(-0.00132383),
  DSP16_Q(0.00066317),
  DSP16_Q(-0.00024717),
  DSP16_Q(0.00003937),
  DSP16_Q(0.00000703),
  DSP16_Q(-0.00014139),
  DSP16_Q(0.00047140),
  DSP16_Q(-0.00103209),
  DSP16_Q(0.00186326),
  DSP16_Q(-0.00301316),
  DSP16_Q(0.00454502),
  DSP16_Q(-0.00654910),
  DSP16_Q(0.00916584),
  DSP16_Q(-0.01263350),
  DSP16_Q(0.01739670),
  DSP16_Q(-0.02439077),
  DSP16_Q(0.03595762),
  DSP16_Q(-0.05999321),
  DSP16_Q(0.14966399),
  DSP16_Q(0.34999322),
  DSP16_Q(-0.07944957),
  DSP16_Q(0.04315172),
  DSP16_Q(-0.02823186),
  DSP16_Q(0.01983860),
  DSP16_Q(-0.01434280),
  DSP16_Q(0.01042928),
  DSP16_Q(-0.00750957),
  DSP16_Q(0.00528183),
  DSP16_Q(-0.00357445),
  DSP16_Q(0.00228086),
  DSP16_Q(-0.00132892),
  DSP16_Q(0.00066542),
  DSP16_Q(-0.00024776),
  DSP16_Q(0.00003931),
  DSP16_Q(0.00000718),
  DSP16_Q(-0.00014264),
  DSP16_Q(0.00047482),
  DSP16_Q(-0.00103896),
  DSP16_Q(0.00187507),
  DSP16_Q(-0.00303167),
  DSP16_Q(0.00457235),
  DSP16_Q(-0.00658793),
  DSP16_Q(0.00921972),
  DSP16_Q(-0.01270753),
  DSP16_Q(0.01749892),
  DSP16_Q(-0.02453580),
  DSP16_Q(0.03617763),
  DSP16_Q(-0.06038698),
  DSP16_Q(0.15092695),
  DSP16_Q(0.34915000),
  DSP16_Q(-0.07971333),
  DSP16_Q(0.04332552),
  DSP16_Q(-0.02835249),
  DSP16_Q(0.01992538),
  DSP16_Q(-0.01440604),
  DSP16_Q(0.01047520),
  DSP16_Q(-0.00754235),
  DSP16_Q(0.00530452),
  DSP16_Q(-0.00358942),
  DSP16_Q(0.00229004),
  DSP16_Q(-0.00133392),
  DSP16_Q(0.00066762),
  DSP16_Q(-0.00024833),
  DSP16_Q(0.00003925),
  DSP16_Q(0.00000733),
  DSP16_Q(-0.00014388),
  DSP16_Q(0.00047823),
  DSP16_Q(-0.00104579),
  DSP16_Q(0.00188681),
  DSP16_Q(-0.00305005),
  DSP16_Q(0.00459948),
  DSP16_Q(-0.00662648),
  DSP16_Q(0.00927321),
  DSP16_Q(-0.01278101),
  DSP16_Q(0.01760040),
  DSP16_Q(-0.02467981),
  DSP16_Q(0.03639622),
  DSP16_Q(-0.06077879),
  DSP16_Q(0.15219051),
  DSP16_Q(0.34830164),
  DSP16_Q(-0.07997208),
  DSP16_Q(0.04349673),
  DSP16_Q(-0.02847147),
  DSP16_Q(0.02001102),
  DSP16_Q(-0.01446845),
  DSP16_Q(0.01052051),
  DSP16_Q(-0.00757469),
  DSP16_Q(0.00532689),
  DSP16_Q(-0.00360417),
  DSP16_Q(0.00229907),
  DSP16_Q(-0.00133883),
  DSP16_Q(0.00066977),
  DSP16_Q(-0.00024888),
  DSP16_Q(0.00003918),
  DSP16_Q(0.00000747),
  DSP16_Q(-0.00014512),
  DSP16_Q(0.00048163),
  DSP16_Q(-0.00105259),
  DSP16_Q(0.00189847),
  DSP16_Q(-0.00306830),
  DSP16_Q(0.00462643),
  DSP16_Q(-0.00666475),
  DSP16_Q(0.00932630),
  DSP16_Q(-0.01285394),
  DSP16_Q(0.01770113),
  DSP16_Q(-0.02482279),
  DSP16_Q(0.03661337),
  DSP16_Q(-0.06116860),
  DSP16_Q(0.15345463),
  DSP16_Q(0.34744817),
  DSP16_Q(-0.08022581),
  DSP16_Q(0.04366535),
  DSP16_Q(-0.02858879),
  DSP16_Q(0.02009549),
  DSP16_Q(-0.01453003),
  DSP16_Q(0.01056522),
  DSP16_Q(-0.00760660),
  DSP16_Q(0.00534896),
  DSP16_Q(-0.00361871),
  DSP16_Q(0.00230797),
  DSP16_Q(-0.00134366),
  DSP16_Q(0.00067188),
  DSP16_Q(-0.00024942),
  DSP16_Q(0.00003912),
  DSP16_Q(0.00000762),
  DSP16_Q(-0.00014636),
  DSP16_Q(0.00048501),
  DSP16_Q(-0.00105935),
  DSP16_Q(0.00191006),
  DSP16_Q(-0.00308644),
  DSP16_Q(0.00465319),
  DSP16_Q(-0.00670274),
  DSP16_Q(0.00937899),
  DSP16_Q(-0.01292631),
  DSP16_Q(0.01780109),
  DSP16_Q(-0.02496473),
  DSP16_Q(0.03682908),
  DSP16_Q(-0.06155639),
  DSP16_Q(0.15471927),
  DSP16_Q(0.34658960),
  DSP16_Q(-0.08047455),
  DSP16_Q(0.04383136),
  DSP16_Q(-0.02870444),
  DSP16_Q(0.02017882),
  DSP16_Q(-0.01459077),
  DSP16_Q(0.01060932),
  DSP16_Q(-0.00763806),
  DSP16_Q(0.00537071),
  DSP16_Q(-0.00363304),
  DSP16_Q(0.00231672),
  DSP16_Q(-0.00134841),
  DSP16_Q(0.00067395),
  DSP16_Q(-0.00024993),
  DSP16_Q(0.00003905),
  DSP16_Q(0.00000777),
  DSP16_Q(-0.00014760),
  DSP16_Q(0.00048838),
  DSP16_Q(-0.00106608),
  DSP16_Q(0.00192158),
  DSP16_Q(-0.00310445),
  DSP16_Q(0.00467975),
  DSP16_Q(-0.00674044),
  DSP16_Q(0.00943128),
  DSP16_Q(-0.01299813),
  DSP16_Q(0.01790030),
  DSP16_Q(-0.02510562),
  DSP16_Q(0.03704333),
  DSP16_Q(-0.06194214),
  DSP16_Q(0.15598440),
  DSP16_Q(0.34572598),
  DSP16_Q(-0.08071828),
  DSP16_Q(0.04399478),
  DSP16_Q(-0.02881843),
  DSP16_Q(0.02026098),
  DSP16_Q(-0.01465068),
  DSP16_Q(0.01065282),
  DSP16_Q(-0.00766908),
  DSP16_Q(0.00539215),
  DSP16_Q(-0.00364714),
  DSP16_Q(0.00232534),
  DSP16_Q(-0.00135307),
  DSP16_Q(0.00067597),
  DSP16_Q(-0.00025043),
  DSP16_Q(0.00003897),
  DSP16_Q(0.00000793),
  DSP16_Q(-0.00014884),
  DSP16_Q(0.00049174),
  DSP16_Q(-0.00107277),
  DSP16_Q(0.00193302),
  DSP16_Q(-0.00312233),
  DSP16_Q(0.00470611),
  DSP16_Q(-0.00677785),
  DSP16_Q(0.00948316),
  DSP16_Q(-0.01306938),
  DSP16_Q(0.01799873),
  DSP16_Q(-0.02524545),
  DSP16_Q(0.03725610),
  DSP16_Q(-0.06232583),
  DSP16_Q(0.15724998),
  DSP16_Q(0.34485732),
  DSP16_Q(-0.08095703),
  DSP16_Q(0.04415559),
  DSP16_Q(-0.02893076),
  DSP16_Q(0.02034198),
  DSP16_Q(-0.01470976),
  DSP16_Q(0.01069570),
  DSP16_Q(-0.00769966),
  DSP16_Q(0.00541327),
  DSP16_Q(-0.00366103),
  DSP16_Q(0.00233381),
  DSP16_Q(-0.00135765),
  DSP16_Q(0.00067794),
  DSP16_Q(-0.00025091),
  DSP16_Q(0.00003889),
  DSP16_Q(0.00000808),
  DSP16_Q(-0.00015007),
  DSP16_Q(0.00049508),
  DSP16_Q(-0.00107942),
  DSP16_Q(0.00194439),
  DSP16_Q(-0.00314009),
  DSP16_Q(0.00473228),
  DSP16_Q(-0.00681497),
  DSP16_Q(0.00953463),
  DSP16_Q(-0.01314007),
  DSP16_Q(0.01809639),
  DSP16_Q(-0.02538422),
  DSP16_Q(0.03746738),
  DSP16_Q(-0.06270742),
  DSP16_Q(0.15851599),
  DSP16_Q(0.34398365),
  DSP16_Q(-0.08119079),
  DSP16_Q(0.04431379),
  DSP16_Q(-0.02904141),
  DSP16_Q(0.02042183),
  DSP16_Q(-0.01476799),
  DSP16_Q(0.01073798),
  DSP16_Q(-0.00772980),
  DSP16_Q(0.00543408),
  DSP16_Q(-0.00367471),
  DSP16_Q(0.00234215),
  DSP16_Q(-0.00136214),
  DSP16_Q(0.00067987),
  DSP16_Q(-0.00025137),
  DSP16_Q(0.00003881),
  DSP16_Q(0.00000824),
  DSP16_Q(-0.00015131),
  DSP16_Q(0.00049841),
  DSP16_Q(-0.00108603),
  DSP16_Q(0.00195568),
  DSP16_Q(-0.00315772),
  DSP16_Q(0.00475825),
  DSP16_Q(-0.00685180),
  DSP16_Q(0.00958568),
  DSP16_Q(-0.01321018),
  DSP16_Q(0.01819326),
  DSP16_Q(-0.02552191),
  DSP16_Q(0.03767716),
  DSP16_Q(-0.06308690),
  DSP16_Q(0.15978239),
  DSP16_Q(0.34310499),
  DSP16_Q(-0.08141958),
  DSP16_Q(0.04446938),
  DSP16_Q(-0.02915039),
  DSP16_Q(0.02050050),
  DSP16_Q(-0.01482539),
  DSP16_Q(0.01077964),
  DSP16_Q(-0.00775949),
  DSP16_Q(0.00545457),
  DSP16_Q(-0.00368817),
  DSP16_Q(0.00235034),
  DSP16_Q(-0.00136655),
  DSP16_Q(0.00068176),
  DSP16_Q(-0.00025182),
  DSP16_Q(0.00003873),
  DSP16_Q(0.00000839),
  DSP16_Q(-0.00015254),
  DSP16_Q(0.00050172),
  DSP16_Q(-0.00109261),
  DSP16_Q(0.00196690),
  DSP16_Q(-0.00317522),
  DSP16_Q(0.00478401),
  DSP16_Q(-0.00688834),
  DSP16_Q(0.00963632),
  DSP16_Q(-0.01327972),
  DSP16_Q(0.01828934),
  DSP16_Q(-0.02565852),
  DSP16_Q(0.03788543),
  DSP16_Q(-0.06346424),
  DSP16_Q(0.16104914),
  DSP16_Q(0.34222137),
  DSP16_Q(-0.08164340),
  DSP16_Q(0.04462236),
  DSP16_Q(-0.02925769),
  DSP16_Q(0.02057801),
  DSP16_Q(-0.01488194),
  DSP16_Q(0.01082068),
  DSP16_Q(-0.00778874),
  DSP16_Q(0.00547475),
  DSP16_Q(-0.00370141),
  DSP16_Q(0.00235839),
  DSP16_Q(-0.00137087),
  DSP16_Q(0.00068360),
  DSP16_Q(-0.00025224),
  DSP16_Q(0.00003864),
  DSP16_Q(0.00000855),
  DSP16_Q(-0.00015377),
  DSP16_Q(0.00050502),
  DSP16_Q(-0.00109914),
  DSP16_Q(0.00197804),
  DSP16_Q(-0.00319258),
  DSP16_Q(0.00480958),
  DSP16_Q(-0.00692458),
  DSP16_Q(0.00968654),
  DSP16_Q(-0.01334867),
  DSP16_Q(0.01838463),
  DSP16_Q(-0.02579404),
  DSP16_Q(0.03809217),
  DSP16_Q(-0.06383941),
  DSP16_Q(0.16231621),
  DSP16_Q(0.34133283),
  DSP16_Q(-0.08186226),
  DSP16_Q(0.04477273),
  DSP16_Q(-0.02936332),
  DSP16_Q(0.02065435),
  DSP16_Q(-0.01493765),
  DSP16_Q(0.01086112),
  DSP16_Q(-0.00781754),
  DSP16_Q(0.00549461),
  DSP16_Q(-0.00371444),
  DSP16_Q(0.00236630),
  DSP16_Q(-0.00137511),
  DSP16_Q(0.00068540),
  DSP16_Q(-0.00025265),
  DSP16_Q(0.00003854),
  DSP16_Q(0.00000871),
  DSP16_Q(-0.00015500),
  DSP16_Q(0.00050830),
  DSP16_Q(-0.00110563),
  DSP16_Q(0.00198910),
  DSP16_Q(-0.00320982),
  DSP16_Q(0.00483494),
  DSP16_Q(-0.00696051),
  DSP16_Q(0.00973633),
  DSP16_Q(-0.01341704),
  DSP16_Q(0.01847912),
  DSP16_Q(-0.02592845),
  DSP16_Q(0.03829736),
  DSP16_Q(-0.06421240),
  DSP16_Q(0.16358356),
  DSP16_Q(0.34043938),
  DSP16_Q(-0.08207617),
  DSP16_Q(0.04492048),
  DSP16_Q(-0.02946726),
  DSP16_Q(0.02072952),
  DSP16_Q(-0.01499251),
  DSP16_Q(0.01090093),
  DSP16_Q(-0.00784590),
  DSP16_Q(0.00551416),
  DSP16_Q(-0.00372724),
  DSP16_Q(0.00237406),
  DSP16_Q(-0.00137926),
  DSP16_Q(0.00068715),
  DSP16_Q(-0.00025304),
  DSP16_Q(0.00003845),
  DSP16_Q(0.00000887),
  DSP16_Q(-0.00015623),
  DSP16_Q(0.00051157),
  DSP16_Q(-0.00111209),
  DSP16_Q(0.00200009),
  DSP16_Q(-0.00322692),
  DSP16_Q(0.00486009),
  DSP16_Q(-0.00699615),
  DSP16_Q(0.00978569),
  DSP16_Q(-0.01348482),
  DSP16_Q(0.01857280),
  DSP16_Q(-0.02606176),
  DSP16_Q(0.03850100),
  DSP16_Q(-0.06458318),
  DSP16_Q(0.16485116),
  DSP16_Q(0.33954106),
  DSP16_Q(-0.08228513),
  DSP16_Q(0.04506562),
  DSP16_Q(-0.02956953),
  DSP16_Q(0.02080351),
  DSP16_Q(-0.01504653),
  DSP16_Q(0.01094013),
  DSP16_Q(-0.00787381),
  DSP16_Q(0.00553338),
  DSP16_Q(-0.00373984),
  DSP16_Q(0.00238169),
  DSP16_Q(-0.00138333),
  DSP16_Q(0.00068886),
  DSP16_Q(-0.00025341),
  DSP16_Q(0.00003835),
  DSP16_Q(0.00000904),
  DSP16_Q(-0.00015745),
  DSP16_Q(0.00051482),
  DSP16_Q(-0.00111850),
  DSP16_Q(0.00201099),
  DSP16_Q(-0.00324389),
  DSP16_Q(0.00488503),
  DSP16_Q(-0.00703148),
  DSP16_Q(0.00983463),
  DSP16_Q(-0.01355201),
  DSP16_Q(0.01866567),
  DSP16_Q(-0.02619394),
  DSP16_Q(0.03870307),
  DSP16_Q(-0.06495172),
  DSP16_Q(0.16611897),
  DSP16_Q(0.33863788),
  DSP16_Q(-0.08248915),
  DSP16_Q(0.04520814),
  DSP16_Q(-0.02967010),
  DSP16_Q(0.02087633),
  DSP16_Q(-0.01509970),
  DSP16_Q(0.01097871),
  DSP16_Q(-0.00790127),
  DSP16_Q(0.00555229),
  DSP16_Q(-0.00375221),
  DSP16_Q(0.00238917),
  DSP16_Q(-0.00138731),
  DSP16_Q(0.00069052),
  DSP16_Q(-0.00025376),
  DSP16_Q(0.00003825),
  DSP16_Q(0.00000920),
  DSP16_Q(-0.00015867),
  DSP16_Q(0.00051806),
  DSP16_Q(-0.00112488),
  DSP16_Q(0.00202181),
  DSP16_Q(-0.00326073),
  DSP16_Q(0.00490977),
  DSP16_Q(-0.00706650),
  DSP16_Q(0.00988313),
  DSP16_Q(-0.01361860),
  DSP16_Q(0.01875772),
  DSP16_Q(-0.02632500),
  DSP16_Q(0.03890356),
  DSP16_Q(-0.06531800),
  DSP16_Q(0.16738696),
  DSP16_Q(0.33772988),
  DSP16_Q(-0.08268824),
  DSP16_Q(0.04534804),
  DSP16_Q(-0.02976899),
  DSP16_Q(0.02094797),
  DSP16_Q(-0.01515202),
  DSP16_Q(0.01101668),
  DSP16_Q(-0.00792828),
  DSP16_Q(0.00557089),
  DSP16_Q(-0.00376436),
  DSP16_Q(0.00239652),
  DSP16_Q(-0.00139121),
  DSP16_Q(0.00069214),
  DSP16_Q(-0.00025410),
  DSP16_Q(0.00003814),
  DSP16_Q(0.00000937),
  DSP16_Q(-0.00015989),
  DSP16_Q(0.00052128),
  DSP16_Q(-0.00113121),
  DSP16_Q(0.00203256),
  DSP16_Q(-0.00327743),
  DSP16_Q(0.00493429),
  DSP16_Q(-0.00710122),
  DSP16_Q(0.00993120),
  DSP16_Q(-0.01368458),
  DSP16_Q(0.01884894),
  DSP16_Q(-0.02645493),
  DSP16_Q(0.03910246),
  DSP16_Q(-0.06568200),
  DSP16_Q(0.16865510),
  DSP16_Q(0.33681709),
  DSP16_Q(-0.08288242),
  DSP16_Q(0.04548532),
  DSP16_Q(-0.02986619),
  DSP16_Q(0.02101843),
  DSP16_Q(-0.01520348),
  DSP16_Q(0.01105402),
  DSP16_Q(-0.00795485),
  DSP16_Q(0.00558916),
  DSP16_Q(-0.00377630),
  DSP16_Q(0.00240372),
  DSP16_Q(-0.00139502),
  DSP16_Q(0.00069371),
  DSP16_Q(-0.00025441),
  DSP16_Q(0.00003803),
  DSP16_Q(0.00000954),
  DSP16_Q(-0.00016111),
  DSP16_Q(0.00052449),
  DSP16_Q(-0.00113750),
  DSP16_Q(0.00204322),
  DSP16_Q(-0.00329399),
  DSP16_Q(0.00495860),
  DSP16_Q(-0.00713562),
  DSP16_Q(0.00997882),
  DSP16_Q(-0.01374996),
  DSP16_Q(0.01893933),
  DSP16_Q(-0.02658371),
  DSP16_Q(0.03929975),
  DSP16_Q(-0.06604369),
  DSP16_Q(0.16992334),
  DSP16_Q(0.33589953),
  DSP16_Q(-0.08307168),
  DSP16_Q(0.04561998),
  DSP16_Q(-0.02996170),
  DSP16_Q(0.02108771),
  DSP16_Q(-0.01525410),
  DSP16_Q(0.01109074),
  DSP16_Q(-0.00798096),
  DSP16_Q(0.00560711),
  DSP16_Q(-0.00378801),
  DSP16_Q(0.00241078),
  DSP16_Q(-0.00139875),
  DSP16_Q(0.00069524),
  DSP16_Q(-0.00025471),
  DSP16_Q(0.00003792),
  DSP16_Q(0.00000971),
  DSP16_Q(-0.00016233),
  DSP16_Q(0.00052767),
  DSP16_Q(-0.00114374),
  DSP16_Q(0.00205380),
  DSP16_Q(-0.00331041),
  DSP16_Q(0.00498270),
  DSP16_Q(-0.00716971),
  DSP16_Q(0.01002601),
  DSP16_Q(-0.01381472),
  DSP16_Q(0.01902888),
  DSP16_Q(-0.02671134),
  DSP16_Q(0.03949541),
  DSP16_Q(-0.06640305),
  DSP16_Q(0.17119167),
  DSP16_Q(0.33497723),
  DSP16_Q(-0.08325604),
  DSP16_Q(0.04575202),
  DSP16_Q(-0.03005551),
  DSP16_Q(0.02115581),
  DSP16_Q(-0.01530386),
  DSP16_Q(0.01112683),
  DSP16_Q(-0.00800663),
  DSP16_Q(0.00562475),
  DSP16_Q(-0.00379951),
  DSP16_Q(0.00241769),
  DSP16_Q(-0.00140240),
  DSP16_Q(0.00069673),
  DSP16_Q(-0.00025499),
  DSP16_Q(0.00003781),
  DSP16_Q(0.00000988),
  DSP16_Q(-0.00016354),
  DSP16_Q(0.00053084),
  DSP16_Q(-0.00114995),
  DSP16_Q(0.00206429),
  DSP16_Q(-0.00332669),
  DSP16_Q(0.00500658),
  DSP16_Q(-0.00720349),
  DSP16_Q(0.01007275),
  DSP16_Q(-0.01387888),
  DSP16_Q(0.01911760),
  DSP16_Q(-0.02683781),
  DSP16_Q(0.03968944),
  DSP16_Q(-0.06676006),
  DSP16_Q(0.17246003),
  DSP16_Q(0.33405022),
  DSP16_Q(-0.08343550),
  DSP16_Q(0.04588143),
  DSP16_Q(-0.03014763),
  DSP16_Q(0.02122272),
  DSP16_Q(-0.01535276),
  DSP16_Q(0.01116231),
  DSP16_Q(-0.00803184),
  DSP16_Q(0.00564206),
  DSP16_Q(-0.00381079),
  DSP16_Q(0.00242447),
  DSP16_Q(-0.00140595),
  DSP16_Q(0.00069817),
  DSP16_Q(-0.00025526),
  DSP16_Q(0.00003769),
  DSP16_Q(0.00001005),
  DSP16_Q(-0.00016475),
  DSP16_Q(0.00053400),
  DSP16_Q(-0.00115611),
  DSP16_Q(0.00207471),
  DSP16_Q(-0.00334283),
  DSP16_Q(0.00503025),
  DSP16_Q(-0.00723694),
  DSP16_Q(0.01011904),
  DSP16_Q(-0.01394241),
  DSP16_Q(0.01920546),
  DSP16_Q(-0.02696311),
  DSP16_Q(0.03988183),
  DSP16_Q(-0.06711468),
  DSP16_Q(0.17372839),
  DSP16_Q(0.33311853),
  DSP16_Q(-0.08361008),
  DSP16_Q(0.04600822),
  DSP16_Q(-0.03023805),
  DSP16_Q(0.02128845),
  DSP16_Q(-0.01540081),
  DSP16_Q(0.01119716),
  DSP16_Q(-0.00805660),
  DSP16_Q(0.00565906),
  DSP16_Q(-0.00382185),
  DSP16_Q(0.00243110),
  DSP16_Q(-0.00140943),
  DSP16_Q(0.00069957),
  DSP16_Q(-0.00025551),
  DSP16_Q(0.00003757),
  DSP16_Q(0.00001022),
  DSP16_Q(-0.00016596),
  DSP16_Q(0.00053713),
  DSP16_Q(-0.00116222),
  DSP16_Q(0.00208503),
  DSP16_Q(-0.00335883),
  DSP16_Q(0.00505369),
  DSP16_Q(-0.00727008),
  DSP16_Q(0.01016487),
  DSP16_Q(-0.01400532),
  DSP16_Q(0.01929247),
  DSP16_Q(-0.02708723),
  DSP16_Q(0.04007255),
  DSP16_Q(-0.06746691),
  DSP16_Q(0.17499673),
  DSP16_Q(0.33218218),
  DSP16_Q(-0.08377978),
  DSP16_Q(0.04613239),
  DSP16_Q(-0.03032677),
  DSP16_Q(0.02135299),
  DSP16_Q(-0.01544800),
  DSP16_Q(0.01123138),
  DSP16_Q(-0.00808091),
  DSP16_Q(0.00567573),
  DSP16_Q(-0.00383269),
  DSP16_Q(0.00243759),
  DSP16_Q(-0.00141282),
  DSP16_Q(0.00070092),
  DSP16_Q(-0.00025574),
  DSP16_Q(0.00003745),
  DSP16_Q(0.00001040),
  DSP16_Q(-0.00016716),
  DSP16_Q(0.00054025),
  DSP16_Q(-0.00116829),
  DSP16_Q(0.00209527),
  DSP16_Q(-0.00337468),
  DSP16_Q(0.00507691),
  DSP16_Q(-0.00730289),
  DSP16_Q(0.01021026),
  DSP16_Q(-0.01406760),
  DSP16_Q(0.01937862),
  DSP16_Q(-0.02721017),
  DSP16_Q(0.04026161),
  DSP16_Q(-0.06781670),
  DSP16_Q(0.17626500),
  DSP16_Q(0.33124120),
  DSP16_Q(-0.08394462),
  DSP16_Q(0.04625393),
  DSP16_Q(-0.03041379),
  DSP16_Q(0.02141633),
  DSP16_Q(-0.01549433),
  DSP16_Q(0.01126498),
  DSP16_Q(-0.00810477),
  DSP16_Q(0.00569208),
  DSP16_Q(-0.00384332),
  DSP16_Q(0.00244394),
  DSP16_Q(-0.00141612),
  DSP16_Q(0.00070223),
  DSP16_Q(-0.00025595),
  DSP16_Q(0.00003732),
  DSP16_Q(0.00001057),
  DSP16_Q(-0.00016836),
  DSP16_Q(0.00054335),
  DSP16_Q(-0.00117432),
  DSP16_Q(0.00210543),
  DSP16_Q(-0.00339039),
  DSP16_Q(0.00509991),
  DSP16_Q(-0.00733538),
  DSP16_Q(0.01025518),
  DSP16_Q(-0.01412924),
  DSP16_Q(0.01946390),
  DSP16_Q(-0.02733192),
  DSP16_Q(0.04044897),
  DSP16_Q(-0.06816404),
  DSP16_Q(0.17753317),
  DSP16_Q(0.33029562),
  DSP16_Q(-0.08410459),
  DSP16_Q(0.04637285),
  DSP16_Q(-0.03049911),
  DSP16_Q(0.02147849),
  DSP16_Q(-0.01553980),
  DSP16_Q(0.01129795),
  DSP16_Q(-0.00812817),
  DSP16_Q(0.00570812),
  DSP16_Q(-0.00385372),
  DSP16_Q(0.00245014),
  DSP16_Q(-0.00141934),
  DSP16_Q(0.00070350),
  DSP16_Q(-0.00025614),
  DSP16_Q(0.00003719),
  DSP16_Q(0.00001075),
  DSP16_Q(-0.00016956),
  DSP16_Q(0.00054644),
  DSP16_Q(-0.00118030),
  DSP16_Q(0.00211550),
  DSP16_Q(-0.00340596),
  DSP16_Q(0.00512269),
  DSP16_Q(-0.00736754),
  DSP16_Q(0.01029965),
  DSP16_Q(-0.01419026),
  DSP16_Q(0.01954832),
  DSP16_Q(-0.02745246),
  DSP16_Q(0.04063464),
  DSP16_Q(-0.06850891),
  DSP16_Q(0.17880120),
  DSP16_Q(0.32934547),
  DSP16_Q(-0.08425972),
  DSP16_Q(0.04648914),
  DSP16_Q(-0.03058273),
  DSP16_Q(0.02153946),
  DSP16_Q(-0.01558441),
  DSP16_Q(0.01133030),
  DSP16_Q(-0.00815112),
  DSP16_Q(0.00572383),
  DSP16_Q(-0.00386390),
  DSP16_Q(0.00245621),
  DSP16_Q(-0.00142248),
  DSP16_Q(0.00070472),
  DSP16_Q(-0.00025632),
  DSP16_Q(0.00003706),
  DSP16_Q(0.00001093),
  DSP16_Q(-0.00017075),
  DSP16_Q(0.00054950),
  DSP16_Q(-0.00118624),
  DSP16_Q(0.00212548),
  DSP16_Q(-0.00342137),
  DSP16_Q(0.00514524),
  DSP16_Q(-0.00739937),
  DSP16_Q(0.01034365),
  DSP16_Q(-0.01425063),
  DSP16_Q(0.01963185),
  DSP16_Q(-0.02757180),
  DSP16_Q(0.04081860),
  DSP16_Q(-0.06885129),
  DSP16_Q(0.18006907),
  DSP16_Q(0.32839078),
  DSP16_Q(-0.08441002),
  DSP16_Q(0.04660281),
  DSP16_Q(-0.03066464),
  DSP16_Q(0.02159923),
  DSP16_Q(-0.01562816),
  DSP16_Q(0.01136201),
  DSP16_Q(-0.00817361),
  DSP16_Q(0.00573921),
  DSP16_Q(-0.00387386),
  DSP16_Q(0.00246213),
  DSP16_Q(-0.00142553),
  DSP16_Q(0.00070590),
  DSP16_Q(-0.00025648),
  DSP16_Q(0.00003692),
  DSP16_Q(0.00001111),
  DSP16_Q(-0.00017195),
  DSP16_Q(0.00055255),
  DSP16_Q(-0.00119213),
  DSP16_Q(0.00213537),
  DSP16_Q(-0.00343664),
  DSP16_Q(0.00516757),
  DSP16_Q(-0.00743087),
  DSP16_Q(0.01038718),
  DSP16_Q(-0.01431036),
  DSP16_Q(0.01971451),
  DSP16_Q(-0.02768991),
  DSP16_Q(0.04100084),
  DSP16_Q(-0.06919114),
  DSP16_Q(0.18133673),
  DSP16_Q(0.32743158),
  DSP16_Q(-0.08455548),
  DSP16_Q(0.04671385),
  DSP16_Q(-0.03074484),
  DSP16_Q(0.02165781),
  DSP16_Q(-0.01567104),
  DSP16_Q(0.01139310),
  DSP16_Q(-0.00819565),
  DSP16_Q(0.00575428),
  DSP16_Q(-0.00388360),
  DSP16_Q(0.00246791),
  DSP16_Q(-0.00142849),
  DSP16_Q(0.00070703),
  DSP16_Q(-0.00025662),
  DSP16_Q(0.00003678),
  DSP16_Q(0.00001129),
  DSP16_Q(-0.00017313),
  DSP16_Q(0.00055558),
  DSP16_Q(-0.00119797),
  DSP16_Q(0.00214517),
  DSP16_Q(-0.00345177),
  DSP16_Q(0.00518966),
  DSP16_Q(-0.00746204),
  DSP16_Q(0.01043025),
  DSP16_Q(-0.01436944),
  DSP16_Q(0.01979627),
  DSP16_Q(-0.02780681),
  DSP16_Q(0.04118134),
  DSP16_Q(-0.06952844),
  DSP16_Q(0.18260414),
  DSP16_Q(0.32646789),
  DSP16_Q(-0.08469613),
  DSP16_Q(0.04682226),
  DSP16_Q(-0.03082334),
  DSP16_Q(0.02171519),
  DSP16_Q(-0.01571306),
  DSP16_Q(0.01142356),
  DSP16_Q(-0.00821724),
  DSP16_Q(0.00576903),
  DSP16_Q(-0.00389313),
  DSP16_Q(0.00247354),
  DSP16_Q(-0.00143137),
  DSP16_Q(0.00070813),
  DSP16_Q(-0.00025675),
  DSP16_Q(0.00003664),
  DSP16_Q(0.00001148),
  DSP16_Q(-0.00017432),
  DSP16_Q(0.00055858),
  DSP16_Q(-0.00120377),
  DSP16_Q(0.00215489),
  DSP16_Q(-0.00346674),
  DSP16_Q(0.00521153),
  DSP16_Q(-0.00749287),
  DSP16_Q(0.01047284),
  DSP16_Q(-0.01442786),
  DSP16_Q(0.01987715),
  DSP16_Q(-0.02792247),
  DSP16_Q(0.04136009),
  DSP16_Q(-0.06986318),
  DSP16_Q(0.18387128),
  DSP16_Q(0.32549975),
  DSP16_Q(-0.08483197),
  DSP16_Q(0.04692806),
  DSP16_Q(-0.03090013),
  DSP16_Q(0.02177137),
  DSP16_Q(-0.01575421),
  DSP16_Q(0.01145338),
  DSP16_Q(-0.00823837),
  DSP16_Q(0.00578345),
  DSP16_Q(-0.00390243),
  DSP16_Q(0.00247904),
  DSP16_Q(-0.00143417),
  DSP16_Q(0.00070917),
  DSP16_Q(-0.00025686),
  DSP16_Q(0.00003650),
  DSP16_Q(0.00001166),
  DSP16_Q(-0.00017550),
  DSP16_Q(0.00056157),
  DSP16_Q(-0.00120951),
  DSP16_Q(0.00216451),
  DSP16_Q(-0.00348156),
  DSP16_Q(0.00523316),
  DSP16_Q(-0.00752337),
  DSP16_Q(0.01051495),
  DSP16_Q(-0.01448563),
  DSP16_Q(0.01995712),
  DSP16_Q(-0.02803688),
  DSP16_Q(0.04153708),
  DSP16_Q(-0.07019533),
  DSP16_Q(0.18513811),
  DSP16_Q(0.32452718),
  DSP16_Q(-0.08496301),
  DSP16_Q(0.04703122),
  DSP16_Q(-0.03097521),
  DSP16_Q(0.02182636),
  DSP16_Q(-0.01579450),
  DSP16_Q(0.01148258),
  DSP16_Q(-0.00825904),
  DSP16_Q(0.00579755),
  DSP16_Q(-0.00391151),
  DSP16_Q(0.00248439),
  DSP16_Q(-0.00143688),
  DSP16_Q(0.00071018),
  DSP16_Q(-0.00025695),
  DSP16_Q(0.00003636),
  DSP16_Q(0.00001185),
  DSP16_Q(-0.00017668),
  DSP16_Q(0.00056454),
  DSP16_Q(-0.00121521),
  DSP16_Q(0.00217404),
  DSP16_Q(-0.00349623),
  DSP16_Q(0.00525456),
  DSP16_Q(-0.00755352),
  DSP16_Q(0.01055659),
  DSP16_Q(-0.01454275),
  DSP16_Q(0.02003619),
  DSP16_Q(-0.02815005),
  DSP16_Q(0.04171230),
  DSP16_Q(-0.07052486),
  DSP16_Q(0.18640460),
  DSP16_Q(0.32355021),
  DSP16_Q(-0.08508926),
  DSP16_Q(0.04713177),
  DSP16_Q(-0.03104858),
  DSP16_Q(0.02188015),
  DSP16_Q(-0.01583392),
  DSP16_Q(0.01151114),
  DSP16_Q(-0.00827925),
  DSP16_Q(0.00581132),
  DSP16_Q(-0.00392037),
  DSP16_Q(0.00248960),
  DSP16_Q(-0.00143951),
  DSP16_Q(0.00071114),
  DSP16_Q(-0.00025703),
  DSP16_Q(0.00003621),
  DSP16_Q(0.00001204),
  DSP16_Q(-0.00017785),
  DSP16_Q(0.00056749),
  DSP16_Q(-0.00122086),
  DSP16_Q(0.00218348),
  DSP16_Q(-0.00351074),
  DSP16_Q(0.00527572),
  DSP16_Q(-0.00758333),
  DSP16_Q(0.01059775),
  DSP16_Q(-0.01459919),
  DSP16_Q(0.02011435),
  DSP16_Q(-0.02826196),
  DSP16_Q(0.04188573),
  DSP16_Q(-0.07085175),
  DSP16_Q(0.18767070),
  DSP16_Q(0.32256887),
  DSP16_Q(-0.08521074),
  DSP16_Q(0.04722969),
  DSP16_Q(-0.03112024),
  DSP16_Q(0.02193273),
  DSP16_Q(-0.01587247),
  DSP16_Q(0.01153907),
  DSP16_Q(-0.00829901),
  DSP16_Q(0.00582478),
  DSP16_Q(-0.00392901),
  DSP16_Q(0.00249467),
  DSP16_Q(-0.00144206),
  DSP16_Q(0.00071206),
  DSP16_Q(-0.00025709),
  DSP16_Q(0.00003606),
  DSP16_Q(0.00001222),
  DSP16_Q(-0.00017902),
  DSP16_Q(0.00057042),
  DSP16_Q(-0.00122647),
  DSP16_Q(0.00219282),
  DSP16_Q(-0.00352510),
  DSP16_Q(0.00529665),
  DSP16_Q(-0.00761280),
  DSP16_Q(0.01063842),
  DSP16_Q(-0.01465498),
  DSP16_Q(0.02019160),
  DSP16_Q(-0.02837261),
  DSP16_Q(0.04205737),
  DSP16_Q(-0.07117598),
  DSP16_Q(0.18893638),
  DSP16_Q(0.32158320),
  DSP16_Q(-0.08532746),
  DSP16_Q(0.04732498),
  DSP16_Q(-0.03119019),
  DSP16_Q(0.02198412),
  DSP16_Q(-0.01591016),
  DSP16_Q(0.01156637),
  DSP16_Q(-0.00831831),
  DSP16_Q(0.00583790),
  DSP16_Q(-0.00393743),
  DSP16_Q(0.00249959),
  DSP16_Q(-0.00144452),
  DSP16_Q(0.00071293),
  DSP16_Q(-0.00025713),
  DSP16_Q(0.00003590),
  DSP16_Q(0.00001241),
  DSP16_Q(-0.00018018),
  DSP16_Q(0.00057333),
  DSP16_Q(-0.00123202),
  DSP16_Q(0.00220207),
  DSP16_Q(-0.00353931),
  DSP16_Q(0.00531734),
  DSP16_Q(-0.00764192),
  DSP16_Q(0.01067861),
  DSP16_Q(-0.01471008),
  DSP16_Q(0.02026792),
  DSP16_Q(-0.02848199),
  DSP16_Q(0.04222719),
  DSP16_Q(-0.07149752),
  DSP16_Q(0.19020161),
  DSP16_Q(0.32059322),
  DSP16_Q(-0.08543942),
  DSP16_Q(0.04741766),
  DSP16_Q(-0.03125842),
  DSP16_Q(0.02203430),
  DSP16_Q(-0.01594697),
  DSP16_Q(0.01159304),
  DSP16_Q(-0.00833716),
  DSP16_Q(0.00585071),
  DSP16_Q(-0.00394563),
  DSP16_Q(0.00250438),
  DSP16_Q(-0.00144689),
  DSP16_Q(0.00071377),
  DSP16_Q(-0.00025716),
  DSP16_Q(0.00003575),
  DSP16_Q(0.00001260),
  DSP16_Q(-0.00018134),
  DSP16_Q(0.00057622),
  DSP16_Q(-0.00123752),
  DSP16_Q(0.00221123),
  DSP16_Q(-0.00355336),
  DSP16_Q(0.00533779),
  DSP16_Q(-0.00767070),
  DSP16_Q(0.01071830),
  DSP16_Q(-0.01476452),
  DSP16_Q(0.02034332),
  DSP16_Q(-0.02859008),
  DSP16_Q(0.04239519),
  DSP16_Q(-0.07181635),
  DSP16_Q(0.19146635),
  DSP16_Q(0.31959895),
  DSP16_Q(-0.08554664),
  DSP16_Q(0.04750772),
  DSP16_Q(-0.03132494),
  DSP16_Q(0.02208329),
  DSP16_Q(-0.01598292),
  DSP16_Q(0.01161907),
  DSP16_Q(-0.00835555),
  DSP16_Q(0.00586319),
  DSP16_Q(-0.00395361),
  DSP16_Q(0.00250902),
  DSP16_Q(-0.00144919),
  DSP16_Q(0.00071456),
  DSP16_Q(-0.00025717),
  DSP16_Q(0.00003559),
  DSP16_Q(0.00001280),
  DSP16_Q(-0.00018250),
  DSP16_Q(0.00057908),
  DSP16_Q(-0.00124297),
  DSP16_Q(0.00222029),
  DSP16_Q(-0.00356725),
  DSP16_Q(0.00535800),
  DSP16_Q(-0.00769912),
  DSP16_Q(0.01075751),
  DSP16_Q(-0.01481827),
  DSP16_Q(0.02041779),
  DSP16_Q(-0.02869689),
  DSP16_Q(0.04256136),
  DSP16_Q(-0.07213246),
  DSP16_Q(0.19273057),
  DSP16_Q(0.31860044),
  DSP16_Q(-0.08564912),
  DSP16_Q(0.04759515),
  DSP16_Q(-0.03138975),
  DSP16_Q(0.02213106),
  DSP16_Q(-0.01601799),
  DSP16_Q(0.01164447),
  DSP16_Q(-0.00837347),
  DSP16_Q(0.00587535),
  DSP16_Q(-0.00396137),
  DSP16_Q(0.00251352),
  DSP16_Q(-0.00145139),
  DSP16_Q(0.00071530),
  DSP16_Q(-0.00025716),
  DSP16_Q(0.00003543),
  DSP16_Q(0.00001299),
  DSP16_Q(-0.00018365),
  DSP16_Q(0.00058193),
  DSP16_Q(-0.00124837),
  DSP16_Q(0.00222926),
  DSP16_Q(-0.00358098),
  DSP16_Q(0.00537797),
  DSP16_Q(-0.00772719),
  DSP16_Q(0.01079622),
  DSP16_Q(-0.01487135),
  DSP16_Q(0.02049133),
  DSP16_Q(-0.02880241),
  DSP16_Q(0.04272569),
  DSP16_Q(-0.07244581),
  DSP16_Q(0.19399423),
  DSP16_Q(0.31759771),
  DSP16_Q(-0.08574689),
  DSP16_Q(0.04767997),
  DSP16_Q(-0.03145285),
  DSP16_Q(0.02217764),
  DSP16_Q(-0.01605220),
  DSP16_Q(0.01166923),
  DSP16_Q(-0.00839094),
  DSP16_Q(0.00588719),
  DSP16_Q(-0.00396891),
  DSP16_Q(0.00251788),
  DSP16_Q(-0.00145352),
  DSP16_Q(0.00071601),
  DSP16_Q(-0.00025714),
  DSP16_Q(0.00003527),
  DSP16_Q(0.00001319),
  DSP16_Q(-0.00018480),
  DSP16_Q(0.00058475),
  DSP16_Q(-0.00125372),
  DSP16_Q(0.00223813),
  DSP16_Q(-0.00359456),
  DSP16_Q(0.00539769),
  DSP16_Q(-0.00775491),
  DSP16_Q(0.01083443),
  DSP16_Q(-0.01492373),
  DSP16_Q(0.02056392),
  DSP16_Q(-0.02890662),
  DSP16_Q(0.04288816),
  DSP16_Q(-0.07275638),
  DSP16_Q(0.19525730),
  DSP16_Q(0.31659079),
  DSP16_Q(-0.08583995),
  DSP16_Q(0.04776218),
  DSP16_Q(-0.03151423),
  DSP16_Q(0.02222301),
  DSP16_Q(-0.01608553),
  DSP16_Q(0.01169336),
  DSP16_Q(-0.00840796),
  DSP16_Q(0.00589870),
  DSP16_Q(-0.00397623),
  DSP16_Q(0.00252210),
  DSP16_Q(-0.00145556),
  DSP16_Q(0.00071667),
  DSP16_Q(-0.00025710),
  DSP16_Q(0.00003510),
  DSP16_Q(0.00001338),
  DSP16_Q(-0.00018594),
  DSP16_Q(0.00058756),
  DSP16_Q(-0.00125902),
  DSP16_Q(0.00224691),
  DSP16_Q(-0.00360797),
  DSP16_Q(0.00541717),
  DSP16_Q(-0.00778227),
  DSP16_Q(0.01087214),
  DSP16_Q(-0.01497543),
  DSP16_Q(0.02063557),
  DSP16_Q(-0.02900952),
  DSP16_Q(0.04304875),
  DSP16_Q(-0.07306414),
  DSP16_Q(0.19651974),
  DSP16_Q(0.31557971),
  DSP16_Q(-0.08592831),
  DSP16_Q(0.04784176),
  DSP16_Q(-0.03157390),
  DSP16_Q(0.02226718),
  DSP16_Q(-0.01611799),
  DSP16_Q(0.01171685),
  DSP16_Q(-0.00842451),
  DSP16_Q(0.00590989),
  DSP16_Q(-0.00398333),
  DSP16_Q(0.00252617),
  DSP16_Q(-0.00145752),
  DSP16_Q(0.00071729),
  DSP16_Q(-0.00025705),
  DSP16_Q(0.00003493),
  DSP16_Q(0.00001358),
  DSP16_Q(-0.00018708),
  DSP16_Q(0.00059034),
  DSP16_Q(-0.00126427),
  DSP16_Q(0.00225558),
  DSP16_Q(-0.00362123),
  DSP16_Q(0.00543640),
  DSP16_Q(-0.00780927),
  DSP16_Q(0.01090934),
  DSP16_Q(-0.01502643),
  DSP16_Q(0.02070626),
  DSP16_Q(-0.02911110),
  DSP16_Q(0.04320747),
  DSP16_Q(-0.07336909),
  DSP16_Q(0.19778151),
  DSP16_Q(0.31456451),
  DSP16_Q(-0.08601199),
  DSP16_Q(0.04791874),
  DSP16_Q(-0.03163185),
  DSP16_Q(0.02231014),
  DSP16_Q(-0.01614958),
  DSP16_Q(0.01173971),
  DSP16_Q(-0.00844060),
  DSP16_Q(0.00592075),
  DSP16_Q(-0.00399021),
  DSP16_Q(0.00253010),
  DSP16_Q(-0.00145939),
  DSP16_Q(0.00071787),
  DSP16_Q(-0.00025697),
  DSP16_Q(0.00003476),
  DSP16_Q(0.00001378),
  DSP16_Q(-0.00018821),
  DSP16_Q(0.00059309),
  DSP16_Q(-0.00126946),
  DSP16_Q(0.00226416),
  DSP16_Q(-0.00363431),
  DSP16_Q(0.00545539),
  DSP16_Q(-0.00783591),
  DSP16_Q(0.01094605),
  DSP16_Q(-0.01507673),
  DSP16_Q(0.02077600),
  DSP16_Q(-0.02921136),
  DSP16_Q(0.04336429),
  DSP16_Q(-0.07367119),
  DSP16_Q(0.19904258),
  DSP16_Q(0.31354520),
  DSP16_Q(-0.08609100),
  DSP16_Q(0.04799310),
  DSP16_Q(-0.03168809),
  DSP16_Q(0.02235189),
  DSP16_Q(-0.01618030),
  DSP16_Q(0.01176193),
  DSP16_Q(-0.00845624),
  DSP16_Q(0.00593129),
  DSP16_Q(-0.00399686),
  DSP16_Q(0.00253389),
  DSP16_Q(-0.00146119),
  DSP16_Q(0.00071840),
  DSP16_Q(-0.00025689),
  DSP16_Q(0.00003459),
  DSP16_Q(0.00001398),
  DSP16_Q(-0.00018934),
  DSP16_Q(0.00059583),
  DSP16_Q(-0.00127460),
  DSP16_Q(0.00227264),
  DSP16_Q(-0.00364724),
  DSP16_Q(0.00547412),
  DSP16_Q(-0.00786219),
  DSP16_Q(0.01098224),
  DSP16_Q(-0.01512634),
  DSP16_Q(0.02084478),
  DSP16_Q(-0.02931029),
  DSP16_Q(0.04351921),
  DSP16_Q(-0.07397042),
  DSP16_Q(0.20030291),
  DSP16_Q(0.31252183),
  DSP16_Q(-0.08616534),
  DSP16_Q(0.04806485),
  DSP16_Q(-0.03174261),
  DSP16_Q(0.02239244),
  DSP16_Q(-0.01621014),
  DSP16_Q(0.01178352),
  DSP16_Q(-0.00847142),
  DSP16_Q(0.00594151),
  DSP16_Q(-0.00400330),
  DSP16_Q(0.00253754),
  DSP16_Q(-0.00146290),
  DSP16_Q(0.00071889),
  DSP16_Q(-0.00025679),
  DSP16_Q(0.00003442),
  DSP16_Q(0.00001418),
  DSP16_Q(-0.00019046),
  DSP16_Q(0.00059854),
  DSP16_Q(-0.00127969),
  DSP16_Q(0.00228101),
  DSP16_Q(-0.00366000),
  DSP16_Q(0.00549260),
  DSP16_Q(-0.00788811),
  DSP16_Q(0.01101792),
  DSP16_Q(-0.01517524),
  DSP16_Q(0.02091259),
  DSP16_Q(-0.02940788),
  DSP16_Q(0.04367221),
  DSP16_Q(-0.07426676),
  DSP16_Q(0.20156247),
  DSP16_Q(0.31149442),
  DSP16_Q(-0.08623504),
  DSP16_Q(0.04813400),
  DSP16_Q(-0.03179542),
  DSP16_Q(0.02243178),
  DSP16_Q(-0.01623911),
  DSP16_Q(0.01180447),
  DSP16_Q(-0.00848613),
  DSP16_Q(0.00595140),
  DSP16_Q(-0.00400952),
  DSP16_Q(0.00254105),
  DSP16_Q(-0.00146452),
  DSP16_Q(0.00071935),
  DSP16_Q(-0.00025667),
  DSP16_Q(0.00003424),
  DSP16_Q(0.00001438),
  DSP16_Q(-0.00019158),
  DSP16_Q(0.00060123),
  DSP16_Q(-0.00128472),
  DSP16_Q(0.00228929),
  DSP16_Q(-0.00367260),
  DSP16_Q(0.00551083),
  DSP16_Q(-0.00791366),
  DSP16_Q(0.01105309),
  DSP16_Q(-0.01522343),
  DSP16_Q(0.02097943),
  DSP16_Q(-0.02950413),
  DSP16_Q(0.04382329),
  DSP16_Q(-0.07456018),
  DSP16_Q(0.20282123),
  DSP16_Q(0.31046300),
  DSP16_Q(-0.08630010),
  DSP16_Q(0.04820054),
  DSP16_Q(-0.03184652),
  DSP16_Q(0.02246992),
  DSP16_Q(-0.01626720),
  DSP16_Q(0.01182479),
  DSP16_Q(-0.00850039),
  DSP16_Q(0.00596097),
  DSP16_Q(-0.00401552),
  DSP16_Q(0.00254442),
  DSP16_Q(-0.00146606),
  DSP16_Q(0.00071976),
  DSP16_Q(-0.00025654),
  DSP16_Q(0.00003407),
  DSP16_Q(0.00001458),
  DSP16_Q(-0.00019269),
  DSP16_Q(0.00060390),
  DSP16_Q(-0.00128970),
  DSP16_Q(0.00229747),
  DSP16_Q(-0.00368503),
  DSP16_Q(0.00552881),
  DSP16_Q(-0.00793884),
  DSP16_Q(0.01108774),
  DSP16_Q(-0.01527091),
  DSP16_Q(0.02104530),
  DSP16_Q(-0.02959902),
  DSP16_Q(0.04397242),
  DSP16_Q(-0.07485066),
  DSP16_Q(0.20407914),
  DSP16_Q(0.30942760),
  DSP16_Q(-0.08636055),
  DSP16_Q(0.04826448),
  DSP16_Q(-0.03189590),
  DSP16_Q(0.02250685),
  DSP16_Q(-0.01629443),
  DSP16_Q(0.01184446),
  DSP16_Q(-0.00851419),
  DSP16_Q(0.00597021),
  DSP16_Q(-0.00402129),
  DSP16_Q(0.00254765),
  DSP16_Q(-0.00146752),
  DSP16_Q(0.00072012),
  DSP16_Q(-0.00025639),
  DSP16_Q(0.00003389),
  DSP16_Q(0.00001479),
  DSP16_Q(-0.00019379),
  DSP16_Q(0.00060655),
  DSP16_Q(-0.00129462),
  DSP16_Q(0.00230554),
  DSP16_Q(-0.00369729),
  DSP16_Q(0.00554653),
  DSP16_Q(-0.00796366),
  DSP16_Q(0.01112187),
  DSP16_Q(-0.01531767),
  DSP16_Q(0.02111018),
  DSP16_Q(-0.02969255),
  DSP16_Q(0.04411961),
  DSP16_Q(-0.07513819),
  DSP16_Q(0.20533618),
  DSP16_Q(0.30838826),
  DSP16_Q(-0.08641638),
  DSP16_Q(0.04832582),
  DSP16_Q(-0.03194357),
  DSP16_Q(0.02254257),
  DSP16_Q(-0.01632078),
  DSP16_Q(0.01186351),
  DSP16_Q(-0.00852753),
  DSP16_Q(0.00597913),
  DSP16_Q(-0.00402685),
  DSP16_Q(0.00255073),
  DSP16_Q(-0.00146890),
  DSP16_Q(0.00072045),
  DSP16_Q(-0.00025622),
  DSP16_Q(0.00003370),
  DSP16_Q(0.00001499),
  DSP16_Q(-0.00019490),
  DSP16_Q(0.00060917),
  DSP16_Q(-0.00129949),
  DSP16_Q(0.00231351),
  DSP16_Q(-0.00370938),
  DSP16_Q(0.00556400),
  DSP16_Q(-0.00798810),
  DSP16_Q(0.01115548),
  DSP16_Q(-0.01536372),
  DSP16_Q(0.02117408),
  DSP16_Q(-0.02978472),
  DSP16_Q(0.04426483),
  DSP16_Q(-0.07542273),
  DSP16_Q(0.20659230),
  DSP16_Q(0.30734501),
  DSP16_Q(-0.08646761),
  DSP16_Q(0.04838456),
  DSP16_Q(-0.03198953),
  DSP16_Q(0.02257709),
  DSP16_Q(-0.01634625),
  DSP16_Q(0.01188191),
  DSP16_Q(-0.00854041),
  DSP16_Q(0.00598773),
  DSP16_Q(-0.00403219),
  DSP16_Q(0.00255368),
  DSP16_Q(-0.00147020),
  DSP16_Q(0.00072074),
  DSP16_Q(-0.00025604),
  DSP16_Q(0.00003352),
  DSP16_Q(0.00001520),
  DSP16_Q(-0.00019599),
  DSP16_Q(0.00061176),
  DSP16_Q(-0.00130431),
  DSP16_Q(0.00232138),
  DSP16_Q(-0.00372131),
  DSP16_Q(0.00558120),
  DSP16_Q(-0.00801216),
  DSP16_Q(0.01118857),
  DSP16_Q(-0.01540904),
  DSP16_Q(0.02123699),
  DSP16_Q(-0.02987551),
  DSP16_Q(0.04440809),
  DSP16_Q(-0.07570427),
  DSP16_Q(0.20784747),
  DSP16_Q(0.30629788),
  DSP16_Q(-0.08651427),
  DSP16_Q(0.04844070),
  DSP16_Q(-0.03203377),
  DSP16_Q(0.02261039),
  DSP16_Q(-0.01637085),
  DSP16_Q(0.01189968),
  DSP16_Q(-0.00855284),
  DSP16_Q(0.00599600),
  DSP16_Q(-0.00403731),
  DSP16_Q(0.00255648),
  DSP16_Q(-0.00147141),
  DSP16_Q(0.00072098),
  DSP16_Q(-0.00025585),
  DSP16_Q(0.00003334),
  DSP16_Q(0.00001540),
  DSP16_Q(-0.00019708),
  DSP16_Q(0.00061433),
  DSP16_Q(-0.00130906),
  DSP16_Q(0.00232915),
  DSP16_Q(-0.00373306),
  DSP16_Q(0.00559815),
  DSP16_Q(-0.00803586),
  DSP16_Q(0.01122113),
  DSP16_Q(-0.01545364),
  DSP16_Q(0.02129891),
  DSP16_Q(-0.02996492),
  DSP16_Q(0.04454935),
  DSP16_Q(-0.07598278),
  DSP16_Q(0.20910166),
  DSP16_Q(0.30524689),
  DSP16_Q(-0.08655635),
  DSP16_Q(0.04849425),
  DSP16_Q(-0.03207631),
  DSP16_Q(0.02264250),
  DSP16_Q(-0.01639458),
  DSP16_Q(0.01191681),
  DSP16_Q(-0.00856480),
  DSP16_Q(0.00600395),
  DSP16_Q(-0.00404221),
  DSP16_Q(0.00255915),
  DSP16_Q(-0.00147254),
  DSP16_Q(0.00072118),
  DSP16_Q(-0.00025564),
  DSP16_Q(0.00003315),
  DSP16_Q(0.00001561),
  DSP16_Q(-0.00019816),
  DSP16_Q(0.00061688),
  DSP16_Q(-0.00131376),
  DSP16_Q(0.00233681),
  DSP16_Q(-0.00374464),
  DSP16_Q(0.00561484),
  DSP16_Q(-0.00805917),
  DSP16_Q(0.01125316),
  DSP16_Q(-0.01549751),
  DSP16_Q(0.02135982),
  DSP16_Q(-0.03005294),
  DSP16_Q(0.04468863),
  DSP16_Q(-0.07625824),
  DSP16_Q(0.21035483),
  DSP16_Q(0.30419208),
  DSP16_Q(-0.08659388),
  DSP16_Q(0.04854521),
  DSP16_Q(-0.03211713),
  DSP16_Q(0.02267339),
  DSP16_Q(-0.01641744),
  DSP16_Q(0.01193331),
  DSP16_Q(-0.00857630),
  DSP16_Q(0.00601158),
  DSP16_Q(-0.00404689),
  DSP16_Q(0.00256167),
  DSP16_Q(-0.00147359),
  DSP16_Q(0.00072134),
  DSP16_Q(-0.00025541),
  DSP16_Q(0.00003296),
  DSP16_Q(0.00001582),
  DSP16_Q(-0.00019924),
  DSP16_Q(0.00061940),
  DSP16_Q(-0.00131841),
  DSP16_Q(0.00234436),
  DSP16_Q(-0.00375605),
  DSP16_Q(0.00563127),
  DSP16_Q(-0.00808211),
  DSP16_Q(0.01128467),
  DSP16_Q(-0.01554065),
  DSP16_Q(0.02141973),
  DSP16_Q(-0.03013957),
  DSP16_Q(0.04482589),
  DSP16_Q(-0.07653062),
  DSP16_Q(0.21160694),
  DSP16_Q(0.30313349),
  DSP16_Q(-0.08662686),
  DSP16_Q(0.04859358),
  DSP16_Q(-0.03215624),
  DSP16_Q(0.02270309),
  DSP16_Q(-0.01643942),
  DSP16_Q(0.01194917),
  DSP16_Q(-0.00858735),
  DSP16_Q(0.00601888),
  DSP16_Q(-0.00405135),
  DSP16_Q(0.00256406),
  DSP16_Q(-0.00147456),
  DSP16_Q(0.00072146),
  DSP16_Q(-0.00025517),
  DSP16_Q(0.00003277),
  DSP16_Q(0.00001603),
  DSP16_Q(-0.00020031),
  DSP16_Q(0.00062190),
  DSP16_Q(-0.00132299),
  DSP16_Q(0.00235181),
  DSP16_Q(-0.00376729),
  DSP16_Q(0.00564743),
  DSP16_Q(-0.00810467),
  DSP16_Q(0.01131563),
  DSP16_Q(-0.01558305),
  DSP16_Q(0.02147864),
  DSP16_Q(-0.03022480),
  DSP16_Q(0.04496115),
  DSP16_Q(-0.07679992),
  DSP16_Q(0.21285796),
  DSP16_Q(0.30207113),
  DSP16_Q(-0.08665531),
  DSP16_Q(0.04863937),
  DSP16_Q(-0.03219365),
  DSP16_Q(0.02273157),
  DSP16_Q(-0.01646052),
  DSP16_Q(0.01196439),
  DSP16_Q(-0.00859793),
  DSP16_Q(0.00602586),
  DSP16_Q(-0.00405559),
  DSP16_Q(0.00256630),
  DSP16_Q(-0.00147545),
  DSP16_Q(0.00072154),
  DSP16_Q(-0.00025492),
  DSP16_Q(0.00003258),
  DSP16_Q(0.00001624),
  DSP16_Q(-0.00020137),
  DSP16_Q(0.00062438),
  DSP16_Q(-0.00132752),
  DSP16_Q(0.00235915),
  DSP16_Q(-0.00377835),
  DSP16_Q(0.00566333),
  DSP16_Q(-0.00812684),
  DSP16_Q(0.01134607),
  DSP16_Q(-0.01562472),
  DSP16_Q(0.02153653),
  DSP16_Q(-0.03030862),
  DSP16_Q(0.04509437),
  DSP16_Q(-0.07706610),
  DSP16_Q(0.21410785),
  DSP16_Q(0.30100506),
  DSP16_Q(-0.08667925),
  DSP16_Q(0.04868258),
  DSP16_Q(-0.03222934),
  DSP16_Q(0.02275885),
  DSP16_Q(-0.01648075),
  DSP16_Q(0.01197898),
  DSP16_Q(-0.00860806),
  DSP16_Q(0.00603252),
  DSP16_Q(-0.00405961),
  DSP16_Q(0.00256841),
  DSP16_Q(-0.00147625),
  DSP16_Q(0.00072158),
  DSP16_Q(-0.00025465),
  DSP16_Q(0.00003238),
  DSP16_Q(0.00001645),
  DSP16_Q(-0.00020243),
  DSP16_Q(0.00062682),
  DSP16_Q(-0.00133199),
  DSP16_Q(0.00236639),
  DSP16_Q(-0.00378924),
  DSP16_Q(0.00567896),
  DSP16_Q(-0.00814863),
  DSP16_Q(0.01137596),
  DSP16_Q(-0.01566564),
  DSP16_Q(0.02159340),
  DSP16_Q(-0.03039102),
  DSP16_Q(0.04522555),
  DSP16_Q(-0.07732913),
  DSP16_Q(0.21535658),
  DSP16_Q(0.29993528),
  DSP16_Q(-0.08669869),
  DSP16_Q(0.04872321),
  DSP16_Q(-0.03226333),
  DSP16_Q(0.02278492),
  DSP16_Q(-0.01650011),
  DSP16_Q(0.01199293),
  DSP16_Q(-0.00861773),
  DSP16_Q(0.00603885),
  DSP16_Q(-0.00406341),
  DSP16_Q(0.00257037),
  DSP16_Q(-0.00147698),
  DSP16_Q(0.00072158),
  DSP16_Q(-0.00025437),
  DSP16_Q(0.00003219),
  DSP16_Q(0.00001666),
  DSP16_Q(-0.00020348),
  DSP16_Q(0.00062925),
  DSP16_Q(-0.00133640),
  DSP16_Q(0.00237351),
  DSP16_Q(-0.00379995),
  DSP16_Q(0.00569433),
  DSP16_Q(-0.00817003),
  DSP16_Q(0.01140531),
  DSP16_Q(-0.01570582),
  DSP16_Q(0.02164925),
  DSP16_Q(-0.03047201),
  DSP16_Q(0.04535469),
  DSP16_Q(-0.07758901),
  DSP16_Q(0.21660411),
  DSP16_Q(0.29886185),
  DSP16_Q(-0.08671364),
  DSP16_Q(0.04876127),
  DSP16_Q(-0.03229561),
  DSP16_Q(0.02280979),
  DSP16_Q(-0.01651860),
  DSP16_Q(0.01200625),
  DSP16_Q(-0.00862694),
  DSP16_Q(0.00604487),
  DSP16_Q(-0.00406700),
  DSP16_Q(0.00257220),
  DSP16_Q(-0.00147762),
  DSP16_Q(0.00072154),
  DSP16_Q(-0.00025407),
  DSP16_Q(0.00003199),
  DSP16_Q(0.00001688),
  DSP16_Q(-0.00020453),
  DSP16_Q(0.00063164),
  DSP16_Q(-0.00134075),
  DSP16_Q(0.00238053),
  DSP16_Q(-0.00381049),
  DSP16_Q(0.00570942),
  DSP16_Q(-0.00819105),
  DSP16_Q(0.01143412),
  DSP16_Q(-0.01574525),
  DSP16_Q(0.02170408),
  DSP16_Q(-0.03055157),
  DSP16_Q(0.04548176),
  DSP16_Q(-0.07784571),
  DSP16_Q(0.21785041),
  DSP16_Q(0.29778479),
  DSP16_Q(-0.08672411),
  DSP16_Q(0.04879676),
  DSP16_Q(-0.03232619),
  DSP16_Q(0.02283346),
  DSP16_Q(-0.01653622),
  DSP16_Q(0.01201893),
  DSP16_Q(-0.00863570),
  DSP16_Q(0.00605056),
  DSP16_Q(-0.00407037),
  DSP16_Q(0.00257388),
  DSP16_Q(-0.00147818),
  DSP16_Q(0.00072146),
  DSP16_Q(-0.00025376),
  DSP16_Q(0.00003179),
  DSP16_Q(0.00001709),
  DSP16_Q(-0.00020557),
  DSP16_Q(0.00063401),
  DSP16_Q(-0.00134505),
  DSP16_Q(0.00238744),
  DSP16_Q(-0.00382084),
  DSP16_Q(0.00572425),
  DSP16_Q(-0.00821168),
  DSP16_Q(0.01146239),
  DSP16_Q(-0.01578394),
  DSP16_Q(0.02175787),
  DSP16_Q(-0.03062969),
  DSP16_Q(0.04560677),
  DSP16_Q(-0.07809920),
  DSP16_Q(0.21909545),
  DSP16_Q(0.29670412),
  DSP16_Q(-0.08673013),
  DSP16_Q(0.04882968),
  DSP16_Q(-0.03235507),
  DSP16_Q(0.02285592),
  DSP16_Q(-0.01655296),
  DSP16_Q(0.01203097),
  DSP16_Q(-0.00864399),
  DSP16_Q(0.00605592),
  DSP16_Q(-0.00407352),
  DSP16_Q(0.00257543),
  DSP16_Q(-0.00147866),
  DSP16_Q(0.00072134),
  DSP16_Q(-0.00025343),
  DSP16_Q(0.00003159),
  DSP16_Q(0.00001731),
  DSP16_Q(-0.00020660),
  DSP16_Q(0.00063635),
  DSP16_Q(-0.00134928),
  DSP16_Q(0.00239424),
  DSP16_Q(-0.00383102),
  DSP16_Q(0.00573881),
  DSP16_Q(-0.00823191),
  DSP16_Q(0.01149010),
  DSP16_Q(-0.01582186),
  DSP16_Q(0.02181063),
  DSP16_Q(-0.03070638),
  DSP16_Q(0.04572970),
  DSP16_Q(-0.07834947),
  DSP16_Q(0.22033917),
  DSP16_Q(0.29561990),
  DSP16_Q(-0.08673171),
  DSP16_Q(0.04886004),
  DSP16_Q(-0.03238224),
  DSP16_Q(0.02287718),
  DSP16_Q(-0.01656883),
  DSP16_Q(0.01204238),
  DSP16_Q(-0.00865183),
  DSP16_Q(0.00606097),
  DSP16_Q(-0.00407645),
  DSP16_Q(0.00257684),
  DSP16_Q(-0.00147907),
  DSP16_Q(0.00072118),
  DSP16_Q(-0.00025309),
  DSP16_Q(0.00003139),
  DSP16_Q(0.00001752),
  DSP16_Q(-0.00020762),
  DSP16_Q(0.00063867),
  DSP16_Q(-0.00135345),
  DSP16_Q(0.00240093),
  DSP16_Q(-0.00384102),
  DSP16_Q(0.00575309),
  DSP16_Q(-0.00825175),
  DSP16_Q(0.01151727),
  DSP16_Q(-0.01585903),
  DSP16_Q(0.02186235),
  DSP16_Q(-0.03078162),
  DSP16_Q(0.04585053),
  DSP16_Q(-0.07859649),
  DSP16_Q(0.22158156),
  DSP16_Q(0.29453213),
  DSP16_Q(-0.08672885),
  DSP16_Q(0.04888784),
  DSP16_Q(-0.03240771),
  DSP16_Q(0.02289724),
  DSP16_Q(-0.01658383),
  DSP16_Q(0.01205316),
  DSP16_Q(-0.00865921),
  DSP16_Q(0.00606570),
  DSP16_Q(-0.00407917),
  DSP16_Q(0.00257811),
  DSP16_Q(-0.00147939),
  DSP16_Q(0.00072098),
  DSP16_Q(-0.00025273),
  DSP16_Q(0.00003119),
  DSP16_Q(0.00001774),
  DSP16_Q(-0.00020864),
  DSP16_Q(0.00064096),
  DSP16_Q(-0.00135756),
  DSP16_Q(0.00240751),
  DSP16_Q(-0.00385084),
  DSP16_Q(0.00576711),
  DSP16_Q(-0.00827120),
  DSP16_Q(0.01154388),
  DSP16_Q(-0.01589544),
  DSP16_Q(0.02191302),
  DSP16_Q(-0.03085541),
  DSP16_Q(0.04596927),
  DSP16_Q(-0.07884024),
  DSP16_Q(0.22282257),
  DSP16_Q(0.29344087),
  DSP16_Q(-0.08672158),
  DSP16_Q(0.04891308),
  DSP16_Q(-0.03243149),
  DSP16_Q(0.02291610),
  DSP16_Q(-0.01659795),
  DSP16_Q(0.01206330),
  DSP16_Q(-0.00866613),
  DSP16_Q(0.00607010),
  DSP16_Q(-0.00408166),
  DSP16_Q(0.00257925),
  DSP16_Q(-0.00147963),
  DSP16_Q(0.00072074),
  DSP16_Q(-0.00025236),
  DSP16_Q(0.00003099),
  DSP16_Q(0.00001796),
  DSP16_Q(-0.00020965),
  DSP16_Q(0.00064322),
  DSP16_Q(-0.00136161),
  DSP16_Q(0.00241398),
  DSP16_Q(-0.00386048),
  DSP16_Q(0.00578084),
  DSP16_Q(-0.00829026),
  DSP16_Q(0.01156995),
  DSP16_Q(-0.01593109),
  DSP16_Q(0.02196265),
  DSP16_Q(-0.03092774),
  DSP16_Q(0.04608589),
  DSP16_Q(-0.07908071),
  DSP16_Q(0.22406217),
  DSP16_Q(0.29234614),
  DSP16_Q(-0.08670991),
  DSP16_Q(0.04893577),
  DSP16_Q(-0.03245356),
  DSP16_Q(0.02293375),
  DSP16_Q(-0.01661121),
  DSP16_Q(0.01207281),
  DSP16_Q(-0.00867260),
  DSP16_Q(0.00607418),
  DSP16_Q(-0.00408394),
  DSP16_Q(0.00258024),
  DSP16_Q(-0.00147979),
  DSP16_Q(0.00072046),
  DSP16_Q(-0.00025198),
  DSP16_Q(0.00003078),
  DSP16_Q(0.00001817),
  DSP16_Q(-0.00021065),
  DSP16_Q(0.00064546),
  DSP16_Q(-0.00136560),
  DSP16_Q(0.00242034),
  DSP16_Q(-0.00386993),
  DSP16_Q(0.00579431),
  DSP16_Q(-0.00830891),
  DSP16_Q(0.01159545),
  DSP16_Q(-0.01596597),
  DSP16_Q(0.02201123),
  DSP16_Q(-0.03099860),
  DSP16_Q(0.04620039),
  DSP16_Q(-0.07931786),
  DSP16_Q(0.22530033),
  DSP16_Q(0.29124797),
  DSP16_Q(-0.08669385),
  DSP16_Q(0.04895592),
  DSP16_Q(-0.03247395),
  DSP16_Q(0.02295021),
  DSP16_Q(-0.01662360),
  DSP16_Q(0.01208168),
  DSP16_Q(-0.00867861),
  DSP16_Q(0.00607794),
  DSP16_Q(-0.00408601),
  DSP16_Q(0.00258110),
  DSP16_Q(-0.00147987),
  DSP16_Q(0.00072014),
  DSP16_Q(-0.00025158),
  DSP16_Q(0.00003057),
  DSP16_Q(0.00001839),
  DSP16_Q(-0.00021165),
  DSP16_Q(0.00064767),
  DSP16_Q(-0.00136953),
  DSP16_Q(0.00242658),
  DSP16_Q(-0.00387920),
  DSP16_Q(0.00580749),
  DSP16_Q(-0.00832717),
  DSP16_Q(0.01162040),
  DSP16_Q(-0.01600008),
  DSP16_Q(0.02205875),
  DSP16_Q(-0.03106800),
  DSP16_Q(0.04631276),
  DSP16_Q(-0.07955167),
  DSP16_Q(0.22653700),
  DSP16_Q(0.29014639),
  DSP16_Q(-0.08667343),
  DSP16_Q(0.04897352),
  DSP16_Q(-0.03249263),
  DSP16_Q(0.02296547),
  DSP16_Q(-0.01663512),
  DSP16_Q(0.01208992),
  DSP16_Q(-0.00868417),
  DSP16_Q(0.00608139),
  DSP16_Q(-0.00408786),
  DSP16_Q(0.00258182),
  DSP16_Q(-0.00147987),
  DSP16_Q(0.00071978),
  DSP16_Q(-0.00025117),
  DSP16_Q(0.00003037),
  DSP16_Q(0.00001861),
  DSP16_Q(-0.00021264),
  DSP16_Q(0.00064985),
  DSP16_Q(-0.00137340),
  DSP16_Q(0.00243271),
  DSP16_Q(-0.00388829),
  DSP16_Q(0.00582040),
  DSP16_Q(-0.00834503),
  DSP16_Q(0.01164478),
  DSP16_Q(-0.01603342),
  DSP16_Q(0.02210522),
  DSP16_Q(-0.03113592),
  DSP16_Q(0.04642299),
  DSP16_Q(-0.07978214),
  DSP16_Q(0.22777215),
  DSP16_Q(0.28904145),
  DSP16_Q(-0.08664865),
  DSP16_Q(0.04898859),
  DSP16_Q(-0.03250963),
  DSP16_Q(0.02297953),
  DSP16_Q(-0.01664576),
  DSP16_Q(0.01209753),
  DSP16_Q(-0.00868927),
  DSP16_Q(0.00608451),
  DSP16_Q(-0.00408949),
  DSP16_Q(0.00258240),
  DSP16_Q(-0.00147980),
  DSP16_Q(0.00071939),
  DSP16_Q(-0.00025075),
  DSP16_Q(0.00003016),
  DSP16_Q(0.00001883),
  DSP16_Q(-0.00021362),
  DSP16_Q(0.00065200),
  DSP16_Q(-0.00137720),
  DSP16_Q(0.00243872),
  DSP16_Q(-0.00389719),
  DSP16_Q(0.00583303),
  DSP16_Q(-0.00836248),
  DSP16_Q(0.01166861),
  DSP16_Q(-0.01606599),
  DSP16_Q(0.02215062),
  DSP16_Q(-0.03120235),
  DSP16_Q(0.04653107),
  DSP16_Q(-0.08000922),
  DSP16_Q(0.22900576),
  DSP16_Q(0.28793317),
  DSP16_Q(-0.08661953),
  DSP16_Q(0.04900112),
  DSP16_Q(-0.03252494),
  DSP16_Q(0.02299239),
  DSP16_Q(-0.01665555),
  DSP16_Q(0.01210451),
  DSP16_Q(-0.00869392),
  DSP16_Q(0.00608731),
  DSP16_Q(-0.00409091),
  DSP16_Q(0.00258285),
  DSP16_Q(-0.00147964),
  DSP16_Q(0.00071895),
  DSP16_Q(-0.00025031),
  DSP16_Q(0.00002995),
  DSP16_Q(0.00001905),
  DSP16_Q(-0.00021459),
  DSP16_Q(0.00065412),
  DSP16_Q(-0.00138094),
  DSP16_Q(0.00244463),
  DSP16_Q(-0.00390591),
  DSP16_Q(0.00584538),
  DSP16_Q(-0.00837953),
  DSP16_Q(0.01169186),
  DSP16_Q(-0.01609778),
  DSP16_Q(0.02219495),
  DSP16_Q(-0.03126730),
  DSP16_Q(0.04663698),
  DSP16_Q(-0.08023292),
  DSP16_Q(0.23023777),
  DSP16_Q(0.28682158),
  DSP16_Q(-0.08658609),
  DSP16_Q(0.04901113),
  DSP16_Q(-0.03253856),
  DSP16_Q(0.02300406),
  DSP16_Q(-0.01666446),
  DSP16_Q(0.01211086),
  DSP16_Q(-0.00869811),
  DSP16_Q(0.00608979),
  DSP16_Q(-0.00409211),
  DSP16_Q(0.00258316),
  DSP16_Q(-0.00147941),
  DSP16_Q(0.00071848),
  DSP16_Q(-0.00024986),
  DSP16_Q(0.00002974),
  DSP16_Q(0.00001927),
  DSP16_Q(-0.00021555),
  DSP16_Q(0.00065622),
  DSP16_Q(-0.00138462),
  DSP16_Q(0.00245041),
  DSP16_Q(-0.00391444),
  DSP16_Q(0.00585745),
  DSP16_Q(-0.00839617),
  DSP16_Q(0.01171456),
  DSP16_Q(-0.01612879),
  DSP16_Q(0.02223821),
  DSP16_Q(-0.03133076),
  DSP16_Q(0.04674073),
  DSP16_Q(-0.08045319),
  DSP16_Q(0.23146817),
  DSP16_Q(0.28570671),
  DSP16_Q(-0.08654834),
  DSP16_Q(0.04901861),
  DSP16_Q(-0.03255049),
  DSP16_Q(0.02301453),
  DSP16_Q(-0.01667251),
  DSP16_Q(0.01211657),
  DSP16_Q(-0.00870185),
  DSP16_Q(0.00609196),
  DSP16_Q(-0.00409310),
  DSP16_Q(0.00258333),
  DSP16_Q(-0.00147909),
  DSP16_Q(0.00071797),
  DSP16_Q(-0.00024939),
  DSP16_Q(0.00002952),
  DSP16_Q(0.00001949),
  DSP16_Q(-0.00021651),
  DSP16_Q(0.00065829),
  DSP16_Q(-0.00138823),
  DSP16_Q(0.00245608),
  DSP16_Q(-0.00392278),
  DSP16_Q(0.00586923),
  DSP16_Q(-0.00841241),
  DSP16_Q(0.01173668),
  DSP16_Q(-0.01615901),
  DSP16_Q(0.02228040),
  DSP16_Q(-0.03139272),
  DSP16_Q(0.04684230),
  DSP16_Q(-0.08067002),
  DSP16_Q(0.23269690),
  DSP16_Q(0.28458861),
  DSP16_Q(-0.08650630),
  DSP16_Q(0.04902357),
  DSP16_Q(-0.03256074),
  DSP16_Q(0.02302381),
  DSP16_Q(-0.01667969),
  DSP16_Q(0.01212166),
  DSP16_Q(-0.00870513),
  DSP16_Q(0.00609381),
  DSP16_Q(-0.00409387),
  DSP16_Q(0.00258337),
  DSP16_Q(-0.00147870),
  DSP16_Q(0.00071742),
  DSP16_Q(-0.00024892),
  DSP16_Q(0.00002931),
  DSP16_Q(0.00001972),
  DSP16_Q(-0.00021746),
  DSP16_Q(0.00066032),
  DSP16_Q(-0.00139178),
  DSP16_Q(0.00246164),
  DSP16_Q(-0.00393094),
  DSP16_Q(0.00588073),
  DSP16_Q(-0.00842824),
  DSP16_Q(0.01175823),
  DSP16_Q(-0.01618845),
  DSP16_Q(0.02232150),
  DSP16_Q(-0.03145317),
  DSP16_Q(0.04694167),
  DSP16_Q(-0.08088340),
  DSP16_Q(0.23392394),
  DSP16_Q(0.28346730),
  DSP16_Q(-0.08645999),
  DSP16_Q(0.04902602),
  DSP16_Q(-0.03256931),
  DSP16_Q(0.02303190),
  DSP16_Q(-0.01668601),
  DSP16_Q(0.01212612),
  DSP16_Q(-0.00870796),
  DSP16_Q(0.00609533),
  DSP16_Q(-0.00409443),
  DSP16_Q(0.00258327),
  DSP16_Q(-0.00147823),
  DSP16_Q(0.00071683),
  DSP16_Q(-0.00024843),
  DSP16_Q(0.00002910),
  DSP16_Q(0.00001994),
  DSP16_Q(-0.00021840),
  DSP16_Q(0.00066233),
  DSP16_Q(-0.00139526),
  DSP16_Q(0.00246707),
  DSP16_Q(-0.00393891),
  DSP16_Q(0.00589195),
  DSP16_Q(-0.00844366),
  DSP16_Q(0.01177921),
  DSP16_Q(-0.01621711),
  DSP16_Q(0.02236153),
  DSP16_Q(-0.03151211),
  DSP16_Q(0.04703885),
  DSP16_Q(-0.08109330),
  DSP16_Q(0.23514925),
  DSP16_Q(0.28234282),
  DSP16_Q(-0.08640942),
  DSP16_Q(0.04902596),
  DSP16_Q(-0.03257620),
  DSP16_Q(0.02303880),
  DSP16_Q(-0.01669146),
  DSP16_Q(0.01212994),
  DSP16_Q(-0.00871034),
  DSP16_Q(0.00609655),
  DSP16_Q(-0.00409477),
  DSP16_Q(0.00258304),
  DSP16_Q(-0.00147769),
  DSP16_Q(0.00071620),
  DSP16_Q(-0.00024792),
  DSP16_Q(0.00002888),
  DSP16_Q(0.00002016),
  DSP16_Q(-0.00021933),
  DSP16_Q(0.00066431),
  DSP16_Q(-0.00139868),
  DSP16_Q(0.00247239),
  DSP16_Q(-0.00394668),
  DSP16_Q(0.00590288),
  DSP16_Q(-0.00845867),
  DSP16_Q(0.01179962),
  DSP16_Q(-0.01624497),
  DSP16_Q(0.02240047),
  DSP16_Q(-0.03156953),
  DSP16_Q(0.04713382),
  DSP16_Q(-0.08129969),
  DSP16_Q(0.23637280),
  DSP16_Q(0.28121519),
  DSP16_Q(-0.08635460),
  DSP16_Q(0.04902340),
  DSP16_Q(-0.03258141),
  DSP16_Q(0.02304451),
  DSP16_Q(-0.01669605),
  DSP16_Q(0.01213314),
  DSP16_Q(-0.00871227),
  DSP16_Q(0.00609744),
  DSP16_Q(-0.00409490),
  DSP16_Q(0.00258267),
  DSP16_Q(-0.00147706),
  DSP16_Q(0.00071554),
  DSP16_Q(-0.00024741),
  DSP16_Q(0.00002867),
  DSP16_Q(0.00002038),
  DSP16_Q(-0.00022025),
  DSP16_Q(0.00066626),
  DSP16_Q(-0.00140203),
  DSP16_Q(0.00247760),
  DSP16_Q(-0.00395427),
  DSP16_Q(0.00591353),
  DSP16_Q(-0.00847327),
  DSP16_Q(0.01181945),
  DSP16_Q(-0.01627204),
  DSP16_Q(0.02243832),
  DSP16_Q(-0.03162544),
  DSP16_Q(0.04722657),
  DSP16_Q(-0.08150257),
  DSP16_Q(0.23759454),
  DSP16_Q(0.28008446),
  DSP16_Q(-0.08629555),
  DSP16_Q(0.04901834),
  DSP16_Q(-0.03258495),
  DSP16_Q(0.02304904),
  DSP16_Q(-0.01669978),
  DSP16_Q(0.01213572),
  DSP16_Q(-0.00871374),
  DSP16_Q(0.00609802),
  DSP16_Q(-0.00409482),
  DSP16_Q(0.00258217),
  DSP16_Q(-0.00147636),
  DSP16_Q(0.00071484),
  DSP16_Q(-0.00024688),
  DSP16_Q(0.00002845),
  DSP16_Q(0.00002061),
  DSP16_Q(-0.00022117),
  DSP16_Q(0.00066818),
  DSP16_Q(-0.00140532),
  DSP16_Q(0.00248268),
  DSP16_Q(-0.00396167),
  DSP16_Q(0.00592388),
  DSP16_Q(-0.00848745),
  DSP16_Q(0.01183870),
  DSP16_Q(-0.01629831),
  DSP16_Q(0.02247507),
  DSP16_Q(-0.03167982),
  DSP16_Q(0.04731710),
  DSP16_Q(-0.08170190),
  DSP16_Q(0.23881446),
  DSP16_Q(0.27895066),
  DSP16_Q(-0.08623230),
  DSP16_Q(0.04901079),
  DSP16_Q(-0.03258682),
  DSP16_Q(0.02305238),
  DSP16_Q(-0.01670265),
  DSP16_Q(0.01213766),
  DSP16_Q(-0.00871477),
  DSP16_Q(0.00609828),
  DSP16_Q(-0.00409453),
  DSP16_Q(0.00258153),
  DSP16_Q(-0.00147558),
  DSP16_Q(0.00071410),
  DSP16_Q(-0.00024633),
  DSP16_Q(0.00002823),
  DSP16_Q(0.00002083),
  DSP16_Q(-0.00022208),
  DSP16_Q(0.00067007),
  DSP16_Q(-0.00140854),
  DSP16_Q(0.00248765),
  DSP16_Q(-0.00396887),
  DSP16_Q(0.00593395),
  DSP16_Q(-0.00850122),
  DSP16_Q(0.01185737),
  DSP16_Q(-0.01632379),
  DSP16_Q(0.02251073),
  DSP16_Q(-0.03173266),
  DSP16_Q(0.04740538),
  DSP16_Q(-0.08189767),
  DSP16_Q(0.24003250),
  DSP16_Q(0.27781381),
  DSP16_Q(-0.08616485),
  DSP16_Q(0.04900075),
  DSP16_Q(-0.03258702),
  DSP16_Q(0.02305453),
  DSP16_Q(-0.01670466),
  DSP16_Q(0.01213898),
  DSP16_Q(-0.00871535),
  DSP16_Q(0.00609823),
  DSP16_Q(-0.00409402),
  DSP16_Q(0.00258076),
  DSP16_Q(-0.00147473),
  DSP16_Q(0.00071332),
  DSP16_Q(-0.00024578),
  DSP16_Q(0.00002801),
  DSP16_Q(0.00002106),
  DSP16_Q(-0.00022297),
  DSP16_Q(0.00067193),
  DSP16_Q(-0.00141170),
  DSP16_Q(0.00249249),
  DSP16_Q(-0.00397588),
  DSP16_Q(0.00594373),
  DSP16_Q(-0.00851457),
  DSP16_Q(0.01187546),
  DSP16_Q(-0.01634846),
  DSP16_Q(0.02254529),
  DSP16_Q(-0.03178397),
  DSP16_Q(0.04749143),
  DSP16_Q(-0.08208986),
  DSP16_Q(0.24124863),
  DSP16_Q(0.27667396),
  DSP16_Q(-0.08609322),
  DSP16_Q(0.04898823),
  DSP16_Q(-0.03258555),
  DSP16_Q(0.02305550),
  DSP16_Q(-0.01670581),
  DSP16_Q(0.01213968),
  DSP16_Q(-0.00871547),
  DSP16_Q(0.00609786),
  DSP16_Q(-0.00409330),
  DSP16_Q(0.00257985),
  DSP16_Q(-0.00147379),
  DSP16_Q(0.00071251),
  DSP16_Q(-0.00024521),
  DSP16_Q(0.00002779),
  DSP16_Q(0.00002128),
  DSP16_Q(-0.00022386),
  DSP16_Q(0.00067376),
  DSP16_Q(-0.00141479),
  DSP16_Q(0.00249722),
  DSP16_Q(-0.00398270),
  DSP16_Q(0.00595322),
  DSP16_Q(-0.00852750),
  DSP16_Q(0.01189296),
  DSP16_Q(-0.01637233),
  DSP16_Q(0.02257875),
  DSP16_Q(-0.03183374),
  DSP16_Q(0.04757522),
  DSP16_Q(-0.08227845),
  DSP16_Q(0.24246283),
  DSP16_Q(0.27553113),
  DSP16_Q(-0.08601744),
  DSP16_Q(0.04897323),
  DSP16_Q(-0.03258243),
  DSP16_Q(0.02305529),
  DSP16_Q(-0.01670611),
  DSP16_Q(0.01213975),
  DSP16_Q(-0.00871515),
  DSP16_Q(0.00609718),
  DSP16_Q(-0.00409237),
  DSP16_Q(0.00257881),
  DSP16_Q(-0.00147279),
  DSP16_Q(0.00071166),
  DSP16_Q(-0.00024463),
  DSP16_Q(0.00002757),
  DSP16_Q(0.00002151),
  DSP16_Q(-0.00022474),
  DSP16_Q(0.00067555),
  DSP16_Q(-0.00141781),
  DSP16_Q(0.00250182),
  DSP16_Q(-0.00398932),
  DSP16_Q(0.00596241),
  DSP16_Q(-0.00854002),
  DSP16_Q(0.01190988),
  DSP16_Q(-0.01639540),
  DSP16_Q(0.02261109),
  DSP16_Q(-0.03188196),
  DSP16_Q(0.04765675),
  DSP16_Q(-0.08246341),
  DSP16_Q(0.24367505),
  DSP16_Q(0.27438536),
  DSP16_Q(-0.08593751),
  DSP16_Q(0.04895577),
  DSP16_Q(-0.03257764),
  DSP16_Q(0.02305390),
  DSP16_Q(-0.01670554),
  DSP16_Q(0.01213920),
  DSP16_Q(-0.00871438),
  DSP16_Q(0.00609618),
  DSP16_Q(-0.00409123),
  DSP16_Q(0.00257764),
  DSP16_Q(-0.00147170),
  DSP16_Q(0.00071078),
  DSP16_Q(-0.00024404),
  DSP16_Q(0.00002735),
  DSP16_Q(0.00002173),
  DSP16_Q(-0.00022561),
  DSP16_Q(0.00067732),
  DSP16_Q(-0.00142076),
  DSP16_Q(0.00250631),
  DSP16_Q(-0.00399575),
  DSP16_Q(0.00597132),
  DSP16_Q(-0.00855211),
  DSP16_Q(0.01192621),
  DSP16_Q(-0.01641766),
  DSP16_Q(0.02264233),
  DSP16_Q(-0.03192862),
  DSP16_Q(0.04773600),
  DSP16_Q(-0.08264473),
  DSP16_Q(0.24488526),
  DSP16_Q(0.27323669),
  DSP16_Q(-0.08585345),
  DSP16_Q(0.04893584),
  DSP16_Q(-0.03257119),
  DSP16_Q(0.02305134),
  DSP16_Q(-0.01670413),
  DSP16_Q(0.01213802),
  DSP16_Q(-0.00871316),
  DSP16_Q(0.00609488),
  DSP16_Q(-0.00408988),
  DSP16_Q(0.00257634),
  DSP16_Q(-0.00147054),
  DSP16_Q(0.00070985),
  DSP16_Q(-0.00024344),
  DSP16_Q(0.00002713),
  DSP16_Q(0.00002196),
  DSP16_Q(-0.00022647),
  DSP16_Q(0.00067906),
  DSP16_Q(-0.00142365),
  DSP16_Q(0.00251067),
  DSP16_Q(-0.00400199),
  DSP16_Q(0.00597993),
  DSP16_Q(-0.00856378),
  DSP16_Q(0.01194196),
  DSP16_Q(-0.01643911),
  DSP16_Q(0.02267246),
  DSP16_Q(-0.03197373),
  DSP16_Q(0.04781298),
  DSP16_Q(-0.08282239),
  DSP16_Q(0.24609343),
  DSP16_Q(0.27208514),
  DSP16_Q(-0.08576529),
  DSP16_Q(0.04891345),
  DSP16_Q(-0.03256309),
  DSP16_Q(0.02304759),
  DSP16_Q(-0.01670186),
  DSP16_Q(0.01213623),
  DSP16_Q(-0.00871150),
  DSP16_Q(0.00609326),
  DSP16_Q(-0.00408832),
  DSP16_Q(0.00257490),
  DSP16_Q(-0.00146931),
  DSP16_Q(0.00070890),
  DSP16_Q(-0.00024282),
  DSP16_Q(0.00002691),
  DSP16_Q(0.00002218),
  DSP16_Q(-0.00022732),
  DSP16_Q(0.00068076),
  DSP16_Q(-0.00142647),
  DSP16_Q(0.00251491),
  DSP16_Q(-0.00400802),
  DSP16_Q(0.00598824),
  DSP16_Q(-0.00857503),
  DSP16_Q(0.01195711),
  DSP16_Q(-0.01645974),
  DSP16_Q(0.02270147),
  DSP16_Q(-0.03201728),
  DSP16_Q(0.04788767),
  DSP16_Q(-0.08299637),
  DSP16_Q(0.24729951),
  DSP16_Q(0.27093075),
  DSP16_Q(-0.08567303),
  DSP16_Q(0.04888862),
  DSP16_Q(-0.03255335),
  DSP16_Q(0.02304268),
  DSP16_Q(-0.01669873),
  DSP16_Q(0.01213381),
  DSP16_Q(-0.00870939),
  DSP16_Q(0.00609132),
  DSP16_Q(-0.00408655),
  DSP16_Q(0.00257333),
  DSP16_Q(-0.00146800),
  DSP16_Q(0.00070790),
  DSP16_Q(-0.00024220),
  DSP16_Q(0.00002669),
  DSP16_Q(0.00002241),
  DSP16_Q(-0.00022816),
  DSP16_Q(0.00068243),
  DSP16_Q(-0.00142922),
  DSP16_Q(0.00251903),
  DSP16_Q(-0.00401387),
  DSP16_Q(0.00599626),
  DSP16_Q(-0.00858586),
  DSP16_Q(0.01197167),
  DSP16_Q(-0.01647957),
  DSP16_Q(0.02272935),
  DSP16_Q(-0.03205926),
  DSP16_Q(0.04796006),
  DSP16_Q(-0.08316664),
  DSP16_Q(0.24850348),
  DSP16_Q(0.26977356),
  DSP16_Q(-0.08557670),
  DSP16_Q(0.04886133),
  DSP16_Q(-0.03254195),
  DSP16_Q(0.02303659),
  DSP16_Q(-0.01669476),
  DSP16_Q(0.01213078),
  DSP16_Q(-0.00870684),
  DSP16_Q(0.00608908),
  DSP16_Q(-0.00408458),
  DSP16_Q(0.00257163),
  DSP16_Q(-0.00146661),
  DSP16_Q(0.00070687),
  DSP16_Q(-0.00024156),
  DSP16_Q(0.00002647),
  DSP16_Q(0.00002264),
  DSP16_Q(-0.00022899),
  DSP16_Q(0.00068407),
  DSP16_Q(-0.00143190),
  DSP16_Q(0.00252302),
  DSP16_Q(-0.00401951),
  DSP16_Q(0.00600398),
  DSP16_Q(-0.00859625),
  DSP16_Q(0.01198564),
  DSP16_Q(-0.01649857),
  DSP16_Q(0.02275612),
  DSP16_Q(-0.03209967),
  DSP16_Q(0.04803014),
  DSP16_Q(-0.08333320),
  DSP16_Q(0.24970530),
  DSP16_Q(0.26861360),
  DSP16_Q(-0.08547631),
  DSP16_Q(0.04883161),
  DSP16_Q(-0.03252891),
  DSP16_Q(0.02302934),
  DSP16_Q(-0.01668994),
  DSP16_Q(0.01212713),
  DSP16_Q(-0.00870384),
  DSP16_Q(0.00608652),
  DSP16_Q(-0.00408239),
  DSP16_Q(0.00256980),
  DSP16_Q(-0.00146515),
  DSP16_Q(0.00070581),
  DSP16_Q(-0.00024091),
  DSP16_Q(0.00002624),
  DSP16_Q(0.00002286),
  DSP16_Q(-0.00022982),
  DSP16_Q(0.00068568),
  DSP16_Q(-0.00143451),
  DSP16_Q(0.00252689),
  DSP16_Q(-0.00402495),
  DSP16_Q(0.00601141),
  DSP16_Q(-0.00860623),
  DSP16_Q(0.01199901),
  DSP16_Q(-0.01651676),
  DSP16_Q(0.02278176),
  DSP16_Q(-0.03213850),
  DSP16_Q(0.04809792),
  DSP16_Q(-0.08349601),
  DSP16_Q(0.25090493),
  DSP16_Q(0.26745090),
  DSP16_Q(-0.08537189),
  DSP16_Q(0.04879946),
  DSP16_Q(-0.03251423),
  DSP16_Q(0.02302092),
  DSP16_Q(-0.01668426),
  DSP16_Q(0.01212286),
  DSP16_Q(-0.00870040),
  DSP16_Q(0.00608366),
  DSP16_Q(-0.00407999),
  DSP16_Q(0.00256784),
  DSP16_Q(-0.00146362),
  DSP16_Q(0.00070470),
  DSP16_Q(-0.00024024),
  DSP16_Q(0.00002602),
  DSP16_Q(0.00002309),
  DSP16_Q(-0.00023063),
  DSP16_Q(0.00068726),
  DSP16_Q(-0.00143705),
  DSP16_Q(0.00253064),
  DSP16_Q(-0.00403020),
  DSP16_Q(0.00601853),
  DSP16_Q(-0.00861577),
  DSP16_Q(0.01201178),
  DSP16_Q(-0.01653412),
  DSP16_Q(0.02280627),
  DSP16_Q(-0.03217575),
  DSP16_Q(0.04816337),
  DSP16_Q(-0.08365506),
  DSP16_Q(0.25210234),
  DSP16_Q(0.26628550),
  DSP16_Q(-0.08526344),
  DSP16_Q(0.04876489),
  DSP16_Q(-0.03249791),
  DSP16_Q(0.02301133),
  DSP16_Q(-0.01667775),
  DSP16_Q(0.01211798),
  DSP16_Q(-0.00869652),
  DSP16_Q(0.00608048),
  DSP16_Q(-0.00407739),
  DSP16_Q(0.00256575),
  DSP16_Q(-0.00146201),
  DSP16_Q(0.00070357),
  DSP16_Q(-0.00023957),
  DSP16_Q(0.00002580),
  DSP16_Q(0.00002331),
  DSP16_Q(-0.00023143),
  DSP16_Q(0.00068880),
  DSP16_Q(-0.00143952),
  DSP16_Q(0.00253426),
  DSP16_Q(-0.00403524),
  DSP16_Q(0.00602536),
  DSP16_Q(-0.00862489),
  DSP16_Q(0.01202396),
  DSP16_Q(-0.01655066),
  DSP16_Q(0.02282965),
  DSP16_Q(-0.03221142),
  DSP16_Q(0.04822649),
  DSP16_Q(-0.08381033),
  DSP16_Q(0.25329750),
  DSP16_Q(0.26511743),
  DSP16_Q(-0.08515099),
  DSP16_Q(0.04872789),
  DSP16_Q(-0.03247996),
  DSP16_Q(0.02300058),
  DSP16_Q(-0.01667038),
  DSP16_Q(0.01211248),
  DSP16_Q(-0.00869219),
  DSP16_Q(0.00607700),
  DSP16_Q(-0.00407458),
  DSP16_Q(0.00256353),
  DSP16_Q(-0.00146033),
  DSP16_Q(0.00070240),
  DSP16_Q(-0.00023888),
  DSP16_Q(0.00002557),
  DSP16_Q(0.00002354),
  DSP16_Q(-0.00023222),
  DSP16_Q(0.00069031),
  DSP16_Q(-0.00144193),
  DSP16_Q(0.00253776),
  DSP16_Q(-0.00404009),
  DSP16_Q(0.00603189),
  DSP16_Q(-0.00863357),
  DSP16_Q(0.01203553),
  DSP16_Q(-0.01656638),
  DSP16_Q(0.02285189),
  DSP16_Q(-0.03224550),
  DSP16_Q(0.04828728),
  DSP16_Q(-0.08396180),
  DSP16_Q(0.25449037),
  DSP16_Q(0.26394673),
  DSP16_Q(-0.08503456),
  DSP16_Q(0.04868849),
  DSP16_Q(-0.03246038),
  DSP16_Q(0.02298867),
  DSP16_Q(-0.01666218),
  DSP16_Q(0.01210636),
  DSP16_Q(-0.00868743),
  DSP16_Q(0.00607321),
  DSP16_Q(-0.00407157),
  DSP16_Q(0.00256118),
  DSP16_Q(-0.00145857),
  DSP16_Q(0.00070119),
  DSP16_Q(-0.00023819),
  DSP16_Q(0.00002535),
  DSP16_Q(0.00002377),
  DSP16_Q(-0.00023301),
  DSP16_Q(0.00069179),
  DSP16_Q(-0.00144426),
  DSP16_Q(0.00254113),
  DSP16_Q(-0.00404473),
  DSP16_Q(0.00603812),
  DSP16_Q(-0.00864182),
  DSP16_Q(0.01204651),
  DSP16_Q(-0.01658127),
  DSP16_Q(0.02287300),
  DSP16_Q(-0.03227798),
  DSP16_Q(0.04834572),
  DSP16_Q(-0.08410946),
  DSP16_Q(0.25568091),
  DSP16_Q(0.26277342),
  DSP16_Q(-0.08491415),
  DSP16_Q(0.04864667),
  DSP16_Q(-0.03243917),
  DSP16_Q(0.02297560),
  DSP16_Q(-0.01665313),
  DSP16_Q(0.01209964),
  DSP16_Q(-0.00868222),
  DSP16_Q(0.00606911),
  DSP16_Q(-0.00406835),
  DSP16_Q(0.00255870),
  DSP16_Q(-0.00145674),
  DSP16_Q(0.00069995),
  DSP16_Q(-0.00023748),
  DSP16_Q(0.00002512),
  DSP16_Q(0.00002399),
  DSP16_Q(-0.00023378),
  DSP16_Q(0.00069323),
  DSP16_Q(-0.00144652),
  DSP16_Q(0.00254437),
  DSP16_Q(-0.00404918),
  DSP16_Q(0.00604404),
  DSP16_Q(-0.00864964),
  DSP16_Q(0.01205688),
  DSP16_Q(-0.01659533),
  DSP16_Q(0.02289297),
  DSP16_Q(-0.03230886),
  DSP16_Q(0.04840180),
  DSP16_Q(-0.08425328),
  DSP16_Q(0.25686909),
  DSP16_Q(0.26159755),
  DSP16_Q(-0.08478980),
  DSP16_Q(0.04860247),
  DSP16_Q(-0.03241634),
  DSP16_Q(0.02296137),
  DSP16_Q(-0.01664324),
  DSP16_Q(0.01209230),
  DSP16_Q(-0.00867658),
  DSP16_Q(0.00606471),
  DSP16_Q(-0.00406492),
  DSP16_Q(0.00255609),
  DSP16_Q(-0.00145484),
  DSP16_Q(0.00069867),
  DSP16_Q(-0.00023676),
  DSP16_Q(0.00002490),
  DSP16_Q(0.00002422),
  DSP16_Q(-0.00023454),
  DSP16_Q(0.00069464),
  DSP16_Q(-0.00144871),
  DSP16_Q(0.00254749),
  DSP16_Q(-0.00405342),
  DSP16_Q(0.00604966),
  DSP16_Q(-0.00865703),
  DSP16_Q(0.01206664),
  DSP16_Q(-0.01660856),
  DSP16_Q(0.02291179),
  DSP16_Q(-0.03233815),
  DSP16_Q(0.04845553),
  DSP16_Q(-0.08439324),
  DSP16_Q(0.25805489),
  DSP16_Q(0.26041915),
  DSP16_Q(-0.08466152),
  DSP16_Q(0.04855587),
  DSP16_Q(-0.03239189),
  DSP16_Q(0.02294600),
  DSP16_Q(-0.01663252),
  DSP16_Q(0.01208436),
  DSP16_Q(-0.00867050),
  DSP16_Q(0.00606000),
  DSP16_Q(-0.00406129),
  DSP16_Q(0.00255335),
  DSP16_Q(-0.00145287),
  DSP16_Q(0.00069736),
  DSP16_Q(-0.00023603),
  DSP16_Q(0.00002467),
  DSP16_Q(0.00002444),
  DSP16_Q(-0.00023529),
  DSP16_Q(0.00069602),
  DSP16_Q(-0.00145082),
  DSP16_Q(0.00255049),
  DSP16_Q(-0.00405746),
  DSP16_Q(0.00605498),
  DSP16_Q(-0.00866398),
  DSP16_Q(0.01207580),
  DSP16_Q(-0.01662096),
  DSP16_Q(0.02292947),
  DSP16_Q(-0.03236582),
  DSP16_Q(0.04850689),
  DSP16_Q(-0.08452933),
  DSP16_Q(0.25923825),
  DSP16_Q(0.25923825),
  DSP16_Q(-0.08452933),
  DSP16_Q(0.04850689),
  DSP16_Q(-0.03236582),
  DSP16_Q(0.02292947),
  DSP16_Q(-0.01662096),
  DSP16_Q(0.01207580),
  DSP16_Q(-0.00866398),
  DSP16_Q(0.00605498),
  DSP16_Q(-0.00405746),
  DSP16_Q(0.00255049),
  DSP16_Q(-0.00145082),
  DSP16_Q(0.00069602),
  DSP16_Q(-0.00023529),
  DSP16_Q(0.00002444),
  DSP16_Q(0.00002467),
  DSP16_Q(-0.00023603),
  DSP16_Q(0.00069736),
  DSP16_Q(-0.00145287),
  DSP16_Q(0.00255335),
  DSP16_Q(-0.00406129),
  DSP16_Q(0.00606000),
  DSP16_Q(-0.00867050),
  DSP16_Q(0.01208436),
  DSP16_Q(-0.01663252),
  DSP16_Q(0.02294600),
  DSP16_Q(-0.03239189),
  DSP16_Q(0.04855587),
  DSP16_Q(-0.08466152),
  DSP16_Q(0.26041915),
  DSP16_Q(0.25805489),
  DSP16_Q(-0.08439324),
  DSP16_Q(0.04845553),
  DSP16_Q(-0.03233815),
  DSP16_Q(0.02291179),
  DSP16_Q(-0.01660856),
  DSP16_Q(0.01206664),
  DSP16_Q(-0.00865703),
  DSP16_Q(0.00604966),
  DSP16_Q(-0.00405342),
  DSP16_Q(0.00254749),
  DSP16_Q(-0.00144871),
  DSP16_Q(0.00069464),
  DSP16_Q(-0.00023454),
  DSP16_Q(0.00002422),
  DSP16_Q(0.00002490),
  DSP16_Q(-0.00023676),
  DSP16_Q(0.00069867),
  DSP16_Q(-0.00145484),
  DSP16_Q(0.00255609),
  DSP16_Q(-0.00406492),
  DSP16_Q(0.00606471),
  DSP16_Q(-0.00867658),
  DSP16_Q(0.01209230),
  DSP16_Q(-0.01664324),
  DSP16_Q(0.02296137),
  DSP16_Q(-0.03241634),
  DSP16_Q(0.04860247),
  DSP16_Q(-0.08478980),
  DSP16_Q(0.26159755),
  DSP16_Q(0.25686909),
  DSP16_Q(-0.08425328),
  DSP16_Q(0.04840180),
  DSP16_Q(-0.03230886),
  DSP16_Q(0.02289297),
  DSP16_Q(-0.01659533),
  DSP16_Q(0.01205688),
  DSP16_Q(-0.00864964),
  DSP16_Q(0.00604404),
  DSP16_Q(-0.00404918),
  DSP16_Q(0.00254437),
  DSP16_Q(-0.00144652),
  DSP16_Q(0.00069323),
  DSP16_Q(-0.00023378),
  DSP16_Q(0.00002399),
  DSP16_Q(0.00002512),
  DSP16_Q(-0.00023748),
  DSP16_Q(0.00069995),
  DSP16_Q(-0.00145674),
  DSP16_Q(0.00255870),
  DSP16_Q(-0.00406835),
  DSP16_Q(0.00606911),
  DSP16_Q(-0.00868222),
  DSP16_Q(0.01209964),
  DSP16_Q(-0.01665313),
  DSP16_Q(0.02297560),
  DSP16_Q(-0.03243917),
  DSP16_Q(0.04864667),
  DSP16_Q(-0.08491415),
  DSP16_Q(0.26277342),
  DSP16_Q(0.25568091),
  DSP16_Q(-0.08410946),
  DSP16_Q(0.04834572),
  DSP16_Q(-0.03227798),
  DSP16_Q(0.02287300),
  DSP16_Q(-0.01658127),
  DSP16_Q(0.01204651),
  DSP16_Q(-0.00864182),
  DSP16_Q(0.00603812),
  DSP16_Q(-0.00404473),
  DSP16_Q(0.00254113),
  DSP16_Q(-0.00144426),
  DSP16_Q(0.00069179),
  DSP16_Q(-0.00023301),
  DSP16_Q(0.00002377),
  DSP16_Q(0.00002535),
  DSP16_Q(-0.00023819),
  DSP16_Q(0.00070119),
  DSP16_Q(-0.00145857),
  DSP16_Q(0.00256118),
  DSP16_Q(-0.00407157),
  DSP16_Q(0.00607321),
  DSP16_Q(-0.00868743),
  DSP16_Q(0.01210636),
  DSP16_Q(-0.01666218),
  DSP16_Q(0.02298867),
  DSP16_Q(-0.03246038),
  DSP16_Q(0.04868849),
  DSP16_Q(-0.08503456),
  DSP16_Q(0.26394673),
  DSP16_Q(0.25449037),
  DSP16_Q(-0.08396180),
  DSP16_Q(0.04828728),
  DSP16_Q(-0.03224550),
  DSP16_Q(0.02285189),
  DSP16_Q(-0.01656638),
  DSP16_Q(0.01203553),
  DSP16_Q(-0.00863357),
  DSP16_Q(0.00603189),
  DSP16_Q(-0.00404009),
  DSP16_Q(0.00253776),
  DSP16_Q(-0.00144193),
  DSP16_Q(0.00069031),
  DSP16_Q(-0.00023222),
  DSP16_Q(0.00002354),
  DSP16_Q(0.00002557),
  DSP16_Q(-0.00023888),
  DSP16_Q(0.00070240),
  DSP16_Q(-0.00146033),
  DSP16_Q(0.00256353),
  DSP16_Q(-0.00407458),
  DSP16_Q(0.00607700),
  DSP16_Q(-0.00869219),
  DSP16_Q(0.01211248),
  DSP16_Q(-0.01667038),
  DSP16_Q(0.02300058),
  DSP16_Q(-0.03247996),
  DSP16_Q(0.04872789),
  DSP16_Q(-0.08515099),
  DSP16_Q(0.26511743),
  DSP16_Q(0.25329750),
  DSP16_Q(-0.08381033),
  DSP16_Q(0.04822649),
  DSP16_Q(-0.03221142),
  DSP16_Q(0.02282965),
  DSP16_Q(-0.01655066),
  DSP16_Q(0.01202396),
  DSP16_Q(-0.00862489),
  DSP16_Q(0.00602536),
  DSP16_Q(-0.00403524),
  DSP16_Q(0.00253426),
  DSP16_Q(-0.00143952),
  DSP16_Q(0.00068880),
  DSP16_Q(-0.00023143),
  DSP16_Q(0.00002331),
  DSP16_Q(0.00002580),
  DSP16_Q(-0.00023957),
  DSP16_Q(0.00070357),
  DSP16_Q(-0.00146201),
  DSP16_Q(0.00256575),
  DSP16_Q(-0.00407739),
  DSP16_Q(0.00608048),
  DSP16_Q(-0.00869652),
  DSP16_Q(0.01211798),
  DSP16_Q(-0.01667775),
  DSP16_Q(0.02301133),
  DSP16_Q(-0.03249791),
  DSP16_Q(0.04876489),
  DSP16_Q(-0.08526344),
  DSP16_Q(0.26628550),
  DSP16_Q(0.25210234),
  DSP16_Q(-0.08365506),
  DSP16_Q(0.04816337),
  DSP16_Q(-0.03217575),
  DSP16_Q(0.02280627),
  DSP16_Q(-0.01653412),
  DSP16_Q(0.01201178),
  DSP16_Q(-0.00861577),
  DSP16_Q(0.00601853),
  DSP16_Q(-0.00403020),
  DSP16_Q(0.00253064),
  DSP16_Q(-0.00143705),
  DSP16_Q(0.00068726),
  DSP16_Q(-0.00023063),
  DSP16_Q(0.00002309),
  DSP16_Q(0.00002602),
  DSP16_Q(-0.00024024),
  DSP16_Q(0.00070470),
  DSP16_Q(-0.00146362),
  DSP16_Q(0.00256784),
  DSP16_Q(-0.00407999),
  DSP16_Q(0.00608366),
  DSP16_Q(-0.00870040),
  DSP16_Q(0.01212286),
  DSP16_Q(-0.01668426),
  DSP16_Q(0.02302092),
  DSP16_Q(-0.03251423),
  DSP16_Q(0.04879946),
  DSP16_Q(-0.08537189),
  DSP16_Q(0.26745090),
  DSP16_Q(0.25090493),
  DSP16_Q(-0.08349601),
  DSP16_Q(0.04809792),
  DSP16_Q(-0.03213850),
  DSP16_Q(0.02278176),
  DSP16_Q(-0.01651676),
  DSP16_Q(0.01199901),
  DSP16_Q(-0.00860623),
  DSP16_Q(0.00601141),
  DSP16_Q(-0.00402495),
  DSP16_Q(0.00252689),
  DSP16_Q(-0.00143451),
  DSP16_Q(0.00068568),
  DSP16_Q(-0.00022982),
  DSP16_Q(0.00002286),
  DSP16_Q(0.00002624),
  DSP16_Q(-0.00024091),
  DSP16_Q(0.00070581),
  DSP16_Q(-0.00146515),
  DSP16_Q(0.00256980),
  DSP16_Q(-0.00408239),
  DSP16_Q(0.00608652),
  DSP16_Q(-0.00870384),
  DSP16_Q(0.01212713),
  DSP16_Q(-0.01668994),
  DSP16_Q(0.02302934),
  DSP16_Q(-0.03252891),
  DSP16_Q(0.04883161),
  DSP16_Q(-0.08547631),
  DSP16_Q(0.26861360),
  DSP16_Q(0.24970530),
  DSP16_Q(-0.08333320),
  DSP16_Q(0.04803014),
  DSP16_Q(-0.03209967),
  DSP16_Q(0.02275612),
  DSP16_Q(-0.01649857),
  DSP16_Q(0.01198564),
  DSP16_Q(-0.00859625),
  DSP16_Q(0.00600398),
  DSP16_Q(-0.00401951),
  DSP16_Q(0.00252302),
  DSP16_Q(-0.00143190),
  DSP16_Q(0.00068407),
  DSP16_Q(-0.00022899),
  DSP16_Q(0.00002264),
  DSP16_Q(0.00002647),
  DSP16_Q(-0.00024156),
  DSP16_Q(0.00070687),
  DSP16_Q(-0.00146661),
  DSP16_Q(0.00257163),
  DSP16_Q(-0.00408458),
  DSP16_Q(0.00608908),
  DSP16_Q(-0.00870684),
  DSP16_Q(0.01213078),
  DSP16_Q(-0.01669476),
  DSP16_Q(0.02303659),
  DSP16_Q(-0.03254195),
  DSP16_Q(0.04886133),
  DSP16_Q(-0.08557670),
  DSP16_Q(0.26977356),
  DSP16_Q(0.24850348),
  DSP16_Q(-0.08316664),
  DSP16_Q(0.04796006),
  DSP16_Q(-0.03205926),
  DSP16_Q(0.02272935),
  DSP16_Q(-0.01647957),
  DSP16_Q(0.01197167),
  DSP16_Q(-0.00858586),
  DSP16_Q(0.00599626),
  DSP16_Q(-0.00401387),
  DSP16_Q(0.00251903),
  DSP16_Q(-0.00142922),
  DSP16_Q(0.00068243),
  DSP16_Q(-0.00022816),
  DSP16_Q(0.00002241),
  DSP16_Q(0.00002669),
  DSP16_Q(-0.00024220),
  DSP16_Q(0.00070790),
  DSP16_Q(-0.00146800),
  DSP16_Q(0.00257333),
  DSP16_Q(-0.00408655),
  DSP16_Q(0.00609132),
  DSP16_Q(-0.00870939),
  DSP16_Q(0.01213381),
  DSP16_Q(-0.01669873),
  DSP16_Q(0.02304268),
  DSP16_Q(-0.03255335),
  DSP16_Q(0.04888862),
  DSP16_Q(-0.08567303),
  DSP16_Q(0.27093075),
  DSP16_Q(0.24729951),
  DSP16_Q(-0.08299637),
  DSP16_Q(0.04788767),
  DSP16_Q(-0.03201728),
  DSP16_Q(0.02270147),
  DSP16_Q(-0.01645974),
  DSP16_Q(0.01195711),
  DSP16_Q(-0.00857503),
  DSP16_Q(0.00598824),
  DSP16_Q(-0.00400802),
  DSP16_Q(0.00251491),
  DSP16_Q(-0.00142647),
  DSP16_Q(0.00068076),
  DSP16_Q(-0.00022732),
  DSP16_Q(0.00002218),
  DSP16_Q(0.00002691),
  DSP16_Q(-0.00024282),
  DSP16_Q(0.00070890),
  DSP16_Q(-0.00146931),
  DSP16_Q(0.00257490),
  DSP16_Q(-0.00408832),
  DSP16_Q(0.00609326),
  DSP16_Q(-0.00871150),
  DSP16_Q(0.01213623),
  DSP16_Q(-0.01670186),
  DSP16_Q(0.02304759),
  DSP16_Q(-0.03256309),
  DSP16_Q(0.04891345),
  DSP16_Q(-0.08576529),
  DSP16_Q(0.27208514),
  DSP16_Q(0.24609343),
  DSP16_Q(-0.08282239),
  DSP16_Q(0.04781298),
  DSP16_Q(-0.03197373),
  DSP16_Q(0.02267246),
  DSP16_Q(-0.01643911),
  DSP16_Q(0.01194196),
  DSP16_Q(-0.00856378),
  DSP16_Q(0.00597993),
  DSP16_Q(-0.00400199),
  DSP16_Q(0.00251067),
  DSP16_Q(-0.00142365),
  DSP16_Q(0.00067906),
  DSP16_Q(-0.00022647),
  DSP16_Q(0.00002196),
  DSP16_Q(0.00002713),
  DSP16_Q(-0.00024344),
  DSP16_Q(0.00070985),
  DSP16_Q(-0.00147054),
  DSP16_Q(0.00257634),
  DSP16_Q(-0.00408988),
  DSP16_Q(0.00609488),
  DSP16_Q(-0.00871316),
  DSP16_Q(0.01213802),
  DSP16_Q(-0.01670413),
  DSP16_Q(0.02305134),
  DSP16_Q(-0.03257119),
  DSP16_Q(0.04893584),
  DSP16_Q(-0.08585345),
  DSP16_Q(0.27323669),
  DSP16_Q(0.24488526),
  DSP16_Q(-0.08264473),
  DSP16_Q(0.04773600),
  DSP16_Q(-0.03192862),
  DSP16_Q(0.02264233),
  DSP16_Q(-0.01641766),
  DSP16_Q(0.01192621),
  DSP16_Q(-0.00855211),
  DSP16_Q(0.00597132),
  DSP16_Q(-0.00399575),
  DSP16_Q(0.00250631),
  DSP16_Q(-0.00142076),
  DSP16_Q(0.00067732),
  DSP16_Q(-0.00022561),
  DSP16_Q(0.00002173),
  DSP16_Q(0.00002735),
  DSP16_Q(-0.00024404),
  DSP16_Q(0.00071078),
  DSP16_Q(-0.00147170),
  DSP16_Q(0.00257764),
  DSP16_Q(-0.00409123),
  DSP16_Q(0.00609618),
  DSP16_Q(-0.00871438),
  DSP16_Q(0.01213920),
  DSP16_Q(-0.01670554),
  DSP16_Q(0.02305390),
  DSP16_Q(-0.03257764),
  DSP16_Q(0.04895577),
  DSP16_Q(-0.08593751),
  DSP16_Q(0.27438536),
  DSP16_Q(0.24367505),
  DSP16_Q(-0.08246341),
  DSP16_Q(0.04765675),
  DSP16_Q(-0.03188196),
  DSP16_Q(0.02261109),
  DSP16_Q(-0.01639540),
  DSP16_Q(0.01190988),
  DSP16_Q(-0.00854002),
  DSP16_Q(0.00596241),
  DSP16_Q(-0.00398932),
  DSP16_Q(0.00250182),
  DSP16_Q(-0.00141781),
  DSP16_Q(0.00067555),
  DSP16_Q(-0.00022474),
  DSP16_Q(0.00002151),
  DSP16_Q(0.00002757),
  DSP16_Q(-0.00024463),
  DSP16_Q(0.00071166),
  DSP16_Q(-0.00147279),
  DSP16_Q(0.00257881),
  DSP16_Q(-0.00409237),
  DSP16_Q(0.00609718),
  DSP16_Q(-0.00871515),
  DSP16_Q(0.01213975),
  DSP16_Q(-0.01670611),
  DSP16_Q(0.02305529),
  DSP16_Q(-0.03258243),
  DSP16_Q(0.04897323),
  DSP16_Q(-0.08601744),
  DSP16_Q(0.27553113),
  DSP16_Q(0.24246283),
  DSP16_Q(-0.08227845),
  DSP16_Q(0.04757522),
  DSP16_Q(-0.03183374),
  DSP16_Q(0.02257875),
  DSP16_Q(-0.01637233),
  DSP16_Q(0.01189296),
  DSP16_Q(-0.00852750),
  DSP16_Q(0.00595322),
  DSP16_Q(-0.00398270),
  DSP16_Q(0.00249722),
  DSP16_Q(-0.00141479),
  DSP16_Q(0.00067376),
  DSP16_Q(-0.00022386),
  DSP16_Q(0.00002128),
  DSP16_Q(0.00002779),
  DSP16_Q(-0.00024521),
  DSP16_Q(0.00071251),
  DSP16_Q(-0.00147379),
  DSP16_Q(0.00257985),
  DSP16_Q(-0.00409330),
  DSP16_Q(0.00609786),
  DSP16_Q(-0.00871547),
  DSP16_Q(0.01213968),
  DSP16_Q(-0.01670581),
  DSP16_Q(0.02305550),
  DSP16_Q(-0.03258555),
  DSP16_Q(0.04898823),
  DSP16_Q(-0.08609322),
  DSP16_Q(0.27667396),
  DSP16_Q(0.24124863),
  DSP16_Q(-0.08208986),
  DSP16_Q(0.04749143),
  DSP16_Q(-0.03178397),
  DSP16_Q(0.02254529),
  DSP16_Q(-0.01634846),
  DSP16_Q(0.01187546),
  DSP16_Q(-0.00851457),
  DSP16_Q(0.00594373),
  DSP16_Q(-0.00397588),
  DSP16_Q(0.00249249),
  DSP16_Q(-0.00141170),
  DSP16_Q(0.00067193),
  DSP16_Q(-0.00022297),
  DSP16_Q(0.00002106),
  DSP16_Q(0.00002801),
  DSP16_Q(-0.00024578),
  DSP16_Q(0.00071332),
  DSP16_Q(-0.00147473),
  DSP16_Q(0.00258076),
  DSP16_Q(-0.00409402),
  DSP16_Q(0.00609823),
  DSP16_Q(-0.00871535),
  DSP16_Q(0.01213898),
  DSP16_Q(-0.01670466),
  DSP16_Q(0.02305453),
  DSP16_Q(-0.03258702),
  DSP16_Q(0.04900075),
  DSP16_Q(-0.08616485),
  DSP16_Q(0.27781381),
  DSP16_Q(0.24003250),
  DSP16_Q(-0.08189767),
  DSP16_Q(0.04740538),
  DSP16_Q(-0.03173266),
  DSP16_Q(0.02251073),
  DSP16_Q(-0.01632379),
  DSP16_Q(0.01185737),
  DSP16_Q(-0.00850122),
  DSP16_Q(0.00593395),
  DSP16_Q(-0.00396887),
  DSP16_Q(0.00248765),
  DSP16_Q(-0.00140854),
  DSP16_Q(0.00067007),
  DSP16_Q(-0.00022208),
  DSP16_Q(0.00002083),
  DSP16_Q(0.00002823),
  DSP16_Q(-0.00024633),
  DSP16_Q(0.00071410),
  DSP16_Q(-0.00147558),
  DSP16_Q(0.00258153),
  DSP16_Q(-0.00409453),
  DSP16_Q(0.00609828),
  DSP16_Q(-0.00871477),
  DSP16_Q(0.01213766),
  DSP16_Q(-0.01670265),
  DSP16_Q(0.02305238),
  DSP16_Q(-0.03258682),
  DSP16_Q(0.04901079),
  DSP16_Q(-0.08623230),
  DSP16_Q(0.27895066),
  DSP16_Q(0.23881446),
  DSP16_Q(-0.08170190),
  DSP16_Q(0.04731710),
  DSP16_Q(-0.03167982),
  DSP16_Q(0.02247507),
  DSP16_Q(-0.01629831),
  DSP16_Q(0.01183870),
  DSP16_Q(-0.00848745),
  DSP16_Q(0.00592388),
  DSP16_Q(-0.00396167),
  DSP16_Q(0.00248268),
  DSP16_Q(-0.00140532),
  DSP16_Q(0.00066818),
  DSP16_Q(-0.00022117),
  DSP16_Q(0.00002061),
  DSP16_Q(0.00002845),
  DSP16_Q(-0.00024688),
  DSP16_Q(0.00071484),
  DSP16_Q(-0.00147636),
  DSP16_Q(0.00258217),
  DSP16_Q(-0.00409482),
  DSP16_Q(0.00609802),
  DSP16_Q(-0.00871374),
  DSP16_Q(0.01213572),
  DSP16_Q(-0.01669978),
  DSP16_Q(0.02304904),
  DSP16_Q(-0.03258495),
  DSP16_Q(0.04901834),
  DSP16_Q(-0.08629555),
  DSP16_Q(0.28008446),
  DSP16_Q(0.23759454),
  DSP16_Q(-0.08150257),
  DSP16_Q(0.04722657),
  DSP16_Q(-0.03162544),
  DSP16_Q(0.02243832),
  DSP16_Q(-0.01627204),
  DSP16_Q(0.01181945),
  DSP16_Q(-0.00847327),
  DSP16_Q(0.00591353),
  DSP16_Q(-0.00395427),
  DSP16_Q(0.00247760),
  DSP16_Q(-0.00140203),
  DSP16_Q(0.00066626),
  DSP16_Q(-0.00022025),
  DSP16_Q(0.00002038),
  DSP16_Q(0.00002867),
  DSP16_Q(-0.00024741),
  DSP16_Q(0.00071554),
  DSP16_Q(-0.00147706),
  DSP16_Q(0.00258267),
  DSP16_Q(-0.00409490),
  DSP16_Q(0.00609744),
  DSP16_Q(-0.00871227),
  DSP16_Q(0.01213314),
  DSP16_Q(-0.01669605),
  DSP16_Q(0.02304451),
  DSP16_Q(-0.03258141),
  DSP16_Q(0.04902340),
  DSP16_Q(-0.08635460),
  DSP16_Q(0.28121519),
  DSP16_Q(0.23637280),
  DSP16_Q(-0.08129969),
  DSP16_Q(0.04713382),
  DSP16_Q(-0.03156953),
  DSP16_Q(0.02240047),
  DSP16_Q(-0.01624497),
  DSP16_Q(0.01179962),
  DSP16_Q(-0.00845867),
  DSP16_Q(0.00590288),
  DSP16_Q(-0.00394668),
  DSP16_Q(0.00247239),
  DSP16_Q(-0.00139868),
  DSP16_Q(0.00066431),
  DSP16_Q(-0.00021933),
  DSP16_Q(0.00002016),
  DSP16_Q(0.00002888),
  DSP16_Q(-0.00024792),
  DSP16_Q(0.00071620),
  DSP16_Q(-0.00147769),
  DSP16_Q(0.00258304),
  DSP16_Q(-0.00409477),
  DSP16_Q(0.00609655),
  DSP16_Q(-0.00871034),
  DSP16_Q(0.01212994),
  DSP16_Q(-0.01669146),
  DSP16_Q(0.02303880),
  DSP16_Q(-0.03257620),
  DSP16_Q(0.04902596),
  DSP16_Q(-0.08640942),
  DSP16_Q(0.28234282),
  DSP16_Q(0.23514925),
  DSP16_Q(-0.08109330),
  DSP16_Q(0.04703885),
  DSP16_Q(-0.03151211),
  DSP16_Q(0.02236153),
  DSP16_Q(-0.01621711),
  DSP16_Q(0.01177921),
  DSP16_Q(-0.00844366),
  DSP16_Q(0.00589195),
  DSP16_Q(-0.00393891),
  DSP16_Q(0.00246707),
  DSP16_Q(-0.00139526),
  DSP16_Q(0.00066233),
  DSP16_Q(-0.00021840),
  DSP16_Q(0.00001994),
  DSP16_Q(0.00002910),
  DSP16_Q(-0.00024843),
  DSP16_Q(0.00071683),
  DSP16_Q(-0.00147823),
  DSP16_Q(0.00258327),
  DSP16_Q(-0.00409443),
  DSP16_Q(0.00609533),
  DSP16_Q(-0.00870796),
  DSP16_Q(0.01212612),
  DSP16_Q(-0.01668601),
  DSP16_Q(0.02303190),
  DSP16_Q(-0.03256931),
  DSP16_Q(0.04902602),
  DSP16_Q(-0.08645999),
  DSP16_Q(0.28346730),
  DSP16_Q(0.23392394),
  DSP16_Q(-0.08088340),
  DSP16_Q(0.04694167),
  DSP16_Q(-0.03145317),
  DSP16_Q(0.02232150),
  DSP16_Q(-0.01618845),
  DSP16_Q(0.01175823),
  DSP16_Q(-0.00842824),
  DSP16_Q(0.00588073),
  DSP16_Q(-0.00393094),
  DSP16_Q(0.00246164),
  DSP16_Q(-0.00139178),
  DSP16_Q(0.00066032),
  DSP16_Q(-0.00021746),
  DSP16_Q(0.00001972),
  DSP16_Q(0.00002931),
  DSP16_Q(-0.00024892),
  DSP16_Q(0.00071742),
  DSP16_Q(-0.00147870),
  DSP16_Q(0.00258337),
  DSP16_Q(-0.00409387),
  DSP16_Q(0.00609381),
  DSP16_Q(-0.00870513),
  DSP16_Q(0.01212166),
  DSP16_Q(-0.01667969),
  DSP16_Q(0.02302381),
  DSP16_Q(-0.03256074),
  DSP16_Q(0.04902357),
  DSP16_Q(-0.08650630),
  DSP16_Q(0.28458861),
  DSP16_Q(0.23269690),
  DSP16_Q(-0.08067002),
  DSP16_Q(0.04684230),
  DSP16_Q(-0.03139272),
  DSP16_Q(0.02228040),
  DSP16_Q(-0.01615901),
  DSP16_Q(0.01173668),
  DSP16_Q(-0.00841241),
  DSP16_Q(0.00586923),
  DSP16_Q(-0.00392278),
  DSP16_Q(0.00245608),
  DSP16_Q(-0.00138823),
  DSP16_Q(0.00065829),
  DSP16_Q(-0.00021651),
  DSP16_Q(0.00001949),
  DSP16_Q(0.00002952),
  DSP16_Q(-0.00024939),
  DSP16_Q(0.00071797),
  DSP16_Q(-0.00147909),
  DSP16_Q(0.00258333),
  DSP16_Q(-0.00409310),
  DSP16_Q(0.00609196),
  DSP16_Q(-0.00870185),
  DSP16_Q(0.01211657),
  DSP16_Q(-0.01667251),
  DSP16_Q(0.02301453),
  DSP16_Q(-0.03255049),
  DSP16_Q(0.04901861),
  DSP16_Q(-0.08654834),
  DSP16_Q(0.28570671),
  DSP16_Q(0.23146817),
  DSP16_Q(-0.08045319),
  DSP16_Q(0.04674073),
  DSP16_Q(-0.03133076),
  DSP16_Q(0.02223821),
  DSP16_Q(-0.01612879),
  DSP16_Q(0.01171456),
  DSP16_Q(-0.00839617),
  DSP16_Q(0.00585745),
  DSP16_Q(-0.00391444),
  DSP16_Q(0.00245041),
  DSP16_Q(-0.00138462),
  DSP16_Q(0.00065622),
  DSP16_Q(-0.00021555),
  DSP16_Q(0.00001927),
  DSP16_Q(0.00002974),
  DSP16_Q(-0.00024986),
  DSP16_Q(0.00071848),
  DSP16_Q(-0.00147941),
  DSP16_Q(0.00258316),
  DSP16_Q(-0.00409211),
  DSP16_Q(0.00608979),
  DSP16_Q(-0.00869811),
  DSP16_Q(0.01211086),
  DSP16_Q(-0.01666446),
  DSP16_Q(0.02300406),
  DSP16_Q(-0.03253856),
  DSP16_Q(0.04901113),
  DSP16_Q(-0.08658609),
  DSP16_Q(0.28682158),
  DSP16_Q(0.23023777),
  DSP16_Q(-0.08023292),
  DSP16_Q(0.04663698),
  DSP16_Q(-0.03126730),
  DSP16_Q(0.02219495),
  DSP16_Q(-0.01609778),
  DSP16_Q(0.01169186),
  DSP16_Q(-0.00837953),
  DSP16_Q(0.00584538),
  DSP16_Q(-0.00390591),
  DSP16_Q(0.00244463),
  DSP16_Q(-0.00138094),
  DSP16_Q(0.00065412),
  DSP16_Q(-0.00021459),
  DSP16_Q(0.00001905),
  DSP16_Q(0.00002995),
  DSP16_Q(-0.00025031),
  DSP16_Q(0.00071895),
  DSP16_Q(-0.00147964),
  DSP16_Q(0.00258285),
  DSP16_Q(-0.00409091),
  DSP16_Q(0.00608731),
  DSP16_Q(-0.00869392),
  DSP16_Q(0.01210451),
  DSP16_Q(-0.01665555),
  DSP16_Q(0.02299239),
  DSP16_Q(-0.03252494),
  DSP16_Q(0.04900112),
  DSP16_Q(-0.08661953),
  DSP16_Q(0.28793317),
  DSP16_Q(0.22900576),
  DSP16_Q(-0.08000922),
  DSP16_Q(0.04653107),
  DSP16_Q(-0.03120235),
  DSP16_Q(0.02215062),
  DSP16_Q(-0.01606599),
  DSP16_Q(0.01166861),
  DSP16_Q(-0.00836248),
  DSP16_Q(0.00583303),
  DSP16_Q(-0.00389719),
  DSP16_Q(0.00243872),
  DSP16_Q(-0.00137720),
  DSP16_Q(0.00065200),
  DSP16_Q(-0.00021362),
  DSP16_Q(0.00001883),
  DSP16_Q(0.00003016),
  DSP16_Q(-0.00025075),
  DSP16_Q(0.00071939),
  DSP16_Q(-0.00147980),
  DSP16_Q(0.00258240),
  DSP16_Q(-0.00408949),
  DSP16_Q(0.00608451),
  DSP16_Q(-0.00868927),
  DSP16_Q(0.01209753),
  DSP16_Q(-0.01664576),
  DSP16_Q(0.02297953),
  DSP16_Q(-0.03250963),
  DSP16_Q(0.04898859),
  DSP16_Q(-0.08664865),
  DSP16_Q(0.28904145),
  DSP16_Q(0.22777215),
  DSP16_Q(-0.07978214),
  DSP16_Q(0.04642299),
  DSP16_Q(-0.03113592),
  DSP16_Q(0.02210522),
  DSP16_Q(-0.01603342),
  DSP16_Q(0.01164478),
  DSP16_Q(-0.00834503),
  DSP16_Q(0.00582040),
  DSP16_Q(-0.00388829),
  DSP16_Q(0.00243271),
  DSP16_Q(-0.00137340),
  DSP16_Q(0.00064985),
  DSP16_Q(-0.00021264),
  DSP16_Q(0.00001861),
  DSP16_Q(0.00003037),
  DSP16_Q(-0.00025117),
  DSP16_Q(0.00071978),
  DSP16_Q(-0.00147987),
  DSP16_Q(0.00258182),
  DSP16_Q(-0.00408786),
  DSP16_Q(0.00608139),
  DSP16_Q(-0.00868417),
  DSP16_Q(0.01208992),
  DSP16_Q(-0.01663512),
  DSP16_Q(0.02296547),
  DSP16_Q(-0.03249263),
  DSP16_Q(0.04897352),
  DSP16_Q(-0.08667343),
  DSP16_Q(0.29014639),
  DSP16_Q(0.22653700),
  DSP16_Q(-0.07955167),
  DSP16_Q(0.04631276),
  DSP16_Q(-0.03106800),
  DSP16_Q(0.02205875),
  DSP16_Q(-0.01600008),
  DSP16_Q(0.01162040),
  DSP16_Q(-0.00832717),
  DSP16_Q(0.00580749),
  DSP16_Q(-0.00387920),
  DSP16_Q(0.00242658),
  DSP16_Q(-0.00136953),
  DSP16_Q(0.00064767),
  DSP16_Q(-0.00021165),
  DSP16_Q(0.00001839),
  DSP16_Q(0.00003057),
  DSP16_Q(-0.00025158),
  DSP16_Q(0.00072014),
  DSP16_Q(-0.00147987),
  DSP16_Q(0.00258110),
  DSP16_Q(-0.00408601),
  DSP16_Q(0.00607794),
  DSP16_Q(-0.00867861),
  DSP16_Q(0.01208168),
  DSP16_Q(-0.01662360),
  DSP16_Q(0.02295021),
  DSP16_Q(-0.03247395),
  DSP16_Q(0.04895592),
  DSP16_Q(-0.08669385),
  DSP16_Q(0.29124797),
  DSP16_Q(0.22530033),
  DSP16_Q(-0.07931786),
  DSP16_Q(0.04620039),
  DSP16_Q(-0.03099860),
  DSP16_Q(0.02201123),
  DSP16_Q(-0.01596597),
  DSP16_Q(0.01159545),
  DSP16_Q(-0.00830891),
  DSP16_Q(0.00579431),
  DSP16_Q(-0.00386993),
  DSP16_Q(0.00242034),
  DSP16_Q(-0.00136560),
  DSP16_Q(0.00064546),
  DSP16_Q(-0.00021065),
  DSP16_Q(0.00001817),
  DSP16_Q(0.00003078),
  DSP16_Q(-0.00025198),
  DSP16_Q(0.00072046),
  DSP16_Q(-0.00147979),
  DSP16_Q(0.00258024),
  DSP16_Q(-0.00408394),
  DSP16_Q(0.00607418),
  DSP16_Q(-0.00867260),
  DSP16_Q(0.01207281),
  DSP16_Q(-0.01661121),
  DSP16_Q(0.02293375),
  DSP16_Q(-0.03245356),
  DSP16_Q(0.04893577),
  DSP16_Q(-0.08670991),
  DSP16_Q(0.29234614),
  DSP16_Q(0.22406217),
  DSP16_Q(-0.07908071),
  DSP16_Q(0.04608589),
  DSP16_Q(-0.03092774),
  DSP16_Q(0.02196265),
  DSP16_Q(-0.01593109),
  DSP16_Q(0.01156995),
  DSP16_Q(-0.00829026),
  DSP16_Q(0.00578084),
  DSP16_Q(-0.00386048),
  DSP16_Q(0.00241398),
  DSP16_Q(-0.00136161),
  DSP16_Q(0.00064322),
  DSP16_Q(-0.00020965),
  DSP16_Q(0.00001796),
  DSP16_Q(0.00003099),
  DSP16_Q(-0.00025236),
  DSP16_Q(0.00072074),
  DSP16_Q(-0.00147963),
  DSP16_Q(0.00257925),
  DSP16_Q(-0.00408166),
  DSP16_Q(0.00607010),
  DSP16_Q(-0.00866613),
  DSP16_Q(0.01206330),
  DSP16_Q(-0.01659795),
  DSP16_Q(0.02291610),
  DSP16_Q(-0.03243149),
  DSP16_Q(0.04891308),
  DSP16_Q(-0.08672158),
  DSP16_Q(0.29344087),
  DSP16_Q(0.22282257),
  DSP16_Q(-0.07884024),
  DSP16_Q(0.04596927),
  DSP16_Q(-0.03085541),
  DSP16_Q(0.02191302),
  DSP16_Q(-0.01589544),
  DSP16_Q(0.01154388),
  DSP16_Q(-0.00827120),
  DSP16_Q(0.00576711),
  DSP16_Q(-0.00385084),
  DSP16_Q(0.00240751),
  DSP16_Q(-0.00135756),
  DSP16_Q(0.00064096),
  DSP16_Q(-0.00020864),
  DSP16_Q(0.00001774),
  DSP16_Q(0.00003119),
  DSP16_Q(-0.00025273),
  DSP16_Q(0.00072098),
  DSP16_Q(-0.00147939),
  DSP16_Q(0.00257811),
  DSP16_Q(-0.00407917),
  DSP16_Q(0.00606570),
  DSP16_Q(-0.00865921),
  DSP16_Q(0.01205316),
  DSP16_Q(-0.01658383),
  DSP16_Q(0.02289724),
  DSP16_Q(-0.03240771),
  DSP16_Q(0.04888784),
  DSP16_Q(-0.08672885),
  DSP16_Q(0.29453213),
  DSP16_Q(0.22158156),
  DSP16_Q(-0.07859649),
  DSP16_Q(0.04585053),
  DSP16_Q(-0.03078162),
  DSP16_Q(0.02186235),
  DSP16_Q(-0.01585903),
  DSP16_Q(0.01151727),
  DSP16_Q(-0.00825175),
  DSP16_Q(0.00575309),
  DSP16_Q(-0.00384102),
  DSP16_Q(0.00240093),
  DSP16_Q(-0.00135345),
  DSP16_Q(0.00063867),
  DSP16_Q(-0.00020762),
  DSP16_Q(0.00001752),
  DSP16_Q(0.00003139),
  DSP16_Q(-0.00025309),
  DSP16_Q(0.00072118),
  DSP16_Q(-0.00147907),
  DSP16_Q(0.00257684),
  DSP16_Q(-0.00407645),
  DSP16_Q(0.00606097),
  DSP16_Q(-0.00865183),
  DSP16_Q(0.01204238),
  DSP16_Q(-0.01656883),
  DSP16_Q(0.02287718),
  DSP16_Q(-0.03238224),
  DSP16_Q(0.04886004),
  DSP16_Q(-0.08673171),
  DSP16_Q(0.29561990),
  DSP16_Q(0.22033917),
  DSP16_Q(-0.07834947),
  DSP16_Q(0.04572970),
  DSP16_Q(-0.03070638),
  DSP16_Q(0.02181063),
  DSP16_Q(-0.01582186),
  DSP16_Q(0.01149010),
  DSP16_Q(-0.00823191),
  DSP16_Q(0.00573881),
  DSP16_Q(-0.00383102),
  DSP16_Q(0.00239424),
  DSP16_Q(-0.00134928),
  DSP16_Q(0.00063635),
  DSP16_Q(-0.00020660),
  DSP16_Q(0.00001731),
  DSP16_Q(0.00003159),
  DSP16_Q(-0.00025343),
  DSP16_Q(0.00072134),
  DSP16_Q(-0.00147866),
  DSP16_Q(0.00257543),
  DSP16_Q(-0.00407352),
  DSP16_Q(0.00605592),
  DSP16_Q(-0.00864399),
  DSP16_Q(0.01203097),
  DSP16_Q(-0.01655296),
  DSP16_Q(0.02285592),
  DSP16_Q(-0.03235507),
  DSP16_Q(0.04882968),
  DSP16_Q(-0.08673013),
  DSP16_Q(0.29670412),
  DSP16_Q(0.21909545),
  DSP16_Q(-0.07809920),
  DSP16_Q(0.04560677),
  DSP16_Q(-0.03062969),
  DSP16_Q(0.02175787),
  DSP16_Q(-0.01578394),
  DSP16_Q(0.01146239),
  DSP16_Q(-0.00821168),
  DSP16_Q(0.00572425),
  DSP16_Q(-0.00382084),
  DSP16_Q(0.00238744),
  DSP16_Q(-0.00134505),
  DSP16_Q(0.00063401),
  DSP16_Q(-0.00020557),
  DSP16_Q(0.00001709),
  DSP16_Q(0.00003179),
  DSP16_Q(-0.00025376),
  DSP16_Q(0.00072146),
  DSP16_Q(-0.00147818),
  DSP16_Q(0.00257388),
  DSP16_Q(-0.00407037),
  DSP16_Q(0.00605056),
  DSP16_Q(-0.00863570),
  DSP16_Q(0.01201893),
  DSP16_Q(-0.01653622),
  DSP16_Q(0.02283346),
  DSP16_Q(-0.03232619),
  DSP16_Q(0.04879676),
  DSP16_Q(-0.08672411),
  DSP16_Q(0.29778479),
  DSP16_Q(0.21785041),
  DSP16_Q(-0.07784571),
  DSP16_Q(0.04548176),
  DSP16_Q(-0.03055157),
  DSP16_Q(0.02170408),
  DSP16_Q(-0.01574525),
  DSP16_Q(0.01143412),
  DSP16_Q(-0.00819105),
  DSP16_Q(0.00570942),
  DSP16_Q(-0.00381049),
  DSP16_Q(0.00238053),
  DSP16_Q(-0.00134075),
  DSP16_Q(0.00063164),
  DSP16_Q(-0.00020453),
  DSP16_Q(0.00001688),
  DSP16_Q(0.00003199),
  DSP16_Q(-0.00025407),
  DSP16_Q(0.00072154),
  DSP16_Q(-0.00147762),
  DSP16_Q(0.00257220),
  DSP16_Q(-0.00406700),
  DSP16_Q(0.00604487),
  DSP16_Q(-0.00862694),
  DSP16_Q(0.01200625),
  DSP16_Q(-0.01651860),
  DSP16_Q(0.02280979),
  DSP16_Q(-0.03229561),
  DSP16_Q(0.04876127),
  DSP16_Q(-0.08671364),
  DSP16_Q(0.29886185),
  DSP16_Q(0.21660411),
  DSP16_Q(-0.07758901),
  DSP16_Q(0.04535469),
  DSP16_Q(-0.03047201),
  DSP16_Q(0.02164925),
  DSP16_Q(-0.01570582),
  DSP16_Q(0.01140531),
  DSP16_Q(-0.00817003),
  DSP16_Q(0.00569433),
  DSP16_Q(-0.00379995),
  DSP16_Q(0.00237351),
  DSP16_Q(-0.00133640),
  DSP16_Q(0.00062925),
  DSP16_Q(-0.00020348),
  DSP16_Q(0.00001666),
  DSP16_Q(0.00003219),
  DSP16_Q(-0.00025437),
  DSP16_Q(0.00072158),
  DSP16_Q(-0.00147698),
  DSP16_Q(0.00257037),
  DSP16_Q(-0.00406341),
  DSP16_Q(0.00603885),
  DSP16_Q(-0.00861773),
  DSP16_Q(0.01199293),
  DSP16_Q(-0.01650011),
  DSP16_Q(0.02278492),
  DSP16_Q(-0.03226333),
  DSP16_Q(0.04872321),
  DSP16_Q(-0.08669869),
  DSP16_Q(0.29993528),
  DSP16_Q(0.21535658),
  DSP16_Q(-0.07732913),
  DSP16_Q(0.04522555),
  DSP16_Q(-0.03039102),
  DSP16_Q(0.02159340),
  DSP16_Q(-0.01566564),
  DSP16_Q(0.01137596),
  DSP16_Q(-0.00814863),
  DSP16_Q(0.00567896),
  DSP16_Q(-0.00378924),
  DSP16_Q(0.00236639),
  DSP16_Q(-0.00133199),
  DSP16_Q(0.00062682),
  DSP16_Q(-0.00020243),
  DSP16_Q(0.00001645),
  DSP16_Q(0.00003238),
  DSP16_Q(-0.00025465),
  DSP16_Q(0.00072158),
  DSP16_Q(-0.00147625),
  DSP16_Q(0.00256841),
  DSP16_Q(-0.00405961),
  DSP16_Q(0.00603252),
  DSP16_Q(-0.00860806),
  DSP16_Q(0.01197898),
  DSP16_Q(-0.01648075),
  DSP16_Q(0.02275885),
  DSP16_Q(-0.03222934),
  DSP16_Q(0.04868258),
  DSP16_Q(-0.08667925),
  DSP16_Q(0.30100506),
  DSP16_Q(0.21410785),
  DSP16_Q(-0.07706610),
  DSP16_Q(0.04509437),
  DSP16_Q(-0.03030862),
  DSP16_Q(0.02153653),
  DSP16_Q(-0.01562472),
  DSP16_Q(0.01134607),
  DSP16_Q(-0.00812684),
  DSP16_Q(0.00566333),
  DSP16_Q(-0.00377835),
  DSP16_Q(0.00235915),
  DSP16_Q(-0.00132752),
  DSP16_Q(0.00062438),
  DSP16_Q(-0.00020137),
  DSP16_Q(0.00001624),
  DSP16_Q(0.00003258),
  DSP16_Q(-0.00025492),
  DSP16_Q(0.00072154),
  DSP16_Q(-0.00147545),
  DSP16_Q(0.00256630),
  DSP16_Q(-0.00405559),
  DSP16_Q(0.00602586),
  DSP16_Q(-0.00859793),
  DSP16_Q(0.01196439),
  DSP16_Q(-0.01646052),
  DSP16_Q(0.02273157),
  DSP16_Q(-0.03219365),
  DSP16_Q(0.04863937),
  DSP16_Q(-0.08665531),
  DSP16_Q(0.30207113),
  DSP16_Q(0.21285796),
  DSP16_Q(-0.07679992),
  DSP16_Q(0.04496115),
  DSP16_Q(-0.03022480),
  DSP16_Q(0.02147864),
  DSP16_Q(-0.01558305),
  DSP16_Q(0.01131563),
  DSP16_Q(-0.00810467),
  DSP16_Q(0.00564743),
  DSP16_Q(-0.00376729),
  DSP16_Q(0.00235181),
  DSP16_Q(-0.00132299),
  DSP16_Q(0.00062190),
  DSP16_Q(-0.00020031),
  DSP16_Q(0.00001603),
  DSP16_Q(0.00003277),
  DSP16_Q(-0.00025517),
  DSP16_Q(0.00072146),
  DSP16_Q(-0.00147456),
  DSP16_Q(0.00256406),
  DSP16_Q(-0.00405135),
  DSP16_Q(0.00601888),
  DSP16_Q(-0.00858735),
  DSP16_Q(0.01194917),
  DSP16_Q(-0.01643942),
  DSP16_Q(0.02270309),
  DSP16_Q(-0.03215624),
  DSP16_Q(0.04859358),
  DSP16_Q(-0.08662686),
  DSP16_Q(0.30313349),
  DSP16_Q(0.21160694),
  DSP16_Q(-0.07653062),
  DSP16_Q(0.04482589),
  DSP16_Q(-0.03013957),
  DSP16_Q(0.02141973),
  DSP16_Q(-0.01554065),
  DSP16_Q(0.01128467),
  DSP16_Q(-0.00808211),
  DSP16_Q(0.00563127),
  DSP16_Q(-0.00375605),
  DSP16_Q(0.00234436),
  DSP16_Q(-0.00131841),
  DSP16_Q(0.00061940),
  DSP16_Q(-0.00019924),
  DSP16_Q(0.00001582),
  DSP16_Q(0.00003296),
  DSP16_Q(-0.00025541),
  DSP16_Q(0.00072134),
  DSP16_Q(-0.00147359),
  DSP16_Q(0.00256167),
  DSP16_Q(-0.00404689),
  DSP16_Q(0.00601158),
  DSP16_Q(-0.00857630),
  DSP16_Q(0.01193331),
  DSP16_Q(-0.01641744),
  DSP16_Q(0.02267339),
  DSP16_Q(-0.03211713),
  DSP16_Q(0.04854521),
  DSP16_Q(-0.08659388),
  DSP16_Q(0.30419208),
  DSP16_Q(0.21035483),
  DSP16_Q(-0.07625824),
  DSP16_Q(0.04468863),
  DSP16_Q(-0.03005294),
  DSP16_Q(0.02135982),
  DSP16_Q(-0.01549751),
  DSP16_Q(0.01125316),
  DSP16_Q(-0.00805917),
  DSP16_Q(0.00561484),
  DSP16_Q(-0.00374464),
  DSP16_Q(0.00233681),
  DSP16_Q(-0.00131376),
  DSP16_Q(0.00061688),
  DSP16_Q(-0.00019816),
  DSP16_Q(0.00001561),
  DSP16_Q(0.00003315),
  DSP16_Q(-0.00025564),
  DSP16_Q(0.00072118),
  DSP16_Q(-0.00147254),
  DSP16_Q(0.00255915),
  DSP16_Q(-0.00404221),
  DSP16_Q(0.00600395),
  DSP16_Q(-0.00856480),
  DSP16_Q(0.01191681),
  DSP16_Q(-0.01639458),
  DSP16_Q(0.02264250),
  DSP16_Q(-0.03207631),
  DSP16_Q(0.04849425),
  DSP16_Q(-0.08655635),
  DSP16_Q(0.30524689),
  DSP16_Q(0.20910166),
  DSP16_Q(-0.07598278),
  DSP16_Q(0.04454935),
  DSP16_Q(-0.02996492),
  DSP16_Q(0.02129891),
  DSP16_Q(-0.01545364),
  DSP16_Q(0.01122113),
  DSP16_Q(-0.00803586),
  DSP16_Q(0.00559815),
  DSP16_Q(-0.00373306),
  DSP16_Q(0.00232915),
  DSP16_Q(-0.00130906),
  DSP16_Q(0.00061433),
  DSP16_Q(-0.00019708),
  DSP16_Q(0.00001540),
  DSP16_Q(0.00003334),
  DSP16_Q(-0.00025585),
  DSP16_Q(0.00072098),
  DSP16_Q(-0.00147141),
  DSP16_Q(0.00255648),
  DSP16_Q(-0.00403731),
  DSP16_Q(0.00599600),
  DSP16_Q(-0.00855284),
  DSP16_Q(0.01189968),
  DSP16_Q(-0.01637085),
  DSP16_Q(0.02261039),
  DSP16_Q(-0.03203377),
  DSP16_Q(0.04844070),
  DSP16_Q(-0.08651427),
  DSP16_Q(0.30629788),
  DSP16_Q(0.20784747),
  DSP16_Q(-0.07570427),
  DSP16_Q(0.04440809),
  DSP16_Q(-0.02987551),
  DSP16_Q(0.02123699),
  DSP16_Q(-0.01540904),
  DSP16_Q(0.01118857),
  DSP16_Q(-0.00801216),
  DSP16_Q(0.00558120),
  DSP16_Q(-0.00372131),
  DSP16_Q(0.00232138),
  DSP16_Q(-0.00130431),
  DSP16_Q(0.00061176),
  DSP16_Q(-0.00019599),
  DSP16_Q(0.00001520),
  DSP16_Q(0.00003352),
  DSP16_Q(-0.00025604),
  DSP16_Q(0.00072074),
  DSP16_Q(-0.00147020),
  DSP16_Q(0.00255368),
  DSP16_Q(-0.00403219),
  DSP16_Q(0.00598773),
  DSP16_Q(-0.00854041),
  DSP16_Q(0.01188191),
  DSP16_Q(-0.01634625),
  DSP16_Q(0.02257709),
  DSP16_Q(-0.03198953),
  DSP16_Q(0.04838456),
  DSP16_Q(-0.08646761),
  DSP16_Q(0.30734501),
  DSP16_Q(0.20659230),
  DSP16_Q(-0.07542273),
  DSP16_Q(0.04426483),
  DSP16_Q(-0.02978472),
  DSP16_Q(0.02117408),
  DSP16_Q(-0.01536372),
  DSP16_Q(0.01115548),
  DSP16_Q(-0.00798810),
  DSP16_Q(0.00556400),
  DSP16_Q(-0.00370938),
  DSP16_Q(0.00231351),
  DSP16_Q(-0.00129949),
  DSP16_Q(0.00060917),
  DSP16_Q(-0.00019490),
  DSP16_Q(0.00001499),
  DSP16_Q(0.00003370),
  DSP16_Q(-0.00025622),
  DSP16_Q(0.00072045),
  DSP16_Q(-0.00146890),
  DSP16_Q(0.00255073),
  DSP16_Q(-0.00402685),
  DSP16_Q(0.00597913),
  DSP16_Q(-0.00852753),
  DSP16_Q(0.01186351),
  DSP16_Q(-0.01632078),
  DSP16_Q(0.02254257),
  DSP16_Q(-0.03194357),
  DSP16_Q(0.04832582),
  DSP16_Q(-0.08641638),
  DSP16_Q(0.30838826),
  DSP16_Q(0.20533618),
  DSP16_Q(-0.07513819),
  DSP16_Q(0.04411961),
  DSP16_Q(-0.02969255),
  DSP16_Q(0.02111018),
  DSP16_Q(-0.01531767),
  DSP16_Q(0.01112187),
  DSP16_Q(-0.00796366),
  DSP16_Q(0.00554653),
  DSP16_Q(-0.00369729),
  DSP16_Q(0.00230554),
  DSP16_Q(-0.00129462),
  DSP16_Q(0.00060655),
  DSP16_Q(-0.00019379),
  DSP16_Q(0.00001479),
  DSP16_Q(0.00003389),
  DSP16_Q(-0.00025639),
  DSP16_Q(0.00072012),
  DSP16_Q(-0.00146752),
  DSP16_Q(0.00254765),
  DSP16_Q(-0.00402129),
  DSP16_Q(0.00597021),
  DSP16_Q(-0.00851419),
  DSP16_Q(0.01184446),
  DSP16_Q(-0.01629443),
  DSP16_Q(0.02250685),
  DSP16_Q(-0.03189590),
  DSP16_Q(0.04826448),
  DSP16_Q(-0.08636055),
  DSP16_Q(0.30942760),
  DSP16_Q(0.20407914),
  DSP16_Q(-0.07485066),
  DSP16_Q(0.04397242),
  DSP16_Q(-0.02959902),
  DSP16_Q(0.02104530),
  DSP16_Q(-0.01527091),
  DSP16_Q(0.01108774),
  DSP16_Q(-0.00793884),
  DSP16_Q(0.00552881),
  DSP16_Q(-0.00368503),
  DSP16_Q(0.00229747),
  DSP16_Q(-0.00128970),
  DSP16_Q(0.00060390),
  DSP16_Q(-0.00019269),
  DSP16_Q(0.00001458),
  DSP16_Q(0.00003407),
  DSP16_Q(-0.00025654),
  DSP16_Q(0.00071976),
  DSP16_Q(-0.00146606),
  DSP16_Q(0.00254442),
  DSP16_Q(-0.00401552),
  DSP16_Q(0.00596097),
  DSP16_Q(-0.00850039),
  DSP16_Q(0.01182479),
  DSP16_Q(-0.01626720),
  DSP16_Q(0.02246992),
  DSP16_Q(-0.03184652),
  DSP16_Q(0.04820054),
  DSP16_Q(-0.08630010),
  DSP16_Q(0.31046300),
  DSP16_Q(0.20282123),
  DSP16_Q(-0.07456018),
  DSP16_Q(0.04382329),
  DSP16_Q(-0.02950413),
  DSP16_Q(0.02097943),
  DSP16_Q(-0.01522343),
  DSP16_Q(0.01105309),
  DSP16_Q(-0.00791366),
  DSP16_Q(0.00551083),
  DSP16_Q(-0.00367260),
  DSP16_Q(0.00228929),
  DSP16_Q(-0.00128472),
  DSP16_Q(0.00060123),
  DSP16_Q(-0.00019158),
  DSP16_Q(0.00001438),
  DSP16_Q(0.00003424),
  DSP16_Q(-0.00025667),
  DSP16_Q(0.00071935),
  DSP16_Q(-0.00146452),
  DSP16_Q(0.00254105),
  DSP16_Q(-0.00400952),
  DSP16_Q(0.00595140),
  DSP16_Q(-0.00848613),
  DSP16_Q(0.01180447),
  DSP16_Q(-0.01623911),
  DSP16_Q(0.02243178),
  DSP16_Q(-0.03179542),
  DSP16_Q(0.04813400),
  DSP16_Q(-0.08623504),
  DSP16_Q(0.31149442),
  DSP16_Q(0.20156247),
  DSP16_Q(-0.07426676),
  DSP16_Q(0.04367221),
  DSP16_Q(-0.02940788),
  DSP16_Q(0.02091259),
  DSP16_Q(-0.01517524),
  DSP16_Q(0.01101792),
  DSP16_Q(-0.00788811),
  DSP16_Q(0.00549260),
  DSP16_Q(-0.00366000),
  DSP16_Q(0.00228101),
  DSP16_Q(-0.00127969),
  DSP16_Q(0.00059854),
  DSP16_Q(-0.00019046),
  DSP16_Q(0.00001418),
  DSP16_Q(0.00003442),
  DSP16_Q(-0.00025679),
  DSP16_Q(0.00071889),
  DSP16_Q(-0.00146290),
  DSP16_Q(0.00253754),
  DSP16_Q(-0.00400330),
  DSP16_Q(0.00594151),
  DSP16_Q(-0.00847142),
  DSP16_Q(0.01178352),
  DSP16_Q(-0.01621014),
  DSP16_Q(0.02239244),
  DSP16_Q(-0.03174261),
  DSP16_Q(0.04806485),
  DSP16_Q(-0.08616534),
  DSP16_Q(0.31252183),
  DSP16_Q(0.20030291),
  DSP16_Q(-0.07397042),
  DSP16_Q(0.04351921),
  DSP16_Q(-0.02931029),
  DSP16_Q(0.02084478),
  DSP16_Q(-0.01512634),
  DSP16_Q(0.01098224),
  DSP16_Q(-0.00786219),
  DSP16_Q(0.00547412),
  DSP16_Q(-0.00364724),
  DSP16_Q(0.00227264),
  DSP16_Q(-0.00127460),
  DSP16_Q(0.00059583),
  DSP16_Q(-0.00018934),
  DSP16_Q(0.00001398),
  DSP16_Q(0.00003459),
  DSP16_Q(-0.00025689),
  DSP16_Q(0.00071840),
  DSP16_Q(-0.00146119),
  DSP16_Q(0.00253389),
  DSP16_Q(-0.00399686),
  DSP16_Q(0.00593129),
  DSP16_Q(-0.00845624),
  DSP16_Q(0.01176193),
  DSP16_Q(-0.01618030),
  DSP16_Q(0.02235189),
  DSP16_Q(-0.03168809),
  DSP16_Q(0.04799310),
  DSP16_Q(-0.08609100),
  DSP16_Q(0.31354520),
  DSP16_Q(0.19904258),
  DSP16_Q(-0.07367119),
  DSP16_Q(0.04336429),
  DSP16_Q(-0.02921136),
  DSP16_Q(0.02077600),
  DSP16_Q(-0.01507673),
  DSP16_Q(0.01094605),
  DSP16_Q(-0.00783591),
  DSP16_Q(0.00545539),
  DSP16_Q(-0.00363431),
  DSP16_Q(0.00226416),
  DSP16_Q(-0.00126946),
  DSP16_Q(0.00059309),
  DSP16_Q(-0.00018821),
  DSP16_Q(0.00001378),
  DSP16_Q(0.00003476),
  DSP16_Q(-0.00025697),
  DSP16_Q(0.00071787),
  DSP16_Q(-0.00145939),
  DSP16_Q(0.00253010),
  DSP16_Q(-0.00399021),
  DSP16_Q(0.00592075),
  DSP16_Q(-0.00844060),
  DSP16_Q(0.01173971),
  DSP16_Q(-0.01614958),
  DSP16_Q(0.02231014),
  DSP16_Q(-0.03163185),
  DSP16_Q(0.04791874),
  DSP16_Q(-0.08601199),
  DSP16_Q(0.31456451),
  DSP16_Q(0.19778151),
  DSP16_Q(-0.07336909),
  DSP16_Q(0.04320747),
  DSP16_Q(-0.02911110),
  DSP16_Q(0.02070626),
  DSP16_Q(-0.01502643),
  DSP16_Q(0.01090934),
  DSP16_Q(-0.00780927),
  DSP16_Q(0.00543640),
  DSP16_Q(-0.00362123),
  DSP16_Q(0.00225558),
  DSP16_Q(-0.00126427),
  DSP16_Q(0.00059034),
  DSP16_Q(-0.00018708),
  DSP16_Q(0.00001358),
  DSP16_Q(0.00003493),
  DSP16_Q(-0.00025705),
  DSP16_Q(0.00071729),
  DSP16_Q(-0.00145752),
  DSP16_Q(0.00252617),
  DSP16_Q(-0.00398333),
  DSP16_Q(0.00590989),
  DSP16_Q(-0.00842451),
  DSP16_Q(0.01171685),
  DSP16_Q(-0.01611799),
  DSP16_Q(0.02226718),
  DSP16_Q(-0.03157390),
  DSP16_Q(0.04784176),
  DSP16_Q(-0.08592831),
  DSP16_Q(0.31557971),
  DSP16_Q(0.19651974),
  DSP16_Q(-0.07306414),
  DSP16_Q(0.04304875),
  DSP16_Q(-0.02900952),
  DSP16_Q(0.02063557),
  DSP16_Q(-0.01497543),
  DSP16_Q(0.01087214),
  DSP16_Q(-0.00778227),
  DSP16_Q(0.00541717),
  DSP16_Q(-0.00360797),
  DSP16_Q(0.00224691),
  DSP16_Q(-0.00125902),
  DSP16_Q(0.00058756),
  DSP16_Q(-0.00018594),
  DSP16_Q(0.00001338),
  DSP16_Q(0.00003510),
  DSP16_Q(-0.00025710),
  DSP16_Q(0.00071667),
  DSP16_Q(-0.00145556),
  DSP16_Q(0.00252210),
  DSP16_Q(-0.00397623),
  DSP16_Q(0.00589870),
  DSP16_Q(-0.00840796),
  DSP16_Q(0.01169336),
  DSP16_Q(-0.01608553),
  DSP16_Q(0.02222301),
  DSP16_Q(-0.03151423),
  DSP16_Q(0.04776218),
  DSP16_Q(-0.08583995),
  DSP16_Q(0.31659079),
  DSP16_Q(0.19525730),
  DSP16_Q(-0.07275638),
  DSP16_Q(0.04288816),
  DSP16_Q(-0.02890662),
  DSP16_Q(0.02056392),
  DSP16_Q(-0.01492373),
  DSP16_Q(0.01083443),
  DSP16_Q(-0.00775491),
  DSP16_Q(0.00539769),
  DSP16_Q(-0.00359456),
  DSP16_Q(0.00223813),
  DSP16_Q(-0.00125372),
  DSP16_Q(0.00058475),
  DSP16_Q(-0.00018480),
  DSP16_Q(0.00001319),
  DSP16_Q(0.00003527),
  DSP16_Q(-0.00025714),
  DSP16_Q(0.00071601),
  DSP16_Q(-0.00145352),
  DSP16_Q(0.00251788),
  DSP16_Q(-0.00396891),
  DSP16_Q(0.00588719),
  DSP16_Q(-0.00839094),
  DSP16_Q(0.01166923),
  DSP16_Q(-0.01605220),
  DSP16_Q(0.02217764),
  DSP16_Q(-0.03145285),
  DSP16_Q(0.04767997),
  DSP16_Q(-0.08574689),
  DSP16_Q(0.31759771),
  DSP16_Q(0.19399423),
  DSP16_Q(-0.07244581),
  DSP16_Q(0.04272569),
  DSP16_Q(-0.02880241),
  DSP16_Q(0.02049133),
  DSP16_Q(-0.01487135),
  DSP16_Q(0.01079622),
  DSP16_Q(-0.00772719),
  DSP16_Q(0.00537797),
  DSP16_Q(-0.00358098),
  DSP16_Q(0.00222926),
  DSP16_Q(-0.00124837),
  DSP16_Q(0.00058193),
  DSP16_Q(-0.00018365),
  DSP16_Q(0.00001299),
  DSP16_Q(0.00003543),
  DSP16_Q(-0.00025716),
  DSP16_Q(0.00071530),
  DSP16_Q(-0.00145139),
  DSP16_Q(0.00251352),
  DSP16_Q(-0.00396137),
  DSP16_Q(0.00587535),
  DSP16_Q(-0.00837347),
  DSP16_Q(0.01164447),
  DSP16_Q(-0.01601799),
  DSP16_Q(0.02213106),
  DSP16_Q(-0.03138975),
  DSP16_Q(0.04759515),
  DSP16_Q(-0.08564912),
  DSP16_Q(0.31860044),
  DSP16_Q(0.19273057),
  DSP16_Q(-0.07213246),
  DSP16_Q(0.04256136),
  DSP16_Q(-0.02869689),
  DSP16_Q(0.02041779),
  DSP16_Q(-0.01481827),
  DSP16_Q(0.01075751),
  DSP16_Q(-0.00769912),
  DSP16_Q(0.00535800),
  DSP16_Q(-0.00356725),
  DSP16_Q(0.00222029),
  DSP16_Q(-0.00124297),
  DSP16_Q(0.00057908),
  DSP16_Q(-0.00018250),
  DSP16_Q(0.00001280),
  DSP16_Q(0.00003559),
  DSP16_Q(-0.00025717),
  DSP16_Q(0.00071456),
  DSP16_Q(-0.00144919),
  DSP16_Q(0.00250902),
  DSP16_Q(-0.00395361),
  DSP16_Q(0.00586319),
  DSP16_Q(-0.00835555),
  DSP16_Q(0.01161907),
  DSP16_Q(-0.01598292),
  DSP16_Q(0.02208329),
  DSP16_Q(-0.03132494),
  DSP16_Q(0.04750772),
  DSP16_Q(-0.08554664),
  DSP16_Q(0.31959895),
  DSP16_Q(0.19146635),
  DSP16_Q(-0.07181635),
  DSP16_Q(0.04239519),
  DSP16_Q(-0.02859008),
  DSP16_Q(0.02034332),
  DSP16_Q(-0.01476452),
  DSP16_Q(0.01071830),
  DSP16_Q(-0.00767070),
  DSP16_Q(0.00533779),
  DSP16_Q(-0.00355336),
  DSP16_Q(0.00221123),
  DSP16_Q(-0.00123752),
  DSP16_Q(0.00057622),
  DSP16_Q(-0.00018134),
  DSP16_Q(0.00001260),
  DSP16_Q(0.00003575),
  DSP16_Q(-0.00025716),
  DSP16_Q(0.00071377),
  DSP16_Q(-0.00144689),
  DSP16_Q(0.00250438),
  DSP16_Q(-0.00394563),
  DSP16_Q(0.00585071),
  DSP16_Q(-0.00833716),
  DSP16_Q(0.01159304),
  DSP16_Q(-0.01594697),
  DSP16_Q(0.02203430),
  DSP16_Q(-0.03125842),
  DSP16_Q(0.04741766),
  DSP16_Q(-0.08543942),
  DSP16_Q(0.32059322),
  DSP16_Q(0.19020161),
  DSP16_Q(-0.07149752),
  DSP16_Q(0.04222719),
  DSP16_Q(-0.02848199),
  DSP16_Q(0.02026792),
  DSP16_Q(-0.01471008),
  DSP16_Q(0.01067861),
  DSP16_Q(-0.00764192),
  DSP16_Q(0.00531734),
  DSP16_Q(-0.00353931),
  DSP16_Q(0.00220207),
  DSP16_Q(-0.00123202),
  DSP16_Q(0.00057333),
  DSP16_Q(-0.00018018),
  DSP16_Q(0.00001241),
  DSP16_Q(0.00003590),
  DSP16_Q(-0.00025713),
  DSP16_Q(0.00071293),
  DSP16_Q(-0.00144452),
  DSP16_Q(0.00249959),
  DSP16_Q(-0.00393743),
  DSP16_Q(0.00583790),
  DSP16_Q(-0.00831831),
  DSP16_Q(0.01156637),
  DSP16_Q(-0.01591016),
  DSP16_Q(0.02198412),
  DSP16_Q(-0.03119019),
  DSP16_Q(0.04732498),
  DSP16_Q(-0.08532746),
  DSP16_Q(0.32158320),
  DSP16_Q(0.18893638),
  DSP16_Q(-0.07117598),
  DSP16_Q(0.04205737),
  DSP16_Q(-0.02837261),
  DSP16_Q(0.02019160),
  DSP16_Q(-0.01465498),
  DSP16_Q(0.01063842),
  DSP16_Q(-0.00761280),
  DSP16_Q(0.00529665),
  DSP16_Q(-0.00352510),
  DSP16_Q(0.00219282),
  DSP16_Q(-0.00122647),
  DSP16_Q(0.00057042),
  DSP16_Q(-0.00017902),
  DSP16_Q(0.00001222),
  DSP16_Q(0.00003606),
  DSP16_Q(-0.00025709),
  DSP16_Q(0.00071206),
  DSP16_Q(-0.00144206),
  DSP16_Q(0.00249467),
  DSP16_Q(-0.00392901),
  DSP16_Q(0.00582478),
  DSP16_Q(-0.00829901),
  DSP16_Q(0.01153907),
  DSP16_Q(-0.01587247),
  DSP16_Q(0.02193273),
  DSP16_Q(-0.03112024),
  DSP16_Q(0.04722969),
  DSP16_Q(-0.08521074),
  DSP16_Q(0.32256887),
  DSP16_Q(0.18767070),
  DSP16_Q(-0.07085175),
  DSP16_Q(0.04188573),
  DSP16_Q(-0.02826196),
  DSP16_Q(0.02011435),
  DSP16_Q(-0.01459919),
  DSP16_Q(0.01059775),
  DSP16_Q(-0.00758333),
  DSP16_Q(0.00527572),
  DSP16_Q(-0.00351074),
  DSP16_Q(0.00218348),
  DSP16_Q(-0.00122086),
  DSP16_Q(0.00056749),
  DSP16_Q(-0.00017785),
  DSP16_Q(0.00001204),
  DSP16_Q(0.00003621),
  DSP16_Q(-0.00025703),
  DSP16_Q(0.00071114),
  DSP16_Q(-0.00143951),
  DSP16_Q(0.00248960),
  DSP16_Q(-0.00392037),
  DSP16_Q(0.00581132),
  DSP16_Q(-0.00827925),
  DSP16_Q(0.01151114),
  DSP16_Q(-0.01583392),
  DSP16_Q(0.02188015),
  DSP16_Q(-0.03104858),
  DSP16_Q(0.04713177),
  DSP16_Q(-0.08508926),
  DSP16_Q(0.32355021),
  DSP16_Q(0.18640460),
  DSP16_Q(-0.07052486),
  DSP16_Q(0.04171230),
  DSP16_Q(-0.02815005),
  DSP16_Q(0.02003619),
  DSP16_Q(-0.01454275),
  DSP16_Q(0.01055659),
  DSP16_Q(-0.00755352),
  DSP16_Q(0.00525456),
  DSP16_Q(-0.00349623),
  DSP16_Q(0.00217404),
  DSP16_Q(-0.00121521),
  DSP16_Q(0.00056454),
  DSP16_Q(-0.00017668),
  DSP16_Q(0.00001185),
  DSP16_Q(0.00003636),
  DSP16_Q(-0.00025695),
  DSP16_Q(0.00071018),
  DSP16_Q(-0.00143688),
  DSP16_Q(0.00248439),
  DSP16_Q(-0.00391151),
  DSP16_Q(0.00579755),
  DSP16_Q(-0.00825904),
  DSP16_Q(0.01148258),
  DSP16_Q(-0.01579450),
  DSP16_Q(0.02182636),
  DSP16_Q(-0.03097521),
  DSP16_Q(0.04703122),
  DSP16_Q(-0.08496301),
  DSP16_Q(0.32452718),
  DSP16_Q(0.18513811),
  DSP16_Q(-0.07019533),
  DSP16_Q(0.04153708),
  DSP16_Q(-0.02803688),
  DSP16_Q(0.01995712),
  DSP16_Q(-0.01448563),
  DSP16_Q(0.01051495),
  DSP16_Q(-0.00752337),
  DSP16_Q(0.00523316),
  DSP16_Q(-0.00348156),
  DSP16_Q(0.00216451),
  DSP16_Q(-0.00120951),
  DSP16_Q(0.00056157),
  DSP16_Q(-0.00017550),
  DSP16_Q(0.00001166),
  DSP16_Q(0.00003650),
  DSP16_Q(-0.00025686),
  DSP16_Q(0.00070917),
  DSP16_Q(-0.00143417),
  DSP16_Q(0.00247904),
  DSP16_Q(-0.00390243),
  DSP16_Q(0.00578345),
  DSP16_Q(-0.00823837),
  DSP16_Q(0.01145338),
  DSP16_Q(-0.01575421),
  DSP16_Q(0.02177137),
  DSP16_Q(-0.03090013),
  DSP16_Q(0.04692806),
  DSP16_Q(-0.08483197),
  DSP16_Q(0.32549975),
  DSP16_Q(0.18387128),
  DSP16_Q(-0.06986318),
  DSP16_Q(0.04136009),
  DSP16_Q(-0.02792247),
  DSP16_Q(0.01987715),
  DSP16_Q(-0.01442786),
  DSP16_Q(0.01047284),
  DSP16_Q(-0.00749287),
  DSP16_Q(0.00521153),
  DSP16_Q(-0.00346674),
  DSP16_Q(0.00215489),
  DSP16_Q(-0.00120377),
  DSP16_Q(0.00055858),
  DSP16_Q(-0.00017432),
  DSP16_Q(0.00001148),
  DSP16_Q(0.00003664),
  DSP16_Q(-0.00025675),
  DSP16_Q(0.00070813),
  DSP16_Q(-0.00143137),
  DSP16_Q(0.00247354),
  DSP16_Q(-0.00389313),
  DSP16_Q(0.00576903),
  DSP16_Q(-0.00821724),
  DSP16_Q(0.01142356),
  DSP16_Q(-0.01571306),
  DSP16_Q(0.02171519),
  DSP16_Q(-0.03082334),
  DSP16_Q(0.04682226),
  DSP16_Q(-0.08469613),
  DSP16_Q(0.32646789),
  DSP16_Q(0.18260414),
  DSP16_Q(-0.06952844),
  DSP16_Q(0.04118134),
  DSP16_Q(-0.02780681),
  DSP16_Q(0.01979627),
  DSP16_Q(-0.01436944),
  DSP16_Q(0.01043025),
  DSP16_Q(-0.00746204),
  DSP16_Q(0.00518966),
  DSP16_Q(-0.00345177),
  DSP16_Q(0.00214517),
  DSP16_Q(-0.00119797),
  DSP16_Q(0.00055558),
  DSP16_Q(-0.00017313),
  DSP16_Q(0.00001129),
  DSP16_Q(0.00003678),
  DSP16_Q(-0.00025662),
  DSP16_Q(0.00070703),
  DSP16_Q(-0.00142849),
  DSP16_Q(0.00246791),
  DSP16_Q(-0.00388360),
  DSP16_Q(0.00575428),
  DSP16_Q(-0.00819565),
  DSP16_Q(0.01139310),
  DSP16_Q(-0.01567104),
  DSP16_Q(0.02165781),
  DSP16_Q(-0.03074484),
  DSP16_Q(0.04671385),
  DSP16_Q(-0.08455548),
  DSP16_Q(0.32743158),
  DSP16_Q(0.18133673),
  DSP16_Q(-0.06919114),
  DSP16_Q(0.04100084),
  DSP16_Q(-0.02768991),
  DSP16_Q(0.01971451),
  DSP16_Q(-0.01431036),
  DSP16_Q(0.01038718),
  DSP16_Q(-0.00743087),
  DSP16_Q(0.00516757),
  DSP16_Q(-0.00343664),
  DSP16_Q(0.00213537),
  DSP16_Q(-0.00119213),
  DSP16_Q(0.00055255),
  DSP16_Q(-0.00017195),
  DSP16_Q(0.00001111),
  DSP16_Q(0.00003692),
  DSP16_Q(-0.00025648),
  DSP16_Q(0.00070590),
  DSP16_Q(-0.00142553),
  DSP16_Q(0.00246213),
  DSP16_Q(-0.00387386),
  DSP16_Q(0.00573921),
  DSP16_Q(-0.00817361),
  DSP16_Q(0.01136201),
  DSP16_Q(-0.01562816),
  DSP16_Q(0.02159923),
  DSP16_Q(-0.03066464),
  DSP16_Q(0.04660281),
  DSP16_Q(-0.08441002),
  DSP16_Q(0.32839078),
  DSP16_Q(0.18006907),
  DSP16_Q(-0.06885129),
  DSP16_Q(0.04081860),
  DSP16_Q(-0.02757180),
  DSP16_Q(0.01963185),
  DSP16_Q(-0.01425063),
  DSP16_Q(0.01034365),
  DSP16_Q(-0.00739937),
  DSP16_Q(0.00514524),
  DSP16_Q(-0.00342137),
  DSP16_Q(0.00212548),
  DSP16_Q(-0.00118624),
  DSP16_Q(0.00054950),
  DSP16_Q(-0.00017075),
  DSP16_Q(0.00001093),
  DSP16_Q(0.00003706),
  DSP16_Q(-0.00025632),
  DSP16_Q(0.00070472),
  DSP16_Q(-0.00142248),
  DSP16_Q(0.00245621),
  DSP16_Q(-0.00386390),
  DSP16_Q(0.00572383),
  DSP16_Q(-0.00815112),
  DSP16_Q(0.01133030),
  DSP16_Q(-0.01558441),
  DSP16_Q(0.02153946),
  DSP16_Q(-0.03058273),
  DSP16_Q(0.04648914),
  DSP16_Q(-0.08425972),
  DSP16_Q(0.32934547),
  DSP16_Q(0.17880120),
  DSP16_Q(-0.06850891),
  DSP16_Q(0.04063464),
  DSP16_Q(-0.02745246),
  DSP16_Q(0.01954832),
  DSP16_Q(-0.01419026),
  DSP16_Q(0.01029965),
  DSP16_Q(-0.00736754),
  DSP16_Q(0.00512269),
  DSP16_Q(-0.00340596),
  DSP16_Q(0.00211550),
  DSP16_Q(-0.00118030),
  DSP16_Q(0.00054644),
  DSP16_Q(-0.00016956),
  DSP16_Q(0.00001075),
  DSP16_Q(0.00003719),
  DSP16_Q(-0.00025614),
  DSP16_Q(0.00070350),
  DSP16_Q(-0.00141934),
  DSP16_Q(0.00245014),
  DSP16_Q(-0.00385372),
  DSP16_Q(0.00570812),
  DSP16_Q(-0.00812817),
  DSP16_Q(0.01129795),
  DSP16_Q(-0.01553980),
  DSP16_Q(0.02147849),
  DSP16_Q(-0.03049911),
  DSP16_Q(0.04637285),
  DSP16_Q(-0.08410459),
  DSP16_Q(0.33029562),
  DSP16_Q(0.17753317),
  DSP16_Q(-0.06816404),
  DSP16_Q(0.04044897),
  DSP16_Q(-0.02733192),
  DSP16_Q(0.01946390),
  DSP16_Q(-0.01412924),
  DSP16_Q(0.01025518),
  DSP16_Q(-0.00733538),
  DSP16_Q(0.00509991),
  DSP16_Q(-0.00339039),
  DSP16_Q(0.00210543),
  DSP16_Q(-0.00117432),
  DSP16_Q(0.00054335),
  DSP16_Q(-0.00016836),
  DSP16_Q(0.00001057),
  DSP16_Q(0.00003732),
  DSP16_Q(-0.00025595),
  DSP16_Q(0.00070223),
  DSP16_Q(-0.00141612),
  DSP16_Q(0.00244394),
  DSP16_Q(-0.00384332),
  DSP16_Q(0.00569208),
  DSP16_Q(-0.00810477),
  DSP16_Q(0.01126498),
  DSP16_Q(-0.01549433),
  DSP16_Q(0.02141633),
  DSP16_Q(-0.03041379),
  DSP16_Q(0.04625393),
  DSP16_Q(-0.08394462),
  DSP16_Q(0.33124120),
  DSP16_Q(0.17626500),
  DSP16_Q(-0.06781670),
  DSP16_Q(0.04026161),
  DSP16_Q(-0.02721017),
  DSP16_Q(0.01937862),
  DSP16_Q(-0.01406760),
  DSP16_Q(0.01021026),
  DSP16_Q(-0.00730289),
  DSP16_Q(0.00507691),
  DSP16_Q(-0.00337468),
  DSP16_Q(0.00209527),
  DSP16_Q(-0.00116829),
  DSP16_Q(0.00054025),
  DSP16_Q(-0.00016716),
  DSP16_Q(0.00001040),
  DSP16_Q(0.00003745),
  DSP16_Q(-0.00025574),
  DSP16_Q(0.00070092),
  DSP16_Q(-0.00141282),
  DSP16_Q(0.00243759),
  DSP16_Q(-0.00383269),
  DSP16_Q(0.00567573),
  DSP16_Q(-0.00808091),
  DSP16_Q(0.01123138),
  DSP16_Q(-0.01544800),
  DSP16_Q(0.02135299),
  DSP16_Q(-0.03032677),
  DSP16_Q(0.04613239),
  DSP16_Q(-0.08377978),
  DSP16_Q(0.33218218),
  DSP16_Q(0.17499673),
  DSP16_Q(-0.06746691),
  DSP16_Q(0.04007255),
  DSP16_Q(-0.02708723),
  DSP16_Q(0.01929247),
  DSP16_Q(-0.01400532),
  DSP16_Q(0.01016487),
  DSP16_Q(-0.00727008),
  DSP16_Q(0.00505369),
  DSP16_Q(-0.00335883),
  DSP16_Q(0.00208503),
  DSP16_Q(-0.00116222),
  DSP16_Q(0.00053713),
  DSP16_Q(-0.00016596),
  DSP16_Q(0.00001022),
  DSP16_Q(0.00003757),
  DSP16_Q(-0.00025551),
  DSP16_Q(0.00069957),
  DSP16_Q(-0.00140943),
  DSP16_Q(0.00243110),
  DSP16_Q(-0.00382185),
  DSP16_Q(0.00565906),
  DSP16_Q(-0.00805660),
  DSP16_Q(0.01119716),
  DSP16_Q(-0.01540081),
  DSP16_Q(0.02128845),
  DSP16_Q(-0.03023805),
  DSP16_Q(0.04600822),
  DSP16_Q(-0.08361008),
  DSP16_Q(0.33311853),
  DSP16_Q(0.17372839),
  DSP16_Q(-0.06711468),
  DSP16_Q(0.03988183),
  DSP16_Q(-0.02696311),
  DSP16_Q(0.01920546),
  DSP16_Q(-0.01394241),
  DSP16_Q(0.01011904),
  DSP16_Q(-0.00723694),
  DSP16_Q(0.00503025),
  DSP16_Q(-0.00334283),
  DSP16_Q(0.00207471),
  DSP16_Q(-0.00115611),
  DSP16_Q(0.00053400),
  DSP16_Q(-0.00016475),
  DSP16_Q(0.00001005),
  DSP16_Q(0.00003769),
  DSP16_Q(-0.00025526),
  DSP16_Q(0.00069817),
  DSP16_Q(-0.00140595),
  DSP16_Q(0.00242447),
  DSP16_Q(-0.00381079),
  DSP16_Q(0.00564206),
  DSP16_Q(-0.00803184),
  DSP16_Q(0.01116231),
  DSP16_Q(-0.01535276),
  DSP16_Q(0.02122272),
  DSP16_Q(-0.03014763),
  DSP16_Q(0.04588143),
  DSP16_Q(-0.08343550),
  DSP16_Q(0.33405022),
  DSP16_Q(0.17246003),
  DSP16_Q(-0.06676006),
  DSP16_Q(0.03968944),
  DSP16_Q(-0.02683781),
  DSP16_Q(0.01911760),
  DSP16_Q(-0.01387888),
  DSP16_Q(0.01007275),
  DSP16_Q(-0.00720349),
  DSP16_Q(0.00500658),
  DSP16_Q(-0.00332669),
  DSP16_Q(0.00206429),
  DSP16_Q(-0.00114995),
  DSP16_Q(0.00053084),
  DSP16_Q(-0.00016354),
  DSP16_Q(0.00000988),
  DSP16_Q(0.00003781),
  DSP16_Q(-0.00025499),
  DSP16_Q(0.00069673),
  DSP16_Q(-0.00140240),
  DSP16_Q(0.00241769),
  DSP16_Q(-0.00379951),
  DSP16_Q(0.00562475),
  DSP16_Q(-0.00800663),
  DSP16_Q(0.01112683),
  DSP16_Q(-0.01530386),
  DSP16_Q(0.02115581),
  DSP16_Q(-0.03005551),
  DSP16_Q(0.04575202),
  DSP16_Q(-0.08325604),
  DSP16_Q(0.33497723),
  DSP16_Q(0.17119167),
  DSP16_Q(-0.06640305),
  DSP16_Q(0.03949541),
  DSP16_Q(-0.02671134),
  DSP16_Q(0.01902888),
  DSP16_Q(-0.01381472),
  DSP16_Q(0.01002601),
  DSP16_Q(-0.00716971),
  DSP16_Q(0.00498270),
  DSP16_Q(-0.00331041),
  DSP16_Q(0.00205380),
  DSP16_Q(-0.00114374),
  DSP16_Q(0.00052767),
  DSP16_Q(-0.00016233),
  DSP16_Q(0.00000971),
  DSP16_Q(0.00003792),
  DSP16_Q(-0.00025471),
  DSP16_Q(0.00069524),
  DSP16_Q(-0.00139875),
  DSP16_Q(0.00241078),
  DSP16_Q(-0.00378801),
  DSP16_Q(0.00560711),
  DSP16_Q(-0.00798096),
  DSP16_Q(0.01109074),
  DSP16_Q(-0.01525410),
  DSP16_Q(0.02108771),
  DSP16_Q(-0.02996170),
  DSP16_Q(0.04561998),
  DSP16_Q(-0.08307168),
  DSP16_Q(0.33589953),
  DSP16_Q(0.16992334),
  DSP16_Q(-0.06604369),
  DSP16_Q(0.03929975),
  DSP16_Q(-0.02658371),
  DSP16_Q(0.01893933),
  DSP16_Q(-0.01374996),
  DSP16_Q(0.00997882),
  DSP16_Q(-0.00713562),
  DSP16_Q(0.00495860),
  DSP16_Q(-0.00329399),
  DSP16_Q(0.00204322),
  DSP16_Q(-0.00113750),
  DSP16_Q(0.00052449),
  DSP16_Q(-0.00016111),
  DSP16_Q(0.00000954),
  DSP16_Q(0.00003803),
  DSP16_Q(-0.00025441),
  DSP16_Q(0.00069371),
  DSP16_Q(-0.00139502),
  DSP16_Q(0.00240372),
  DSP16_Q(-0.00377630),
  DSP16_Q(0.00558916),
  DSP16_Q(-0.00795485),
  DSP16_Q(0.01105402),
  DSP16_Q(-0.01520348),
  DSP16_Q(0.02101843),
  DSP16_Q(-0.02986619),
  DSP16_Q(0.04548532),
  DSP16_Q(-0.08288242),
  DSP16_Q(0.33681709),
  DSP16_Q(0.16865510),
  DSP16_Q(-0.06568200),
  DSP16_Q(0.03910246),
  DSP16_Q(-0.02645493),
  DSP16_Q(0.01884894),
  DSP16_Q(-0.01368458),
  DSP16_Q(0.00993120),
  DSP16_Q(-0.00710122),
  DSP16_Q(0.00493429),
  DSP16_Q(-0.00327743),
  DSP16_Q(0.00203256),
  DSP16_Q(-0.00113121),
  DSP16_Q(0.00052128),
  DSP16_Q(-0.00015989),
  DSP16_Q(0.00000937),
  DSP16_Q(0.00003814),
  DSP16_Q(-0.00025410),
  DSP16_Q(0.00069214),
  DSP16_Q(-0.00139121),
  DSP16_Q(0.00239652),
  DSP16_Q(-0.00376436),
  DSP16_Q(0.00557089),
  DSP16_Q(-0.00792828),
  DSP16_Q(0.01101668),
  DSP16_Q(-0.01515202),
  DSP16_Q(0.02094797),
  DSP16_Q(-0.02976899),
  DSP16_Q(0.04534804),
  DSP16_Q(-0.08268824),
  DSP16_Q(0.33772988),
  DSP16_Q(0.16738696),
  DSP16_Q(-0.06531800),
  DSP16_Q(0.03890356),
  DSP16_Q(-0.02632500),
  DSP16_Q(0.01875772),
  DSP16_Q(-0.01361860),
  DSP16_Q(0.00988313),
  DSP16_Q(-0.00706650),
  DSP16_Q(0.00490977),
  DSP16_Q(-0.00326073),
  DSP16_Q(0.00202181),
  DSP16_Q(-0.00112488),
  DSP16_Q(0.00051806),
  DSP16_Q(-0.00015867),
  DSP16_Q(0.00000920),
  DSP16_Q(0.00003825),
  DSP16_Q(-0.00025376),
  DSP16_Q(0.00069052),
  DSP16_Q(-0.00138731),
  DSP16_Q(0.00238917),
  DSP16_Q(-0.00375221),
  DSP16_Q(0.00555229),
  DSP16_Q(-0.00790127),
  DSP16_Q(0.01097871),
  DSP16_Q(-0.01509970),
  DSP16_Q(0.02087633),
  DSP16_Q(-0.02967010),
  DSP16_Q(0.04520814),
  DSP16_Q(-0.08248915),
  DSP16_Q(0.33863788),
  DSP16_Q(0.16611897),
  DSP16_Q(-0.06495172),
  DSP16_Q(0.03870307),
  DSP16_Q(-0.02619394),
  DSP16_Q(0.01866567),
  DSP16_Q(-0.01355201),
  DSP16_Q(0.00983463),
  DSP16_Q(-0.00703148),
  DSP16_Q(0.00488503),
  DSP16_Q(-0.00324389),
  DSP16_Q(0.00201099),
  DSP16_Q(-0.00111850),
  DSP16_Q(0.00051482),
  DSP16_Q(-0.00015745),
  DSP16_Q(0.00000904),
  DSP16_Q(0.00003835),
  DSP16_Q(-0.00025341),
  DSP16_Q(0.00068886),
  DSP16_Q(-0.00138333),
  DSP16_Q(0.00238169),
  DSP16_Q(-0.00373984),
  DSP16_Q(0.00553338),
  DSP16_Q(-0.00787381),
  DSP16_Q(0.01094013),
  DSP16_Q(-0.01504653),
  DSP16_Q(0.02080351),
  DSP16_Q(-0.02956953),
  DSP16_Q(0.04506562),
  DSP16_Q(-0.08228513),
  DSP16_Q(0.33954106),
  DSP16_Q(0.16485116),
  DSP16_Q(-0.06458318),
  DSP16_Q(0.03850100),
  DSP16_Q(-0.02606176),
  DSP16_Q(0.01857280),
  DSP16_Q(-0.01348482),
  DSP16_Q(0.00978569),
  DSP16_Q(-0.00699615),
  DSP16_Q(0.00486009),
  DSP16_Q(-0.00322692),
  DSP16_Q(0.00200009),
  DSP16_Q(-0.00111209),
  DSP16_Q(0.00051157),
  DSP16_Q(-0.00015623),
  DSP16_Q(0.00000887),
  DSP16_Q(0.00003845),
  DSP16_Q(-0.00025304),
  DSP16_Q(0.00068715),
  DSP16_Q(-0.00137926),
  DSP16_Q(0.00237406),
  DSP16_Q(-0.00372724),
  DSP16_Q(0.00551416),
  DSP16_Q(-0.00784590),
  DSP16_Q(0.01090093),
  DSP16_Q(-0.01499251),
  DSP16_Q(0.02072952),
  DSP16_Q(-0.02946726),
  DSP16_Q(0.04492048),
  DSP16_Q(-0.08207617),
  DSP16_Q(0.34043938),
  DSP16_Q(0.16358356),
  DSP16_Q(-0.06421240),
  DSP16_Q(0.03829736),
  DSP16_Q(-0.02592845),
  DSP16_Q(0.01847912),
  DSP16_Q(-0.01341704),
  DSP16_Q(0.00973633),
  DSP16_Q(-0.00696051),
  DSP16_Q(0.00483494),
  DSP16_Q(-0.00320982),
  DSP16_Q(0.00198910),
  DSP16_Q(-0.00110563),
  DSP16_Q(0.00050830),
  DSP16_Q(-0.00015500),
  DSP16_Q(0.00000871),
  DSP16_Q(0.00003854),
  DSP16_Q(-0.00025265),
  DSP16_Q(0.00068540),
  DSP16_Q(-0.00137511),
  DSP16_Q(0.00236630),
  DSP16_Q(-0.00371444),
  DSP16_Q(0.00549461),
  DSP16_Q(-0.00781754),
  DSP16_Q(0.01086112),
  DSP16_Q(-0.01493765),
  DSP16_Q(0.02065435),
  DSP16_Q(-0.02936332),
  DSP16_Q(0.04477273),
  DSP16_Q(-0.08186226),
  DSP16_Q(0.34133283),
  DSP16_Q(0.16231621),
  DSP16_Q(-0.06383941),
  DSP16_Q(0.03809217),
  DSP16_Q(-0.02579404),
  DSP16_Q(0.01838463),
  DSP16_Q(-0.01334867),
  DSP16_Q(0.00968654),
  DSP16_Q(-0.00692458),
  DSP16_Q(0.00480958),
  DSP16_Q(-0.00319258),
  DSP16_Q(0.00197804),
  DSP16_Q(-0.00109914),
  DSP16_Q(0.00050502),
  DSP16_Q(-0.00015377),
  DSP16_Q(0.00000855),
  DSP16_Q(0.00003864),
  DSP16_Q(-0.00025224),
  DSP16_Q(0.00068360),
  DSP16_Q(-0.00137087),
  DSP16_Q(0.00235839),
  DSP16_Q(-0.00370141),
  DSP16_Q(0.00547475),
  DSP16_Q(-0.00778874),
  DSP16_Q(0.01082068),
  DSP16_Q(-0.01488194),
  DSP16_Q(0.02057801),
  DSP16_Q(-0.02925769),
  DSP16_Q(0.04462236),
  DSP16_Q(-0.08164340),
  DSP16_Q(0.34222137),
  DSP16_Q(0.16104914),
  DSP16_Q(-0.06346424),
  DSP16_Q(0.03788543),
  DSP16_Q(-0.02565852),
  DSP16_Q(0.01828934),
  DSP16_Q(-0.01327972),
  DSP16_Q(0.00963632),
  DSP16_Q(-0.00688834),
  DSP16_Q(0.00478401),
  DSP16_Q(-0.00317522),
  DSP16_Q(0.00196690),
  DSP16_Q(-0.00109261),
  DSP16_Q(0.00050172),
  DSP16_Q(-0.00015254),
  DSP16_Q(0.00000839),
  DSP16_Q(0.00003873),
  DSP16_Q(-0.00025182),
  DSP16_Q(0.00068176),
  DSP16_Q(-0.00136655),
  DSP16_Q(0.00235034),
  DSP16_Q(-0.00368817),
  DSP16_Q(0.00545457),
  DSP16_Q(-0.00775949),
  DSP16_Q(0.01077964),
  DSP16_Q(-0.01482539),
  DSP16_Q(0.02050050),
  DSP16_Q(-0.02915039),
  DSP16_Q(0.04446938),
  DSP16_Q(-0.08141958),
  DSP16_Q(0.34310499),
  DSP16_Q(0.15978239),
  DSP16_Q(-0.06308690),
  DSP16_Q(0.03767716),
  DSP16_Q(-0.02552191),
  DSP16_Q(0.01819326),
  DSP16_Q(-0.01321018),
  DSP16_Q(0.00958568),
  DSP16_Q(-0.00685180),
  DSP16_Q(0.00475825),
  DSP16_Q(-0.00315772),
  DSP16_Q(0.00195568),
  DSP16_Q(-0.00108603),
  DSP16_Q(0.00049841),
  DSP16_Q(-0.00015131),
  DSP16_Q(0.00000824),
  DSP16_Q(0.00003881),
  DSP16_Q(-0.00025137),
  DSP16_Q(0.00067987),
  DSP16_Q(-0.00136214),
  DSP16_Q(0.00234215),
  DSP16_Q(-0.00367471),
  DSP16_Q(0.00543408),
  DSP16_Q(-0.00772980),
  DSP16_Q(0.01073798),
  DSP16_Q(-0.01476799),
  DSP16_Q(0.02042183),
  DSP16_Q(-0.02904141),
  DSP16_Q(0.04431379),
  DSP16_Q(-0.08119079),
  DSP16_Q(0.34398365),
  DSP16_Q(0.15851599),
  DSP16_Q(-0.06270742),
  DSP16_Q(0.03746738),
  DSP16_Q(-0.02538422),
  DSP16_Q(0.01809639),
  DSP16_Q(-0.01314007),
  DSP16_Q(0.00953463),
  DSP16_Q(-0.00681497),
  DSP16_Q(0.00473228),
  DSP16_Q(-0.00314009),
  DSP16_Q(0.00194439),
  DSP16_Q(-0.00107942),
  DSP16_Q(0.00049508),
  DSP16_Q(-0.00015007),
  DSP16_Q(0.00000808),
  DSP16_Q(0.00003889),
  DSP16_Q(-0.00025091),
  DSP16_Q(0.00067794),
  DSP16_Q(-0.00135765),
  DSP16_Q(0.00233381),
  DSP16_Q(-0.00366103),
  DSP16_Q(0.00541327),
  DSP16_Q(-0.00769966),
  DSP16_Q(0.01069570),
  DSP16_Q(-0.01470976),
  DSP16_Q(0.02034198),
  DSP16_Q(-0.02893076),
  DSP16_Q(0.04415559),
  DSP16_Q(-0.08095703),
  DSP16_Q(0.34485732),
  DSP16_Q(0.15724998),
  DSP16_Q(-0.06232583),
  DSP16_Q(0.03725610),
  DSP16_Q(-0.02524545),
  DSP16_Q(0.01799873),
  DSP16_Q(-0.01306938),
  DSP16_Q(0.00948316),
  DSP16_Q(-0.00677785),
  DSP16_Q(0.00470611),
  DSP16_Q(-0.00312233),
  DSP16_Q(0.00193302),
  DSP16_Q(-0.00107277),
  DSP16_Q(0.00049174),
  DSP16_Q(-0.00014884),
  DSP16_Q(0.00000793),
  DSP16_Q(0.00003897),
  DSP16_Q(-0.00025043),
  DSP16_Q(0.00067597),
  DSP16_Q(-0.00135307),
  DSP16_Q(0.00232534),
  DSP16_Q(-0.00364714),
  DSP16_Q(0.00539215),
  DSP16_Q(-0.00766908),
  DSP16_Q(0.01065282),
  DSP16_Q(-0.01465068),
  DSP16_Q(0.02026098),
  DSP16_Q(-0.02881843),
  DSP16_Q(0.04399478),
  DSP16_Q(-0.08071828),
  DSP16_Q(0.34572598),
  DSP16_Q(0.15598440),
  DSP16_Q(-0.06194214),
  DSP16_Q(0.03704333),
  DSP16_Q(-0.02510562),
  DSP16_Q(0.01790030),
  DSP16_Q(-0.01299813),
  DSP16_Q(0.00943128),
  DSP16_Q(-0.00674044),
  DSP16_Q(0.00467975),
  DSP16_Q(-0.00310445),
  DSP16_Q(0.00192158),
  DSP16_Q(-0.00106608),
  DSP16_Q(0.00048838),
  DSP16_Q(-0.00014760),
  DSP16_Q(0.00000777),
  DSP16_Q(0.00003905),
  DSP16_Q(-0.00024993),
  DSP16_Q(0.00067395),
  DSP16_Q(-0.00134841),
  DSP16_Q(0.00231672),
  DSP16_Q(-0.00363304),
  DSP16_Q(0.00537071),
  DSP16_Q(-0.00763806),
  DSP16_Q(0.01060932),
  DSP16_Q(-0.01459077),
  DSP16_Q(0.02017882),
  DSP16_Q(-0.02870444),
  DSP16_Q(0.04383136),
  DSP16_Q(-0.08047455),
  DSP16_Q(0.34658960),
  DSP16_Q(0.15471927),
  DSP16_Q(-0.06155639),
  DSP16_Q(0.03682908),
  DSP16_Q(-0.02496473),
  DSP16_Q(0.01780109),
  DSP16_Q(-0.01292631),
  DSP16_Q(0.00937899),
  DSP16_Q(-0.00670274),
  DSP16_Q(0.00465319),
  DSP16_Q(-0.00308644),
  DSP16_Q(0.00191006),
  DSP16_Q(-0.00105935),
  DSP16_Q(0.00048501),
  DSP16_Q(-0.00014636),
  DSP16_Q(0.00000762),
  DSP16_Q(0.00003912),
  DSP16_Q(-0.00024942),
  DSP16_Q(0.00067188),
  DSP16_Q(-0.00134366),
  DSP16_Q(0.00230797),
  DSP16_Q(-0.00361871),
  DSP16_Q(0.00534896),
  DSP16_Q(-0.00760660),
  DSP16_Q(0.01056522),
  DSP16_Q(-0.01453003),
  DSP16_Q(0.02009549),
  DSP16_Q(-0.02858879),
  DSP16_Q(0.04366535),
  DSP16_Q(-0.08022581),
  DSP16_Q(0.34744817),
  DSP16_Q(0.15345463),
  DSP16_Q(-0.06116860),
  DSP16_Q(0.03661337),
  DSP16_Q(-0.02482279),
  DSP16_Q(0.01770113),
  DSP16_Q(-0.01285394),
  DSP16_Q(0.00932630),
  DSP16_Q(-0.00666475),
  DSP16_Q(0.00462643),
  DSP16_Q(-0.00306830),
  DSP16_Q(0.00189847),
  DSP16_Q(-0.00105259),
  DSP16_Q(0.00048163),
  DSP16_Q(-0.00014512),
  DSP16_Q(0.00000747),
  DSP16_Q(0.00003918),
  DSP16_Q(-0.00024888),
  DSP16_Q(0.00066977),
  DSP16_Q(-0.00133883),
  DSP16_Q(0.00229907),
  DSP16_Q(-0.00360417),
  DSP16_Q(0.00532689),
  DSP16_Q(-0.00757469),
  DSP16_Q(0.01052051),
  DSP16_Q(-0.01446845),
  DSP16_Q(0.02001102),
  DSP16_Q(-0.02847147),
  DSP16_Q(0.04349673),
  DSP16_Q(-0.07997208),
  DSP16_Q(0.34830164),
  DSP16_Q(0.15219051),
  DSP16_Q(-0.06077879),
  DSP16_Q(0.03639622),
  DSP16_Q(-0.02467981),
  DSP16_Q(0.01760040),
  DSP16_Q(-0.01278101),
  DSP16_Q(0.00927321),
  DSP16_Q(-0.00662648),
  DSP16_Q(0.00459948),
  DSP16_Q(-0.00305005),
  DSP16_Q(0.00188681),
  DSP16_Q(-0.00104579),
  DSP16_Q(0.00047823),
  DSP16_Q(-0.00014388),
  DSP16_Q(0.00000733),
  DSP16_Q(0.00003925),
  DSP16_Q(-0.00024833),
  DSP16_Q(0.00066762),
  DSP16_Q(-0.00133392),
  DSP16_Q(0.00229004),
  DSP16_Q(-0.00358942),
  DSP16_Q(0.00530452),
  DSP16_Q(-0.00754235),
  DSP16_Q(0.01047520),
  DSP16_Q(-0.01440604),
  DSP16_Q(0.01992538),
  DSP16_Q(-0.02835249),
  DSP16_Q(0.04332552),
  DSP16_Q(-0.07971333),
  DSP16_Q(0.34915000),
  DSP16_Q(0.15092695),
  DSP16_Q(-0.06038698),
  DSP16_Q(0.03617763),
  DSP16_Q(-0.02453580),
  DSP16_Q(0.01749892),
  DSP16_Q(-0.01270753),
  DSP16_Q(0.00921972),
  DSP16_Q(-0.00658793),
  DSP16_Q(0.00457235),
  DSP16_Q(-0.00303167),
  DSP16_Q(0.00187507),
  DSP16_Q(-0.00103896),
  DSP16_Q(0.00047482),
  DSP16_Q(-0.00014264),
  DSP16_Q(0.00000718),
  DSP16_Q(0.00003931),
  DSP16_Q(-0.00024776),
  DSP16_Q(0.00066542),
  DSP16_Q(-0.00132892),
  DSP16_Q(0.00228086),
  DSP16_Q(-0.00357445),
  DSP16_Q(0.00528183),
  DSP16_Q(-0.00750957),
  DSP16_Q(0.01042928),
  DSP16_Q(-0.01434280),
  DSP16_Q(0.01983860),
  DSP16_Q(-0.02823186),
  DSP16_Q(0.04315172),
  DSP16_Q(-0.07944957),
  DSP16_Q(0.34999322),
  DSP16_Q(0.14966399),
  DSP16_Q(-0.05999321),
  DSP16_Q(0.03595762),
  DSP16_Q(-0.02439077),
  DSP16_Q(0.01739670),
  DSP16_Q(-0.01263350),
  DSP16_Q(0.00916584),
  DSP16_Q(-0.00654910),
  DSP16_Q(0.00454502),
  DSP16_Q(-0.00301316),
  DSP16_Q(0.00186326),
  DSP16_Q(-0.00103209),
  DSP16_Q(0.00047140),
  DSP16_Q(-0.00014139),
  DSP16_Q(0.00000703),
  DSP16_Q(0.00003937),
  DSP16_Q(-0.00024717),
  DSP16_Q(0.00066317),
  DSP16_Q(-0.00132383),
  DSP16_Q(0.00227154),
  DSP16_Q(-0.00355927),
  DSP16_Q(0.00525883),
  DSP16_Q(-0.00747636),
  DSP16_Q(0.01038275),
  DSP16_Q(-0.01427874),
  DSP16_Q(0.01975067),
  DSP16_Q(-0.02810958),
  DSP16_Q(0.04297532),
  DSP16_Q(-0.07918078),
  DSP16_Q(0.35083127),
  DSP16_Q(0.14840166),
  DSP16_Q(-0.05959749),
  DSP16_Q(0.03573620),
  DSP16_Q(-0.02424473),
  DSP16_Q(0.01729373),
  DSP16_Q(-0.01255894),
  DSP16_Q(0.00911157),
  DSP16_Q(-0.00650999),
  DSP16_Q(0.00451750),
  DSP16_Q(-0.00299454),
  DSP16_Q(0.00185139),
  DSP16_Q(-0.00102518),
  DSP16_Q(0.00046797),
  DSP16_Q(-0.00014015),
  DSP16_Q(0.00000689),
  DSP16_Q(0.00003942),
  DSP16_Q(-0.00024656),
  DSP16_Q(0.00066088),
  DSP16_Q(-0.00131866),
  DSP16_Q(0.00226209),
  DSP16_Q(-0.00354388),
  DSP16_Q(0.00523552),
  DSP16_Q(-0.00744271),
  DSP16_Q(0.01033563),
  DSP16_Q(-0.01421385),
  DSP16_Q(0.01966160),
  DSP16_Q(-0.02798565),
  DSP16_Q(0.04279633),
  DSP16_Q(-0.07890697),
  DSP16_Q(0.35166413),
  DSP16_Q(0.14713998),
  DSP16_Q(-0.05919985),
  DSP16_Q(0.03551339),
  DSP16_Q(-0.02409768),
  DSP16_Q(0.01719003),
  DSP16_Q(-0.01248383),
  DSP16_Q(0.00905690),
  DSP16_Q(-0.00647062),
  DSP16_Q(0.00448980),
  DSP16_Q(-0.00297580),
  DSP16_Q(0.00183944),
  DSP16_Q(-0.00101824),
  DSP16_Q(0.00046452),
  DSP16_Q(-0.00013891),
  DSP16_Q(0.00000675),
  DSP16_Q(0.00003947),
  DSP16_Q(-0.00024593),
  DSP16_Q(0.00065855),
  DSP16_Q(-0.00131340),
  DSP16_Q(0.00225249),
  DSP16_Q(-0.00352827),
  DSP16_Q(0.00521190),
  DSP16_Q(-0.00740862),
  DSP16_Q(0.01028791),
  DSP16_Q(-0.01414813),
  DSP16_Q(0.01957138),
  DSP16_Q(-0.02786007),
  DSP16_Q(0.04261476),
  DSP16_Q(-0.07862812),
  DSP16_Q(0.35249177),
  DSP16_Q(0.14587901),
  DSP16_Q(-0.05880032),
  DSP16_Q(0.03528920),
  DSP16_Q(-0.02394963),
  DSP16_Q(0.01708561),
  DSP16_Q(-0.01240820),
  DSP16_Q(0.00900186),
  DSP16_Q(-0.00643097),
  DSP16_Q(0.00446192),
  DSP16_Q(-0.00295695),
  DSP16_Q(0.00182743),
  DSP16_Q(-0.00101127),
  DSP16_Q(0.00046106),
  DSP16_Q(-0.00013766),
  DSP16_Q(0.00000661),
  DSP16_Q(0.00003951),
  DSP16_Q(-0.00024528),
  DSP16_Q(0.00065617),
  DSP16_Q(-0.00130806),
  DSP16_Q(0.00224275),
  DSP16_Q(-0.00351244),
  DSP16_Q(0.00518798),
  DSP16_Q(-0.00737410),
  DSP16_Q(0.01023959),
  DSP16_Q(-0.01408160),
  DSP16_Q(0.01948003),
  DSP16_Q(-0.02773285),
  DSP16_Q(0.04243060),
  DSP16_Q(-0.07834423),
  DSP16_Q(0.35331417),
  DSP16_Q(0.14461876),
  DSP16_Q(-0.05839891),
  DSP16_Q(0.03506365),
  DSP16_Q(-0.02380061),
  DSP16_Q(0.01698046),
  DSP16_Q(-0.01233204),
  DSP16_Q(0.00894643),
  DSP16_Q(-0.00639105),
  DSP16_Q(0.00443385),
  DSP16_Q(-0.00293797),
  DSP16_Q(0.00181535),
  DSP16_Q(-0.00100426),
  DSP16_Q(0.00045759),
  DSP16_Q(-0.00013641),
  DSP16_Q(0.00000647),
  DSP16_Q(0.00003955),
  DSP16_Q(-0.00024461),
  DSP16_Q(0.00065374),
  DSP16_Q(-0.00130264),
  DSP16_Q(0.00223288),
  DSP16_Q(-0.00349641),
  DSP16_Q(0.00516374),
  DSP16_Q(-0.00733915),
  DSP16_Q(0.01019067),
  DSP16_Q(-0.01401425),
  DSP16_Q(0.01938754),
  DSP16_Q(-0.02760399),
  DSP16_Q(0.04224387),
  DSP16_Q(-0.07805529),
  DSP16_Q(0.35413131),
  DSP16_Q(0.14335927),
  DSP16_Q(-0.05799566),
  DSP16_Q(0.03483675),
  DSP16_Q(-0.02365060),
  DSP16_Q(0.01687461),
  DSP16_Q(-0.01225536),
  DSP16_Q(0.00889063),
  DSP16_Q(-0.00635086),
  DSP16_Q(0.00440561),
  DSP16_Q(-0.00291888),
  DSP16_Q(0.00180320),
  DSP16_Q(-0.00099722),
  DSP16_Q(0.00045411),
  DSP16_Q(-0.00013517),
  DSP16_Q(0.00000633),
  DSP16_Q(0.00003959),
  DSP16_Q(-0.00024393),
  DSP16_Q(0.00065127),
  DSP16_Q(-0.00129713),
  DSP16_Q(0.00222287),
  DSP16_Q(-0.00348017),
  DSP16_Q(0.00513920),
  DSP16_Q(-0.00730376),
  DSP16_Q(0.01014116),
  DSP16_Q(-0.01394608),
  DSP16_Q(0.01929391),
  DSP16_Q(-0.02747350),
  DSP16_Q(0.04205456),
  DSP16_Q(-0.07776131),
  DSP16_Q(0.35494315),
  DSP16_Q(0.14210059),
  DSP16_Q(-0.05759058),
  DSP16_Q(0.03460851),
  DSP16_Q(-0.02349963),
  DSP16_Q(0.01676804),
  DSP16_Q(-0.01217816),
  DSP16_Q(0.00883445),
  DSP16_Q(-0.00631042),
  DSP16_Q(0.00437718),
  DSP16_Q(-0.00289968),
  DSP16_Q(0.00179099),
  DSP16_Q(-0.00099015),
  DSP16_Q(0.00045061),
  DSP16_Q(-0.00013392),
  DSP16_Q(0.00000620),
  DSP16_Q(0.00003962),
  DSP16_Q(-0.00024322),
  DSP16_Q(0.00064875),
  DSP16_Q(-0.00129154),
  DSP16_Q(0.00221271),
  DSP16_Q(-0.00346371),
  DSP16_Q(0.00511435),
  DSP16_Q(-0.00726795),
  DSP16_Q(0.01009105),
  DSP16_Q(-0.01387710),
  DSP16_Q(0.01919916),
  DSP16_Q(-0.02734137),
  DSP16_Q(0.04186268),
  DSP16_Q(-0.07746226),
  DSP16_Q(0.35574968),
  DSP16_Q(0.14084273),
  DSP16_Q(-0.05718371),
  DSP16_Q(0.03437894),
  DSP16_Q(-0.02334770),
  DSP16_Q(0.01666077),
  DSP16_Q(-0.01210045),
  DSP16_Q(0.00877790),
  DSP16_Q(-0.00626971),
  DSP16_Q(0.00434858),
  DSP16_Q(-0.00288037),
  DSP16_Q(0.00177871),
  DSP16_Q(-0.00098305),
  DSP16_Q(0.00044711),
  DSP16_Q(-0.00013267),
  DSP16_Q(0.00000607),
  DSP16_Q(0.00003965),
  DSP16_Q(-0.00024250),
  DSP16_Q(0.00064619),
  DSP16_Q(-0.00128586),
  DSP16_Q(0.00220242),
  DSP16_Q(-0.00344704),
  DSP16_Q(0.00508919),
  DSP16_Q(-0.00723170),
  DSP16_Q(0.01004036),
  DSP16_Q(-0.01380731),
  DSP16_Q(0.01910328),
  DSP16_Q(-0.02720762),
  DSP16_Q(0.04166823),
  DSP16_Q(-0.07715816),
  DSP16_Q(0.35655086),
  DSP16_Q(0.13958574),
  DSP16_Q(-0.05677506),
  DSP16_Q(0.03414807),
  DSP16_Q(-0.02319482),
  DSP16_Q(0.01655281),
  DSP16_Q(-0.01202223),
  DSP16_Q(0.00872099),
  DSP16_Q(-0.00622874),
  DSP16_Q(0.00431981),
  DSP16_Q(-0.00286094),
  DSP16_Q(0.00176637),
  DSP16_Q(-0.00097591),
  DSP16_Q(0.00044360),
  DSP16_Q(-0.00013143),
  DSP16_Q(0.00000593),
  DSP16_Q(0.00003967),
  DSP16_Q(-0.00024176),
  DSP16_Q(0.00064359),
  DSP16_Q(-0.00128010),
  DSP16_Q(0.00219199),
  DSP16_Q(-0.00343016),
  DSP16_Q(0.00506373),
  DSP16_Q(-0.00719503),
  DSP16_Q(0.00998907),
  DSP16_Q(-0.01373671),
  DSP16_Q(0.01900627),
  DSP16_Q(-0.02707225),
  DSP16_Q(0.04147122),
  DSP16_Q(-0.07684899),
  DSP16_Q(0.35734668),
  DSP16_Q(0.13832965),
  DSP16_Q(-0.05636466),
  DSP16_Q(0.03391590),
  DSP16_Q(-0.02304100),
  DSP16_Q(0.01644416),
  DSP16_Q(-0.01194350),
  DSP16_Q(0.00866371),
  DSP16_Q(-0.00618752),
  DSP16_Q(0.00429086),
  DSP16_Q(-0.00284141),
  DSP16_Q(0.00175396),
  DSP16_Q(-0.00096875),
  DSP16_Q(0.00044007),
  DSP16_Q(-0.00013018),
  DSP16_Q(0.00000580),
  DSP16_Q(0.00003969),
  DSP16_Q(-0.00024100),
  DSP16_Q(0.00064094),
  DSP16_Q(-0.00127426),
  DSP16_Q(0.00218142),
  DSP16_Q(-0.00341307),
  DSP16_Q(0.00503797),
  DSP16_Q(-0.00715793),
  DSP16_Q(0.00993720),
  DSP16_Q(-0.01366530),
  DSP16_Q(0.01890814),
  DSP16_Q(-0.02693526),
  DSP16_Q(0.04127165),
  DSP16_Q(-0.07653475),
  DSP16_Q(0.35813711),
  DSP16_Q(0.13707449),
  DSP16_Q(-0.05595254),
  DSP16_Q(0.03368245),
  DSP16_Q(-0.02288625),
  DSP16_Q(0.01633483),
  DSP16_Q(-0.01186428),
  DSP16_Q(0.00860607),
  DSP16_Q(-0.00614604),
  DSP16_Q(0.00426174),
  DSP16_Q(-0.00282176),
  DSP16_Q(0.00174150),
  DSP16_Q(-0.00096155),
  DSP16_Q(0.00043654),
  DSP16_Q(-0.00012893),
  DSP16_Q(0.00000568),
  DSP16_Q(0.00003971),
  DSP16_Q(-0.00024022),
  DSP16_Q(0.00063824),
  DSP16_Q(-0.00126833),
  DSP16_Q(0.00217072),
  DSP16_Q(-0.00339577),
  DSP16_Q(0.00501190),
  DSP16_Q(-0.00712041),
  DSP16_Q(0.00988474),
  DSP16_Q(-0.01359309),
  DSP16_Q(0.01880890),
  DSP16_Q(-0.02679665),
  DSP16_Q(0.04106952),
  DSP16_Q(-0.07621543),
  DSP16_Q(0.35892213),
  DSP16_Q(0.13582030),
  DSP16_Q(-0.05553872),
  DSP16_Q(0.03344774),
  DSP16_Q(-0.02273057),
  DSP16_Q(0.01622482),
  DSP16_Q(-0.01178456),
  DSP16_Q(0.00854808),
  DSP16_Q(-0.00610432),
  DSP16_Q(0.00423245),
  DSP16_Q(-0.00280201),
  DSP16_Q(0.00172896),
  DSP16_Q(-0.00095432),
  DSP16_Q(0.00043299),
  DSP16_Q(-0.00012769),
  DSP16_Q(0.00000555),
  DSP16_Q(0.00003972),
  DSP16_Q(-0.00023942),
  DSP16_Q(0.00063550),
  DSP16_Q(-0.00126231),
  DSP16_Q(0.00215988),
  DSP16_Q(-0.00337827),
  DSP16_Q(0.00498553),
  DSP16_Q(-0.00708246),
  DSP16_Q(0.00983169),
  DSP16_Q(-0.01352007),
  DSP16_Q(0.01870854),
  DSP16_Q(-0.02665643),
  DSP16_Q(0.04086484),
  DSP16_Q(-0.07589104),
  DSP16_Q(0.35970171),
  DSP16_Q(0.13456710),
  DSP16_Q(-0.05512322),
  DSP16_Q(0.03321177),
  DSP16_Q(-0.02257399),
  DSP16_Q(0.01611415),
  DSP16_Q(-0.01170436),
  DSP16_Q(0.00848973),
  DSP16_Q(-0.00606234),
  DSP16_Q(0.00420299),
  DSP16_Q(-0.00278215),
  DSP16_Q(0.00171637),
  DSP16_Q(-0.00094707),
  DSP16_Q(0.00042944),
  DSP16_Q(-0.00012644),
  DSP16_Q(0.00000542),
  DSP16_Q(0.00003973),
  DSP16_Q(-0.00023860),
  DSP16_Q(0.00063271),
  DSP16_Q(-0.00125622),
  DSP16_Q(0.00214890),
  DSP16_Q(-0.00336055),
  DSP16_Q(0.00495886),
  DSP16_Q(-0.00704409),
  DSP16_Q(0.00977807),
  DSP16_Q(-0.01344626),
  DSP16_Q(0.01860707),
  DSP16_Q(-0.02651460),
  DSP16_Q(0.04065761),
  DSP16_Q(-0.07556156),
  DSP16_Q(0.36047583),
  DSP16_Q(0.13331494),
  DSP16_Q(-0.05470607),
  DSP16_Q(0.03297456),
  DSP16_Q(-0.02241651),
  DSP16_Q(0.01600281),
  DSP16_Q(-0.01162367),
  DSP16_Q(0.00843103),
  DSP16_Q(-0.00602012),
  DSP16_Q(0.00417337),
  DSP16_Q(-0.00276219),
  DSP16_Q(0.00170372),
  DSP16_Q(-0.00093978),
  DSP16_Q(0.00042587),
  DSP16_Q(-0.00012519),
  DSP16_Q(0.00000530),
  DSP16_Q(0.00003973),
  DSP16_Q(-0.00023776),
  DSP16_Q(0.00062988),
  DSP16_Q(-0.00125004),
  DSP16_Q(0.00213778),
  DSP16_Q(-0.00334262),
  DSP16_Q(0.00493189),
  DSP16_Q(-0.00700530),
  DSP16_Q(0.00972386),
  DSP16_Q(-0.01337165),
  DSP16_Q(0.01850450),
  DSP16_Q(-0.02637118),
  DSP16_Q(0.04044785),
  DSP16_Q(-0.07522699),
  DSP16_Q(0.36124446),
  DSP16_Q(0.13206385),
  DSP16_Q(-0.05428729),
  DSP16_Q(0.03273613),
  DSP16_Q(-0.02225813),
  DSP16_Q(0.01589082),
  DSP16_Q(-0.01154250),
  DSP16_Q(0.00837199),
  DSP16_Q(-0.00597766),
  DSP16_Q(0.00414358),
  DSP16_Q(-0.00274212),
  DSP16_Q(0.00169101),
  DSP16_Q(-0.00093247),
  DSP16_Q(0.00042230),
  DSP16_Q(-0.00012395),
  DSP16_Q(0.00000518),
  DSP16_Q(0.00003973),
  DSP16_Q(-0.00023690),
  DSP16_Q(0.00062700),
  DSP16_Q(-0.00124377),
  DSP16_Q(0.00212653),
  DSP16_Q(-0.00332449),
  DSP16_Q(0.00490461),
  DSP16_Q(-0.00696609),
  DSP16_Q(0.00966907),
  DSP16_Q(-0.01329625),
  DSP16_Q(0.01840082),
  DSP16_Q(-0.02622615),
  DSP16_Q(0.04023554),
  DSP16_Q(-0.07488733),
  DSP16_Q(0.36200759),
  DSP16_Q(0.13081385),
  DSP16_Q(-0.05386692),
  DSP16_Q(0.03249649),
  DSP16_Q(-0.02209887),
  DSP16_Q(0.01577818),
  DSP16_Q(-0.01146086),
  DSP16_Q(0.00831260),
  DSP16_Q(-0.00593495),
  DSP16_Q(0.00411363),
  DSP16_Q(-0.00272195),
  DSP16_Q(0.00167824),
  DSP16_Q(-0.00092513),
  DSP16_Q(0.00041872),
  DSP16_Q(-0.00012270),
  DSP16_Q(0.00000506),
  DSP16_Q(0.00003973),
  DSP16_Q(-0.00023602),
  DSP16_Q(0.00062408),
  DSP16_Q(-0.00123743),
  DSP16_Q(0.00211514),
  DSP16_Q(-0.00330615),
  DSP16_Q(0.00487704),
  DSP16_Q(-0.00692645),
  DSP16_Q(0.00961371),
  DSP16_Q(-0.01322006),
  DSP16_Q(0.01829604),
  DSP16_Q(-0.02607954),
  DSP16_Q(0.04002070),
  DSP16_Q(-0.07454258),
  DSP16_Q(0.36276518),
  DSP16_Q(0.12956499),
  DSP16_Q(-0.05344496),
  DSP16_Q(0.03225565),
  DSP16_Q(-0.02193873),
  DSP16_Q(0.01566490),
  DSP16_Q(-0.01137874),
  DSP16_Q(0.00825288),
  DSP16_Q(-0.00589201),
  DSP16_Q(0.00408352),
  DSP16_Q(-0.00270168),
  DSP16_Q(0.00166541),
  DSP16_Q(-0.00091776),
  DSP16_Q(0.00041512),
  DSP16_Q(-0.00012145),
  DSP16_Q(0.00000494),
  DSP16_Q(0.00003972),
  DSP16_Q(-0.00023512),
  DSP16_Q(0.00062111),
  DSP16_Q(-0.00123099),
  DSP16_Q(0.00210361),
  DSP16_Q(-0.00328761),
  DSP16_Q(0.00484917),
  DSP16_Q(-0.00688641),
  DSP16_Q(0.00955778),
  DSP16_Q(-0.01314308),
  DSP16_Q(0.01819016),
  DSP16_Q(-0.02593133),
  DSP16_Q(0.03980333),
  DSP16_Q(-0.07419272),
  DSP16_Q(0.36351722),
  DSP16_Q(0.12831730),
  DSP16_Q(-0.05302145),
  DSP16_Q(0.03201364),
  DSP16_Q(-0.02177773),
  DSP16_Q(0.01555098),
  DSP16_Q(-0.01129616),
  DSP16_Q(0.00819282),
  DSP16_Q(-0.00584883),
  DSP16_Q(0.00405325),
  DSP16_Q(-0.00268131),
  DSP16_Q(0.00165253),
  DSP16_Q(-0.00091036),
  DSP16_Q(0.00041153),
  DSP16_Q(-0.00012021),
  DSP16_Q(0.00000482),
  DSP16_Q(0.00003970),
  DSP16_Q(-0.00023421),
  DSP16_Q(0.00061810),
  DSP16_Q(-0.00122448),
  DSP16_Q(0.00209195),
  DSP16_Q(-0.00326886),
  DSP16_Q(0.00482101),
  DSP16_Q(-0.00684594),
  DSP16_Q(0.00950127),
  DSP16_Q(-0.01306531),
  DSP16_Q(0.01808319),
  DSP16_Q(-0.02578154),
  DSP16_Q(0.03958344),
  DSP16_Q(-0.07383777),
  DSP16_Q(0.36426368),
  DSP16_Q(0.12707080),
  DSP16_Q(-0.05259642),
  DSP16_Q(0.03177045),
  DSP16_Q(-0.02161588),
  DSP16_Q(0.01543644),
  DSP16_Q(-0.01121313),
  DSP16_Q(0.00813243),
  DSP16_Q(-0.00580542),
  DSP16_Q(0.00402283),
  DSP16_Q(-0.00266084),
  DSP16_Q(0.00163959),
  DSP16_Q(-0.00090294),
  DSP16_Q(0.00040792),
  DSP16_Q(-0.00011897),
  DSP16_Q(0.00000470),
  DSP16_Q(0.00003968),
  DSP16_Q(-0.00023327),
  DSP16_Q(0.00061504),
  DSP16_Q(-0.00121788),
  DSP16_Q(0.00208015),
  DSP16_Q(-0.00324990),
  DSP16_Q(0.00479254),
  DSP16_Q(-0.00680506),
  DSP16_Q(0.00944419),
  DSP16_Q(-0.01298676),
  DSP16_Q(0.01797514),
  DSP16_Q(-0.02563017),
  DSP16_Q(0.03936103),
  DSP16_Q(-0.07347771),
  DSP16_Q(0.36500454),
  DSP16_Q(0.12582553),
  DSP16_Q(-0.05216988),
  DSP16_Q(0.03152611),
  DSP16_Q(-0.02145317),
  DSP16_Q(0.01532127),
  DSP16_Q(-0.01112963),
  DSP16_Q(0.00807171),
  DSP16_Q(-0.00576178),
  DSP16_Q(0.00399225),
  DSP16_Q(-0.00264027),
  DSP16_Q(0.00162659),
  DSP16_Q(-0.00089549),
  DSP16_Q(0.00040430),
  DSP16_Q(-0.00011772),
  DSP16_Q(0.00000459),
  DSP16_Q(0.00003966),
  DSP16_Q(-0.00023232),
  DSP16_Q(0.00061194),
  DSP16_Q(-0.00121121),
  DSP16_Q(0.00206822),
  DSP16_Q(-0.00323074),
  DSP16_Q(0.00476379),
  DSP16_Q(-0.00676377),
  DSP16_Q(0.00938654),
  DSP16_Q(-0.01290743),
  DSP16_Q(0.01786599),
  DSP16_Q(-0.02547723),
  DSP16_Q(0.03913611),
  DSP16_Q(-0.07311254),
  DSP16_Q(0.36573978),
  DSP16_Q(0.12458153),
  DSP16_Q(-0.05174186),
  DSP16_Q(0.03128064),
  DSP16_Q(-0.02128964),
  DSP16_Q(0.01520549),
  DSP16_Q(-0.01104569),
  DSP16_Q(0.00801066),
  DSP16_Q(-0.00571791),
  DSP16_Q(0.00396152),
  DSP16_Q(-0.00261961),
  DSP16_Q(0.00161354),
  DSP16_Q(-0.00088801),
  DSP16_Q(0.00040068),
  DSP16_Q(-0.00011648),
  DSP16_Q(0.00000448),
  DSP16_Q(0.00003963),
  DSP16_Q(-0.00023134),
  DSP16_Q(0.00060879),
  DSP16_Q(-0.00120444),
  DSP16_Q(0.00205615),
  DSP16_Q(-0.00321138),
  DSP16_Q(0.00473474),
  DSP16_Q(-0.00672207),
  DSP16_Q(0.00932833),
  DSP16_Q(-0.01282733),
  DSP16_Q(0.01775577),
  DSP16_Q(-0.02532272),
  DSP16_Q(0.03890869),
  DSP16_Q(-0.07274226),
  DSP16_Q(0.36646938),
  DSP16_Q(0.12333883),
  DSP16_Q(-0.05131239),
  DSP16_Q(0.03103404),
  DSP16_Q(-0.02112528),
  DSP16_Q(0.01508910),
  DSP16_Q(-0.01096130),
  DSP16_Q(0.00794930),
  DSP16_Q(-0.00567382),
  DSP16_Q(0.00393064),
  DSP16_Q(-0.00259885),
  DSP16_Q(0.00160044),
  DSP16_Q(-0.00088051),
  DSP16_Q(0.00039705),
  DSP16_Q(-0.00011524),
  DSP16_Q(0.00000437),
  DSP16_Q(0.00003960),
  DSP16_Q(-0.00023035),
  DSP16_Q(0.00060560),
  DSP16_Q(-0.00119760),
  DSP16_Q(0.00204395),
  DSP16_Q(-0.00319181),
  DSP16_Q(0.00470539),
  DSP16_Q(-0.00667996),
  DSP16_Q(0.00926955),
  DSP16_Q(-0.01274645),
  DSP16_Q(0.01764447),
  DSP16_Q(-0.02516665),
  DSP16_Q(0.03867876),
  DSP16_Q(-0.07236687),
  DSP16_Q(0.36719330),
  DSP16_Q(0.12209745),
  DSP16_Q(-0.05088148),
  DSP16_Q(0.03078633),
  DSP16_Q(-0.02096010),
  DSP16_Q(0.01497211),
  DSP16_Q(-0.01087648),
  DSP16_Q(0.00788761),
  DSP16_Q(-0.00562950),
  DSP16_Q(0.00389961),
  DSP16_Q(-0.00257800),
  DSP16_Q(0.00158728),
  DSP16_Q(-0.00087299),
  DSP16_Q(0.00039341),
  DSP16_Q(-0.00011400),
  DSP16_Q(0.00000426),
  DSP16_Q(0.00003956),
  DSP16_Q(-0.00022933),
  DSP16_Q(0.00060236),
  DSP16_Q(-0.00119067),
  DSP16_Q(0.00203162),
  DSP16_Q(-0.00317205),
  DSP16_Q(0.00467576),
  DSP16_Q(-0.00663744),
  DSP16_Q(0.00921022),
  DSP16_Q(-0.01266480),
  DSP16_Q(0.01753210),
  DSP16_Q(-0.02500901),
  DSP16_Q(0.03844634),
  DSP16_Q(-0.07198637),
  DSP16_Q(0.36791154),
  DSP16_Q(0.12085744),
  DSP16_Q(-0.05044918),
  DSP16_Q(0.03053753),
  DSP16_Q(-0.02079411),
  DSP16_Q(0.01485453),
  DSP16_Q(-0.01079121),
  DSP16_Q(0.00782562),
  DSP16_Q(-0.00558497),
  DSP16_Q(0.00386843),
  DSP16_Q(-0.00255706),
  DSP16_Q(0.00157407),
  DSP16_Q(-0.00086544),
  DSP16_Q(0.00038977),
  DSP16_Q(-0.00011276),
  DSP16_Q(0.00000415),
  DSP16_Q(0.00003952),
  DSP16_Q(-0.00022830),
  DSP16_Q(0.00059908),
  DSP16_Q(-0.00118366),
  DSP16_Q(0.00201915),
  DSP16_Q(-0.00315207),
  DSP16_Q(0.00464583),
  DSP16_Q(-0.00659451),
  DSP16_Q(0.00915032),
  DSP16_Q(-0.01258238),
  DSP16_Q(0.01741865),
  DSP16_Q(-0.02484983),
  DSP16_Q(0.03821142),
  DSP16_Q(-0.07160074),
  DSP16_Q(0.36862407),
  DSP16_Q(0.11961883),
  DSP16_Q(-0.05001549),
  DSP16_Q(0.03028765),
  DSP16_Q(-0.02062733),
  DSP16_Q(0.01473636),
  DSP16_Q(-0.01070552),
  DSP16_Q(0.00776331),
  DSP16_Q(-0.00554022),
  DSP16_Q(0.00383710),
  DSP16_Q(-0.00253602),
  DSP16_Q(0.00156081),
  DSP16_Q(-0.00085787),
  DSP16_Q(0.00038612),
  DSP16_Q(-0.00011152),
  DSP16_Q(0.00000405),
  DSP16_Q(0.00003947),
  DSP16_Q(-0.00022724),
  DSP16_Q(0.00059575),
  DSP16_Q(-0.00117657),
  DSP16_Q(0.00200655),
  DSP16_Q(-0.00313190),
  DSP16_Q(0.00461561),
  DSP16_Q(-0.00655118),
  DSP16_Q(0.00908986),
  DSP16_Q(-0.01249920),
  DSP16_Q(0.01730415),
  DSP16_Q(-0.02468909),
  DSP16_Q(0.03797403),
  DSP16_Q(-0.07121000),
  DSP16_Q(0.36933086),
  DSP16_Q(0.11838164),
  DSP16_Q(-0.04958044),
  DSP16_Q(0.03003670),
  DSP16_Q(-0.02045976),
  DSP16_Q(0.01461760),
  DSP16_Q(-0.01061940),
  DSP16_Q(0.00770070),
  DSP16_Q(-0.00549525),
  DSP16_Q(0.00380563),
  DSP16_Q(-0.00251490),
  DSP16_Q(0.00154750),
  DSP16_Q(-0.00085027),
  DSP16_Q(0.00038246),
  DSP16_Q(-0.00011029),
  DSP16_Q(0.00000394),
  DSP16_Q(0.00003942),
  DSP16_Q(-0.00022617),
  DSP16_Q(0.00059238),
  DSP16_Q(-0.00116940),
  DSP16_Q(0.00199381),
  DSP16_Q(-0.00311153),
  DSP16_Q(0.00458511),
  DSP16_Q(-0.00650744),
  DSP16_Q(0.00902885),
  DSP16_Q(-0.01241526),
  DSP16_Q(0.01718858),
  DSP16_Q(-0.02452682),
  DSP16_Q(0.03773415),
  DSP16_Q(-0.07081414),
  DSP16_Q(0.37003190),
  DSP16_Q(0.11714591),
  DSP16_Q(-0.04914407),
  DSP16_Q(0.02978470),
  DSP16_Q(-0.02029141),
  DSP16_Q(0.01449828),
  DSP16_Q(-0.01053286),
  DSP16_Q(0.00763779),
  DSP16_Q(-0.00545007),
  DSP16_Q(0.00377403),
  DSP16_Q(-0.00249369),
  DSP16_Q(0.00153414),
  DSP16_Q(-0.00084266),
  DSP16_Q(0.00037879),
  DSP16_Q(-0.00010905),
  DSP16_Q(0.00000384),
  DSP16_Q(0.00003936),
  DSP16_Q(-0.00022507),
  DSP16_Q(0.00058896),
  DSP16_Q(-0.00116214),
  DSP16_Q(0.00198094),
  DSP16_Q(-0.00309096),
  DSP16_Q(0.00455431),
  DSP16_Q(-0.00646330),
  DSP16_Q(0.00896729),
  DSP16_Q(-0.01233056),
  DSP16_Q(0.01707196),
  DSP16_Q(-0.02436300),
  DSP16_Q(0.03749181),
  DSP16_Q(-0.07041315),
  DSP16_Q(0.37072716),
  DSP16_Q(0.11591168),
  DSP16_Q(-0.04870638),
  DSP16_Q(0.02953167),
  DSP16_Q(-0.02012229),
  DSP16_Q(0.01437839),
  DSP16_Q(-0.01044591),
  DSP16_Q(0.00757457),
  DSP16_Q(-0.00540469),
  DSP16_Q(0.00374228),
  DSP16_Q(-0.00247239),
  DSP16_Q(0.00152074),
  DSP16_Q(-0.00083502),
  DSP16_Q(0.00037513),
  DSP16_Q(-0.00010782),
  DSP16_Q(0.00000374),
  DSP16_Q(0.00003930),
  DSP16_Q(-0.00022396),
  DSP16_Q(0.00058550),
  DSP16_Q(-0.00115481),
  DSP16_Q(0.00196794),
  DSP16_Q(-0.00307018),
  DSP16_Q(0.00452323),
  DSP16_Q(-0.00641877),
  DSP16_Q(0.00890518),
  DSP16_Q(-0.01224510),
  DSP16_Q(0.01695428),
  DSP16_Q(-0.02419766),
  DSP16_Q(0.03724700),
  DSP16_Q(-0.07000704),
  DSP16_Q(0.37141662),
  DSP16_Q(0.11467897),
  DSP16_Q(-0.04826742),
  DSP16_Q(0.02927761),
  DSP16_Q(-0.01995242),
  DSP16_Q(0.01425793),
  DSP16_Q(-0.01035855),
  DSP16_Q(0.00751107),
  DSP16_Q(-0.00535909),
  DSP16_Q(0.00371039),
  DSP16_Q(-0.00245100),
  DSP16_Q(0.00150728),
  DSP16_Q(-0.00082735),
  DSP16_Q(0.00037145),
  DSP16_Q(-0.00010659),
  DSP16_Q(0.00000364),
  DSP16_Q(0.00003923),
  DSP16_Q(-0.00022283),
  DSP16_Q(0.00058199),
  DSP16_Q(-0.00114739),
  DSP16_Q(0.00195481),
  DSP16_Q(-0.00304921),
  DSP16_Q(0.00449187),
  DSP16_Q(-0.00637383),
  DSP16_Q(0.00884252),
  DSP16_Q(-0.01215889),
  DSP16_Q(0.01683556),
  DSP16_Q(-0.02403079),
  DSP16_Q(0.03699973),
  DSP16_Q(-0.06959580),
  DSP16_Q(0.37210027),
  DSP16_Q(0.11344781),
  DSP16_Q(-0.04782719),
  DSP16_Q(0.02902255),
  DSP16_Q(-0.01978180),
  DSP16_Q(0.01413693),
  DSP16_Q(-0.01027078),
  DSP16_Q(0.00744727),
  DSP16_Q(-0.00531330),
  DSP16_Q(0.00367837),
  DSP16_Q(-0.00242953),
  DSP16_Q(0.00149378),
  DSP16_Q(-0.00081967),
  DSP16_Q(0.00036777),
  DSP16_Q(-0.00010536),
  DSP16_Q(0.00000354),
  DSP16_Q(0.00003916),
  DSP16_Q(-0.00022167),
  DSP16_Q(0.00057844),
  DSP16_Q(-0.00113989),
  DSP16_Q(0.00194155),
  DSP16_Q(-0.00302805),
  DSP16_Q(0.00446022),
  DSP16_Q(-0.00632850),
  DSP16_Q(0.00877931),
  DSP16_Q(-0.01207194),
  DSP16_Q(0.01671579),
  DSP16_Q(-0.02386239),
  DSP16_Q(0.03675001),
  DSP16_Q(-0.06917943),
  DSP16_Q(0.37277807),
  DSP16_Q(0.11221825),
  DSP16_Q(-0.04738574),
  DSP16_Q(0.02876650),
  DSP16_Q(-0.01961044),
  DSP16_Q(0.01401538),
  DSP16_Q(-0.01018261),
  DSP16_Q(0.00738318),
  DSP16_Q(-0.00526730),
  DSP16_Q(0.00364621),
  DSP16_Q(-0.00240798),
  DSP16_Q(0.00148023),
  DSP16_Q(-0.00081197),
  DSP16_Q(0.00036408),
  DSP16_Q(-0.00010413),
  DSP16_Q(0.00000344),
  DSP16_Q(0.00003908),
  DSP16_Q(-0.00022050),
  DSP16_Q(0.00057485),
  DSP16_Q(-0.00113231),
  DSP16_Q(0.00192816),
  DSP16_Q(-0.00300668),
  DSP16_Q(0.00442828),
  DSP16_Q(-0.00628277),
  DSP16_Q(0.00871557),
  DSP16_Q(-0.01198424),
  DSP16_Q(0.01659498),
  DSP16_Q(-0.02369249),
  DSP16_Q(0.03649784),
  DSP16_Q(-0.06875794),
  DSP16_Q(0.37345002),
  DSP16_Q(0.11099031),
  DSP16_Q(-0.04694307),
  DSP16_Q(0.02850946),
  DSP16_Q(-0.01943835),
  DSP16_Q(0.01389329),
  DSP16_Q(-0.01009405),
  DSP16_Q(0.00731881),
  DSP16_Q(-0.00522110),
  DSP16_Q(0.00361392),
  DSP16_Q(-0.00238634),
  DSP16_Q(0.00146663),
  DSP16_Q(-0.00080425),
  DSP16_Q(0.00036039),
  DSP16_Q(-0.00010290),
  DSP16_Q(0.00000335),
  DSP16_Q(0.00003900),
  DSP16_Q(-0.00021931),
  DSP16_Q(0.00057121),
  DSP16_Q(-0.00112465),
  DSP16_Q(0.00191463),
  DSP16_Q(-0.00298512),
  DSP16_Q(0.00439607),
  DSP16_Q(-0.00623665),
  DSP16_Q(0.00865128),
  DSP16_Q(-0.01189580),
  DSP16_Q(0.01647314),
  DSP16_Q(-0.02352108),
  DSP16_Q(0.03624324),
  DSP16_Q(-0.06833132),
  DSP16_Q(0.37411608),
  DSP16_Q(0.10976401),
  DSP16_Q(-0.04649922),
  DSP16_Q(0.02825147),
  DSP16_Q(-0.01926554),
  DSP16_Q(0.01377067),
  DSP16_Q(-0.01000509),
  DSP16_Q(0.00725415),
  DSP16_Q(-0.00517471),
  DSP16_Q(0.00358150),
  DSP16_Q(-0.00236463),
  DSP16_Q(0.00145300),
  DSP16_Q(-0.00079650),
  DSP16_Q(0.00035670),
  DSP16_Q(-0.00010168),
  DSP16_Q(0.00000326),
  DSP16_Q(0.00003892),
  DSP16_Q(-0.00021809),
  DSP16_Q(0.00056752),
  DSP16_Q(-0.00111691),
  DSP16_Q(0.00190098),
  DSP16_Q(-0.00296336),
  DSP16_Q(0.00436358),
  DSP16_Q(-0.00619013),
  DSP16_Q(0.00858645),
  DSP16_Q(-0.01180662),
  DSP16_Q(0.01635028),
  DSP16_Q(-0.02334816),
  DSP16_Q(0.03598621),
  DSP16_Q(-0.06789957),
  DSP16_Q(0.37477625),
  DSP16_Q(0.10853941),
  DSP16_Q(-0.04605421),
  DSP16_Q(0.02799252),
  DSP16_Q(-0.01909202),
  DSP16_Q(0.01364753),
  DSP16_Q(-0.00991576),
  DSP16_Q(0.00718923),
  DSP16_Q(-0.00512813),
  DSP16_Q(0.00354896),
  DSP16_Q(-0.00234283),
  DSP16_Q(0.00143931),
  DSP16_Q(-0.00078874),
  DSP16_Q(0.00035300),
  DSP16_Q(-0.00010046),
  DSP16_Q(0.00000316),
  DSP16_Q(0.00003882),
  DSP16_Q(-0.00021686),
  DSP16_Q(0.00056379),
  DSP16_Q(-0.00110908),
  DSP16_Q(0.00188720),
  DSP16_Q(-0.00294141),
  DSP16_Q(0.00433080),
  DSP16_Q(-0.00614323),
  DSP16_Q(0.00852109),
  DSP16_Q(-0.01171670),
  DSP16_Q(0.01622638),
  DSP16_Q(-0.02317375),
  DSP16_Q(0.03572675),
  DSP16_Q(-0.06746269),
  DSP16_Q(0.37543049),
  DSP16_Q(0.10731652),
  DSP16_Q(-0.04560807),
  DSP16_Q(0.02773265),
  DSP16_Q(-0.01891781),
  DSP16_Q(0.01352386),
  DSP16_Q(-0.00982604),
  DSP16_Q(0.00712403),
  DSP16_Q(-0.00508135),
  DSP16_Q(0.00351628),
  DSP16_Q(-0.00232096),
  DSP16_Q(0.00142559),
  DSP16_Q(-0.00078096),
  DSP16_Q(0.00034929),
  DSP16_Q(-0.00009924),
  DSP16_Q(0.00000307),
  DSP16_Q(0.00003873),
  DSP16_Q(-0.00021561),
  DSP16_Q(0.00056002),
  DSP16_Q(-0.00110118),
  DSP16_Q(0.00187328),
  DSP16_Q(-0.00291927),
  DSP16_Q(0.00429775),
  DSP16_Q(-0.00609594),
  DSP16_Q(0.00845519),
  DSP16_Q(-0.01162606),
  DSP16_Q(0.01610147),
  DSP16_Q(-0.02299785),
  DSP16_Q(0.03546487),
  DSP16_Q(-0.06702068),
  DSP16_Q(0.37607879),
  DSP16_Q(0.10609538),
  DSP16_Q(-0.04516082),
  DSP16_Q(0.02747185),
  DSP16_Q(-0.01874290),
  DSP16_Q(0.01339969),
  DSP16_Q(-0.00973595),
  DSP16_Q(0.00705856),
  DSP16_Q(-0.00503439),
  DSP16_Q(0.00348349),
  DSP16_Q(-0.00229901),
  DSP16_Q(0.00141182),
  DSP16_Q(-0.00077316),
  DSP16_Q(0.00034559),
  DSP16_Q(-0.00009802),
  DSP16_Q(0.00000299),
  DSP16_Q(0.00003863),
  DSP16_Q(-0.00021433),
  DSP16_Q(0.00055620),
  DSP16_Q(-0.00109320),
  DSP16_Q(0.00185924),
  DSP16_Q(-0.00289693),
  DSP16_Q(0.00426442),
  DSP16_Q(-0.00604826),
  DSP16_Q(0.00838877),
  DSP16_Q(-0.01153468),
  DSP16_Q(0.01597554),
  DSP16_Q(-0.02282046),
  DSP16_Q(0.03520059),
  DSP16_Q(-0.06657354),
  DSP16_Q(0.37672113),
  DSP16_Q(0.10487601),
  DSP16_Q(-0.04471248),
  DSP16_Q(0.02721015),
  DSP16_Q(-0.01856732),
  DSP16_Q(0.01327501),
  DSP16_Q(-0.00964549),
  DSP16_Q(0.00699282),
  DSP16_Q(-0.00498725),
  DSP16_Q(0.00345057),
  DSP16_Q(-0.00227699),
  DSP16_Q(0.00139801),
  DSP16_Q(-0.00076534),
  DSP16_Q(0.00034187),
  DSP16_Q(-0.00009680),
  DSP16_Q(0.00000290),
  DSP16_Q(0.00003852),
  DSP16_Q(-0.00021304),
  DSP16_Q(0.00055233),
  DSP16_Q(-0.00108514),
  DSP16_Q(0.00184508),
  DSP16_Q(-0.00287440),
  DSP16_Q(0.00423082),
  DSP16_Q(-0.00600020),
  DSP16_Q(0.00832182),
  DSP16_Q(-0.01144259),
  DSP16_Q(0.01584860),
  DSP16_Q(-0.02264160),
  DSP16_Q(0.03493391),
  DSP16_Q(-0.06612127),
  DSP16_Q(0.37735749),
  DSP16_Q(0.10365846),
  DSP16_Q(-0.04426308),
  DSP16_Q(0.02694756),
  DSP16_Q(-0.01839107),
  DSP16_Q(0.01314984),
  DSP16_Q(-0.00955467),
  DSP16_Q(0.00692682),
  DSP16_Q(-0.00493992),
  DSP16_Q(0.00341753),
  DSP16_Q(-0.00225489),
  DSP16_Q(0.00138417),
  DSP16_Q(-0.00075751),
  DSP16_Q(0.00033816),
  DSP16_Q(-0.00009559),
  DSP16_Q(0.00000281),
  DSP16_Q(0.00003840),
  DSP16_Q(-0.00021173),
  DSP16_Q(0.00054843),
  DSP16_Q(-0.00107700),
  DSP16_Q(0.00183078),
  DSP16_Q(-0.00285168),
  DSP16_Q(0.00419694),
  DSP16_Q(-0.00595176),
  DSP16_Q(0.00825434),
  DSP16_Q(-0.01134977),
  DSP16_Q(0.01572066),
  DSP16_Q(-0.02246127),
  DSP16_Q(0.03466483),
  DSP16_Q(-0.06566387),
  DSP16_Q(0.37798785),
  DSP16_Q(0.10244275),
  DSP16_Q(-0.04381264),
  DSP16_Q(0.02668410),
  DSP16_Q(-0.01821416),
  DSP16_Q(0.01302418),
  DSP16_Q(-0.00946348),
  DSP16_Q(0.00686057),
  DSP16_Q(-0.00489241),
  DSP16_Q(0.00338437),
  DSP16_Q(-0.00223272),
  DSP16_Q(0.00137028),
  DSP16_Q(-0.00074966),
  DSP16_Q(0.00033444),
  DSP16_Q(-0.00009438),
  DSP16_Q(0.00000273),
  DSP16_Q(0.00003829),
  DSP16_Q(-0.00021039),
  DSP16_Q(0.00054447),
  DSP16_Q(-0.00106878),
  DSP16_Q(0.00181635),
  DSP16_Q(-0.00282877),
  DSP16_Q(0.00416278),
  DSP16_Q(-0.00590294),
  DSP16_Q(0.00818634),
  DSP16_Q(-0.01125624),
  DSP16_Q(0.01559171),
  DSP16_Q(-0.02227947),
  DSP16_Q(0.03439336),
  DSP16_Q(-0.06520134),
  DSP16_Q(0.37861219),
  DSP16_Q(0.10122891),
  DSP16_Q(-0.04336119),
  DSP16_Q(0.02641978),
  DSP16_Q(-0.01803660),
  DSP16_Q(0.01289803),
  DSP16_Q(-0.00937195),
  DSP16_Q(0.00679406),
  DSP16_Q(-0.00484473),
  DSP16_Q(0.00335109),
  DSP16_Q(-0.00221047),
  DSP16_Q(0.00135635),
  DSP16_Q(-0.00074179),
  DSP16_Q(0.00033072),
  DSP16_Q(-0.00009317),
  DSP16_Q(0.00000265),
  DSP16_Q(0.00003816),
  DSP16_Q(-0.00020904),
  DSP16_Q(0.00054048),
  DSP16_Q(-0.00106048),
  DSP16_Q(0.00180180),
  DSP16_Q(-0.00280566),
  DSP16_Q(0.00412836),
  DSP16_Q(-0.00585374),
  DSP16_Q(0.00811782),
  DSP16_Q(-0.01116199),
  DSP16_Q(0.01546177),
  DSP16_Q(-0.02209621),
  DSP16_Q(0.03411952),
  DSP16_Q(-0.06473369),
  DSP16_Q(0.37923050),
  DSP16_Q(0.10001698),
  DSP16_Q(-0.04290875),
  DSP16_Q(0.02615461),
  DSP16_Q(-0.01785840),
  DSP16_Q(0.01277141),
  DSP16_Q(-0.00928006),
  DSP16_Q(0.00672730),
  DSP16_Q(-0.00479687),
  DSP16_Q(0.00331770),
  DSP16_Q(-0.00218816),
  DSP16_Q(0.00134239),
  DSP16_Q(-0.00073391),
  DSP16_Q(0.00032700),
  DSP16_Q(-0.00009197),
  DSP16_Q(0.00000257),
  DSP16_Q(0.00003803),
  DSP16_Q(-0.00020767),
  DSP16_Q(0.00053644),
  DSP16_Q(-0.00105210),
  DSP16_Q(0.00178713),
  DSP16_Q(-0.00278237),
  DSP16_Q(0.00409367),
  DSP16_Q(-0.00580416),
  DSP16_Q(0.00804879),
  DSP16_Q(-0.01106704),
  DSP16_Q(0.01533084),
  DSP16_Q(-0.02191151),
  DSP16_Q(0.03384331),
  DSP16_Q(-0.06426091),
  DSP16_Q(0.37984274),
  DSP16_Q(0.09880698),
  DSP16_Q(-0.04245534),
  DSP16_Q(0.02588861),
  DSP16_Q(-0.01767957),
  DSP16_Q(0.01264433),
  DSP16_Q(-0.00918784),
  DSP16_Q(0.00666030),
  DSP16_Q(-0.00474884),
  DSP16_Q(0.00328420),
  DSP16_Q(-0.00216578),
  DSP16_Q(0.00132839),
  DSP16_Q(-0.00072601),
  DSP16_Q(0.00032327),
  DSP16_Q(-0.00009076),
  DSP16_Q(0.00000249),
  DSP16_Q(0.00003790),
  DSP16_Q(-0.00020627),
  DSP16_Q(0.00053236),
  DSP16_Q(-0.00104364),
  DSP16_Q(0.00177233),
  DSP16_Q(-0.00275890),
  DSP16_Q(0.00405870),
  DSP16_Q(-0.00575421),
  DSP16_Q(0.00797924),
  DSP16_Q(-0.01097138),
  DSP16_Q(0.01519892),
  DSP16_Q(-0.02172536),
  DSP16_Q(0.03356474),
  DSP16_Q(-0.06378300),
  DSP16_Q(0.38044891),
  DSP16_Q(0.09759895),
  DSP16_Q(-0.04200100),
  DSP16_Q(0.02562180),
  DSP16_Q(-0.01750012),
  DSP16_Q(0.01251678),
  DSP16_Q(-0.00909527),
  DSP16_Q(0.00659305),
  DSP16_Q(-0.00470064),
  DSP16_Q(0.00325059),
  DSP16_Q(-0.00214333),
  DSP16_Q(0.00131435),
  DSP16_Q(-0.00071810),
  DSP16_Q(0.00031954),
  DSP16_Q(-0.00008956),
  DSP16_Q(0.00000241),
  DSP16_Q(0.00003776),
  DSP16_Q(-0.00020486),
  DSP16_Q(0.00052823),
  DSP16_Q(-0.00103511),
  DSP16_Q(0.00175740),
  DSP16_Q(-0.00273523),
  DSP16_Q(0.00402347),
  DSP16_Q(-0.00570388),
  DSP16_Q(0.00790918),
  DSP16_Q(-0.01087502),
  DSP16_Q(0.01506603),
  DSP16_Q(-0.02153777),
  DSP16_Q(0.03328381),
  DSP16_Q(-0.06329996),
  DSP16_Q(0.38104898),
  DSP16_Q(0.09639291),
  DSP16_Q(-0.04154574),
  DSP16_Q(0.02535419),
  DSP16_Q(-0.01732006),
  DSP16_Q(0.01238878),
  DSP16_Q(-0.00900237),
  DSP16_Q(0.00652556),
  DSP16_Q(-0.00465228),
  DSP16_Q(0.00321686),
  DSP16_Q(-0.00212081),
  DSP16_Q(0.00130028),
  DSP16_Q(-0.00071017),
  DSP16_Q(0.00031581),
  DSP16_Q(-0.00008836),
  DSP16_Q(0.00000234),
  DSP16_Q(0.00003762),
  DSP16_Q(-0.00020343),
  DSP16_Q(0.00052406),
  DSP16_Q(-0.00102650),
  DSP16_Q(0.00174235),
  DSP16_Q(-0.00271138),
  DSP16_Q(0.00398798),
  DSP16_Q(-0.00565319),
  DSP16_Q(0.00783861),
  DSP16_Q(-0.01077796),
  DSP16_Q(0.01493216),
  DSP16_Q(-0.02134875),
  DSP16_Q(0.03300054),
  DSP16_Q(-0.06281181),
  DSP16_Q(0.38164294),
  DSP16_Q(0.09518891),
  DSP16_Q(-0.04108960),
  DSP16_Q(0.02508580),
  DSP16_Q(-0.01713941),
  DSP16_Q(0.01226033),
  DSP16_Q(-0.00890915),
  DSP16_Q(0.00645784),
  DSP16_Q(-0.00460376),
  DSP16_Q(0.00318304),
  DSP16_Q(-0.00209823),
  DSP16_Q(0.00128618),
  DSP16_Q(-0.00070223),
  DSP16_Q(0.00031208),
  DSP16_Q(-0.00008717),
  DSP16_Q(0.00000226),
  DSP16_Q(0.00003746),
  DSP16_Q(-0.00020197),
  DSP16_Q(0.00051984),
  DSP16_Q(-0.00101781),
  DSP16_Q(0.00172717),
  DSP16_Q(-0.00268734),
  DSP16_Q(0.00395221),
  DSP16_Q(-0.00560212),
  DSP16_Q(0.00776754),
  DSP16_Q(-0.01068021),
  DSP16_Q(0.01479732),
  DSP16_Q(-0.02115831),
  DSP16_Q(0.03271493),
  DSP16_Q(-0.06231853),
  DSP16_Q(0.38223076),
  DSP16_Q(0.09398696),
  DSP16_Q(-0.04063258),
  DSP16_Q(0.02481663),
  DSP16_Q(-0.01695817),
  DSP16_Q(0.01213144),
  DSP16_Q(-0.00881560),
  DSP16_Q(0.00638989),
  DSP16_Q(-0.00455507),
  DSP16_Q(0.00314910),
  DSP16_Q(-0.00207559),
  DSP16_Q(0.00127204),
  DSP16_Q(-0.00069428),
  DSP16_Q(0.00030834),
  DSP16_Q(-0.00008598),
  DSP16_Q(0.00000219),
  DSP16_Q(0.00003731),
  DSP16_Q(-0.00020050),
  DSP16_Q(0.00051558),
  DSP16_Q(-0.00100904),
  DSP16_Q(0.00171187),
  DSP16_Q(-0.00266312),
  DSP16_Q(0.00391619),
  DSP16_Q(-0.00555069),
  DSP16_Q(0.00769597),
  DSP16_Q(-0.01058177),
  DSP16_Q(0.01466151),
  DSP16_Q(-0.02096645),
  DSP16_Q(0.03242700),
  DSP16_Q(-0.06182013),
  DSP16_Q(0.38281244),
  DSP16_Q(0.09278710),
  DSP16_Q(-0.04017473),
  DSP16_Q(0.02454671),
  DSP16_Q(-0.01677634),
  DSP16_Q(0.01200213),
  DSP16_Q(-0.00872173),
  DSP16_Q(0.00632171),
  DSP16_Q(-0.00450623),
  DSP16_Q(0.00311506),
  DSP16_Q(-0.00205288),
  DSP16_Q(0.00125786),
  DSP16_Q(-0.00068631),
  DSP16_Q(0.00030461),
  DSP16_Q(-0.00008479),
  DSP16_Q(0.00000212),
  DSP16_Q(0.00003715),
  DSP16_Q(-0.00019901),
  DSP16_Q(0.00051128),
  DSP16_Q(-0.00100019),
  DSP16_Q(0.00169645),
  DSP16_Q(-0.00263872),
  DSP16_Q(0.00387990),
  DSP16_Q(-0.00549890),
  DSP16_Q(0.00762389),
  DSP16_Q(-0.01048265),
  DSP16_Q(0.01452475),
  DSP16_Q(-0.02077319),
  DSP16_Q(0.03213674),
  DSP16_Q(-0.06131661),
  DSP16_Q(0.38338795),
  DSP16_Q(0.09158935),
  DSP16_Q(-0.03971605),
  DSP16_Q(0.02427605),
  DSP16_Q(-0.01659395),
  DSP16_Q(0.01187238),
  DSP16_Q(-0.00862756),
  DSP16_Q(0.00625331),
  DSP16_Q(-0.00445724),
  DSP16_Q(0.00308093),
  DSP16_Q(-0.00203012),
  DSP16_Q(0.00124366),
  DSP16_Q(-0.00067833),
  DSP16_Q(0.00030087),
  DSP16_Q(-0.00008360),
  DSP16_Q(0.00000205),
  DSP16_Q(0.00003698),
  DSP16_Q(-0.00019749),
  DSP16_Q(0.00050694),
  DSP16_Q(-0.00099127),
  DSP16_Q(0.00168090),
  DSP16_Q(-0.00261413),
  DSP16_Q(0.00384335),
  DSP16_Q(-0.00544675),
  DSP16_Q(0.00755132),
  DSP16_Q(-0.01038284),
  DSP16_Q(0.01438704),
  DSP16_Q(-0.02057852),
  DSP16_Q(0.03184418),
  DSP16_Q(-0.06080798),
  DSP16_Q(0.38395728),
  DSP16_Q(0.09039376),
  DSP16_Q(-0.03925659),
  DSP16_Q(0.02400467),
  DSP16_Q(-0.01641101),
  DSP16_Q(0.01174222),
  DSP16_Q(-0.00853308),
  DSP16_Q(0.00618469),
  DSP16_Q(-0.00440809),
  DSP16_Q(0.00304669),
  DSP16_Q(-0.00200729),
  DSP16_Q(0.00122943),
  DSP16_Q(-0.00067034),
  DSP16_Q(0.00029713),
  DSP16_Q(-0.00008242),
  DSP16_Q(0.00000198),
  DSP16_Q(0.00003681),
  DSP16_Q(-0.00019596),
  DSP16_Q(0.00050255),
  DSP16_Q(-0.00098227),
  DSP16_Q(0.00166524),
  DSP16_Q(-0.00258936),
  DSP16_Q(0.00380655),
  DSP16_Q(-0.00539423),
  DSP16_Q(0.00747826),
  DSP16_Q(-0.01028236),
  DSP16_Q(0.01424837),
  DSP16_Q(-0.02038245),
  DSP16_Q(0.03154932),
  DSP16_Q(-0.06029424),
  DSP16_Q(0.38452040),
  DSP16_Q(0.08920035),
  DSP16_Q(-0.03879635),
  DSP16_Q(0.02373257),
  DSP16_Q(-0.01622751),
  DSP16_Q(0.01161165),
  DSP16_Q(-0.00843829),
  DSP16_Q(0.00611585),
  DSP16_Q(-0.00435879),
  DSP16_Q(0.00301235),
  DSP16_Q(-0.00198441),
  DSP16_Q(0.00121516),
  DSP16_Q(-0.00066234),
  DSP16_Q(0.00029339),
  DSP16_Q(-0.00008124),
  DSP16_Q(0.00000191),
  DSP16_Q(0.00003663),
  DSP16_Q(-0.00019440),
  DSP16_Q(0.00049812),
  DSP16_Q(-0.00097320),
  DSP16_Q(0.00164945),
  DSP16_Q(-0.00256441),
  DSP16_Q(0.00376948),
  DSP16_Q(-0.00534136),
  DSP16_Q(0.00740470),
  DSP16_Q(-0.01018120),
  DSP16_Q(0.01410877),
  DSP16_Q(-0.02018501),
  DSP16_Q(0.03125216),
  DSP16_Q(-0.05977538),
  DSP16_Q(0.38507730),
  DSP16_Q(0.08800915),
  DSP16_Q(-0.03833537),
  DSP16_Q(0.02345978),
  DSP16_Q(-0.01604347),
  DSP16_Q(0.01148068),
  DSP16_Q(-0.00834321),
  DSP16_Q(0.00604680),
  DSP16_Q(-0.00430935),
  DSP16_Q(0.00297793),
  DSP16_Q(-0.00196146),
  DSP16_Q(0.00120087),
  DSP16_Q(-0.00065433),
  DSP16_Q(0.00028966),
  DSP16_Q(-0.00008007),
  DSP16_Q(0.00000184),
  DSP16_Q(0.00003644),
  DSP16_Q(-0.00019283),
  DSP16_Q(0.00049364),
  DSP16_Q(-0.00096405),
  DSP16_Q(0.00163354),
  DSP16_Q(-0.00253928),
  DSP16_Q(0.00373216),
  DSP16_Q(-0.00528813),
  DSP16_Q(0.00733066),
  DSP16_Q(-0.01007938),
  DSP16_Q(0.01396823),
  DSP16_Q(-0.01998618),
  DSP16_Q(0.03095272),
  DSP16_Q(-0.05925142),
  DSP16_Q(0.38562797),
  DSP16_Q(0.08682018),
  DSP16_Q(-0.03787367),
  DSP16_Q(0.02318631),
  DSP16_Q(-0.01585891),
  DSP16_Q(0.01134931),
  DSP16_Q(-0.00824784),
  DSP16_Q(0.00597754),
  DSP16_Q(-0.00425977),
  DSP16_Q(0.00294340),
  DSP16_Q(-0.00193847),
  DSP16_Q(0.00118654),
  DSP16_Q(-0.00064630),
  DSP16_Q(0.00028592),
  DSP16_Q(-0.00007890),
  DSP16_Q(0.00000178),
  DSP16_Q(0.00003625),
  DSP16_Q(-0.00019123),
  DSP16_Q(0.00048912),
  DSP16_Q(-0.00095482),
  DSP16_Q(0.00161751),
  DSP16_Q(-0.00251397),
  DSP16_Q(0.00369459),
  DSP16_Q(-0.00523455),
  DSP16_Q(0.00725614),
  DSP16_Q(-0.00997689),
  DSP16_Q(0.01382676),
  DSP16_Q(-0.01978598),
  DSP16_Q(0.03065102),
  DSP16_Q(-0.05872235),
  DSP16_Q(0.38617238),
  DSP16_Q(0.08563349),
  DSP16_Q(-0.03741127),
  DSP16_Q(0.02291217),
  DSP16_Q(-0.01567383),
  DSP16_Q(0.01121755),
  DSP16_Q(-0.00815219),
  DSP16_Q(0.00590808),
  DSP16_Q(-0.00421004),
  DSP16_Q(0.00290879),
  DSP16_Q(-0.00191542),
  DSP16_Q(0.00117219),
  DSP16_Q(-0.00063827),
  DSP16_Q(0.00028218),
  DSP16_Q(-0.00007773),
  DSP16_Q(0.00000172),
  DSP16_Q(0.00003606),
  DSP16_Q(-0.00018962),
  DSP16_Q(0.00048456),
  DSP16_Q(-0.00094552),
  DSP16_Q(0.00160136),
  DSP16_Q(-0.00248849),
  DSP16_Q(0.00365676),
  DSP16_Q(-0.00518062),
  DSP16_Q(0.00718113),
  DSP16_Q(-0.00987374),
  DSP16_Q(0.01368436),
  DSP16_Q(-0.01958441),
  DSP16_Q(0.03034704),
  DSP16_Q(-0.05818818),
  DSP16_Q(0.38671052),
  DSP16_Q(0.08444909),
  DSP16_Q(-0.03694820),
  DSP16_Q(0.02263738),
  DSP16_Q(-0.01548825),
  DSP16_Q(0.01108541),
  DSP16_Q(-0.00805625),
  DSP16_Q(0.00583842),
  DSP16_Q(-0.00416018),
  DSP16_Q(0.00287409),
  DSP16_Q(-0.00189231),
  DSP16_Q(0.00115782),
  DSP16_Q(-0.00063023),
  DSP16_Q(0.00027844),
  DSP16_Q(-0.00007656),
  DSP16_Q(0.00000166),
  DSP16_Q(0.00003585),
  DSP16_Q(-0.00018798),
  DSP16_Q(0.00047996),
  DSP16_Q(-0.00093614),
  DSP16_Q(0.00158509),
  DSP16_Q(-0.00246283),
  DSP16_Q(0.00361868),
  DSP16_Q(-0.00512634),
  DSP16_Q(0.00710565),
  DSP16_Q(-0.00976994),
  DSP16_Q(0.01354105),
  DSP16_Q(-0.01938149),
  DSP16_Q(0.03004082),
  DSP16_Q(-0.05764891),
  DSP16_Q(0.38724238),
  DSP16_Q(0.08326702),
  DSP16_Q(-0.03648448),
  DSP16_Q(0.02236196),
  DSP16_Q(-0.01530216),
  DSP16_Q(0.01095290),
  DSP16_Q(-0.00796004),
  DSP16_Q(0.00576857),
  DSP16_Q(-0.00411018),
  DSP16_Q(0.00283930),
  DSP16_Q(-0.00186916),
  DSP16_Q(0.00114341),
  DSP16_Q(-0.00062217),
  DSP16_Q(0.00027470),
  DSP16_Q(-0.00007540),
  DSP16_Q(0.00000160),
  DSP16_Q(0.00003565),
  DSP16_Q(-0.00018633),
  DSP16_Q(0.00047531),
  DSP16_Q(-0.00092669),
  DSP16_Q(0.00156871),
  DSP16_Q(-0.00243699),
  DSP16_Q(0.00358036),
  DSP16_Q(-0.00507171),
  DSP16_Q(0.00702969),
  DSP16_Q(-0.00966548),
  DSP16_Q(0.01339682),
  DSP16_Q(-0.01917722),
  DSP16_Q(0.02973235),
  DSP16_Q(-0.05710454),
  DSP16_Q(0.38776793),
  DSP16_Q(0.08208731),
  DSP16_Q(-0.03602014),
  DSP16_Q(0.02208592),
  DSP16_Q(-0.01511559),
  DSP16_Q(0.01082002),
  DSP16_Q(-0.00786356),
  DSP16_Q(0.00569852),
  DSP16_Q(-0.00406005),
  DSP16_Q(0.00280442),
  DSP16_Q(-0.00184595),
  DSP16_Q(0.00112898),
  DSP16_Q(-0.00061411),
  DSP16_Q(0.00027096),
  DSP16_Q(-0.00007424),
  DSP16_Q(0.00000154),
  DSP16_Q(0.00003543),
  DSP16_Q(-0.00018465),
  DSP16_Q(0.00047062),
  DSP16_Q(-0.00091716),
  DSP16_Q(0.00155220),
  DSP16_Q(-0.00241098),
  DSP16_Q(0.00354178),
  DSP16_Q(-0.00501674),
  DSP16_Q(0.00695326),
  DSP16_Q(-0.00956038),
  DSP16_Q(0.01325169),
  DSP16_Q(-0.01897161),
  DSP16_Q(0.02942165),
  DSP16_Q(-0.05655509),
  DSP16_Q(0.38828716),
  DSP16_Q(0.08090999),
  DSP16_Q(-0.03555519),
  DSP16_Q(0.02180927),
  DSP16_Q(-0.01492854),
  DSP16_Q(0.01068678),
  DSP16_Q(-0.00776682),
  DSP16_Q(0.00562828),
  DSP16_Q(-0.00400979),
  DSP16_Q(0.00276946),
  DSP16_Q(-0.00182270),
  DSP16_Q(0.00111453),
  DSP16_Q(-0.00060605),
  DSP16_Q(0.00026723),
  DSP16_Q(-0.00007309),
  DSP16_Q(0.00000148),
  DSP16_Q(0.00003521),
  DSP16_Q(-0.00018296),
  DSP16_Q(0.00046589),
  DSP16_Q(-0.00090756),
  DSP16_Q(0.00153558),
  DSP16_Q(-0.00238480),
  DSP16_Q(0.00350296),
  DSP16_Q(-0.00496142),
  DSP16_Q(0.00687636),
  DSP16_Q(-0.00945463),
  DSP16_Q(0.01310565),
  DSP16_Q(-0.01876467),
  DSP16_Q(0.02910872),
  DSP16_Q(-0.05600054),
  DSP16_Q(0.38880005),
  DSP16_Q(0.07973508),
  DSP16_Q(-0.03508967),
  DSP16_Q(0.02153203),
  DSP16_Q(-0.01474103),
  DSP16_Q(0.01055319),
  DSP16_Q(-0.00766982),
  DSP16_Q(0.00555786),
  DSP16_Q(-0.00395941),
  DSP16_Q(0.00273442),
  DSP16_Q(-0.00179939),
  DSP16_Q(0.00110006),
  DSP16_Q(-0.00059797),
  DSP16_Q(0.00026349),
  DSP16_Q(-0.00007194),
  DSP16_Q(0.00000142),
  DSP16_Q(0.00003499),
  DSP16_Q(-0.00018124),
  DSP16_Q(0.00046112),
  DSP16_Q(-0.00089789),
  DSP16_Q(0.00151885),
  DSP16_Q(-0.00235844),
  DSP16_Q(0.00346389),
  DSP16_Q(-0.00490577),
  DSP16_Q(0.00679900),
  DSP16_Q(-0.00934825),
  DSP16_Q(0.01295872),
  DSP16_Q(-0.01855640),
  DSP16_Q(0.02879359),
  DSP16_Q(-0.05544092),
  DSP16_Q(0.38930660),
  DSP16_Q(0.07856262),
  DSP16_Q(-0.03462360),
  DSP16_Q(0.02125422),
  DSP16_Q(-0.01455306),
  DSP16_Q(0.01041926),
  DSP16_Q(-0.00757256),
  DSP16_Q(0.00548725),
  DSP16_Q(-0.00390890),
  DSP16_Q(0.00269930),
  DSP16_Q(-0.00177605),
  DSP16_Q(0.00108556),
  DSP16_Q(-0.00058989),
  DSP16_Q(0.00025976),
  DSP16_Q(-0.00007079),
  DSP16_Q(0.00000137),
  DSP16_Q(0.00003476),
  DSP16_Q(-0.00017951),
  DSP16_Q(0.00045631),
  DSP16_Q(-0.00088814),
  DSP16_Q(0.00150199),
  DSP16_Q(-0.00233191),
  DSP16_Q(0.00342458),
  DSP16_Q(-0.00484978),
  DSP16_Q(0.00672118),
  DSP16_Q(-0.00924123),
  DSP16_Q(0.01281090),
  DSP16_Q(-0.01834682),
  DSP16_Q(0.02847625),
  DSP16_Q(-0.05487621),
  DSP16_Q(0.38980678),
  DSP16_Q(0.07739264),
  DSP16_Q(-0.03415700),
  DSP16_Q(0.02097584),
  DSP16_Q(-0.01436464),
  DSP16_Q(0.01028499),
  DSP16_Q(-0.00747506),
  DSP16_Q(0.00541647),
  DSP16_Q(-0.00385827),
  DSP16_Q(0.00266410),
  DSP16_Q(-0.00175265),
  DSP16_Q(0.00107104),
  DSP16_Q(-0.00058180),
  DSP16_Q(0.00025603),
  DSP16_Q(-0.00006965),
  DSP16_Q(0.00000132),
  DSP16_Q(0.00003452),
  DSP16_Q(-0.00017775),
  DSP16_Q(0.00045145),
  DSP16_Q(-0.00087832),
  DSP16_Q(0.00148503),
  DSP16_Q(-0.00230521),
  DSP16_Q(0.00338502),
  DSP16_Q(-0.00479346),
  DSP16_Q(0.00664289),
  DSP16_Q(-0.00913359),
  DSP16_Q(0.01266220),
  DSP16_Q(-0.01813593),
  DSP16_Q(0.02815672),
  DSP16_Q(-0.05430643),
  DSP16_Q(0.39030057),
  DSP16_Q(0.07622516),
  DSP16_Q(-0.03368990),
  DSP16_Q(0.02069692),
  DSP16_Q(-0.01417579),
  DSP16_Q(0.01015039),
  DSP16_Q(-0.00737731),
  DSP16_Q(0.00534552),
  DSP16_Q(-0.00380752),
  DSP16_Q(0.00262883),
  DSP16_Q(-0.00172922),
  DSP16_Q(0.00105650),
  DSP16_Q(-0.00057370),
  DSP16_Q(0.00025230),
  DSP16_Q(-0.00006851),
  DSP16_Q(0.00000126),
  DSP16_Q(0.00003428),
  DSP16_Q(-0.00017598),
  DSP16_Q(0.00044655),
  DSP16_Q(-0.00086843),
  DSP16_Q(0.00146794),
  DSP16_Q(-0.00227834),
  DSP16_Q(0.00334523),
  DSP16_Q(-0.00473680),
  DSP16_Q(0.00656416),
  DSP16_Q(-0.00902532),
  DSP16_Q(0.01251262),
  DSP16_Q(-0.01792373),
  DSP16_Q(0.02783501),
  DSP16_Q(-0.05373157),
  DSP16_Q(0.39078797),
  DSP16_Q(0.07506021),
  DSP16_Q(-0.03322231),
  DSP16_Q(0.02041747),
  DSP16_Q(-0.01398651),
  DSP16_Q(0.01001546),
  DSP16_Q(-0.00727933),
  DSP16_Q(0.00527440),
  DSP16_Q(-0.00375666),
  DSP16_Q(0.00259349),
  DSP16_Q(-0.00170574),
  DSP16_Q(0.00104194),
  DSP16_Q(-0.00056560),
  DSP16_Q(0.00024857),
  DSP16_Q(-0.00006738),
  DSP16_Q(0.00000121),
  DSP16_Q(0.00003403),
  DSP16_Q(-0.00017418),
  DSP16_Q(0.00044161),
  DSP16_Q(-0.00085846),
  DSP16_Q(0.00145075),
  DSP16_Q(-0.00225131),
  DSP16_Q(0.00330520),
  DSP16_Q(-0.00467981),
  DSP16_Q(0.00648497),
  DSP16_Q(-0.00891643),
  DSP16_Q(0.01236218),
  DSP16_Q(-0.01771025),
  DSP16_Q(0.02751112),
  DSP16_Q(-0.05315166),
  DSP16_Q(0.39126895),
  DSP16_Q(0.07389782),
  DSP16_Q(-0.03275427),
  DSP16_Q(0.02013751),
  DSP16_Q(-0.01379682),
  DSP16_Q(0.00988023),
  DSP16_Q(-0.00718112),
  DSP16_Q(0.00520312),
  DSP16_Q(-0.00370569),
  DSP16_Q(0.00255807),
  DSP16_Q(-0.00168222),
  DSP16_Q(0.00102736),
  DSP16_Q(-0.00055749),
  DSP16_Q(0.00024484),
  DSP16_Q(-0.00006625),
  DSP16_Q(0.00000116),
  DSP16_Q(0.00003377),
  DSP16_Q(-0.00017237),
  DSP16_Q(0.00043663),
  DSP16_Q(-0.00084842),
  DSP16_Q(0.00143344),
  DSP16_Q(-0.00222410),
  DSP16_Q(0.00326493),
  DSP16_Q(-0.00462250),
  DSP16_Q(0.00640533),
  DSP16_Q(-0.00880692),
  DSP16_Q(0.01221086),
  DSP16_Q(-0.01749549),
  DSP16_Q(0.02718508),
  DSP16_Q(-0.05256668),
  DSP16_Q(0.39174351),
  DSP16_Q(0.07273802),
  DSP16_Q(-0.03228579),
  DSP16_Q(0.01985704),
  DSP16_Q(-0.01360673),
  DSP16_Q(0.00974468),
  DSP16_Q(-0.00708268),
  DSP16_Q(0.00513167),
  DSP16_Q(-0.00365460),
  DSP16_Q(0.00252258),
  DSP16_Q(-0.00165866),
  DSP16_Q(0.00101276),
  DSP16_Q(-0.00054938),
  DSP16_Q(0.00024112),
  DSP16_Q(-0.00006512),
  DSP16_Q(0.00000112),
  DSP16_Q(0.00003351),
  DSP16_Q(-0.00017053),
  DSP16_Q(0.00043160),
  DSP16_Q(-0.00083831),
  DSP16_Q(0.00141602),
  DSP16_Q(-0.00219673),
  DSP16_Q(0.00322443),
  DSP16_Q(-0.00456486),
  DSP16_Q(0.00632525),
  DSP16_Q(-0.00869681),
  DSP16_Q(0.01205869),
  DSP16_Q(-0.01727945),
  DSP16_Q(0.02685689),
  DSP16_Q(-0.05197664),
  DSP16_Q(0.39221163),
  DSP16_Q(0.07158084),
  DSP16_Q(-0.03181691),
  DSP16_Q(0.01957609),
  DSP16_Q(-0.01341623),
  DSP16_Q(0.00960883),
  DSP16_Q(-0.00698401),
  DSP16_Q(0.00506006),
  DSP16_Q(-0.00360341),
  DSP16_Q(0.00248703),
  DSP16_Q(-0.00163506),
  DSP16_Q(0.00099814),
  DSP16_Q(-0.00054126),
  DSP16_Q(0.00023740),
  DSP16_Q(-0.00006400),
  DSP16_Q(0.00000107),
  DSP16_Q(0.00003324),
  DSP16_Q(-0.00016868),
  DSP16_Q(0.00042654),
  DSP16_Q(-0.00082813),
  DSP16_Q(0.00139848),
  DSP16_Q(-0.00216920),
  DSP16_Q(0.00318369),
  DSP16_Q(-0.00450690),
  DSP16_Q(0.00624473),
  DSP16_Q(-0.00858609),
  DSP16_Q(0.01190567),
  DSP16_Q(-0.01706214),
  DSP16_Q(0.02652656),
  DSP16_Q(-0.05138156),
  DSP16_Q(0.39267329),
  DSP16_Q(0.07042630),
  DSP16_Q(-0.03134764),
  DSP16_Q(0.01929467),
  DSP16_Q(-0.01322536),
  DSP16_Q(0.00947269),
  DSP16_Q(-0.00688514),
  DSP16_Q(0.00498831),
  DSP16_Q(-0.00355212),
  DSP16_Q(0.00245141),
  DSP16_Q(-0.00161142),
  DSP16_Q(0.00098351),
  DSP16_Q(-0.00053315),
  DSP16_Q(0.00023368),
  DSP16_Q(-0.00006288),
  DSP16_Q(0.00000103),
  DSP16_Q(0.00003297),
  DSP16_Q(-0.00016680),
  DSP16_Q(0.00042143),
  DSP16_Q(-0.00081788),
  DSP16_Q(0.00138084),
  DSP16_Q(-0.00214150),
  DSP16_Q(0.00314272),
  DSP16_Q(-0.00444862),
  DSP16_Q(0.00616377),
  DSP16_Q(-0.00847476),
  DSP16_Q(0.01175181),
  DSP16_Q(-0.01684358),
  DSP16_Q(0.02619411),
  DSP16_Q(-0.05078143),
  DSP16_Q(0.39312848),
  DSP16_Q(0.06927444),
  DSP16_Q(-0.03087801),
  DSP16_Q(0.01901279),
  DSP16_Q(-0.01303411),
  DSP16_Q(0.00933627),
  DSP16_Q(-0.00678605),
  DSP16_Q(0.00491640),
  DSP16_Q(-0.00350072),
  DSP16_Q(0.00241572),
  DSP16_Q(-0.00158775),
  DSP16_Q(0.00096886),
  DSP16_Q(-0.00052502),
  DSP16_Q(0.00022997),
  DSP16_Q(-0.00006177),
  DSP16_Q(0.00000098),
  DSP16_Q(0.00003269),
  DSP16_Q(-0.00016491),
  DSP16_Q(0.00041629),
  DSP16_Q(-0.00080756),
  DSP16_Q(0.00136308),
  DSP16_Q(-0.00211364),
  DSP16_Q(0.00310152),
  DSP16_Q(-0.00439002),
  DSP16_Q(0.00608237),
  DSP16_Q(-0.00836285),
  DSP16_Q(0.01159710),
  DSP16_Q(-0.01662377),
  DSP16_Q(0.02585954),
  DSP16_Q(-0.05017626),
  DSP16_Q(0.39357718),
  DSP16_Q(0.06812529),
  DSP16_Q(-0.03040804),
  DSP16_Q(0.01873047),
  DSP16_Q(-0.01284249),
  DSP16_Q(0.00919956),
  DSP16_Q(-0.00668676),
  DSP16_Q(0.00484435),
  DSP16_Q(-0.00344923),
  DSP16_Q(0.00237998),
  DSP16_Q(-0.00156405),
  DSP16_Q(0.00095420),
  DSP16_Q(-0.00051690),
  DSP16_Q(0.00022625),
  DSP16_Q(-0.00006066),
  DSP16_Q(0.00000094),
  DSP16_Q(0.00003240),
  DSP16_Q(-0.00016299),
  DSP16_Q(0.00041110),
  DSP16_Q(-0.00079717),
  DSP16_Q(0.00134522),
  DSP16_Q(-0.00208562),
  DSP16_Q(0.00306010),
  DSP16_Q(-0.00433110),
  DSP16_Q(0.00600055),
  DSP16_Q(-0.00825034),
  DSP16_Q(0.01144157),
  DSP16_Q(-0.01640272),
  DSP16_Q(0.02552287),
  DSP16_Q(-0.04956606),
  DSP16_Q(0.39401939),
  DSP16_Q(0.06697886),
  DSP16_Q(-0.02993775),
  DSP16_Q(0.01844773),
  DSP16_Q(-0.01265053),
  DSP16_Q(0.00906259),
  DSP16_Q(-0.00658726),
  DSP16_Q(0.00477215),
  DSP16_Q(-0.00339764),
  DSP16_Q(0.00234417),
  DSP16_Q(-0.00154031),
  DSP16_Q(0.00093952),
  DSP16_Q(-0.00050877),
  DSP16_Q(0.00022255),
  DSP16_Q(-0.00005956),
  DSP16_Q(0.00000090),
  DSP16_Q(0.00003211),
  DSP16_Q(-0.00016106),
  DSP16_Q(0.00040587),
  DSP16_Q(-0.00078670),
  DSP16_Q(0.00132724),
  DSP16_Q(-0.00205744),
  DSP16_Q(0.00301844),
  DSP16_Q(-0.00427188),
  DSP16_Q(0.00591830),
  DSP16_Q(-0.00813724),
  DSP16_Q(0.01128521),
  DSP16_Q(-0.01618044),
  DSP16_Q(0.02518411),
  DSP16_Q(-0.04895084),
  DSP16_Q(0.39445508),
  DSP16_Q(0.06583519),
  DSP16_Q(-0.02946718),
  DSP16_Q(0.01816457),
  DSP16_Q(-0.01245822),
  DSP16_Q(0.00892535),
  DSP16_Q(-0.00648758),
  DSP16_Q(0.00469982),
  DSP16_Q(-0.00334596),
  DSP16_Q(0.00230831),
  DSP16_Q(-0.00151654),
  DSP16_Q(0.00092483),
  DSP16_Q(-0.00050064),
  DSP16_Q(0.00021884),
  DSP16_Q(-0.00005846),
  DSP16_Q(0.00000086),
  DSP16_Q(0.00003181),
  DSP16_Q(-0.00015911),
  DSP16_Q(0.00040060),
  DSP16_Q(-0.00077617),
  DSP16_Q(0.00130916),
  DSP16_Q(-0.00202910),
  DSP16_Q(0.00297657),
  DSP16_Q(-0.00421234),
  DSP16_Q(0.00583562),
  DSP16_Q(-0.00802357),
  DSP16_Q(0.01112803),
  DSP16_Q(-0.01595694),
  DSP16_Q(0.02484327),
  DSP16_Q(-0.04833059),
  DSP16_Q(0.39488425),
  DSP16_Q(0.06469431),
  DSP16_Q(-0.02899633),
  DSP16_Q(0.01788102),
  DSP16_Q(-0.01226557),
  DSP16_Q(0.00878786),
  DSP16_Q(-0.00638770),
  DSP16_Q(0.00462736),
  DSP16_Q(-0.00329419),
  DSP16_Q(0.00227239),
  DSP16_Q(-0.00149274),
  DSP16_Q(0.00091012),
  DSP16_Q(-0.00049251),
  DSP16_Q(0.00021514),
  DSP16_Q(-0.00005736),
  DSP16_Q(0.00000082),
  DSP16_Q(0.00003151),
  DSP16_Q(-0.00015713),
  DSP16_Q(0.00039529),
  DSP16_Q(-0.00076557),
  DSP16_Q(0.00129097),
  DSP16_Q(-0.00200060),
  DSP16_Q(0.00293447),
  DSP16_Q(-0.00415250),
  DSP16_Q(0.00575253),
  DSP16_Q(-0.00790932),
  DSP16_Q(0.01097004),
  DSP16_Q(-0.01573223),
  DSP16_Q(0.02450036),
  DSP16_Q(-0.04770533),
  DSP16_Q(0.39530689),
  DSP16_Q(0.06355624),
  DSP16_Q(-0.02852525),
  DSP16_Q(0.01759709),
  DSP16_Q(-0.01207261),
  DSP16_Q(0.00865012),
  DSP16_Q(-0.00628764),
  DSP16_Q(0.00455476),
  DSP16_Q(-0.00324233),
  DSP16_Q(0.00223642),
  DSP16_Q(-0.00146891),
  DSP16_Q(0.00089540),
  DSP16_Q(-0.00048438),
  DSP16_Q(0.00021145),
  DSP16_Q(-0.00005627),
  DSP16_Q(0.00000078),
  DSP16_Q(0.00003119),
  DSP16_Q(-0.00015514),
  DSP16_Q(0.00038994),
  DSP16_Q(-0.00075490),
  DSP16_Q(0.00127267),
  DSP16_Q(-0.00197195),
  DSP16_Q(0.00289215),
  DSP16_Q(-0.00409235),
  DSP16_Q(0.00566902),
  DSP16_Q(-0.00779449),
  DSP16_Q(0.01081125),
  DSP16_Q(-0.01550631),
  DSP16_Q(0.02415539),
  DSP16_Q(-0.04707506),
  DSP16_Q(0.39572297),
  DSP16_Q(0.06242101),
  DSP16_Q(-0.02805394),
  DSP16_Q(0.01731279),
  DSP16_Q(-0.01187933),
  DSP16_Q(0.00851213),
  DSP16_Q(-0.00618741),
  DSP16_Q(0.00448204),
  DSP16_Q(-0.00319039),
  DSP16_Q(0.00220040),
  DSP16_Q(-0.00144505),
  DSP16_Q(0.00088068),
  DSP16_Q(-0.00047624),
  DSP16_Q(0.00020776),
  DSP16_Q(-0.00005518),
  DSP16_Q(0.00000074),
  DSP16_Q(0.00003088),
  DSP16_Q(-0.00015312),
  DSP16_Q(0.00038456),
  DSP16_Q(-0.00074416),
  DSP16_Q(0.00125427),
  DSP16_Q(-0.00194314),
  DSP16_Q(0.00284961),
  DSP16_Q(-0.00403190),
  DSP16_Q(0.00558510),
  DSP16_Q(-0.00767910),
  DSP16_Q(0.01065166),
  DSP16_Q(-0.01527920),
  DSP16_Q(0.02380838),
  DSP16_Q(-0.04643979),
  DSP16_Q(0.39613248),
  DSP16_Q(0.06128865),
  DSP16_Q(-0.02758243),
  DSP16_Q(0.01702815),
  DSP16_Q(-0.01168575),
  DSP16_Q(0.00837392),
  DSP16_Q(-0.00608700),
  DSP16_Q(0.00440920),
  DSP16_Q(-0.00313837),
  DSP16_Q(0.00216432),
  DSP16_Q(-0.00142117),
  DSP16_Q(0.00086594),
  DSP16_Q(-0.00046811),
  DSP16_Q(0.00020407),
  DSP16_Q(-0.00005410),
  DSP16_Q(0.00000071),
  DSP16_Q(0.00003055),
  DSP16_Q(-0.00015109),
  DSP16_Q(0.00037913),
  DSP16_Q(-0.00073336),
  DSP16_Q(0.00123576),
  DSP16_Q(-0.00191417),
  DSP16_Q(0.00280685),
  DSP16_Q(-0.00397115),
  DSP16_Q(0.00550077),
  DSP16_Q(-0.00756315),
  DSP16_Q(0.01049128),
  DSP16_Q(-0.01505091),
  DSP16_Q(0.02345934),
  DSP16_Q(-0.04579952),
  DSP16_Q(0.39653542),
  DSP16_Q(0.06015918),
  DSP16_Q(-0.02711075),
  DSP16_Q(0.01674316),
  DSP16_Q(-0.01149188),
  DSP16_Q(0.00823547),
  DSP16_Q(-0.00598642),
  DSP16_Q(0.00433624),
  DSP16_Q(-0.00308627),
  DSP16_Q(0.00212820),
  DSP16_Q(-0.00139726),
  DSP16_Q(0.00085119),
  DSP16_Q(-0.00045998),
  DSP16_Q(0.00020039),
  DSP16_Q(-0.00005303),
  DSP16_Q(0.00000067),
  DSP16_Q(0.00003022),
  DSP16_Q(-0.00014904),
  DSP16_Q(0.00037366),
  DSP16_Q(-0.00072248),
  DSP16_Q(0.00121715),
  DSP16_Q(-0.00188506),
  DSP16_Q(0.00276388),
  DSP16_Q(-0.00391010),
  DSP16_Q(0.00541603),
  DSP16_Q(-0.00744664),
  DSP16_Q(0.01033011),
  DSP16_Q(-0.01482144),
  DSP16_Q(0.02310829),
  DSP16_Q(-0.04515427),
  DSP16_Q(0.39693177),
  DSP16_Q(0.05903264),
  DSP16_Q(-0.02663892),
  DSP16_Q(0.01645786),
  DSP16_Q(-0.01129772),
  DSP16_Q(0.00809681),
  DSP16_Q(-0.00588568),
  DSP16_Q(0.00426317),
  DSP16_Q(-0.00303409),
  DSP16_Q(0.00209204),
  DSP16_Q(-0.00137333),
  DSP16_Q(0.00083644),
  DSP16_Q(-0.00045185),
  DSP16_Q(0.00019671),
  DSP16_Q(-0.00005196),
  DSP16_Q(0.00000064),
  DSP16_Q(0.00002988),
  DSP16_Q(-0.00014697),
  DSP16_Q(0.00036815),
  DSP16_Q(-0.00071154),
  DSP16_Q(0.00119844),
  DSP16_Q(-0.00185579),
  DSP16_Q(0.00272069),
  DSP16_Q(-0.00384876),
  DSP16_Q(0.00533089),
  DSP16_Q(-0.00732959),
  DSP16_Q(0.01016817),
  DSP16_Q(-0.01459081),
  DSP16_Q(0.02275522),
  DSP16_Q(-0.04450404),
  DSP16_Q(0.39732152),
  DSP16_Q(0.05790904),
  DSP16_Q(-0.02616696),
  DSP16_Q(0.01617224),
  DSP16_Q(-0.01110330),
  DSP16_Q(0.00795793),
  DSP16_Q(-0.00578479),
  DSP16_Q(0.00418998),
  DSP16_Q(-0.00298184),
  DSP16_Q(0.00205582),
  DSP16_Q(-0.00134937),
  DSP16_Q(0.00082168),
  DSP16_Q(-0.00044371),
  DSP16_Q(0.00019304),
  DSP16_Q(-0.00005089),
  DSP16_Q(0.00000061),
  DSP16_Q(0.00002954),
  DSP16_Q(-0.00014487),
  DSP16_Q(0.00036260),
  DSP16_Q(-0.00070054),
  DSP16_Q(0.00117962),
  DSP16_Q(-0.00182637),
  DSP16_Q(0.00267730),
  DSP16_Q(-0.00378713),
  DSP16_Q(0.00524536),
  DSP16_Q(-0.00721198),
  DSP16_Q(0.01000546),
  DSP16_Q(-0.01435901),
  DSP16_Q(0.02240016),
  DSP16_Q(-0.04384884),
  DSP16_Q(0.39770465),
  DSP16_Q(0.05678842),
  DSP16_Q(-0.02569490),
  DSP16_Q(0.01588634),
  DSP16_Q(-0.01090861),
  DSP16_Q(0.00781885),
  DSP16_Q(-0.00568374),
  DSP16_Q(0.00411669),
  DSP16_Q(-0.00292952),
  DSP16_Q(0.00201957),
  DSP16_Q(-0.00132540),
  DSP16_Q(0.00080691),
  DSP16_Q(-0.00043559),
  DSP16_Q(0.00018937),
  DSP16_Q(-0.00004983),
  DSP16_Q(0.00000057),
  DSP16_Q(0.00002919),
  DSP16_Q(-0.00014276),
  DSP16_Q(0.00035702),
  DSP16_Q(-0.00068946),
  DSP16_Q(0.00116070),
  DSP16_Q(-0.00179680),
  DSP16_Q(0.00263369),
  DSP16_Q(-0.00372522),
  DSP16_Q(0.00515943),
  DSP16_Q(-0.00709384),
  DSP16_Q(0.00984198),
  DSP16_Q(-0.01412608),
  DSP16_Q(0.02204312),
  DSP16_Q(-0.04318868),
  DSP16_Q(0.39808116),
  DSP16_Q(0.05567081),
  DSP16_Q(-0.02522276),
  DSP16_Q(0.01560016),
  DSP16_Q(-0.01071368),
  DSP16_Q(0.00767958),
  DSP16_Q(-0.00558255),
  DSP16_Q(0.00404330),
  DSP16_Q(-0.00287713),
  DSP16_Q(0.00198328),
  DSP16_Q(-0.00130140),
  DSP16_Q(0.00079213),
  DSP16_Q(-0.00042746),
  DSP16_Q(0.00018571),
  DSP16_Q(-0.00004877),
  DSP16_Q(0.00000054),
  DSP16_Q(0.00002884),
  DSP16_Q(-0.00014063),
  DSP16_Q(0.00035139),
  DSP16_Q(-0.00067832),
  DSP16_Q(0.00114167),
  DSP16_Q(-0.00176709),
  DSP16_Q(0.00258987),
  DSP16_Q(-0.00366301),
  DSP16_Q(0.00507311),
  DSP16_Q(-0.00697516),
  DSP16_Q(0.00967775),
  DSP16_Q(-0.01389200),
  DSP16_Q(0.02168411),
  DSP16_Q(-0.04252356),
  DSP16_Q(0.39845103),
  DSP16_Q(0.05455622),
  DSP16_Q(-0.02475055),
  DSP16_Q(0.01531372),
  DSP16_Q(-0.01051850),
  DSP16_Q(0.00754011),
  DSP16_Q(-0.00548122),
  DSP16_Q(0.00396981),
  DSP16_Q(-0.00282468),
  DSP16_Q(0.00194695),
  DSP16_Q(-0.00127739),
  DSP16_Q(0.00077735),
  DSP16_Q(-0.00041934),
  DSP16_Q(0.00018206),
  DSP16_Q(-0.00004772),
  DSP16_Q(0.00000051),
  DSP16_Q(0.00002847),
  DSP16_Q(-0.00013848),
  DSP16_Q(0.00034573),
  DSP16_Q(-0.00066712),
  DSP16_Q(0.00112255),
  DSP16_Q(-0.00173723),
  DSP16_Q(0.00254586),
  DSP16_Q(-0.00360052),
  DSP16_Q(0.00498641),
  DSP16_Q(-0.00685595),
  DSP16_Q(0.00951277),
  DSP16_Q(-0.01365680),
  DSP16_Q(0.02132315),
  DSP16_Q(-0.04185349),
  DSP16_Q(0.39881425),
  DSP16_Q(0.05344468),
  DSP16_Q(-0.02427831),
  DSP16_Q(0.01502703),
  DSP16_Q(-0.01032310),
  DSP16_Q(0.00740046),
  DSP16_Q(-0.00537976),
  DSP16_Q(0.00389623),
  DSP16_Q(-0.00277217),
  DSP16_Q(0.00191058),
  DSP16_Q(-0.00125336),
  DSP16_Q(0.00076256),
  DSP16_Q(-0.00041121),
  DSP16_Q(0.00017841),
  DSP16_Q(-0.00004668),
  DSP16_Q(0.00000049),
  DSP16_Q(0.00002810),
  DSP16_Q(-0.00013631),
  DSP16_Q(0.00034003),
  DSP16_Q(-0.00065585),
  DSP16_Q(0.00110333),
  DSP16_Q(-0.00170722),
  DSP16_Q(0.00250163),
  DSP16_Q(-0.00353776),
  DSP16_Q(0.00489932),
  DSP16_Q(-0.00673622),
  DSP16_Q(0.00934705),
  DSP16_Q(-0.01342049),
  DSP16_Q(0.02096024),
  DSP16_Q(-0.04117849),
  DSP16_Q(0.39917082),
  DSP16_Q(0.05233623),
  DSP16_Q(-0.02380606),
  DSP16_Q(0.01474011),
  DSP16_Q(-0.01012747),
  DSP16_Q(0.00726064),
  DSP16_Q(-0.00527816),
  DSP16_Q(0.00382255),
  DSP16_Q(-0.00271960),
  DSP16_Q(0.00187418),
  DSP16_Q(-0.00122931),
  DSP16_Q(0.00074778),
  DSP16_Q(-0.00040310),
  DSP16_Q(0.00017477),
  DSP16_Q(-0.00004564),
  DSP16_Q(0.00000046),
  DSP16_Q(0.00002773),
  DSP16_Q(-0.00013412),
  DSP16_Q(0.00033429),
  DSP16_Q(-0.00064452),
  DSP16_Q(0.00108401),
  DSP16_Q(-0.00167707),
  DSP16_Q(0.00245721),
  DSP16_Q(-0.00347471),
  DSP16_Q(0.00481186),
  DSP16_Q(-0.00661597),
  DSP16_Q(0.00918060),
  DSP16_Q(-0.01318306),
  DSP16_Q(0.02059541),
  DSP16_Q(-0.04049855),
  DSP16_Q(0.39952071),
  DSP16_Q(0.05123089),
  DSP16_Q(-0.02333382),
  DSP16_Q(0.01445298),
  DSP16_Q(-0.00993163),
  DSP16_Q(0.00712065),
  DSP16_Q(-0.00517644),
  DSP16_Q(0.00374879),
  DSP16_Q(-0.00266697),
  DSP16_Q(0.00183775),
  DSP16_Q(-0.00120525),
  DSP16_Q(0.00073298),
  DSP16_Q(-0.00039498),
  DSP16_Q(0.00017113),
  DSP16_Q(-0.00004460),
  DSP16_Q(0.00000043),
  DSP16_Q(0.00002735),
  DSP16_Q(-0.00013192),
  DSP16_Q(0.00032851),
  DSP16_Q(-0.00063312),
  DSP16_Q(0.00106459),
  DSP16_Q(-0.00164678),
  DSP16_Q(0.00241258),
  DSP16_Q(-0.00341139),
  DSP16_Q(0.00472402),
  DSP16_Q(-0.00649520),
  DSP16_Q(0.00901342),
  DSP16_Q(-0.01294454),
  DSP16_Q(0.02022866),
  DSP16_Q(-0.03981369),
  DSP16_Q(0.39986392),
  DSP16_Q(0.05012868),
  DSP16_Q(-0.02286161),
  DSP16_Q(0.01416564),
  DSP16_Q(-0.00973560),
  DSP16_Q(0.00698050),
  DSP16_Q(-0.00507461),
  DSP16_Q(0.00367495),
  DSP16_Q(-0.00261429),
  DSP16_Q(0.00180129),
  DSP16_Q(-0.00118117),
  DSP16_Q(0.00071819),
  DSP16_Q(-0.00038687),
  DSP16_Q(0.00016750),
  DSP16_Q(-0.00004357),
  DSP16_Q(0.00000041),
  DSP16_Q(0.00002696),
  DSP16_Q(-0.00012969),
  DSP16_Q(0.00032269),
  DSP16_Q(-0.00062166),
  DSP16_Q(0.00104507),
  DSP16_Q(-0.00161634),
  DSP16_Q(0.00236776),
  DSP16_Q(-0.00334780),
  DSP16_Q(0.00463582),
  DSP16_Q(-0.00637393),
  DSP16_Q(0.00884552),
  DSP16_Q(-0.01270493),
  DSP16_Q(0.01986001),
  DSP16_Q(-0.03912392),
  DSP16_Q(0.40020044),
  DSP16_Q(0.04902963),
  DSP16_Q(-0.02238946),
  DSP16_Q(0.01387811),
  DSP16_Q(-0.00953938),
  DSP16_Q(0.00684020),
  DSP16_Q(-0.00497265),
  DSP16_Q(0.00360103),
  DSP16_Q(-0.00256156),
  DSP16_Q(0.00176479),
  DSP16_Q(-0.00115708),
  DSP16_Q(0.00070339),
  DSP16_Q(-0.00037877),
  DSP16_Q(0.00016388),
  DSP16_Q(-0.00004254),
  DSP16_Q(0.00000038),
  DSP16_Q(0.00002656),
  DSP16_Q(-0.00012744),
  DSP16_Q(0.00031684),
  DSP16_Q(-0.00061014),
  DSP16_Q(0.00102545),
  DSP16_Q(-0.00158577),
  DSP16_Q(0.00232274),
  DSP16_Q(-0.00328394),
  DSP16_Q(0.00454725),
  DSP16_Q(-0.00625215),
  DSP16_Q(0.00867691),
  DSP16_Q(-0.01246425),
  DSP16_Q(0.01948947),
  DSP16_Q(-0.03842924),
  DSP16_Q(0.40053026),
  DSP16_Q(0.04793376),
  DSP16_Q(-0.02191739),
  DSP16_Q(0.01359041),
  DSP16_Q(-0.00934297),
  DSP16_Q(0.00669975),
  DSP16_Q(-0.00487060),
  DSP16_Q(0.00352703),
  DSP16_Q(-0.00250879),
  DSP16_Q(0.00172828),
  DSP16_Q(-0.00113299),
  DSP16_Q(0.00068860),
  DSP16_Q(-0.00037067),
  DSP16_Q(0.00016026),
  DSP16_Q(-0.00004153),
  DSP16_Q(0.00000036),
  DSP16_Q(0.00002616),
  DSP16_Q(-0.00012518),
  DSP16_Q(0.00031095),
  DSP16_Q(-0.00059855),
  DSP16_Q(0.00100574),
  DSP16_Q(-0.00155505),
  DSP16_Q(0.00227753),
  DSP16_Q(-0.00321982),
  DSP16_Q(0.00445831),
  DSP16_Q(-0.00612988),
  DSP16_Q(0.00850759),
  DSP16_Q(-0.01222250),
  DSP16_Q(0.01911706),
  DSP16_Q(-0.03772967),
  DSP16_Q(0.40085336),
  DSP16_Q(0.04684110),
  DSP16_Q(-0.02144542),
  DSP16_Q(0.01330255),
  DSP16_Q(-0.00914640),
  DSP16_Q(0.00655917),
  DSP16_Q(-0.00476843),
  DSP16_Q(0.00345296),
  DSP16_Q(-0.00245597),
  DSP16_Q(0.00169174),
  DSP16_Q(-0.00110888),
  DSP16_Q(0.00067380),
  DSP16_Q(-0.00036258),
  DSP16_Q(0.00015666),
  DSP16_Q(-0.00004051),
  DSP16_Q(0.00000034),
  DSP16_Q(0.00002575),
  DSP16_Q(-0.00012289),
  DSP16_Q(0.00030502),
  DSP16_Q(-0.00058690),
  DSP16_Q(0.00098594),
  DSP16_Q(-0.00152420),
  DSP16_Q(0.00223212),
  DSP16_Q(-0.00315543),
  DSP16_Q(0.00436902),
  DSP16_Q(-0.00600711),
  DSP16_Q(0.00833758),
  DSP16_Q(-0.01197969),
  DSP16_Q(0.01874278),
  DSP16_Q(-0.03702521),
  DSP16_Q(0.40116974),
  DSP16_Q(0.04575168),
  DSP16_Q(-0.02097357),
  DSP16_Q(0.01301455),
  DSP16_Q(-0.00894967),
  DSP16_Q(0.00641845),
  DSP16_Q(-0.00466618),
  DSP16_Q(0.00337883),
  DSP16_Q(-0.00240310),
  DSP16_Q(0.00165517),
  DSP16_Q(-0.00108476),
  DSP16_Q(0.00065901),
  DSP16_Q(-0.00035449),
  DSP16_Q(0.00015305),
  DSP16_Q(-0.00003950),
  DSP16_Q(0.00000032),
  DSP16_Q(0.00002534),
  DSP16_Q(-0.00012059),
  DSP16_Q(0.00029905),
  DSP16_Q(-0.00057519),
  DSP16_Q(0.00096604),
  DSP16_Q(-0.00149322),
  DSP16_Q(0.00218653),
  DSP16_Q(-0.00309078),
  DSP16_Q(0.00427937),
  DSP16_Q(-0.00588386),
  DSP16_Q(0.00816688),
  DSP16_Q(-0.01173583),
  DSP16_Q(0.01836666),
  DSP16_Q(-0.03631588),
  DSP16_Q(0.40147939),
  DSP16_Q(0.04466552),
  DSP16_Q(-0.02050187),
  DSP16_Q(0.01272642),
  DSP16_Q(-0.00875280),
  DSP16_Q(0.00627761),
  DSP16_Q(-0.00456383),
  DSP16_Q(0.00330463),
  DSP16_Q(-0.00235020),
  DSP16_Q(0.00161859),
  DSP16_Q(-0.00106064),
  DSP16_Q(0.00064422),
  DSP16_Q(-0.00034641),
  DSP16_Q(0.00014946),
  DSP16_Q(-0.00003850),
  DSP16_Q(0.00000030),
  DSP16_Q(0.00002491),
  DSP16_Q(-0.00011826),
  DSP16_Q(0.00029305),
  DSP16_Q(-0.00056342),
  DSP16_Q(0.00094605),
  DSP16_Q(-0.00146210),
  DSP16_Q(0.00214075),
  DSP16_Q(-0.00302588),
  DSP16_Q(0.00418938),
  DSP16_Q(-0.00576013),
  DSP16_Q(0.00799549),
  DSP16_Q(-0.01149094),
  DSP16_Q(0.01798871),
  DSP16_Q(-0.03560169),
  DSP16_Q(0.40178230),
  DSP16_Q(0.04358264),
  DSP16_Q(-0.02003033),
  DSP16_Q(0.01243817),
  DSP16_Q(-0.00855578),
  DSP16_Q(0.00613666),
  DSP16_Q(-0.00446139),
  DSP16_Q(0.00323038),
  DSP16_Q(-0.00229726),
  DSP16_Q(0.00158199),
  DSP16_Q(-0.00103651),
  DSP16_Q(0.00062943),
  DSP16_Q(-0.00033834),
  DSP16_Q(0.00014588),
  DSP16_Q(-0.00003750),
  DSP16_Q(0.00000028),
  DSP16_Q(0.00002449),
  DSP16_Q(-0.00011592),
  DSP16_Q(0.00028701),
  DSP16_Q(-0.00055159),
  DSP16_Q(0.00092597),
  DSP16_Q(-0.00143084),
  DSP16_Q(0.00209478),
  DSP16_Q(-0.00296072),
  DSP16_Q(0.00409903),
  DSP16_Q(-0.00563592),
  DSP16_Q(0.00782344),
  DSP16_Q(-0.01124503),
  DSP16_Q(0.01760894),
  DSP16_Q(-0.03488263),
  DSP16_Q(0.40207846),
  DSP16_Q(0.04250308),
  DSP16_Q(-0.01955899),
  DSP16_Q(0.01214983),
  DSP16_Q(-0.00835864),
  DSP16_Q(0.00599560),
  DSP16_Q(-0.00435887),
  DSP16_Q(0.00315607),
  DSP16_Q(-0.00224429),
  DSP16_Q(0.00154537),
  DSP16_Q(-0.00101238),
  DSP16_Q(0.00061464),
  DSP16_Q(-0.00033027),
  DSP16_Q(0.00014230),
  DSP16_Q(-0.00003651),
  DSP16_Q(0.00000026),
  DSP16_Q(0.00002405),
  DSP16_Q(-0.00011356),
  DSP16_Q(0.00028094),
  DSP16_Q(-0.00053970),
  DSP16_Q(0.00090579),
  DSP16_Q(-0.00139946),
  DSP16_Q(0.00204863),
  DSP16_Q(-0.00289531),
  DSP16_Q(0.00400835),
  DSP16_Q(-0.00551124),
  DSP16_Q(0.00765071),
  DSP16_Q(-0.01099810),
  DSP16_Q(0.01722736),
  DSP16_Q(-0.03415873),
  DSP16_Q(0.40236785),
  DSP16_Q(0.04142685),
  DSP16_Q(-0.01908786),
  DSP16_Q(0.01186140),
  DSP16_Q(-0.00816138),
  DSP16_Q(0.00585443),
  DSP16_Q(-0.00425628),
  DSP16_Q(0.00308171),
  DSP16_Q(-0.00219129),
  DSP16_Q(0.00150873),
  DSP16_Q(-0.00098825),
  DSP16_Q(0.00059986),
  DSP16_Q(-0.00032221),
  DSP16_Q(0.00013873),
  DSP16_Q(-0.00003552),
  DSP16_Q(0.00000024),
  DSP16_Q(0.00002361),
  DSP16_Q(-0.00011118),
  DSP16_Q(0.00027482),
  DSP16_Q(-0.00052774),
  DSP16_Q(0.00088553),
  DSP16_Q(-0.00136794),
  DSP16_Q(0.00200230),
  DSP16_Q(-0.00282966),
  DSP16_Q(0.00391733),
  DSP16_Q(-0.00538610),
  DSP16_Q(0.00747733),
  DSP16_Q(-0.01075017),
  DSP16_Q(0.01684399),
  DSP16_Q(-0.03343000),
  DSP16_Q(0.40265048),
  DSP16_Q(0.04035398),
  DSP16_Q(-0.01861697),
  DSP16_Q(0.01157290),
  DSP16_Q(-0.00796401),
  DSP16_Q(0.00571317),
  DSP16_Q(-0.00415362),
  DSP16_Q(0.00300730),
  DSP16_Q(-0.00213826),
  DSP16_Q(0.00147209),
  DSP16_Q(-0.00096411),
  DSP16_Q(0.00058508),
  DSP16_Q(-0.00031416),
  DSP16_Q(0.00013517),
  DSP16_Q(-0.00003454),
  DSP16_Q(0.00000022),
  DSP16_Q(0.00002316),
  DSP16_Q(-0.00010879),
  DSP16_Q(0.00026868),
  DSP16_Q(-0.00051573),
  DSP16_Q(0.00086517),
  DSP16_Q(-0.00133630),
  DSP16_Q(0.00195579),
  DSP16_Q(-0.00276375),
  DSP16_Q(0.00382598),
  DSP16_Q(-0.00526050),
  DSP16_Q(0.00730330),
  DSP16_Q(-0.01050124),
  DSP16_Q(0.01645885),
  DSP16_Q(-0.03269644),
  DSP16_Q(0.40292633),
  DSP16_Q(0.03928450),
  DSP16_Q(-0.01814634),
  DSP16_Q(0.01128435),
  DSP16_Q(-0.00776655),
  DSP16_Q(0.00557183),
  DSP16_Q(-0.00405089),
  DSP16_Q(0.00293284),
  DSP16_Q(-0.00208520),
  DSP16_Q(0.00143543),
  DSP16_Q(-0.00093997),
  DSP16_Q(0.00057031),
  DSP16_Q(-0.00030612),
  DSP16_Q(0.00013162),
  DSP16_Q(-0.00003357),
  DSP16_Q(0.00000021),
  DSP16_Q(0.00002271),
  DSP16_Q(-0.00010637),
  DSP16_Q(0.00026249),
  DSP16_Q(-0.00050366),
  DSP16_Q(0.00084473),
  DSP16_Q(-0.00130453),
  DSP16_Q(0.00190910),
  DSP16_Q(-0.00269761),
  DSP16_Q(0.00373429),
  DSP16_Q(-0.00513445),
  DSP16_Q(0.00712862),
  DSP16_Q(-0.01025133),
  DSP16_Q(0.01607195),
  DSP16_Q(-0.03195807),
  DSP16_Q(0.40319539),
  DSP16_Q(0.03821842),
  DSP16_Q(-0.01767598),
  DSP16_Q(0.01099575),
  DSP16_Q(-0.00756900),
  DSP16_Q(0.00543041),
  DSP16_Q(-0.00394811),
  DSP16_Q(0.00285835),
  DSP16_Q(-0.00203213),
  DSP16_Q(0.00139877),
  DSP16_Q(-0.00091583),
  DSP16_Q(0.00055555),
  DSP16_Q(-0.00029809),
  DSP16_Q(0.00012807),
  DSP16_Q(-0.00003260),
  DSP16_Q(0.00000019),
  DSP16_Q(0.00002224),
  DSP16_Q(-0.00010393),
  DSP16_Q(0.00025628),
  DSP16_Q(-0.00049154),
  DSP16_Q(0.00082419),
  DSP16_Q(-0.00127263),
  DSP16_Q(0.00186224),
  DSP16_Q(-0.00263123),
  DSP16_Q(0.00364229),
  DSP16_Q(-0.00500795),
  DSP16_Q(0.00695332),
  DSP16_Q(-0.01000045),
  DSP16_Q(0.01568330),
  DSP16_Q(-0.03121489),
  DSP16_Q(0.40345766),
  DSP16_Q(0.03715578),
  DSP16_Q(-0.01720593),
  DSP16_Q(0.01070713),
  DSP16_Q(-0.00737137),
  DSP16_Q(0.00528891),
  DSP16_Q(-0.00384526),
  DSP16_Q(0.00278383),
  DSP16_Q(-0.00197903),
  DSP16_Q(0.00136209),
  DSP16_Q(-0.00089170),
  DSP16_Q(0.00054079),
  DSP16_Q(-0.00029007),
  DSP16_Q(0.00012454),
  DSP16_Q(-0.00003164),
  DSP16_Q(0.00000018),
  DSP16_Q(0.00002177),
  DSP16_Q(-0.00010148),
  DSP16_Q(0.00025002),
  DSP16_Q(-0.00047935),
  DSP16_Q(0.00080357),
  DSP16_Q(-0.00124061),
  DSP16_Q(0.00181520),
  DSP16_Q(-0.00256461),
  DSP16_Q(0.00354996),
  DSP16_Q(-0.00488102),
  DSP16_Q(0.00677738),
  DSP16_Q(-0.00974861),
  DSP16_Q(0.01529292),
  DSP16_Q(-0.03046692),
  DSP16_Q(0.40371313),
  DSP16_Q(0.03609659),
  DSP16_Q(-0.01673621),
  DSP16_Q(0.01041850),
  DSP16_Q(-0.00717368),
  DSP16_Q(0.00514736),
  DSP16_Q(-0.00374238),
  DSP16_Q(0.00270927),
  DSP16_Q(-0.00192592),
  DSP16_Q(0.00132542),
  DSP16_Q(-0.00086757),
  DSP16_Q(0.00052605),
  DSP16_Q(-0.00028206),
  DSP16_Q(0.00012101),
  DSP16_Q(-0.00003068),
  DSP16_Q(0.00000016),
  DSP16_Q(0.00002130),
  DSP16_Q(-0.00009901),
  DSP16_Q(0.00024373),
  DSP16_Q(-0.00046711),
  DSP16_Q(0.00078287),
  DSP16_Q(-0.00120846),
  DSP16_Q(0.00176799),
  DSP16_Q(-0.00249776),
  DSP16_Q(0.00345731),
  DSP16_Q(-0.00475364),
  DSP16_Q(0.00660082),
  DSP16_Q(-0.00949581),
  DSP16_Q(0.01490083),
  DSP16_Q(-0.02971417),
  DSP16_Q(0.40396178),
  DSP16_Q(0.03504089),
  DSP16_Q(-0.01626682),
  DSP16_Q(0.01012986),
  DSP16_Q(-0.00697593),
  DSP16_Q(0.00500574),
  DSP16_Q(-0.00363944),
  DSP16_Q(0.00263468),
  DSP16_Q(-0.00187279),
  DSP16_Q(0.00128874),
  DSP16_Q(-0.00084344),
  DSP16_Q(0.00051131),
  DSP16_Q(-0.00027406),
  DSP16_Q(0.00011750),
  DSP16_Q(-0.00002973),
  DSP16_Q(0.00000015),
  DSP16_Q(0.00002082),
  DSP16_Q(-0.00009652),
  DSP16_Q(0.00023741),
  DSP16_Q(-0.00045481),
  DSP16_Q(0.00076208),
  DSP16_Q(-0.00117620),
  DSP16_Q(0.00172062),
  DSP16_Q(-0.00243068),
  DSP16_Q(0.00336436),
  DSP16_Q(-0.00462584),
  DSP16_Q(0.00642366),
  DSP16_Q(-0.00924208),
  DSP16_Q(0.01450703),
  DSP16_Q(-0.02895666),
  DSP16_Q(0.40420362),
  DSP16_Q(0.03398869),
  DSP16_Q(-0.01579781),
  DSP16_Q(0.00984125),
  DSP16_Q(-0.00677813),
  DSP16_Q(0.00486408),
  DSP16_Q(-0.00353647),
  DSP16_Q(0.00256007),
  DSP16_Q(-0.00181965),
  DSP16_Q(0.00125206),
  DSP16_Q(-0.00081932),
  DSP16_Q(0.00049658),
  DSP16_Q(-0.00026607),
  DSP16_Q(0.00011399),
  DSP16_Q(-0.00002878),
  DSP16_Q(0.00000014),
  DSP16_Q(0.00002033),
  DSP16_Q(-0.00009401),
  DSP16_Q(0.00023105),
  DSP16_Q(-0.00044246),
  DSP16_Q(0.00074121),
  DSP16_Q(-0.00114381),
  DSP16_Q(0.00167308),
  DSP16_Q(-0.00236337),
  DSP16_Q(0.00327110),
  DSP16_Q(-0.00449762),
  DSP16_Q(0.00624589),
  DSP16_Q(-0.00898742),
  DSP16_Q(0.01411155),
  DSP16_Q(-0.02819438),
  DSP16_Q(0.40443863),
  DSP16_Q(0.03294002),
  DSP16_Q(-0.01532919),
  DSP16_Q(0.00955267),
  DSP16_Q(-0.00658029),
  DSP16_Q(0.00472237),
  DSP16_Q(-0.00343347),
  DSP16_Q(0.00248544),
  DSP16_Q(-0.00176651),
  DSP16_Q(0.00121538),
  DSP16_Q(-0.00079521),
  DSP16_Q(0.00048186),
  DSP16_Q(-0.00025809),
  DSP16_Q(0.00011049),
  DSP16_Q(-0.00002784),
  DSP16_Q(0.00000013),
  DSP16_Q(0.00001983),
  DSP16_Q(-0.00009148),
  DSP16_Q(0.00022466),
  DSP16_Q(-0.00043004),
  DSP16_Q(0.00072025),
  DSP16_Q(-0.00111130),
  DSP16_Q(0.00162537),
  DSP16_Q(-0.00229584),
  DSP16_Q(0.00317753),
  DSP16_Q(-0.00436898),
  DSP16_Q(0.00606753),
  DSP16_Q(-0.00873185),
  DSP16_Q(0.01371440),
  DSP16_Q(-0.02742736),
  DSP16_Q(0.40466680),
  DSP16_Q(0.03189490),
  DSP16_Q(-0.01486098),
  DSP16_Q(0.00926413),
  DSP16_Q(-0.00638244),
  DSP16_Q(0.00458063),
  DSP16_Q(-0.00333044),
  DSP16_Q(0.00241080),
  DSP16_Q(-0.00171335),
  DSP16_Q(0.00117870),
  DSP16_Q(-0.00077110),
  DSP16_Q(0.00046715),
  DSP16_Q(-0.00025012),
  DSP16_Q(0.00010700),
  DSP16_Q(-0.00002691),
  DSP16_Q(0.00000012),
  DSP16_Q(0.00001933),
  DSP16_Q(-0.00008894),
  DSP16_Q(0.00021823),
  DSP16_Q(-0.00041758),
  DSP16_Q(0.00069921),
  DSP16_Q(-0.00107868),
  DSP16_Q(0.00157750),
  DSP16_Q(-0.00222809),
  DSP16_Q(0.00308367),
  DSP16_Q(-0.00423993),
  DSP16_Q(0.00588858),
  DSP16_Q(-0.00847537),
  DSP16_Q(0.01331560),
  DSP16_Q(-0.02665560),
  DSP16_Q(0.40488814),
  DSP16_Q(0.03085335),
  DSP16_Q(-0.01439320),
  DSP16_Q(0.00897565),
  DSP16_Q(-0.00618456),
  DSP16_Q(0.00443886),
  DSP16_Q(-0.00322739),
  DSP16_Q(0.00233614),
  DSP16_Q(-0.00166020),
  DSP16_Q(0.00114203),
  DSP16_Q(-0.00074701),
  DSP16_Q(0.00045246),
  DSP16_Q(-0.00024216),
  DSP16_Q(0.00010353),
  DSP16_Q(-0.00002598),
  DSP16_Q(0.00000010),
  DSP16_Q(0.00001882),
  DSP16_Q(-0.00008637),
  DSP16_Q(0.00021177),
  DSP16_Q(-0.00040506),
  DSP16_Q(0.00067809),
  DSP16_Q(-0.00104594),
  DSP16_Q(0.00152947),
  DSP16_Q(-0.00216012),
  DSP16_Q(0.00298951),
  DSP16_Q(-0.00411047),
  DSP16_Q(0.00570905),
  DSP16_Q(-0.00821799),
  DSP16_Q(0.01291515),
  DSP16_Q(-0.02587913),
  DSP16_Q(0.40510263),
  DSP16_Q(0.02981541),
  DSP16_Q(-0.01392587),
  DSP16_Q(0.00868725),
  DSP16_Q(-0.00598668),
  DSP16_Q(0.00429707),
  DSP16_Q(-0.00312432),
  DSP16_Q(0.00226147),
  DSP16_Q(-0.00160705),
  DSP16_Q(0.00110536),
  DSP16_Q(-0.00072292),
  DSP16_Q(0.00043777),
  DSP16_Q(-0.00023422),
  DSP16_Q(0.00010006),
  DSP16_Q(-0.00002506),
  DSP16_Q(0.00000010),
  DSP16_Q(0.00001830),
  DSP16_Q(-0.00008379),
  DSP16_Q(0.00020528),
  DSP16_Q(-0.00039248),
  DSP16_Q(0.00065689),
  DSP16_Q(-0.00101309),
  DSP16_Q(0.00148129),
  DSP16_Q(-0.00209194),
  DSP16_Q(0.00289506),
  DSP16_Q(-0.00398061),
  DSP16_Q(0.00552895),
  DSP16_Q(-0.00795974),
  DSP16_Q(0.01251308),
  DSP16_Q(-0.02509794),
  DSP16_Q(0.40531027),
  DSP16_Q(0.02878108),
  DSP16_Q(-0.01345903),
  DSP16_Q(0.00839893),
  DSP16_Q(-0.00578880),
  DSP16_Q(0.00415526),
  DSP16_Q(-0.00302123),
  DSP16_Q(0.00218680),
  DSP16_Q(-0.00155389),
  DSP16_Q(0.00106870),
  DSP16_Q(-0.00069885),
  DSP16_Q(0.00042311),
  DSP16_Q(-0.00022629),
  DSP16_Q(0.00009660),
  DSP16_Q(-0.00002414),
  DSP16_Q(0.00000009),
  DSP16_Q(0.00001778),
  DSP16_Q(-0.00008119),
  DSP16_Q(0.00019875),
  DSP16_Q(-0.00037986),
  DSP16_Q(0.00063561),
  DSP16_Q(-0.00098012),
  DSP16_Q(0.00143295),
  DSP16_Q(-0.00202355),
  DSP16_Q(0.00280032),
  DSP16_Q(-0.00385037),
  DSP16_Q(0.00534829),
  DSP16_Q(-0.00770061),
  DSP16_Q(0.01210941),
  DSP16_Q(-0.02431206),
  DSP16_Q(0.40551104),
  DSP16_Q(0.02775040),
  DSP16_Q(-0.01299268),
  DSP16_Q(0.00811072),
  DSP16_Q(-0.00559094),
  DSP16_Q(0.00401345),
  DSP16_Q(-0.00291815),
  DSP16_Q(0.00211213),
  DSP16_Q(-0.00150075),
  DSP16_Q(0.00103206),
  DSP16_Q(-0.00067479),
  DSP16_Q(0.00040845),
  DSP16_Q(-0.00021837),
  DSP16_Q(0.00009316),
  DSP16_Q(-0.00002323),
  DSP16_Q(0.00000008),
  DSP16_Q(0.00001725),
  DSP16_Q(-0.00007858),
  DSP16_Q(0.00019219),
  DSP16_Q(-0.00036718),
  DSP16_Q(0.00061425),
  DSP16_Q(-0.00094705),
  DSP16_Q(0.00138446),
  DSP16_Q(-0.00195495),
  DSP16_Q(0.00270531),
  DSP16_Q(-0.00371973),
  DSP16_Q(0.00516708),
  DSP16_Q(-0.00744062),
  DSP16_Q(0.01170414),
  DSP16_Q(-0.02352150),
  DSP16_Q(0.40570495),
  DSP16_Q(0.02672339),
  DSP16_Q(-0.01252685),
  DSP16_Q(0.00782263),
  DSP16_Q(-0.00539310),
  DSP16_Q(0.00387164),
  DSP16_Q(-0.00281506),
  DSP16_Q(0.00203746),
  DSP16_Q(-0.00144761),
  DSP16_Q(0.00099542),
  DSP16_Q(-0.00065075),
  DSP16_Q(0.00039381),
  DSP16_Q(-0.00021047),
  DSP16_Q(0.00008972),
  DSP16_Q(-0.00002233),
  DSP16_Q(0.00000007),
  DSP16_Q(0.00001671),
  DSP16_Q(-0.00007594),
  DSP16_Q(0.00018560),
  DSP16_Q(-0.00035444),
  DSP16_Q(0.00059281),
  DSP16_Q(-0.00091386),
  DSP16_Q(0.00133581),
  DSP16_Q(-0.00188614),
  DSP16_Q(0.00261001),
  DSP16_Q(-0.00358871),
  DSP16_Q(0.00498532),
  DSP16_Q(-0.00717978),
  DSP16_Q(0.01129730),
  DSP16_Q(-0.02272626),
  DSP16_Q(0.40589199),
  DSP16_Q(0.02570006),
  DSP16_Q(-0.01206156),
  DSP16_Q(0.00753467),
  DSP16_Q(-0.00519529),
  DSP16_Q(0.00372984),
  DSP16_Q(-0.00271198),
  DSP16_Q(0.00196280),
  DSP16_Q(-0.00139448),
  DSP16_Q(0.00095880),
  DSP16_Q(-0.00062672),
  DSP16_Q(0.00037919),
  DSP16_Q(-0.00020258),
  DSP16_Q(0.00008629),
  DSP16_Q(-0.00002143),
  DSP16_Q(0.00000006),
  DSP16_Q(0.00001617),
  DSP16_Q(-0.00007329),
  DSP16_Q(0.00017898),
  DSP16_Q(-0.00034166),
  DSP16_Q(0.00057130),
  DSP16_Q(-0.00088057),
  DSP16_Q(0.00128702),
  DSP16_Q(-0.00181714),
  DSP16_Q(0.00251445),
  DSP16_Q(-0.00345732),
  DSP16_Q(0.00480302),
  DSP16_Q(-0.00691811),
  DSP16_Q(0.01088889),
  DSP16_Q(-0.02192637),
  DSP16_Q(0.40607215),
  DSP16_Q(0.02468045),
  DSP16_Q(-0.01159683),
  DSP16_Q(0.00724685),
  DSP16_Q(-0.00499753),
  DSP16_Q(0.00358806),
  DSP16_Q(-0.00260890),
  DSP16_Q(0.00188815),
  DSP16_Q(-0.00134137),
  DSP16_Q(0.00092220),
  DSP16_Q(-0.00060271),
  DSP16_Q(0.00036458),
  DSP16_Q(-0.00019470),
  DSP16_Q(0.00008288),
  DSP16_Q(-0.00002054),
  DSP16_Q(0.00000006),
  DSP16_Q(0.00001562),
  DSP16_Q(-0.00007062),
  DSP16_Q(0.00017232),
  DSP16_Q(-0.00032882),
  DSP16_Q(0.00054971),
  DSP16_Q(-0.00084717),
  DSP16_Q(0.00123808),
  DSP16_Q(-0.00174794),
  DSP16_Q(0.00241862),
  DSP16_Q(-0.00332557),
  DSP16_Q(0.00462020),
  DSP16_Q(-0.00665561),
  DSP16_Q(0.01047895),
  DSP16_Q(-0.02112183),
  DSP16_Q(0.40624543),
  DSP16_Q(0.02366457),
  DSP16_Q(-0.01113268),
  DSP16_Q(0.00695920),
  DSP16_Q(-0.00479983),
  DSP16_Q(0.00344630),
  DSP16_Q(-0.00250585),
  DSP16_Q(0.00181351),
  DSP16_Q(-0.00128827),
  DSP16_Q(0.00088561),
  DSP16_Q(-0.00057872),
  DSP16_Q(0.00034999),
  DSP16_Q(-0.00018685),
  DSP16_Q(0.00007948),
  DSP16_Q(-0.00001966),
  DSP16_Q(0.00000005),
  DSP16_Q(0.00001506),
  DSP16_Q(-0.00006793),
  DSP16_Q(0.00016563),
  DSP16_Q(-0.00031594),
  DSP16_Q(0.00052804),
  DSP16_Q(-0.00081366),
  DSP16_Q(0.00118900),
  DSP16_Q(-0.00167854),
  DSP16_Q(0.00232252),
  DSP16_Q(-0.00319345),
  DSP16_Q(0.00443685),
  DSP16_Q(-0.00639230),
  DSP16_Q(0.01006747),
  DSP16_Q(-0.02031266),
  DSP16_Q(0.40641181),
  DSP16_Q(0.02265244),
  DSP16_Q(-0.01066914),
  DSP16_Q(0.00667172),
  DSP16_Q(-0.00460218),
  DSP16_Q(0.00330457),
  DSP16_Q(-0.00240281),
  DSP16_Q(0.00173890),
  DSP16_Q(-0.00123520),
  DSP16_Q(0.00084905),
  DSP16_Q(-0.00055475),
  DSP16_Q(0.00033542),
  DSP16_Q(-0.00017900),
  DSP16_Q(0.00007608),
  DSP16_Q(-0.00001878),
  DSP16_Q(0.00000004),
  DSP16_Q(0.00001450),
  DSP16_Q(-0.00006523),
  DSP16_Q(0.00015891),
  DSP16_Q(-0.00030300),
  DSP16_Q(0.00050631),
  DSP16_Q(-0.00078005),
  DSP16_Q(0.00113978),
  DSP16_Q(-0.00160895),
  DSP16_Q(0.00222617),
  DSP16_Q(-0.00306097),
  DSP16_Q(0.00425300),
  DSP16_Q(-0.00612819),
  DSP16_Q(0.00965449),
  DSP16_Q(-0.01949887),
  DSP16_Q(0.40657130),
  DSP16_Q(0.02164410),
  DSP16_Q(-0.01020623),
  DSP16_Q(0.00638442),
  DSP16_Q(-0.00440461),
  DSP16_Q(0.00316288),
  DSP16_Q(-0.00229980),
  DSP16_Q(0.00166430),
  DSP16_Q(-0.00118214),
  DSP16_Q(0.00081250),
  DSP16_Q(-0.00053079),
  DSP16_Q(0.00032087),
  DSP16_Q(-0.00017117),
  DSP16_Q(0.00007270),
  DSP16_Q(-0.00001791),
  DSP16_Q(0.00000004),
  DSP16_Q(0.00001393),
  DSP16_Q(-0.00006251),
  DSP16_Q(0.00015216),
  DSP16_Q(-0.00029002),
  DSP16_Q(0.00048450),
  DSP16_Q(-0.00074634),
  DSP16_Q(0.00109041),
  DSP16_Q(-0.00153918),
  DSP16_Q(0.00212956),
  DSP16_Q(-0.00292814),
  DSP16_Q(0.00406864),
  DSP16_Q(-0.00586329),
  DSP16_Q(0.00924001),
  DSP16_Q(-0.01868048),
  DSP16_Q(0.40672390),
  DSP16_Q(0.02063955),
  DSP16_Q(-0.00974396),
  DSP16_Q(0.00609733),
  DSP16_Q(-0.00420713),
  DSP16_Q(0.00302123),
  DSP16_Q(-0.00219681),
  DSP16_Q(0.00158974),
  DSP16_Q(-0.00112911),
  DSP16_Q(0.00077598),
  DSP16_Q(-0.00050686),
  DSP16_Q(0.00030634),
  DSP16_Q(-0.00016336),
  DSP16_Q(0.00006934),
  DSP16_Q(-0.00001704),
  DSP16_Q(0.00000003),
  DSP16_Q(0.00001335),
  DSP16_Q(-0.00005977),
  DSP16_Q(0.00014538),
  DSP16_Q(-0.00027698),
  DSP16_Q(0.00046262),
  DSP16_Q(-0.00071253),
  DSP16_Q(0.00104092),
  DSP16_Q(-0.00146921),
  DSP16_Q(0.00203271),
  DSP16_Q(-0.00279497),
  DSP16_Q(0.00388379),
  DSP16_Q(-0.00559760),
  DSP16_Q(0.00882406),
  DSP16_Q(-0.01785750),
  DSP16_Q(0.40686959),
  DSP16_Q(0.01963882),
  DSP16_Q(-0.00928235),
  DSP16_Q(0.00581046),
  DSP16_Q(-0.00400974),
  DSP16_Q(0.00287963),
  DSP16_Q(-0.00209387),
  DSP16_Q(0.00151520),
  DSP16_Q(-0.00107611),
  DSP16_Q(0.00073949),
  DSP16_Q(-0.00048296),
  DSP16_Q(0.00029182),
  DSP16_Q(-0.00015556),
  DSP16_Q(0.00006598),
  DSP16_Q(-0.00001618),
  DSP16_Q(0.00000003),
  DSP16_Q(0.00001277),
  DSP16_Q(-0.00005701),
  DSP16_Q(0.00013857),
  DSP16_Q(-0.00026390),
  DSP16_Q(0.00044066),
  DSP16_Q(-0.00067862),
  DSP16_Q(0.00099128),
  DSP16_Q(-0.00139907),
  DSP16_Q(0.00193561),
  DSP16_Q(-0.00266147),
  DSP16_Q(0.00369845),
  DSP16_Q(-0.00533116),
  DSP16_Q(0.00840664),
  DSP16_Q(-0.01702995),
  DSP16_Q(0.40700837),
  DSP16_Q(0.01864194),
  DSP16_Q(-0.00882144),
  DSP16_Q(0.00552381),
  DSP16_Q(-0.00381245),
  DSP16_Q(0.00273809),
  DSP16_Q(-0.00199096),
  DSP16_Q(0.00144069),
  DSP16_Q(-0.00102314),
  DSP16_Q(0.00070302),
  DSP16_Q(-0.00045908),
  DSP16_Q(0.00027733),
  DSP16_Q(-0.00014778),
  DSP16_Q(0.00006263),
  DSP16_Q(-0.00001533),
  DSP16_Q(0.00000002),
  DSP16_Q(0.00001218),
  DSP16_Q(-0.00005424),
  DSP16_Q(0.00013172),
  DSP16_Q(-0.00025077),
  DSP16_Q(0.00041864),
  DSP16_Q(-0.00064461),
  DSP16_Q(0.00094152),
  DSP16_Q(-0.00132875),
  DSP16_Q(0.00183827),
  DSP16_Q(-0.00252763),
  DSP16_Q(0.00351264),
  DSP16_Q(-0.00506396),
  DSP16_Q(0.00798778),
  DSP16_Q(-0.01619784),
  DSP16_Q(0.40714024),
  DSP16_Q(0.01764892),
  DSP16_Q(-0.00836123),
  DSP16_Q(0.00523741),
  DSP16_Q(-0.00361528),
  DSP16_Q(0.00259662),
  DSP16_Q(-0.00188811),
  DSP16_Q(0.00136623),
  DSP16_Q(-0.00097020),
  DSP16_Q(0.00066658),
  DSP16_Q(-0.00043522),
  DSP16_Q(0.00026286),
  DSP16_Q(-0.00014002),
  DSP16_Q(0.00005930),
  DSP16_Q(-0.00001448),
  DSP16_Q(0.00000002),
  DSP16_Q(0.00001158),
  DSP16_Q(-0.00005145),
  DSP16_Q(0.00012485),
  DSP16_Q(-0.00023759),
  DSP16_Q(0.00039655),
  DSP16_Q(-0.00061051),
  DSP16_Q(0.00089162),
  DSP16_Q(-0.00125826),
  DSP16_Q(0.00174069),
  DSP16_Q(-0.00239347),
  DSP16_Q(0.00332636),
  DSP16_Q(-0.00479602),
  DSP16_Q(0.00756750),
  DSP16_Q(-0.01536118),
  DSP16_Q(0.40726519),
  DSP16_Q(0.01665978),
  DSP16_Q(-0.00790175),
  DSP16_Q(0.00495127),
  DSP16_Q(-0.00341823),
  DSP16_Q(0.00245522),
  DSP16_Q(-0.00178530),
  DSP16_Q(0.00129180),
  DSP16_Q(-0.00091729),
  DSP16_Q(0.00063017),
  DSP16_Q(-0.00041139),
  DSP16_Q(0.00024842),
  DSP16_Q(-0.00013228),
  DSP16_Q(0.00005598),
  DSP16_Q(-0.00001364),
  DSP16_Q(0.00000002),
  DSP16_Q(0.00001097),
  DSP16_Q(-0.00004864),
  DSP16_Q(0.00011795),
  DSP16_Q(-0.00022437),
  DSP16_Q(0.00037440),
  DSP16_Q(-0.00057631),
  DSP16_Q(0.00084160),
  DSP16_Q(-0.00118760),
  DSP16_Q(0.00164288),
  DSP16_Q(-0.00225899),
  DSP16_Q(0.00313962),
  DSP16_Q(-0.00452735),
  DSP16_Q(0.00714580),
  DSP16_Q(-0.01451998),
  DSP16_Q(0.40738322),
  DSP16_Q(0.01567455),
  DSP16_Q(-0.00744302),
  DSP16_Q(0.00466540),
  DSP16_Q(-0.00322131),
  DSP16_Q(0.00231390),
  DSP16_Q(-0.00168255),
  DSP16_Q(0.00121742),
  DSP16_Q(-0.00086443),
  DSP16_Q(0.00059380),
  DSP16_Q(-0.00038759),
  DSP16_Q(0.00023399),
  DSP16_Q(-0.00012455),
  DSP16_Q(0.00005267),
  DSP16_Q(-0.00001281),
  DSP16_Q(0.00000001),
  DSP16_Q(0.00001036),
  DSP16_Q(-0.00004582),
  DSP16_Q(0.00011101),
  DSP16_Q(-0.00021110),
  DSP16_Q(0.00035217),
  DSP16_Q(-0.00054202),
  DSP16_Q(0.00079145),
  DSP16_Q(-0.00111676),
  DSP16_Q(0.00154485),
  DSP16_Q(-0.00212420),
  DSP16_Q(0.00295242),
  DSP16_Q(-0.00425796),
  DSP16_Q(0.00672272),
  DSP16_Q(-0.01367428),
  DSP16_Q(0.40749433),
  DSP16_Q(0.01469324),
  DSP16_Q(-0.00698506),
  DSP16_Q(0.00437982),
  DSP16_Q(-0.00302453),
  DSP16_Q(0.00217267),
  DSP16_Q(-0.00157987),
  DSP16_Q(0.00114309),
  DSP16_Q(-0.00081160),
  DSP16_Q(0.00055746),
  DSP16_Q(-0.00036382),
  DSP16_Q(0.00021959),
  DSP16_Q(-0.00011684),
  DSP16_Q(0.00004937),
  DSP16_Q(-0.00001198),
  DSP16_Q(0.00000001),
  DSP16_Q(0.00000974),
  DSP16_Q(-0.00004298),
  DSP16_Q(0.00010405),
  DSP16_Q(-0.00019778),
  DSP16_Q(0.00032988),
  DSP16_Q(-0.00050765),
  DSP16_Q(0.00074118),
  DSP16_Q(-0.00104577),
  DSP16_Q(0.00144659),
  DSP16_Q(-0.00198911),
  DSP16_Q(0.00276479),
  DSP16_Q(-0.00398786),
  DSP16_Q(0.00629825),
  DSP16_Q(-0.01282407),
  DSP16_Q(0.40759851),
  DSP16_Q(0.01371589),
  DSP16_Q(-0.00652789),
  DSP16_Q(0.00409453),
  DSP16_Q(-0.00282791),
  DSP16_Q(0.00203153),
  DSP16_Q(-0.00147725),
  DSP16_Q(0.00106881),
  DSP16_Q(-0.00075882),
  DSP16_Q(0.00052116),
  DSP16_Q(-0.00034008),
  DSP16_Q(0.00020522),
  DSP16_Q(-0.00010915),
  DSP16_Q(0.00004609),
  DSP16_Q(-0.00001116),
  DSP16_Q(0.00000001),
  DSP16_Q(0.00000912),
  DSP16_Q(-0.00004012),
  DSP16_Q(0.00009706),
  DSP16_Q(-0.00018442),
  DSP16_Q(0.00030753),
  DSP16_Q(-0.00047318),
  DSP16_Q(0.00069079),
  DSP16_Q(-0.00097461),
  DSP16_Q(0.00134812),
  DSP16_Q(-0.00185371),
  DSP16_Q(0.00257672),
  DSP16_Q(-0.00371708),
  DSP16_Q(0.00587243),
  DSP16_Q(-0.01196937),
  DSP16_Q(0.40769576),
  DSP16_Q(0.01274250),
  DSP16_Q(-0.00607152),
  DSP16_Q(0.00380956),
  DSP16_Q(-0.00263145),
  DSP16_Q(0.00189050),
  DSP16_Q(-0.00137470),
  DSP16_Q(0.00099459),
  DSP16_Q(-0.00070608),
  DSP16_Q(0.00048489),
  DSP16_Q(-0.00031637),
  DSP16_Q(0.00019087),
  DSP16_Q(-0.00010148),
  DSP16_Q(0.00004282),
  DSP16_Q(-0.00001035),
  DSP16_Q(0.00000001),
  DSP16_Q(0.00000848),
  DSP16_Q(-0.00003725),
  DSP16_Q(0.00009004),
  DSP16_Q(-0.00017102),
  DSP16_Q(0.00028511),
  DSP16_Q(-0.00043862),
  DSP16_Q(0.00064028),
  DSP16_Q(-0.00090329),
  DSP16_Q(0.00124944),
  DSP16_Q(-0.00171803),
  DSP16_Q(0.00238823),
  DSP16_Q(-0.00344561),
  DSP16_Q(0.00544527),
  DSP16_Q(-0.01111020),
  DSP16_Q(0.40778608),
  DSP16_Q(0.01177309),
  DSP16_Q(-0.00561599),
  DSP16_Q(0.00352492),
  DSP16_Q(-0.00243516),
  DSP16_Q(0.00174957),
  DSP16_Q(-0.00127223),
  DSP16_Q(0.00092043),
  DSP16_Q(-0.00065339),
  DSP16_Q(0.00044867),
  DSP16_Q(-0.00029269),
  DSP16_Q(0.00017655),
  DSP16_Q(-0.00009383),
  DSP16_Q(0.00003956),
  DSP16_Q(-0.00000954),
  DSP16_Q(0.00000001),
  DSP16_Q(0.00000784),
  DSP16_Q(-0.00003436),
  DSP16_Q(0.00008299),
  DSP16_Q(-0.00015757),
  DSP16_Q(0.00026263),
  DSP16_Q(-0.00040398),
  DSP16_Q(0.00058966),
  DSP16_Q(-0.00083183),
  DSP16_Q(0.00115055),
  DSP16_Q(-0.00158206),
  DSP16_Q(0.00219933),
  DSP16_Q(-0.00317348),
  DSP16_Q(0.00501679),
  DSP16_Q(-0.01024658),
  DSP16_Q(0.40786945),
  DSP16_Q(0.01080770),
  DSP16_Q(-0.00516131),
  DSP16_Q(0.00324061),
  DSP16_Q(-0.00223905),
  DSP16_Q(0.00160876),
  DSP16_Q(-0.00116984),
  DSP16_Q(0.00084633),
  DSP16_Q(-0.00060076),
  DSP16_Q(0.00041249),
  DSP16_Q(-0.00026905),
  DSP16_Q(0.00016225),
  DSP16_Q(-0.00008620),
  DSP16_Q(0.00003632),
  DSP16_Q(-0.00000874),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000720),
  DSP16_Q(-0.00003146),
  DSP16_Q(0.00007592),
  DSP16_Q(-0.00014408),
  DSP16_Q(0.00024009),
  DSP16_Q(-0.00036926),
  DSP16_Q(0.00053892),
  DSP16_Q(-0.00076021),
  DSP16_Q(0.00105146),
  DSP16_Q(-0.00144581),
  DSP16_Q(0.00201001),
  DSP16_Q(-0.00290069),
  DSP16_Q(0.00458700),
  DSP16_Q(-0.00937852),
  DSP16_Q(0.40794589),
  DSP16_Q(0.00984633),
  DSP16_Q(-0.00470750),
  DSP16_Q(0.00295666),
  DSP16_Q(-0.00204314),
  DSP16_Q(0.00146807),
  DSP16_Q(-0.00106755),
  DSP16_Q(0.00077230),
  DSP16_Q(-0.00054818),
  DSP16_Q(0.00037635),
  DSP16_Q(-0.00024544),
  DSP16_Q(0.00014798),
  DSP16_Q(-0.00007859),
  DSP16_Q(0.00003309),
  DSP16_Q(-0.00000794),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000654),
  DSP16_Q(-0.00002853),
  DSP16_Q(0.00006881),
  DSP16_Q(-0.00013055),
  DSP16_Q(0.00021749),
  DSP16_Q(-0.00033445),
  DSP16_Q(0.00048807),
  DSP16_Q(-0.00068844),
  DSP16_Q(0.00095217),
  DSP16_Q(-0.00130928),
  DSP16_Q(0.00182030),
  DSP16_Q(-0.00262725),
  DSP16_Q(0.00415593),
  DSP16_Q(-0.00850604),
  DSP16_Q(0.40801539),
  DSP16_Q(0.00888901),
  DSP16_Q(-0.00425458),
  DSP16_Q(0.00267308),
  DSP16_Q(-0.00184743),
  DSP16_Q(0.00132751),
  DSP16_Q(-0.00096534),
  DSP16_Q(0.00069834),
  DSP16_Q(-0.00049565),
  DSP16_Q(0.00034026),
  DSP16_Q(-0.00022187),
  DSP16_Q(0.00013374),
  DSP16_Q(-0.00007100),
  DSP16_Q(0.00002987),
  DSP16_Q(-0.00000715),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000588),
  DSP16_Q(-0.00002560),
  DSP16_Q(0.00006168),
  DSP16_Q(-0.00011697),
  DSP16_Q(0.00019483),
  DSP16_Q(-0.00029956),
  DSP16_Q(0.00043712),
  DSP16_Q(-0.00061653),
  DSP16_Q(0.00085269),
  DSP16_Q(-0.00117249),
  DSP16_Q(0.00163021),
  DSP16_Q(-0.00235319),
  DSP16_Q(0.00372358),
  DSP16_Q(-0.00762915),
  DSP16_Q(0.40807795),
  DSP16_Q(0.00793575),
  DSP16_Q(-0.00380257),
  DSP16_Q(0.00238988),
  DSP16_Q(-0.00165192),
  DSP16_Q(0.00118709),
  DSP16_Q(-0.00086323),
  DSP16_Q(0.00062446),
  DSP16_Q(-0.00044319),
  DSP16_Q(0.00030421),
  DSP16_Q(-0.00019834),
  DSP16_Q(0.00011953),
  DSP16_Q(-0.00006344),
  DSP16_Q(0.00002667),
  DSP16_Q(-0.00000637),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000522),
  DSP16_Q(-0.00002264),
  DSP16_Q(0.00005452),
  DSP16_Q(-0.00010336),
  DSP16_Q(0.00017212),
  DSP16_Q(-0.00026460),
  DSP16_Q(0.00038606),
  DSP16_Q(-0.00054448),
  DSP16_Q(0.00075302),
  DSP16_Q(-0.00103545),
  DSP16_Q(0.00143973),
  DSP16_Q(-0.00207851),
  DSP16_Q(0.00328999),
  DSP16_Q(-0.00674787),
  DSP16_Q(0.40813356),
  DSP16_Q(0.00698659),
  DSP16_Q(-0.00335149),
  DSP16_Q(0.00210708),
  DSP16_Q(-0.00145664),
  DSP16_Q(0.00104681),
  DSP16_Q(-0.00076123),
  DSP16_Q(0.00055065),
  DSP16_Q(-0.00039078),
  DSP16_Q(0.00026822),
  DSP16_Q(-0.00017485),
  DSP16_Q(0.00010535),
  DSP16_Q(-0.00005589),
  DSP16_Q(0.00002348),
  DSP16_Q(-0.00000560),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000454),
  DSP16_Q(-0.00001967),
  DSP16_Q(0.00004734),
  DSP16_Q(-0.00008970),
  DSP16_Q(0.00014934),
  DSP16_Q(-0.00022955),
  DSP16_Q(0.00033490),
  DSP16_Q(-0.00047229),
  DSP16_Q(0.00065316),
  DSP16_Q(-0.00089815),
  DSP16_Q(0.00124888),
  DSP16_Q(-0.00180322),
  DSP16_Q(0.00285516),
  DSP16_Q(-0.00586221),
  DSP16_Q(0.40818222),
  DSP16_Q(0.00604152),
  DSP16_Q(-0.00290136),
  DSP16_Q(0.00182469),
  DSP16_Q(-0.00126159),
  DSP16_Q(0.00090668),
  DSP16_Q(-0.00065933),
  DSP16_Q(0.00047693),
  DSP16_Q(-0.00033845),
  DSP16_Q(0.00023227),
  DSP16_Q(-0.00015139),
  DSP16_Q(0.00009120),
  DSP16_Q(-0.00004836),
  DSP16_Q(0.00002030),
  DSP16_Q(-0.00000483),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000386),
  DSP16_Q(-0.00001669),
  DSP16_Q(0.00004012),
  DSP16_Q(-0.00007600),
  DSP16_Q(0.00012651),
  DSP16_Q(-0.00019443),
  DSP16_Q(0.00028363),
  DSP16_Q(-0.00039997),
  DSP16_Q(0.00055313),
  DSP16_Q(-0.00076060),
  DSP16_Q(0.00105768),
  DSP16_Q(-0.00152734),
  DSP16_Q(0.00241912),
  DSP16_Q(-0.00497220),
  DSP16_Q(0.40822393),
  DSP16_Q(0.00510059),
  DSP16_Q(-0.00245220),
  DSP16_Q(0.00154271),
  DSP16_Q(-0.00106677),
  DSP16_Q(0.00076671),
  DSP16_Q(-0.00055755),
  DSP16_Q(0.00040330),
  DSP16_Q(-0.00028617),
  DSP16_Q(0.00019638),
  DSP16_Q(-0.00012798),
  DSP16_Q(0.00007708),
  DSP16_Q(-0.00004086),
  DSP16_Q(0.00001714),
  DSP16_Q(-0.00000407),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000318),
  DSP16_Q(-0.00001369),
  DSP16_Q(0.00003289),
  DSP16_Q(-0.00006227),
  DSP16_Q(0.00010363),
  DSP16_Q(-0.00015924),
  DSP16_Q(0.00023227),
  DSP16_Q(-0.00032753),
  DSP16_Q(0.00045293),
  DSP16_Q(-0.00062282),
  DSP16_Q(0.00086612),
  DSP16_Q(-0.00125089),
  DSP16_Q(0.00198188),
  DSP16_Q(-0.00407784),
  DSP16_Q(0.40825869),
  DSP16_Q(0.00416379),
  DSP16_Q(-0.00200403),
  DSP16_Q(0.00126117),
  DSP16_Q(-0.00087221),
  DSP16_Q(0.00062691),
  DSP16_Q(-0.00045589),
  DSP16_Q(0.00032975),
  DSP16_Q(-0.00023397),
  DSP16_Q(0.00016054),
  DSP16_Q(-0.00010461),
  DSP16_Q(0.00006299),
  DSP16_Q(-0.00003338),
  DSP16_Q(0.00001399),
  DSP16_Q(-0.00000331),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000248),
  DSP16_Q(-0.00001067),
  DSP16_Q(0.00002562),
  DSP16_Q(-0.00004850),
  DSP16_Q(0.00008069),
  DSP16_Q(-0.00012397),
  DSP16_Q(0.00018081),
  DSP16_Q(-0.00025495),
  DSP16_Q(0.00035256),
  DSP16_Q(-0.00048480),
  DSP16_Q(0.00067422),
  DSP16_Q(-0.00097386),
  DSP16_Q(0.00154347),
  DSP16_Q(-0.00317917),
  DSP16_Q(0.40828650),
  DSP16_Q(0.00323116),
  DSP16_Q(-0.00155686),
  DSP16_Q(0.00098009),
  DSP16_Q(-0.00067790),
  DSP16_Q(0.00048727),
  DSP16_Q(-0.00035435),
  DSP16_Q(0.00025630),
  DSP16_Q(-0.00018184),
  DSP16_Q(0.00012476),
  DSP16_Q(-0.00008128),
  DSP16_Q(0.00004893),
  DSP16_Q(-0.00002592),
  DSP16_Q(0.00001086),
  DSP16_Q(-0.00000257),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000178),
  DSP16_Q(-0.00000764),
  DSP16_Q(0.00001833),
  DSP16_Q(-0.00003469),
  DSP16_Q(0.00005770),
  DSP16_Q(-0.00008864),
  DSP16_Q(0.00012926),
  DSP16_Q(-0.00018225),
  DSP16_Q(0.00025202),
  DSP16_Q(-0.00034655),
  DSP16_Q(0.00048198),
  DSP16_Q(-0.00069628),
  DSP16_Q(0.00110389),
  DSP16_Q(-0.00227618),
  DSP16_Q(0.40830736),
  DSP16_Q(0.00230271),
  DSP16_Q(-0.00111073),
  DSP16_Q(0.00069946),
  DSP16_Q(-0.00048386),
  DSP16_Q(0.00034782),
  DSP16_Q(-0.00025293),
  DSP16_Q(0.00018294),
  DSP16_Q(-0.00012979),
  DSP16_Q(0.00008904),
  DSP16_Q(-0.00005800),
  DSP16_Q(0.00003491),
  DSP16_Q(-0.00001848),
  DSP16_Q(0.00000774),
  DSP16_Q(-0.00000182),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000107),
  DSP16_Q(-0.00000460),
  DSP16_Q(0.00001102),
  DSP16_Q(-0.00002084),
  DSP16_Q(0.00003466),
  DSP16_Q(-0.00005323),
  DSP16_Q(0.00007762),
  DSP16_Q(-0.00010944),
  DSP16_Q(0.00015133),
  DSP16_Q(-0.00020809),
  DSP16_Q(0.00028942),
  DSP16_Q(-0.00041816),
  DSP16_Q(0.00066317),
  DSP16_Q(-0.00136891),
  DSP16_Q(0.40832127),
  DSP16_Q(0.00137846),
  DSP16_Q(-0.00066563),
  DSP16_Q(0.00041931),
  DSP16_Q(-0.00029010),
  DSP16_Q(0.00020855),
  DSP16_Q(-0.00015166),
  DSP16_Q(0.00010969),
  DSP16_Q(-0.00007781),
  DSP16_Q(0.00005338),
  DSP16_Q(-0.00003477),
  DSP16_Q(0.00002092),
  DSP16_Q(-0.00001107),
  DSP16_Q(0.00000463),
  DSP16_Q(-0.00000109),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00000036),
  DSP16_Q(-0.00000154),
  DSP16_Q(0.00000368),
  DSP16_Q(-0.00000696),
  DSP16_Q(0.00001156),
  DSP16_Q(-0.00001776),
  DSP16_Q(0.00002590),
  DSP16_Q(-0.00003651),
  DSP16_Q(0.00005048),
  DSP16_Q(-0.00006942),
  DSP16_Q(0.00009655),
  DSP16_Q(-0.00013952),
  DSP16_Q(0.00022133),
  DSP16_Q(-0.00045737),
  DSP16_Q(0.40832822),
  DSP16_Q(0.00045843),
  DSP16_Q(-0.00022161),
  DSP16_Q(0.00013964),
  DSP16_Q(-0.00009663),
  DSP16_Q(0.00006947),
  DSP16_Q(-0.00005052),
  DSP16_Q(0.00003654),
  DSP16_Q(-0.00002592),
  DSP16_Q(0.00001778),
  DSP16_Q(-0.00001158),
  DSP16_Q(0.00000696),
  DSP16_Q(-0.00000368),
  DSP16_Q(0.00000154),
  DSP16_Q(-0.00000036),
  DSP16_Q(0.00000000)
};
